(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    740089,      15572]
NotebookOptionsPosition[    716583,      14777]
NotebookOutlinePosition[    717099,      14798]
CellTagsIndexPosition[    717056,      14795]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Analysis of the sweet spot for the coil- T1000164-v4draft", "Title",
 CellChangeTimes->{{3.662846845378744*^9, 3.662846854708425*^9}}],

Cell[CellGroupData[{

Cell["Instructions", "Section"],

Cell["\<\
1. Make sure that the notebook of utility functions for magnetic dipoles, \
MagDipole.nb, and the associated autosave file, MagDipole.m, are in the same \
directory as this notebook.
2. Do likewise for NewCoilTheory.nb and NewCoilTheory.m.
3. Edit the path setting statement in the Preliminaries section below to make \
it add this directory to the path. The directory name has to be specified in \
the correct format and the correct branch of the Switch[] statement for your \
system. Check the value of $System and add new branches if necessary.
4. Evaluate the Preliminaries section.
5. Evaluate the rest of the notebook and/or hack around to your heart's \
content.\
\>", "Text",
 CellChangeTimes->{{3.662606486924474*^9, 3.6626064944261007`*^9}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"useprecomputed", " ", "=", " ", "True"}], ";", " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "whether", " ", "to", " ", "use", " ", "archived", " ", "values", " ", 
     "for", " ", "certain", " ", "time"}], "-", 
    RowBox[{"consuming", " ", "calculations"}]}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.480244231326439*^9, 3.48024423792516*^9}, {
  3.480703939177309*^9, 3.48070394080156*^9}, {3.481941928523884*^9, 
  3.481941957601687*^9}, {3.662606252913006*^9, 3.66260627414581*^9}, {
  3.662606542247143*^9, 3.662606543728855*^9}, {3.6628468634118023`*^9, 
  3.662846863916623*^9}}],

Cell[CellGroupData[{

Cell["Preliminaries", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Dependencies", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
The path in which the model definition and model-specific support files are \
installed. 
**** EDIT THE PATHS AND/OR ADD CLAUSES FOR NEW SYSTEMS AS APPROPRIATE ****\
\>", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Switch", "[", "\[IndentingNewLine]", "\t", 
   RowBox[{
   "$System", ",", "\[IndentingNewLine]", "\t", 
    "\"\<Mac OS X x86 (64-bit)\>\"", ",", 
    RowBox[{"$Path", " ", "=", " ", 
     RowBox[{"Append", "[", 
      RowBox[{
      "$Path", ",", 
       "\"\</Users/mbarton/Work/LIGO/writeups/Sweet Spot Measurement \
(T1000164)/sweetspotcalcnew\>\""}], "]"}]}], ",", "\[IndentingNewLine]", 
    "\t", "\"\<Microsoft Windows\>\"", ",", 
    RowBox[{"$Path", " ", "=", " ", 
     RowBox[{"Append", "[", 
      RowBox[{"$Path", ",", "\"\<c:\\\\EDIT ME\>\""}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.453747804876116*^9, 3.4537478086805983`*^9}, {
   3.662606320813328*^9, 3.662606344907859*^9}, {3.662606620105997*^9, 
   3.662606660892832*^9}, 3.662606796394608*^9}]
}, Open  ]]
}, Open  ]],

Cell["<<\"MagDipole.m\"", "Input"],

Cell["<<\"NewCoilTheory.m\"", "Input",
 CellChangeTimes->{3.631828660846888*^9}],

Cell[CellGroupData[{

Cell["Disable spell-checking", "Subsection"],

Cell[BoxData[
 RowBox[{"Off", "[", 
  RowBox[{
   RowBox[{"General", "::", "spell"}], ",", 
   RowBox[{"General", "::", "spell1"}]}], "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functions for manipulating lists of substitutions", "Subsection"],

Cell[CellGroupData[{

Cell["Replace a single substitution", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Override", "[", 
   RowBox[{"oldsubs_", ",", "newsubs_"}], "]"}], " ", ":=", " ", 
  RowBox[{"oldsubs", "/.", 
   RowBox[{"(", 
    RowBox[{"newsubs", "/.", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"param_", "\[Rule]", "newval_"}], ")"}], "\[RuleDelayed]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"param", "\[Rule]", "oldval_"}], ")"}], "\[RuleDelayed]", 
        RowBox[{"(", 
         RowBox[{"param", "\[Rule]", "newval"}], ")"}]}], ")"}]}]}], 
    ")"}]}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
A function to reduce a substitution list to fully numerical form by applying \
it repeatedly to itself:\
\>", "Subsubsection",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Recurse[sublist_List] := 
\tsublist//.(x_->y_):>(x->(y/.sublist))\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["A function to scale a substitution list:", "Subsubsection",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
scale[sublist_List, factor_] := 
\tsublist/.(x_->y_):>(x->factor*y)\
\>", "Input",
 CellChangeTimes->{3.453749631833597*^9},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Derive the axial and radial components of B", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
Baxial = Simplify[
\tTogether[
\t\tdipoleB[[3]]
\t\t/.dx->0
\t\t/.dy->0
\t\t/.dz->0
\t\t/.Xx->r
\t\t/.Yy->0
\t\t/.Zz->z
\t]
]
\
\>", "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"mu0", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "m1z"}], " ", 
      SuperscriptBox["r", "2"]}], "+", 
     RowBox[{"3", " ", "m1x", " ", "r", " ", "z"}], "+", 
     RowBox[{"2", " ", "m1z", " ", 
      SuperscriptBox["z", "2"]}]}], ")"}]}], 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["r", "2"], "+", 
      SuperscriptBox["z", "2"]}], ")"}], 
    RowBox[{"5", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{
  3.453747965547722*^9, 3.453749599994955*^9, 3.4638444535242777`*^9, {
   3.478894405842181*^9, 3.478894421027747*^9}, 3.478960340825461*^9, 
   3.479485741071822*^9, 3.479486052836144*^9, 3.4796583821237583`*^9, 
   3.480082564582583*^9, 3.4802436759582167`*^9, 3.4806922469034033`*^9, 
   3.481566005895687*^9, {3.4819409141959743`*^9, 3.48194093732237*^9}, 
   3.48194192328915*^9, 3.662606573885989*^9, {3.662606989900323*^9, 
   3.662607015810851*^9}, 3.662607108876596*^9, 3.6626240600072823`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Baxial", "/.", 
  RowBox[{"r", "\[Rule]", "0"}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"m1z", " ", "mu0"}], 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["z", "2"], ")"}], 
    RowBox[{"3", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{
  3.4537479655831127`*^9, 3.453749600034116*^9, 3.4638444538148317`*^9, {
   3.478894405888887*^9, 3.478894421080052*^9}, 3.47896034086206*^9, 
   3.4794857411376143`*^9, 3.4794860528885927`*^9, 3.479658382192664*^9, 
   3.480082564654179*^9, 3.480243676115644*^9, 3.480692246945731*^9, 
   3.4815660059479713`*^9, {3.4819409142460823`*^9, 3.4819409373890877`*^9}, 
   3.4819419233788652`*^9, 3.6626065739127083`*^9, {3.662606990014765*^9, 
   3.662607015954369*^9}, 3.662607108934417*^9, 3.662624060038443*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Btransverse = Simplify[
\tTogether[
\t\tdipoleB[[1]]
\t\t/.dx->0
\t\t/.dy->0
\t\t/.dz->0
\t\t/.Xx->r
\t\t/.Yy->0
\t\t/.Zz->z
\t]
]\
\>", "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"mu0", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "m1x", " ", 
      SuperscriptBox["r", "2"]}], "+", 
     RowBox[{"3", " ", "m1z", " ", "r", " ", "z"}], "-", 
     RowBox[{"m1x", " ", 
      SuperscriptBox["z", "2"]}]}], ")"}]}], 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["r", "2"], "+", 
      SuperscriptBox["z", "2"]}], ")"}], 
    RowBox[{"5", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{
  3.453747965615678*^9, 3.453749600077715*^9, 3.463844455487849*^9, {
   3.478894405942997*^9, 3.4788944211302834`*^9}, 3.478960340942863*^9, 
   3.479485741189885*^9, 3.4794860529295588`*^9, 3.4796583822416077`*^9, 
   3.480082564700638*^9, 3.48024367617673*^9, 3.480692246987156*^9, 
   3.481566005979335*^9, {3.481940914277701*^9, 3.481940937448995*^9}, 
   3.481941923414253*^9, 3.662606573961648*^9, {3.662606990066422*^9, 
   3.662607015998637*^9}, 3.662607108999185*^9, 3.662624060105956*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
force[Zz_] = Simplify[-mz \
D[dipoleBz,Zz]/.dx->0/.dy->0/.dz->0/.Xx->0/.Yy->0]/.powerfix\
\>", "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"3", " ", "m1z", " ", "mu0", " ", "mz"}], 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SuperscriptBox["Zz", "4"]}]]], "Output",
 CellChangeTimes->{
  3.453747965823358*^9, 3.4537496001121492`*^9, 3.46384446080796*^9, {
   3.4788944059930553`*^9, 3.478894421180645*^9}, 3.47896034097888*^9, 
   3.4794857412398157`*^9, 3.479486052963105*^9, 3.479658382309431*^9, 
   3.4800825649222116`*^9, 3.480243676306188*^9, 3.48069224701851*^9, 
   3.4815660060302887`*^9, {3.481940914334242*^9, 3.481940937496923*^9}, 
   3.481941923466711*^9, 3.662606574022719*^9, {3.6626069901552343`*^9, 
   3.662607016065351*^9}, 3.662607109064283*^9, 3.662624060172635*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"force", "[", "1", "]"}], "/.", 
     RowBox[{"mz", "\[Rule]", "1."}]}], "/.", 
    RowBox[{"m1z", "\[Rule]", "1."}]}], "/.", 
   RowBox[{"Zz", "\[Rule]", "1."}]}], "/.", 
  RowBox[{"mu0", "\[Rule]", "1", " ", 
   RowBox[{"(*", 
    RowBox[{"4", " ", "Pi", " ", 
     RowBox[{"10", "^", 
      RowBox[{"-", "7"}]}]}], "*)"}]}]}]], "Input"],

Cell[BoxData["0.477464829275686`"], "Output",
 CellChangeTimes->{
  3.4537479659442177`*^9, 3.4537496001816998`*^9, 3.463844461260048*^9, {
   3.478894406093301*^9, 3.4788944212800493`*^9}, 3.478960341011427*^9, 
   3.4794857412898493`*^9, 3.47948605300837*^9, 3.4796583823753366`*^9, 
   3.4800825649736032`*^9, 3.480243676359799*^9, 3.480692247054192*^9, 
   3.4815660060631313`*^9, {3.481940914365226*^9, 3.481940937547433*^9}, 
   3.4819419235105124`*^9, 3.6626065740757732`*^9, {3.662606990213984*^9, 
   3.662607016116412*^9}, 3.6626071091101513`*^9, 3.662624060236904*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Basic constants", "Subsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
basicvals = Recurse[{
\tkB->1.38 10^-23,
\tT->295,
\tg->9.8,
\tmu0->4 N[Pi] 10^-7,
\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\tmassM->rhomM l N[Pi] a^2,
\tBresid->1.25,\t\t\t\t(* Residual field *)
\tPi->N[Pi],
\tl->0.003175,\t\t\t\t(* Length of magnets *)
\ta->0.0009525,\t\t\t\t(* Radius of magnets *)
\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\tmasspullapart->0.060\t\t(* Force (in kgf) to separate magnets *)
}];\
\>", "Input",
 AspectRatioFixed->True],

Cell["\<\
SOSvals = Recurse[{
\tdpend->0.248,\t(* SOS final design *)
\troptic->0.0762/2,\t(* SOS final design *)
\tdyaw->0.0157,\t(* SOS final design *)
\tmassoptic->0.25,
\tw0->2 N[Pi] 1.0
}];\
\>", "Input"],

Cell["\<\
LOSvals = Recurse[{
\tw0->2 N[Pi] 0.743,
\trwire->0.0031/2,
\tawire->N[Pi] rwire^2,
\tdpend->0.450,\t(* LOS final design *)
\tdyaw->0.0333,\t(* LOS final design *)
\tmassoptic->10.7,
\tloptic->0.1,
\troptic->0.125,
\tIoptic->0.25 massoptic*roptic^2 + (1/12) massoptic loptic^2,
\twpitch->2 N[Pi] 0.6,
\twpend->2 N[Pi] 0.744,
\twyaw->2 N[Pi] 0.5,
\tkpitch->wpitch^2 Ioptic, (* Angular restoring force *)
\tkyaw->wyaw^2 Ioptic, (* Angular restoring force *)\t
\tpitchlever->0.0808,\t(* lever arm, pitch direction, per magnet *)
\tyawlever->0.0808,\t(* lever arm, pitch direction, per magnet *)
\tkxpitch->kpitch/pitchlever
}];\
\>", "Input",
 CellChangeTimes->{3.478894781983313*^9}]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["New coil calc for bigmagnetvals", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}}],

Cell[CellGroupData[{

Cell["\<\
bigmagnetvals = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.010,\t\t\t\t(* length of big magnets *)
\t\ta->0.005,\t\t\t\t(* radius of big magnets *)
\t\t(* coil length *)
\t\tcoillen->0.16*0.0254,
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.35*0.0254,
\t\tcoilrad2->0.55*0.0254,
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453837228357688*^9, 3.453837230833909*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.005811946409141117`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.007999999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.01`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.005`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.004064`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.002032`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.002032`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.008889999999999999`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.01397`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.9375038750077497`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.463844663941598*^9, 3.479667628840351*^9, 
  3.480245057580022*^9, 3.48069224815385*^9, 3.4815660167539787`*^9, 
  3.481941596985648*^9, 3.481941924708386*^9, 3.662623278532525*^9, 
  3.66262406040844*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "BM", "]"}], " ", ":=", " ", "bigmagnetvals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1.084332204665714`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.006361536563952735`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"fz", "[", 
          RowBox[{"BM", ",", "z"}], "]"}]}], ",", " ", 
        RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.479667008672338*^9, 3.4796670332310963`*^9}, {
   3.479667207329587*^9, 3.479667207950783*^9}, {3.4802442654999228`*^9, 
   3.480244302808629*^9}, 3.6626232869812593`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.0843322046661032`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.006361540102283618`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6626243337155247`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nc8VW8cB3A/DaIQmSmlKFERFcKHiiT8yMgooSFCGZd7z71klboaGsqI
X9KQJKshCWmIkorscK2snBsqKv2e/jqv9+s557zO8z3Pdyz2PLR9n6CAgMC0
fwQE/l5LJDtO2Wz4atjduzUhyzLIaE/YsZJdRbVGBrZRU4qFtsjw6DHTK+ow
KnLU6Bwv8EDFhwuiy4poo+zmqJiOggB8ODk0vKBIAMPFumk1BZFw9ZbbLV8k
ATXmgurMgrP4b0eOrGzRItyUVNqtXJCOcuuJUekiTRT57RmTyMvDQ5eOncp+
JviW5krz9z2FeI3QdX7XVjS4PvqijmpUMGuGlORsIUhrXFTrf4f896wYq0QH
3B0Z647gfMSV2S/FLlU7QyknzrQ3qxnlYgyZPic3TN8QEnFvXjtYYxoW7AMe
0PXZuXXoaifO2h4WnBu+BzSrnGqO6UKF5N6JW2X7MJ+uHopg9mC8IrO/ttUL
+dWT3wS0+7C6UzhhxxdvxBoNflv5+jOiPOWPdGr4orRqcI+FzwDqP1CeE5v9
kccPjn1UM4gr9mYbRUwP41DvYt6RVcNwGW/N3eIZAOrSVdV1e75gnpiioqVv
ILJXGupbeowAB810ag4HwmjloIvtvhH4VB62tGEEIv+QsJC99wjKop5z7MMD
8WFbj8D2gBH4ffdv2xkfiJNySSGakSN40VGe5lcYiGLBD2ahV0bALPBafOZX
IJJuWVDqbSNocSpQfX8yCEv/aDedX0ajd0eti9DZIKwX73BZoUbjq+PwaYOE
IKRV3XlZuoKGsMOy7zdSgxDrmuTZt5KGjm3KS3ZOENouL09V06Fxcmv0AZXa
IJjochZTxjSM9O2ymFLBkFZbaLfNicbV+aMrlZKD8fZpt3FODA0G+9SBnLRg
XNEKTZ9/jIZ5y7IMw4xgcBnzSmJjaYwk75TbmR2MphdnVHZyaRgovBBMehKM
99sDHo+fodEgl9Qg2RWMVg0PkaFkGrNlEDlTg4Ed+xHSc5dGO6OpOEGTgTMK
EZYr8mjk1wd9W7qWgf0jZu1++TScEzIPbjJioH/0hj6/kMaNeZKOETYMLCsM
rfpcRMNYqmfFZDADKi1lu1IqyPdKxNUNlzDwtm1nk9hHGotuptR4PWXghXuy
rmoDjdeG2ZWdLxjIX+PjadBIQ/ngm8f1bxlIDVSU2ddMo/a5+PWSTgb0WCYC
mZ9oqLMvME7NCMHX5Oix0V4anT2pMiutQmA06SJ+/RuJJydH4qZtCC67vaIT
vtPQlSoVWewYAn7dn/+O/qBx2rhjat7uEMhn2h3wmCTxSVHu+3U4BGtUOjNE
pmhcsrn54PWFEJgaJHcumcGHVXGuk29rCJQUzFwDJfloHC3wT+oIAetcYPpq
KT72ajyIedEdgsbQhx2DxFRqSe6i4RAUOQtt85DmI/NIlXD97xD4Ff14Bzk+
BDd3PzRUCoV6HL+iegEfD1/Lyot7hmLkWoDsouV8bJ4xf7XB/lA8EDAveUz8
1nChqbdPKA5c0Hd3UuOjN2dpQEVgKAKpf9JOruBD6qzWq9DoUFx60fzrswYf
/g7bWB3XQmG5eZpXgBYfSz+FN+X1haLokuuXcj0+mKF/xnWHQtH2PXDEXJ+P
aokIyTI6FBrqt5/XEAduitxWMxGKgEuWXz9u4KMsM7pkQJSJ5xu6bJsM+dgV
dDx9iSYTObN37bhhwkfu7FlPsnSY6La4+lRhIx/Tb5xo1tJjomByy8zTxNmN
XCnjjUxMD+DKBmziY9Lw1NGd9kz0LmnxUjPl46LwOe8EJhMfsy+PeJrzMZAu
eUwxjAnHYebkM2LDDeevZkQysUh6eafKVj66/S605HGZ0Apo39hNvObDRaua
y0ys2zG+y24biVdqipZQOROZN5xVflrxobxe0fr0cyZY512Et1nzEVJ72Ue6
iol3915WJREvnJaWseQDE6YhAiPa//Lhe+CKtHEPE6kDBsUuNnwIa1+fYM5i
4ckLTmLgdj4M/OXWFMxhQS6mnJ1NfOhWnM/wXBaebX67v4f4o1Jgi4cCC2++
z3Wwt+Pj2myUWKizMF5nlKhqT87PlvzxmNUsKNl4lToRi0arrCrVZuHTlbGR
E8SBE6L/aRuwEKcr5t9PbNLbGKFoxUJL30TXZQc+ghdbFjnasqD/XHDnS+LM
naX8eAcWpD5KtdPEEh+ue85wY2HT+uVCJo58fCoN3PzFn6xLDHfXE0v+7OEs
D2JBM02m+Aex6Trne56hLBgrfEtV2EH+VzZUG46wEH3nLteVmEqaLVwWz8Lk
xNSM98Q5dUeMJy+w0PClesswcaf4KFMniYVZT6clCjnxYX6sqT8znby/M36v
HjGn3FK56zoLykP2nTbEd3+VuizIYkHDzsPPi1gm6Eb12XwWMueuKTxLbJEj
P/31fRZMVfcfuk4c1n/SYGYxC+Zzn+o/JO7eHXSHqmBh/qq3gi3Ecim9PYUv
WUheMfZngNjyo/PCkWpyv7+y2CRxgaXxmT115H3px3ZJO5P8iS14mdrIgh1D
5cpiYoUKVYHGVrLfr7ljGsTWU0m6kp0scI08XdcTR+nNCbDsYYGRGlhnTHw/
OOLWsX4WcgLmu28l7r872lk2zMK/G85P2RArDu5X+MlnwT1VPncHsY1q8/a1
31gQtesJ3kUc42EVd2iShar1mlaexA8ul1XcmiLfb6qjt594oEH7V5cghaAL
6nrexAulbuosFKIw4GxjdZB4u7WCn5Mohav9rQxf4qMnTl0/J07hfKFowV8/
fCbw6bUUhXSO9Iy/HvoTJCMkR6HiuK6vD/GPgF1iGooU6ifOffcintZtNtN2
EQUO52L6XmIxR80pxlIKZjUcH/e/8amU/5a8nMLv/gXbXYlV9ad9KdWg4Gfu
6+xAvCZ7qKdbk0JAuVmENbHRwo9ts9ZSuH2I98KMeGt8af0qPQqXg0JXGhHb
C956Y2dIIV7YqFCH2D343HOmCYWhaH/XFcS+veySVFMKrg4mS5SImU777j3d
SkFKaERU6m/8qqzv9FlRWOB+R3om8RkD3euzt5P9/35s/IP87xuLRBMcXSiM
aF/52UScf27sJNuNwrSRvrhXxCXTP8Vc8STP9+82+nue6j7nBg/4UHDKey5y
nrjDJdlX/BCFagtVlSPEQ6+j9+oEUVA8cdXTh3hanqN9OJuC6JkHW4yIxZYY
W2YcoXD/yasRVWKFBLXNldEURr80FosRr2H90pY8SfZb9aGsheSLu8lVqRuX
Kejr3I45SOxbECdafYWCUss0OyviUBXGNPoaBdVIjS2riE/PMh/Vu0PhnFxT
+jDJ15J3w+/flFCoXTN3mSdx5aaGqq/lFBamBa0wJK67V/ZU9gWFdol6fVni
oaTz+R41FI6X3RN+ReqDgqfeufFPFLSXXucqE6vWKXMVusj+qivffSP1Rsts
dhT6KIgkB26sIjZf0R5wYoRC373/iv2JQ7/G2C4QYONusUzIHVLf6qJqJUwX
s2GloyQ1jdS/TIf14s9U2NDj/Vz13Jbk//K0OZtWsPFkDX/7MeIlNQdFTLTZ
UC91L5xBHCgvNN3QlA2qrLfnB6m/c3MNv+t4s7HEzHNrHqnf3VHXxgv82Pgn
aER0L/FDB9GxNYFs5DiebpEmdv/ZSGuy2bjluikjxJL0I7PgAY1TbNRn7m7T
IP3Aui2rbWkeGwmjzpt8ST9Rzp3bmnGPDb/qH7/Eib9FMZuVH7Gh/7SkMn8L
H2nLzRoWVbAxcFswcdyMj+GgzlrFejbuf+IsPEz61UkRuWfzJthY5xQlpUf6
26v1R7Omm3BgUXK2R5H0S072p2frTDnIj3118zbpp5qLddsPbOVgMHYwQ484
UWRQ6o0tWU+R3WZH+vGBNpuwBE8Ojgbd3Bm2no+Z0Yo2qjEcjDpqv8rWJvNA
TcH4lpcc6C/VyqPUSf5unCNBVXPg99VPl0/6f/aD/Suy33KgetZG0OvvPJAu
v1uikYMwvvVuGzIv8IKOVDZ+5kAtrsBUYRkfkfLbUrxFwhCRqiQYp8zHk708
4zirMMzz2rOKR+YTff0iD9ntYVib4i2rQ3xfPD4qwzEMnifOahyVJfX/keGz
4t1haJtR0rpUhsRLImnLUEAY/g2PcXMh80/443+trS6GoemOr27aHFIP5pW4
ireHwX/X2tdx//BRWnEp5PzhcCikLG2Q7KMxr7bbUYQRjuJrn4rXkXnuQKvW
+khWONgSpQPOPTQkxqu/+0eRdSNqeVoXDXdVAZbFhXBMznddubCDhsCJA+x/
HoYjbPN41i8yP2601os49CccclHteWuraDxvbD6x7fQRLEwfyM/OotGzpsty
n2UEJgxnbbD0puEvefRaT2sErL0XCbbI0/i+kk292hOJ32MFPoVnRxC1VBcz
PkeiNYu9Tu3zF0jppH+IDI1CW32BvYfqF1w74tbr8TsKy+bHxFv4DMOg+2Vl
1OlobG7iDfgkDqEu5qiakEwMmg5797FqB+EvIMLqSo6BsGfDpKLIIMQS9BMF
1I/ieWfKZK7WAHL2la6NzDuKmitM3jWvftj/S1/duOkYxDWapx6e+oxfUp+n
XN8fQ1a7tFZFUR+uzdNpatwRi9FK48Tj33pht0oj+uLnWAwYJT7RVe2FYAzz
9oNDx0HdLXLz9upBQWHcU82x43AwG6vQyO2Gz5TFrYHoEyiSkq2eGu7C4hg3
MWERLqpMeDp7DbtgfL+lz202FxNhFwVd9Lvg/tmp/J4YF9mv2Bo267uQZmkX
vEeKC/sy8QRDrS4oSps3P1Hk4qhR3SNFlS7I3NC6wVjNBTm4e4dmd0GkcrpR
lz0XsrGPj71r5UFtMlJWfwcXSiu9R9838WCu8YeOd+aCWltXUveRh9j4iQwj
Ny6at+rZNdXyMN35y6xkLy6ezNm7uu8ZD1P9DfU2FBdslTqXeXd4WKDocPcm
hwuha1GZ87N4MLB+f3wqnIvbJcn2S27ywM5/vSE7mgt1Nc1K7XQeflDl6UKn
uPAdnLnQOYEH2TtGbLczXHi8kHffc46Hde3F9vfOcsG16BHwP8MDY9N9oT0X
uUiMf+0Wc4KHCwztzqJELgbNf86PP8ZD4c3cRxIpXFy8JKx7OZqHD00rL3il
cnHyze/8zAgevore9nvyHxcy6t0n74Xx8D9V9tKE
        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 1.0843321794484708`}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BM", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.479666887455168*^9, 
   3.479666888838862*^9}, {3.479667208457279*^9, 3.479667208895832*^9}, {
   3.48024520498495*^9, 3.4802452202413063`*^9}, 3.662623284294729*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], LineBox[CompressedData["
1:eJwV1nk4VdsbB3CUK1K6IiUKRWUIoSJ8o24IZSihVObIzOGcfTiRqY4GQ0qa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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 0.013}, {0., 1.084332179462006}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.662624366216887*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "BM", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "BM", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.479666890574193*^9, 
   3.479666892310862*^9}, {3.4796672094171343`*^9, 3.4796672098856077`*^9}}],

Cell[BoxData["0.006361540102283618`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.4796669544241667`*^9, 
  3.4796682577475853`*^9, 3.4802452914839983`*^9, 3.480692248270643*^9, 
  3.481566016936092*^9, 3.481941597128859*^9, 3.481941924843739*^9, 
  3.662624366497341*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "BM", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "BM", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.479666893782012*^9, 
   3.479666894910797*^9}, {3.479667219043417*^9, 3.4796672194929113`*^9}}],

Cell[BoxData["1.0843322046661032`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.479666954466415*^9, 
  3.479668257772698*^9, 3.48024529160467*^9, 3.480692248321662*^9, 
  3.481566016972385*^9, 3.481941597184218*^9, 3.481941924879663*^9, 
  3.662624366528409*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"BM", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}}],

Cell[BoxData[
 TagBox[
  TemplateBox[{RowBox[{
      StyleBox[
       TagBox["InterpolatingFunction", "SummaryHead"], 
       "NonInterpretableSummary"], 
      StyleBox["[", "NonInterpretableSummary"], 
      DynamicModuleBox[{Typeset`open$$ = False}, 
       PanelBox[
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{}, {}, {
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVjnsw2wcAx0ONbjpVPaOYZnRnlasSj271+NKxeXVNaa0eK6ERqww1GioI
IUhnbNE5HcM6VfXao7KjZWea0oUOs3jNeSVEKpLfanTa6OyPz33++9znjdjk
EIYuiUTy2OF/r1d3Hsz2X/Mkkcj7jhukeI0X5basP6BA+YWbvu+FVkwkEoTe
3x7g9v8yffdaD4KUPe7lXD9Y6UjuFzQ/gIWOGWXkQjB2yVZCsyaG4PLiUORJ
9WnE35iWV4pHYezgGhnGOouR8QFzT5oUlGFqk61LOOiFoUcbTKeQG5dZGqiM
gq5btEp7ZwYFoZbSQMcYqLxKb2Vw56BoS/ls1DgWFyn6e/U8F8CM1YlhjcRB
PmF79/yjReR9LtqmljCwMXu0VxQgh3ta7P3IeCYcy/eEGo0tYe+PAY1f2X4M
1djwqzyqArwmux+c9RNhVGP4RFG1AuEBe752loXr9VXkdpkS3fPMjMmqJNjn
1bTG6a2iz+nRwFWPFETcptvdO6RCh7W+zNnqElYeipYkFmtgJ3SalBqlYkX5
bz3fUI2ite2bnOepCPQa87CcUaOBvBCQPvUp9jDPC5x8Nfiy3Zt0UJIGF39e
Qq9Qg1Klh3ikOR1hdB9S5YgGUrpEbVF8GfvDJuiNugTUrn8eMWWzUaOXNneY
QsBUxLliHpaB6mhhVIgfAUNh7dTg+5lg10QIGGcJnGo5U2fmegUvUuflfuEE
6i41piWaZIHzLOhpfwiBXmF6VIouB92Ola+E++z06fMhOQscRHbJlIQdgUTW
bJtNTza+W/bysjQg8PMf56wzWnLw3njSvlPTGhgvJ1dLBbk4tvjRHLtZg2qK
jtkTTy4OOrw0LU7RQPTOAWZuGxe/uej3ebtosMnYWpFa5UEo2qplKdSo867a
4Ffkoars3dFzZ9SgEXyBu14+yF6MpKFf15BAo97yz87H905DyfHWa2gcuvmU
vJ6PAgbreRZbBRX54rA2lodN2kalbHwV120eOzlP89Di+/Bag90qPtjqsvgk
qAC7J09qN7iPcVgT6pbaWQDJmJs28C8lWBW3p393LAS1q3T4n7eUEBnRdlPr
CrFtctW7Jm8FCcd+6lk15yMp6LRiclABn5zZxtQyPrzvrL0ptFKA/HWEuVbL
h7grwrcpcxnMeKHJXHoReLvonbqSJXQYWFb0y4twwzL39eP2S0j8MKbWILoY
Ha9x94tz5PAXJ82YSIsR/E2rLWdSBsrLg9/a+JUgcOHtdpcTMlx+tkQIuktQ
fo9qUFa/iIE+2sDmEcHOv8PohNEiiAq35J5aAdaDCUFH9gL+A7Z915E=
                   
                   "]]}}}, {
               DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                PlotRange -> {{0., 0.013}, {0., 1.084295175525028}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{}, {}, {
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVjnsw2wcAx0ONbjpVPaOYZnRnlasSj271+NKxeXVNaa0eK6ERqww1GioI
IUhnbNE5HcM6VfXao7KjZWea0oUOs3jNeSVEKpLfanTa6OyPz33++9znjdjk
EIYuiUTy2OF/r1d3Hsz2X/Mkkcj7jhukeI0X5basP6BA+YWbvu+FVkwkEoTe
3x7g9v8yffdaD4KUPe7lXD9Y6UjuFzQ/gIWOGWXkQjB2yVZCsyaG4PLiUORJ
9WnE35iWV4pHYezgGhnGOouR8QFzT5oUlGFqk61LOOiFoUcbTKeQG5dZGqiM
gq5btEp7ZwYFoZbSQMcYqLxKb2Vw56BoS/ls1DgWFyn6e/U8F8CM1YlhjcRB
PmF79/yjReR9LtqmljCwMXu0VxQgh3ta7P3IeCYcy/eEGo0tYe+PAY1f2X4M
1djwqzyqArwmux+c9RNhVGP4RFG1AuEBe752loXr9VXkdpkS3fPMjMmqJNjn
1bTG6a2iz+nRwFWPFETcptvdO6RCh7W+zNnqElYeipYkFmtgJ3SalBqlYkX5
bz3fUI2ite2bnOepCPQa87CcUaOBvBCQPvUp9jDPC5x8Nfiy3Zt0UJIGF39e
Qq9Qg1Klh3ikOR1hdB9S5YgGUrpEbVF8GfvDJuiNugTUrn8eMWWzUaOXNneY
QsBUxLliHpaB6mhhVIgfAUNh7dTg+5lg10QIGGcJnGo5U2fmegUvUuflfuEE
6i41piWaZIHzLOhpfwiBXmF6VIouB92Ola+E++z06fMhOQscRHbJlIQdgUTW
bJtNTza+W/bysjQg8PMf56wzWnLw3njSvlPTGhgvJ1dLBbk4tvjRHLtZg2qK
jtkTTy4OOrw0LU7RQPTOAWZuGxe/uej3ebtosMnYWpFa5UEo2qplKdSo867a
4Ffkoars3dFzZ9SgEXyBu14+yF6MpKFf15BAo97yz87H905DyfHWa2gcuvmU
vJ6PAgbreRZbBRX54rA2lodN2kalbHwV120eOzlP89Di+/Bag90qPtjqsvgk
qAC7J09qN7iPcVgT6pbaWQDJmJs28C8lWBW3p393LAS1q3T4n7eUEBnRdlPr
CrFtctW7Jm8FCcd+6lk15yMp6LRiclABn5zZxtQyPrzvrL0ptFKA/HWEuVbL
h7grwrcpcxnMeKHJXHoReLvonbqSJXQYWFb0y4twwzL39eP2S0j8MKbWILoY
Ha9x94tz5PAXJ82YSIsR/E2rLWdSBsrLg9/a+JUgcOHtdpcTMlx+tkQIuktQ
fo9qUFa/iIE+2sDmEcHOv8PohNEiiAq35J5aAdaDCUFH9gL+A7Z915E=
                   
                   "]]}}}, {
               DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                PlotRange -> {{0., 0.013}, {0., 1.084295175525028}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["3", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["False", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
        Baseline], DynamicModuleValues :> {}], 
      StyleBox["]", "NonInterpretableSummary"]}]},
   "CopyTag",
   DisplayFunction->(#& ),
   InterpretationFunction->("InterpolatingFunction[{{0., 0.013}}, <>]"& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.662624375842202*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"deriv2", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "BM", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "BM", "]"}], ",", "2"}], "}"}]}], "]"}], "]"}],
      ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}}],

Cell[BoxData["53808.558131265105`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.6626243761012707`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fz", "[", 
  RowBox[{"BM", ",", 
   RowBox[{"-", "0.0064"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.45375087506522*^9, 3.453750875607725*^9}}],

Cell[BoxData[
 RowBox[{"-", "1.084292460250462`"}]], "Output",
 CellChangeTimes->{3.453749602972189*^9, 3.453749666574046*^9, 
  3.453750876352957*^9, 3.453752731604185*^9, 3.453823764931923*^9, 
  3.453823801509736*^9, 3.4538385837598877`*^9, 3.453838637735564*^9, 
  3.46384467782513*^9, 3.4796682584643373`*^9, 3.4802452924391212`*^9, 
  3.480692249102811*^9, 3.481566017649225*^9, 3.4819415980291986`*^9, 
  3.4819419259636927`*^9, 3.662624376253016*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"oldsweetspot", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "0.0254"}], "*", 
    RowBox[{"0.205", "/", "2"}]}], "-", 
   RowBox[{"0.0254", "*", "0.12"}], "-", "0.001115", "+", 
   RowBox[{"0.003175", "/", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.4537508826011543`*^9, 3.453750883775889*^9}, {
  3.4537527418735323`*^9, 3.453752742503742*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.0051790000000000004`"}]], "Output",
 CellChangeTimes->{
  3.4537496030114202`*^9, 3.453749666610465*^9, {3.453750887396463*^9, 
   3.453750909722947*^9}, 3.4537527433073397`*^9, 3.453823764961364*^9, 
   3.463844678344269*^9, 3.479668258488261*^9, 3.480245292474451*^9, 
   3.480692249189704*^9, 3.481566017673868*^9, 3.48194159812962*^9, 
   3.481941926000042*^9, 3.6626243762992783`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"BM", ",", "oldsweetspot"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4537509122631893`*^9, 3.45375094919713*^9}, {
  3.453823813188589*^9, 3.4538238137302923`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.137565`", ",", 
   RowBox[{"-", "1.0436583953898713`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.453750950353718*^9, 3.453823765066656*^9, 
  3.45382381697288*^9, 3.4638446806023808`*^9, 3.479668258688435*^9, 
  3.480245292720821*^9, 3.480692249415637*^9, 3.481566017911345*^9, 
  3.481941598383407*^9, 3.481941926247629*^9, 3.662624376460092*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Sweet spot of hybrid OSEM with dipole correction (two 10 mm long by 10 mm \
diameter magnets, 5 mm between faces) relative to centre of coil\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"If", "[", "\[IndentingNewLine]", 
  RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk4VG8UB3DZk6SxlSxRRJhCtHsLbUhaaEMimpEsKTH3zpA9ayGkItoo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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{-0.01, 0.5},
    PlotRange->{{-0.01, -0.003}, {0.4602013907859698, 0.9124418225431208}},
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fz", "[", 
         RowBox[{"BM", ",", "p"}], "]"}], "-", 
        RowBox[{"fz", "[", 
         RowBox[{"BM", ",", 
          RowBox[{"p", "-", "0.015"}]}], "]"}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"p", ",", 
       RowBox[{"-", "0.010"}], ",", 
       RowBox[{"-", "0.003"}]}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.453823411637844*^9, 3.453823415837685*^9}, {
  3.480245301978496*^9, 3.4802453263238277`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwV13k4VVsbAHCZb8mVDJnnqUJSEl2rQTKkfLqorlRI50iZh3P2PueYc0lC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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-0.01, 0.44},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{-0.01, -0.003}, {0.46020139078597, 0.9124418225373456}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.453823529739856*^9, 3.463844847582552*^9, 
  3.480245328076311*^9, 3.480692249849388*^9, 3.481566018664538*^9, 
  3.481941598416605*^9, 3.481941926329867*^9, 3.662624416436451*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
If[
useprecomputed,
{-0.912442, {p \[Rule] -0.00680076}},
FindMinimum[fz[BM,p]-fz[BM,p-0.015],{p,-0.007,-0.006}]
]\
\>", "Input",
 CellChangeTimes->{{3.45382342881886*^9, 3.4538234334668007`*^9}, {
  3.4538235413508263`*^9, 3.453823587089514*^9}, {3.480245341853726*^9, 
  3.480245360684174*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.9124418416938367`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", 
     RowBox[{"-", "0.00680076479455031`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.453823532157748*^9, 3.4538235906330833`*^9}, 
   3.463844850994608*^9, {3.480245357148303*^9, 3.480245361221218*^9}, 
   3.480692249882522*^9, 3.481566018727625*^9, 3.48194159846943*^9, 
   3.4819419263446903`*^9, 3.662624418589693*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["New coil calc for LIGO-I", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
  3.45382361286519*^9, 3.4538236144707003`*^9}}],

Cell[CellGroupData[{

Cell["\<\
OOvals = Recurse[
\tbasicvals~Join~LOSvals~Join~{
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* preferred value of magnet dipole moment per volume *)
\t\tmz->mzpref/(l*N[Pi]*a^2),
\t\t(* nominal distance between PAM and optic magnet centres *)
\t\tz0->0.013,
\t\t(* thread spacing (40 tpi, cf. 32 in original design) *)
\t\tthreadpitch->0.0254/40, \t\t
\t\t(* standard perturbation to (normalised) magnet strength *)
\t\tspert->0.1, 
\t\t(* standard perturbation to magnet position *)
\t\tzpert->threadpitch, 
\t\t(* elasticity of pendulum mode *)
\t\tkpend->massoptic g/dpend,
\t\t(* distance that the magnet sticks out of the OSEM *)
\t\tstandofftoosem->0.00114681,
\t\t(* coil length *)
\t\tcoillen->0.207*0.0254,
\t\t(* the ends of the coil relative to the end of the OSEM *)
\t\tcoilz1OSEM->0.12*0.0254,
\t\tcoilz2OSEM->coilz1OSEM+coillen,
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.302*0.0254,
\t\tcoilrad2->0.498*0.0254,
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.4538264235745993`*^9, 3.45382644840556*^9}, {
   3.453837031795086*^9, 3.453837041528119*^9}, {3.453837099708474*^9, 
   3.453837132901514*^9}, 3.453837267777411*^9, {3.453840139813717*^9, 
   3.453840149255684*^9}, {3.4538402007979527`*^9, 3.453840204355585*^9}, {
   3.4538636089891777`*^9, 3.453863609530529*^9}, {3.453863819107182*^9, 
   3.453863840974169*^9}, {3.45386389080914*^9, 3.4538638933349*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.00006696614374535085`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.014824999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"z0", "\[Rule]", "0.013`"}], ",", 
   RowBox[{"threadpitch", "\[Rule]", "0.000635`"}], ",", 
   RowBox[{"spert", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"zpert", "\[Rule]", "0.000635`"}], ",", 
   RowBox[{"kpend", "\[Rule]", "233.0222222222222`"}], ",", 
   RowBox[{"standofftoosem", "\[Rule]", "0.00114681`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.005257799999999999`"}], ",", 
   RowBox[{"coilz1OSEM", "\[Rule]", "0.003048`"}], ",", 
   RowBox[{"coilz2OSEM", "\[Rule]", "0.008305799999999999`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.0026288999999999996`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.0026288999999999996`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.007670799999999999`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.0126492`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.5281505471815046`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4538636242380333`*^9, 3.4538639022226553`*^9, 
  3.463844851197278*^9, 3.4806922499105587`*^9, 3.481941926405641*^9, 
  3.662624418650628*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "OO", "]"}], " ", ":=", " ", "OOvals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, {
  3.453823624487136*^9, 3.453823640631469*^9}, {3.453837378474317*^9, 
  3.453837393571328*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fz", "[", 
  RowBox[{"OO", ",", 
   RowBox[{"-", "0.0064"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.45375087506522*^9, 3.453750875607725*^9}, 
   3.453823640650034*^9, 3.453837393601057*^9}],

Cell[BoxData[
 RowBox[{"-", "0.015387096244059591`"}]], "Output",
 CellChangeTimes->{
  3.453749602972189*^9, 3.453749666574046*^9, 3.453750876352957*^9, 
   3.453752731604185*^9, 3.4538236694422503`*^9, 3.4538259483409157`*^9, 
   3.453826469350016*^9, {3.4538373992114477`*^9, 3.4538374256931763`*^9}, 
   3.453837477368595*^9, 3.453838646018355*^9, {3.4538401571878767`*^9, 
   3.453840174075727*^9}, 3.453840210377989*^9, 3.4538636411134653`*^9, 
   3.453863909646071*^9, 3.463844851305705*^9, 3.480692249973194*^9, 
   3.4819419265374804`*^9, 3.662624418743021*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"oldsweetspot", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "0.0254"}], "*", 
    RowBox[{"0.205", "/", "2"}]}], "-", 
   RowBox[{"0.0254", "*", "0.12"}], "-", "0.001115", "+", 
   RowBox[{"0.003175", "/", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.4537508826011543`*^9, 3.453750883775889*^9}, {
  3.4537527418735323`*^9, 3.453752742503742*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.0051790000000000004`"}]], "Output",
 CellChangeTimes->{
  3.4537496030114202`*^9, 3.453749666610465*^9, {3.453750887396463*^9, 
   3.453750909722947*^9}, 3.4537527433073397`*^9, 3.4538236694697313`*^9, 
   3.453825948369759*^9, 3.453837425726906*^9, 3.453840157247375*^9, 
   3.4538402104113083`*^9, 3.453863641155484*^9, 3.453863909695507*^9, 
   3.4638448513697023`*^9, 3.4806922500076113`*^9, 3.481941926588934*^9, 
   3.662624418792185*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"OO", ",", "oldsweetspot"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4537509122631893`*^9, 3.45375094919713*^9}, {
   3.453823640684885*^9, 3.453823640735626*^9}, {3.453826474859961*^9, 
   3.45382647576938*^9}, 3.4538373936510477`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.031724`", ",", 
   RowBox[{"-", "0.015851396334673775`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.453750950353718*^9, 3.453823671960964*^9, 
  3.453825948604528*^9, 3.453826476451028*^9, 3.453837425763947*^9, 
  3.453840157347342*^9, 3.453840210506116*^9, 3.453863641201985*^9, 
  3.4538639097501583`*^9, 3.463844851469378*^9, 3.480692250041*^9, 
  3.4819419266883163`*^9, 3.662624418850252*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"OO", ",", 
    RowBox[{"-", "0.010"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.453751088575416*^9, 3.453751089087048*^9}, 
   3.453823640769184*^9, 3.453837393699996*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.023699`", ",", 
   RowBox[{"-", "0.010507386986391542`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.453749683527301*^9, 3.45375109040812*^9, 
  3.4538236722686167`*^9, 3.453825948821306*^9, 3.45382648659874*^9, 
  3.453837425793631*^9, 3.4538401576313677`*^9, 3.453840210546205*^9, 
  3.453863641238579*^9, 3.453863909799973*^9, 3.4638448515362864`*^9, 
  3.4806922500657587`*^9, 3.481941926915098*^9, 3.662624418897685*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"OO", ",", 
    RowBox[{"-", "0.003"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.453751094726705*^9, 3.453751095317946*^9}, 
   3.453823640822011*^9, 3.453837393750527*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.048824`", ",", 
   RowBox[{"-", "0.012824745749794315`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4537496838232193`*^9, 3.4537510967086277`*^9, 
  3.453823672557324*^9, 3.4538259490222588`*^9, 3.4538264890979757`*^9, 
  3.453837425851626*^9, 3.4538401579824533`*^9, 3.453840210608426*^9, 
  3.4538636412980003`*^9, 3.453863909861566*^9, 3.463844851657218*^9, 
  3.480692250121179*^9, 3.481941926976323*^9, 3.662624418971629*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sweet spot relative to centre of coil", "Text",
 CellChangeTimes->{{3.453823657396553*^9, 3.45382366152324*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"OO", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"-", "0.010"}], ",", "0.010"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453750960628242*^9, 3.453750962514122*^9}, 
   3.453823640869858*^9, 3.4538373938007517`*^9, {3.453838657031551*^9, 
   3.453838662984824*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwt2Xk0Ve/3B3BjAylpMmaohGRIKUO2CCmlSVEoShnDHc2Re83uOSGVkCSV
T4lSNG5RSiEpZGigEKEMkah+z3et3193vda969xzzvO89z57HVV3/50eIkJC
QteEhYT+98lrumzUEcLDAeWYoi4eH1ulH/64yuWhwr20Y5fj+ai3peEyg8XD
Ix1zM7wEfGzHqQVix3ho1/zP8PtpPhpc3TGs7sbDU1XKQf8K+NgZOlnga8ND
ETPpkwav+Wiuaq/4ax4PY59kVHcpxeCUz9jf2dejcUGPVtrWshg0ze3C/toT
+Ov1vUZtiThMmGjoSv0ThRPzh69YWcfjUpvzW3foR+Hxqe50RlACxqyZVfxo
VyT2jVlMpt5LxP74weG+mcfRI/bDhgPNSejaJx5aZhuOg0565tuHkzEF1hx6
ZxGORuHT13uMJWNV2uEtv0zCUbDJQCTodzLqQKXCOp1wVESdtnQRAf5LjXxQ
KhOOqxYlHr8rI8Cc9ZN/7rSFYduVqs30KgF20j8ib/uF4fGg9ojAAAEeXdsW
c/NkKJr25d7y+SLAvPBV9zYlhuKJywm5uT0C/FQZP/CBF4pa+TulmvsEuG/7
ut2SQaHooO+ydd2QAO28Tqkedg1Fj9yVa9v/CFDvnP2DBStC0fzvtsLLCymc
+Fs5FPQkBFvncQZNrSk0tFJYNudRCP7K3P9xsS2FjESG46XSENzt9kL47xYK
+xep4uuCEHw00vD61g4KP+hFJGmdDMGoKsHtCWcKK9zXLW93CcHF7nozpjEp
TKy65gzjwdhutmP6+0wK6+Z2zNnyIxhNsnNupp+nUNplQeWe3mAsZIuX2uVS
mD4SrnmsLRh7++89un6ZwlwV+7FMDMY7z44wLW9SWBYyRP2ODcZkRxu8V0Vh
t45h5W3ZYLQqF5Wu7KdQM8Sb83huMKbIvWoT/k6h79NszVqJYDRfrZ5lOkTh
0P7p9JepIEwJFxu99JPCqbh3zvM6grDkvFSGzV8K530OGQu4GoR5D9XF3KfT
aH4aNbWNg5AOzS2yWkhj4hsFjUKDIHw1o7hNZhGNTXOC1PVWBuFuU1nZD8R+
cXpLVqsE4UfXYTwmR2NG8AVF02lBGLCx+XKQIo2j+6Pn2DVwMS2XKlupRiOc
+ShV95KL14auH2gjTnhrMmv7Uy4+r78gGruERtWtozN2l3HxonGF6bulNG4z
8xBxzuaimEfNdvflNF5Rsfnp483FcnD4OE+bxhHniyMDh7ioII53c4jNzv4b
8nfhYvt5TtiKlTQ2zi0bZG7n4vaqG7eNdWgUEdX8GmrIxauijDegR+NW4Hf/
0eXidWlGzX3iM6EdX45rctHTLvriGn0adUfPdkQrcrFo/EG32ioanbsk2hJF
uOgx+0XWZwMaL6sebZGa4uCfPymHtq2mcdilspn6ycHlWWv/3CGObwp9m/qV
g7MKJ/Oj1tBkXftrz9VxUKjApnjKkEZhMdsapecc1C0vHXZYS6Od+aUX5x9z
sLfx6NQ14s9lLs8ulnBQ1Oqz1+51NEoX1JX/l8HBj0vGI+OMaJz9wShwWxoH
m1PfxtcRS8pcUh1K5uCtlegpY0zjtJDQE4ZRHLx+VCUvlVissHtVSwgHZz6b
+lNPLNK543Moi4MK8ss0Z5nQ+MdWY+PjoxyUsLIfDCX+HZ46esiNg/uM1sYU
Ef8q/ps3bT8H4wTZfZ3Eo3KN4nbbOHh/9Zb5G0zJ9W81vzNow0FK3KDZl/h7
1H9HTm7gYFDsV7d04r7eqGdNqzkYPlvsRSfxV6UBbrAOBz+F5OeIr6exa4ej
hqIGB1e/emymTtzJr3z3SJWDbkursjcSf7qrE++mwEEfZgweJP4wcNZIbAEH
tUcbz4cQt6uK9+XP5mCNUpxZCnGrQ0CG7QwOTl4OyLhM3BzftrlfmIObXnvf
vEf89qH1pGCSjZ8cTPkviRuGiv/T/8lGx4Hyua3E9cuUnN8OsnHKqXZPN3Gd
U9ws7lc2/so13PWDuCZ55IFcJxu1FjSI/yKufuzq96CNjfqOkX5/iKt+Visd
aGTjOhCOFzKj8YnmmjrhV2x061yzV5i4wiUnIu85GxsKR5v+kd/jSUldmwo2
Nh6VmT5F/OAp52PvfTY6TXh1/yS+N9FBJd1m48eH9cwB4rKVW811b7Dx9I7F
hZ3Ed9zKfry+wsa2bK20RuKSU0susHLZaPH8+dIq4uJqwY5FmWzMj2lzLSEu
/DMhfO8UG59kGG7IIb6m73HTmWKjid6tF/HEBR717v/i2GjupvU7gPjKWZN5
uSfYqPKOU+dAnF+bX7kxjNwfa4b1OuKLwjKsHjYbL2iOH5Qlzvb6+lbbi43L
zU2CX5P1zszaxX/lzkbLnjBWAfHZ14/WMJzJ8evaZaKI04xOpZfas/GZ2E35
5cQpfkI2+2zZGBM3EjNG9ht9wWd8yoKNXsuvJVUSJ860cLQwZOP+u68P7CGO
W399RpcuG1VlJ7UUiWMCZe/GarIxSnZ64key30+0DMrVKrJxVMZC/ABx0NVz
bXtF2fhg7GWFOclPWOdnyYApFrbnGbn2k7xFKmibxv1kYZi88sJTxHHJDzLL
eljoMrO48T3J5+nA9y5yNeR763IfO5LnjIJlAv2nLNwZu7zyE8l79me/R7aP
WKgUd2MFgzjf4e/ikCIW9gmv00oi9eGOkfKn1jQWHp6GpZmkvtxjHJUeSWZh
sfBYgBzxo/9umEvGstBfTEsvldSjKiXzCybBLFT3e3UvnNSrRmE390wXFtpI
FbTqkPo2Wp37xUWdhaqLbs8V0iR5Ffk2n6PMwpYZ1nw7DRqnTAysBLIsdNj3
/eup5f+rB5WXHkmwsChMO1RZncZ5KV+OKH9nYtytsUtSpB6v2qfe+6mUiUmm
Fv27ST03TD0mN1HExJUJMyr8FWg0rrljO7eAieM5tYxYeRotzGwKNmQy8XGE
1sHrsjTuVPP0yY1kouQWA+s382kM7Ls6cMiWiUHmMktiZtEYMV/ea9iCiWv4
Jj2RkqQfmCV8iTRlonr+z/YgCRpzU7zbsnSZmG0l53RwBsmr8Yrq5gVMfJu7
PEhKjJxP4rW8LZ0MVO5S7H1E+pvFbUWV1jYGXqt7d9tphMJtH5POeTYyUDPL
smrwB4VHDfxS+M8Z6CopKJhO+ueZtpWRWMjAO+WVW0Y7KJxccWO/QSgDObUO
dqU1FM7Yo9z8mMXACZYK42c1hfMjqZ3bjzHQx6b+4cpnFGq/9bf1c2Ngg7oj
Jj2m0DVMb+1lGwb+c19lJHaHwvKaYhmF+QzMNHUJbc6ikO9XUi1yPRBDOsNX
iXqR/88UfjotPxCzZyipr/WgsODltnKJ84G48rvpxCE3Cus1e+/InAzEqPGR
NVecKJTvVspTYweiJh38upU8rxS6xkZYrA9EXtTL9m4NCt/Z7zM4URuAFa7f
1iR3CLAv4rJOTFUAtoie9mppF+Cf66OaCRiAkZufblj8ToBqsyiVlOIAPDS4
o+VknQB9n1dK5Z4KwFcJFVyV+wIU3rDy62OXAHxnPHNua4oAHQ4LGYu2+2Ns
uo5jiakAPxSXpdnV+eM77fEM7bUC9PwX8P1UuT9eE316NktfgGEZHXkal/wx
yLuyykudPM/VV8zZdswfC/daPyqYI8BRU37XGSFyvPb3K+s+kefLBRIndZYd
wxPyr+amhSfjq6p5X52O+aLO4tnW33OS0HtMoYVy88VZdzp7ZmckoZj60hdP
d/ui3xfl2RqpSWjMX31N38QX94n1dlvzkzDP0iFg5gxfHDxVWGnolYQh5em/
yi74YGaCpehH3SRUvyc3U7bRG+8tfze1vSwRI64razWZeKHP65L/8HYCLuvp
kB9f6YUPnmVLxF1LwBqVPElZFS/MrUpv2HQxARXSNAacxLxw98sdObfoBPK8
pl/0vsYTJRodrHV8EnDYxtKwy8UTJ16yPMoWJ+DRziMWo8ePYu7ZS4vVI+Nx
+6LCfTJPPLDHXTzwsnYcOoqvUWbFuqOc2KaYCx58FB8Iy1sh6Yr8i39LbSei
sCwqVk5VYy9+2KmVFhMehk2Lo++43d+OWsNqfbv/spDFm+62Mc4Sn/L8MLDN
EzcF/EcSq4VbHPLldpRuxy3ZM7suftWAuNa4PXVf7eF6tsf763M2gt3FS55L
+F4Q5P5m3baw7VAzybHn3WTB7u+Dl6xC94K9oXGjVVsYNFTLiCU6ucJYx389
BaonYLhWLavioDsMndi3cI4FH1pu3a3+1+IB+6b7dCuZxcHBlYoav7o9wNk2
/6zXpjjozo+I+THiAb92VfUU7oyD0bOWlh1SR2BvjqG9+tE4kI6sfVCx4Qi8
qlq27DkVB9Z2HTf4V49A9ujIi6aPcXDzy4x0yeCjELx3Qc6i0HhIWODovkjW
C5RXZN/4npUA185nOtct9QLFF9Mb/fIToE6zYw9f3wtmlTtldBUmgIyZ95aR
zV5wsO6eSAUmQMaRsNWvwr0gcqHRep2OBCgozZkW+9kLrthsm3ijlggvnXoL
xgq9Qdp0o87OC4kw+Hnlpev3vaF5aDBV9GoiSB9jnD/83Btu7z1MFRYlwu4T
k6kNHd7gqGtgM4SJ0F4gFV443wd0z5wt1fyQCP2T+vZHQnxg6JETdUQuCWZl
h4w0WvlCmW7kNunEJFBbLD54YZcv1G/uNE1ISYK12dRXPzdfiLPIPD91Ngnc
s/Pei4f7guierZUvriRBWXbdszUlvpBeFJU8qyoJDp9Xyzyl5gf3V1ieUP+X
BA9yXmx0+OcHe9KGmKU+ydCg4gCqUscgOpRbY85Ihp6cj0YD8sfA13drQUVQ
MshcGNXhGx4D0ef/ft3gJ4PnhcVyt/2OAd+065fe+WSYn8sYmN9+DGZviNxQ
W58MPhfl09+W+cO9arM8to4AAjY4/L711B9WXknlFBsIgPWRck1t8AfRJQc7
utcJIEJBfPnOfn/wqLHmmVkK4Hn1eFvPnAAoUlJXuLBXAG0bOn09LAPgXWUW
c/VxAQitKhUcLAiAFmMq7ly1AESi3prXFwVA55OS0Fl1AhCrHxqG0gDQNV+6
gtsggJnHtPcqPwmAnm/jlUZtApApuKD84X0AJDSYCbP6BbBMLalo/9xAOJXt
9fahFAWbZdwa9gQFwvkn0YKiLRRYO18Q23E8EKxsX+0usKfAIr/DcEtMIEjE
7xzJ3EWBsbH7OUgLhNL8d+W++ynQcj90WKMoEBhqno13vCmQvOkxNtETCCel
Cq+OxVIwY+qSxuhgIOQMBH6JSKRAzLp73+DPQHjhNUNWiKJgquUIdooygLNE
jzFwioJ+Yc+4l8oM2N2brMO6SEHNDm/5rL0MSJPqKDJ4SMHzcwV2p10ZMHet
a7hdOQVPuvoiTnowYHxWu4drJQUPgn0+85kMSKz8lupXTcG1C77XjlEMYOQo
XTJqpCBp6JiZ+TMGmNyzyk/4RsHWk0z3z4ZMKDrymkvPpMG8L9H26Hom8BV2
9GZJ0LDaMk/vmyUTVo4eDr0iSYPiz7d/h7czQeN7gPhtKRr6HA3PifgwQXzI
ou6/uTTEqUy8UT3PhMcK9cpz5WgIC557/9IlJrQrV8gOEfs3aOZqXmOC35CJ
ZZ08DXt4+wL07zLhYrCifqQiDcu+3p+14Q0TfEJnUxXKNFTciLA6OJ0FQiKl
thXLaLgz47T2FykWNLbEfWCr03DV7cY8z/kscH3Mv6O+nAZ63qcOf1UWTOYG
rY7UoOEAd0PEcRMW3FjcFSuzgoad9U4eohYsGNc+41BEbK3JsIvdxALH78f9
t2jToNOWK085sODvmsyk4JU0TJmJlWb7syBL9WzibV0afpxWzFbjsODR7/lt
6/Vo+PxjNT8/jAW9Rb+OVxK/yPXYVRjPgpcHqLoqfRrOTnv2/eFFFrRJvTl/
3YCGpAMfmzYUsMB6hup9ldU0RJaNP3xaxIJ2UY01J4k9vTWSah+yYOiL92bv
NTQY1sVrvG9mQUrTb9k/hjRwdVNdzD+wQOt9Y5DTWhrK6MyUi19YoHguZ98t
YpNdN6a8hlhgWsW/cmAduf8lZfq14ywIqKxaeJP40YKKI3p/WcDcmSQpYkTW
+93b+jEJNqQ49SZlEEcZfRDfN5cNXmKVCp+JKzJ6jB8uYsORWnqNpjENVi6/
86KXsqFV4fTsQuKYR6Kt3VpsOH91QX0/8XNlqTmb9dnwwHeeqqYJDZs7lYOl
zdiwf84STgZxoqVmIXMjG/4zjQh7RVyTt+pz02Y2LJIcXShiSoP9UautWXvZ
4G9WMOsgMf182wkhVzbMkTb3TiRu0HQsPXSYDSUaO/eXEO/u91bVCmSDnWn0
wn/Ep7ay9iRz2fBaJfC9ynoamgrDE3+Es8E259sGc2JZ6djyXTw21Nu2bHQh
dgqkf95JYIOujWsPlzij4ayW/Ek2hKre1KKJ2w0uHgg/Tc6P/31OPrHSqWtp
n7LI8e2sztwldh27XW2Zx4b0jPdPXhCf34t/8wvY0DzVk95C/KnsuYFEMRsu
zuDPIfMjqMk3ePqVssG4/4sumR/hUGhbVv1DNpydbTAxTpzX/qXB4Akb2uWy
fMn8CN3rB6effsEGOc0tiWR+hOXnx01/17PBMspnD5kfwVNImOHSzAZD1HpF
5keSB4nL5e/ZcLrx1tgkcV/FvPYlX9hwvF+njsyPoL1UaW5sHxvCUlv2kPkR
/Pjq1n0/2FAd/O4kmR+hsFs3dOs4G54XOEWS+RF+2BgVFf1hw56gxCVkfgT9
qxZd88Q48CE4M4zMj8CQsJPnSnDAaU9JEpkf4ZaPg32rNAd25Uk7JBCP1rjy
1i/iwHR+S1MgsaGO590cJQ6syzKbt5eYSwUOii7lwLkGf0lj4rIfIUuOanHg
9+ascnni3zt4ji/0OODqM24wQdY3bP7pCno9Bww67F1vED9i54yPWHLgRJT9
vFjif01Xtfdu5sDNp5DoTHzi7IN0pb0ciH9c9lyIuPL305eRLhw4aXeJ/t/+
E3N+JfTlEAeawy1UMoljF3d6FwRwILMw5pwOcUXIbJUzXA4cPFLI+072958m
40Z+BAekdz5ruk7MpFLBLYkDUkttH6gRF37D0W2pHBh++ntnC8lPr03/VdMM
DqT7jzkmEx8Qspove4UD2z0bywZIHjOcA6vFb3DgiXHjggzixrKsiJHbHHB+
vP+rJfGWwLGvdZUcWFTcNUKRfK/tvPyQ/5EDez8sfzWT1AOG2VsGs5tc/8sH
IrmkXlzPENJwG+CA5LTe0rXES3Y5pZhOkvWJECncT+rLnCcSR0cWcuFiV/QI
fxUNPZf8pN22caGydC546JD9KZLxdJsDF5QOtm5qIvXPxbUqxNSZC7sKjAc2
Er9ZqNy1yJsLxmJTkgqkXmJs/d06PheC76rWFmjScNrL4JDpQy5s8NC877SU
5PXpAVmtJ1y4bu+peWkJDVJqSbWLXnJB9p/elkE1GqJbv6wdeceFK8nZN4JV
SX/Ykj6rYJQLvMOXl7MX02CzcuL2Iu0geL3eapWQLA0hZ/4oU6uCwN2fK2u4
iIZroiIJ04yC4Oq+knneC2mQaZVw/WkVBNOKL2yrmU/yG6M47c2BIJixKmAi
mPSngE+wR5AaBI7LlSGU9LeM1JgxsckgoKVz35iOkX77N+FgmHAwqOwofrVq
lIJ/XtSLkenBUFLXZb1smILD5meyO+cHA71pe/G/AQp0Bq5al+sEQ5fW7/sJ
XRRUWtemh7oHQ5uJc/vkG9LPJ+atHa4mx9uv17S/kALZgyaqo/XBEPLxkUXx
fxRsrHKXHGsOBtfs3m8iVynISin+ONEVDMy+UqFzpP9vW2EfJywSAhEzhpKz
z1BQ7JzQIm0cAio6SYM/oyjgoFCYbkEIqPa6Vk7uIOfLGyj3TQiF3g8SJdJf
BRA0Ij6x9WQobNbo1c7+IoBht8X6umdCwfWHSKVGhwC6zewvDF0KhVan7zvW
tAqg7ldRFOdxKNwertisXSOAbF+WReSvUNCu7ZFNuyGA9bsnK1OPhMGiG40J
riwBhC6Z+eyeRTgMzM2u4YwlQ/txDVHO+wjYT/k6PhtNgj1bRfM8t0ZCRfQd
+5OViVBsxOqwU4qCT91mPJn0BEDdae/le6NgXWFuo4FHPIjxx9vXVZ2AOyZb
/D4tiIP1d/u4yWnR0CC+8ML69zFw8/pQlfqZaLjpNnNmfXMMaOT+WlB+LhrW
ZqWje0MMyCROKxnOjQbBrVzF+Gcx0O2s9mNvcTRI2y4vaSmOAYHQPk+1umj4
sbTJIjEmBj7ZVDuWTufBnZOvvxvqxYCDaf3l7ZI8yDwYod6oFQMv9JrHemfz
4EFa/UvmshgoketKU1zIg9ntKkduysdA/Deh11FLeTD/s+PIavEYWEWts7Xb
wIOR7zNNt7fy4XI0nOnayAO5k99e/HzLB8Ug656ITTzozutrOveKD9PcdvOL
7XlQ//K+V+8TPrStCni80JUHIFKbknCDD9uXc6WL3HhgpP5EbXUBH6oUIg7Y
evBA3abE8EMeH4rEkv6E+vLAhm4dMMjgw7KJFLsFATyQrb+f8jGNDxkDZ88V
MnlgvL7/USLFhzmdOX02XB7c/GnGXJfAh/9/XwX//74K/g/F3D22
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{-0.01, 0.01}, {-0.015861531207948313`, 0.015861531161932573`}},
  
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.45374974088566*^9, 3.453751021464161*^9, 3.453823734388617*^9, 
   3.45382595105693*^9, 3.453826495876092*^9, 3.453837430614188*^9, {
   3.453838660033111*^9, 3.45383867436195*^9}, 3.453840159929102*^9, 
   3.453840225991082*^9, 3.4538636558574543`*^9, 3.453863924479361*^9, 
   3.4638448686389313`*^9, 3.4806922643363953`*^9, 3.481941942064209*^9, 
   3.662624432690221*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"OO", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.0", ",", "0.01"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, 
   3.453823640937874*^9, {3.4538265543875103`*^9, 3.453826559178968*^9}, 
   3.453837393850636*^9, {3.453838705965811*^9, 3.453838717842711*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwV13k8VN8bB3BEKqXIFpKokBKlyLd8SmQN3+lbIpQtkWwz9459nUGWmbGk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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0., 0.01}, {0., 0.01586153136472531}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4538234640829372`*^9, 3.45382375947115*^9, 
  3.453825952943671*^9, 3.4538265081040163`*^9, 3.453826563804844*^9, 
  3.45383743232346*^9, 3.453838725272155*^9, 3.453840161864758*^9, 
  3.4538402352085543`*^9, 3.4538636649073067`*^9, 3.453863933391049*^9, 
  3.46384487886052*^9, 3.480692273326301*^9, 3.481941951327619*^9, 
  3.662624441306498*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSdata", "[", "OO", "]"}], " ", "=", " ", 
  RowBox[{"FindMinimum", "[", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"fz", "[", 
      RowBox[{"OO", ",", "p"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"p", ",", "0.005"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.453823404829797*^9, 3.453823405956604*^9}, {
   3.453823506088236*^9, 3.453823516693254*^9}, 3.453823641011278*^9, {
   3.4538265379087467`*^9, 3.453826543745769*^9}, 3.453837393910678*^9, {
   3.4538387257460747`*^9, 3.453838749683352*^9}, {3.4538387973199577`*^9, 
   3.453838821469616*^9}, {3.453862450307226*^9, 3.45386248039209*^9}, {
   3.453862568949154*^9, 3.453862570115514*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.015861531596904697`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", "0.0053252761898093665`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453823468555167*^9, 3.453823535452108*^9, 3.453825954168241*^9, {
   3.453826526324848*^9, 3.453826545225122*^9}, 3.4538374328189507`*^9, {
   3.4538387298936996`*^9, 3.4538387449128933`*^9}, {3.4538387984605837`*^9, 
   3.453838822542676*^9}, 3.453840162093855*^9, 3.4538402359560423`*^9, {
   3.4538624679971113`*^9, 3.4538624812382927`*^9}, 3.453862586264966*^9, 
   3.4538636654918613`*^9, 3.463844880212677*^9, 3.480692273883992*^9, 
   3.4819419518975058`*^9, 3.662624441878827*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSpos", "[", "OO", "]"}], " ", "=", " ", 
  RowBox[{"p", "/.", 
   RowBox[{
    RowBox[{"SSdata", "[", "OO", "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.453862483701729*^9, 3.4538625105182133`*^9}, {
  3.453862576749049*^9, 3.453862581411574*^9}}],

Cell[BoxData["0.0053252761898093665`"], "Output",
 CellChangeTimes->{{3.4538625068641663`*^9, 3.4538625109082727`*^9}, 
   3.4538625864136257`*^9, 3.453863665522478*^9, 3.4638448803345337`*^9, 
   3.480692273901267*^9, 3.48194195198164*^9, 3.662624441920925*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSpeak", "[", "OO", "]"}], " ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"SSdata", "[", "OO", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.453862473476694*^9, 3.453862474190342*^9}, {
  3.453862598812314*^9, 3.453862615921789*^9}}],

Cell[BoxData["0.015861531596904697`"], "Output",
 CellChangeTimes->{3.453862616387323*^9, 3.4538636655554333`*^9, 
  3.463844880438141*^9, 3.480692273921216*^9, 3.4819419520177402`*^9, 
  3.662624441968322*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["New coil calc for value-engineered LIGO-I", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
  3.45382361286519*^9, 3.4538236144707003`*^9}, {3.453838874626217*^9, 
  3.4538388807274017`*^9}}],

Cell[CellGroupData[{

Cell["\<\
VEvals = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->lold,\t\t\t\t(* length *)
\t\ta->aold,\t\t\t(* radius *)
\t\t(* coil length *)
\t\tcoillen->0.347*0.0254, (* increased from 0.16\" for LIGO-I *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\tcoilz1OSEM->0.05*0.0254,
\t\tcoilz2OSEM->coilz1OSEM+coillen,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.334*0.0254, (* 0.334=0.498-0.164, increased from 0.302 *)
\t\tcoilrad2->0.498*0.0254, (* same *)
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453819143842659*^9, 3.45381916873015*^9}, {
   3.453819205916604*^9, 3.453819229397924*^9}, {3.4538192680904627`*^9, 
   3.453819317992671*^9}, {3.453819379538721*^9, 3.453819381962309*^9}, {
   3.453819414835219*^9, 3.453819449256628*^9}, {3.453823205503562*^9, 
   3.453823222597754*^9}, {3.453826073117807*^9, 3.453826150751071*^9}, 
   3.4538373389188223`*^9, {3.453862135114468*^9, 3.4538622312380953`*^9}, {
   3.4538622812810287`*^9, 3.453862282014607*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.00006696614374535086`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.014824999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.008813799999999998`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.004406899999999999`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.004406899999999999`"}], ",", 
   RowBox[{"coilz1OSEM", "\[Rule]", "0.00127`"}], ",", 
   RowBox[{"coilz2OSEM", "\[Rule]", "0.010083799999999999`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.0084836`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.0126492`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.0894799325270267`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453862217965355*^9, {3.453862264142426*^9, 3.453862285813403*^9}, 
   3.463844880536422*^9, 3.4802620957847557`*^9, 3.48069227394248*^9, 
   3.481941952073387*^9, 3.6626244420201607`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "VE", "]"}], " ", ":=", " ", "VEvals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, {
  3.453823624487136*^9, 3.453823640631469*^9}, {3.453837378474317*^9, 
  3.453837393571328*^9}, {3.4538388861923847`*^9, 3.453838889904484*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "VE", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.013119230572857864`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.006315461295902202`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"fz", "[", 
          RowBox[{"VE", ",", "z"}], "]"}]}], ",", " ", 
        RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.479667008672338*^9, 3.4796670332310963`*^9}, {
   3.480244318582687*^9, 3.4802443450940313`*^9}, {3.48026206168556*^9, 
   3.480262062286573*^9}, 3.480262239842697*^9, 3.662623959952838*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.01311923057285788`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.006315461406890476`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.662624488662723*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "VE", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nk4lOsbB3CHQrYsWVORVhGFUuGLpA3hIJVUKrQgzDDvLPZt3lQqKkRE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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 0.013119230033113495`}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"VE", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.479666887455168*^9, 
   3.479666888838862*^9}, {3.480244879780376*^9, 3.480244897499516*^9}, 
   3.4802450058581*^9, {3.48026206307683*^9, 3.4802620637527103`*^9}, 
   3.480262264694813*^9, 3.662623963897244*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], LineBox[CompressedData["
1:eJwV13k4lF8bB3C0iBTZWlCWlKLIFjX5oj0pLZQKvyhrlphhnllE1nlarUmJ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 0.013}, {0., 0.013119230032904723`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.662624495590671*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "VE", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "VE", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.479666890574193*^9, 
   3.479666892310862*^9}, {3.48026206489049*^9, 3.480262065861014*^9}}],

Cell[BoxData["0.006315461406890476`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.4796669544241667`*^9, 
  3.479667628122774*^9, 3.480244912925961*^9, 3.480262195337325*^9, 
  3.48069227397675*^9, 3.4819419522162*^9, 3.662624495638719*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "VE", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "VE", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.479666893782012*^9, 
   3.479666894910797*^9}, {3.4802620669164543`*^9, 3.480262067600336*^9}}],

Cell[BoxData["0.01311923057285788`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.479666954466415*^9, 
  3.4796676281467333`*^9, 3.480244912993281*^9, 3.480262195361561*^9, 
  3.480692273996217*^9, 3.481941952298916*^9, 3.662624495703776*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "VE", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"VE", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, {3.662623545865924*^9, 3.662623547424322*^9}}],

Cell[BoxData[
 TagBox[
  TemplateBox[{RowBox[{
      StyleBox[
       TagBox["InterpolatingFunction", "SummaryHead"], 
       "NonInterpretableSummary"], 
      StyleBox["[", "NonInterpretableSummary"], 
      DynamicModuleBox[{Typeset`open$$ = False}, 
       PanelBox[
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{}, {}, {
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVzG0w2wcAx/Ewp1On1dyUkgtj2lOnKqE49Nfu1nloSzysqG4lpPFMPSUe
Io/y8J+0hvbYMnJOo8zs1GpnPW5mVarqqbJiptRTWRGzMR3Wvfje5933fWZa
CEufRCJ5v+1/N1Rt1jy/FR8SKbr4PYf9p3+V8Rs3uh1hadCT07nti+dJOp3B
ujeKfNSUuLUInF/q8CoRnEPvUWv7PC4TlnrmjkNxF6DLSkwYCIiH694HURdX
g0H64ueRPXEqTE+4RV1K/gRW70TtV1llwHGQVm/nGgnmBMtJaZMNfmyuMmDp
Cg77ul5M0OdCEmqlDTgZDY8KoaDi6zwsNqUXD5syMey5o6kK54HN1ItOHoqF
Mm9FvNLDh/BG6y5NwQLDbnh8zEgIryzmL1HX2PiUE1Ma6iHCwXv+dbftEuBm
yghb/1AMcf2xZrphEqpK9rh2IRKUHTku3ZlKRik1NjDTvwjt02zuWGUqNE9v
nZunStHl8rTnc+90iKu19cvrUtynGs7SKdcRUa/jMDUycOLbyMoDGdg8pnog
DpNDtrKrKfg3A6l3VIvNS3LcsZnxzx7PxInRvm8L4xQo/e4MybovCxeIhRHO
MwWUS94Ph77JRpczVa05TkAb07dqKc/B/NhAMD2VwKrbqJMZh4N154ViXS0B
s9aCPItLXJQG0WvCHhEwLqsef+KbC51J6fDkOIGgxjC1uVse/Bqml6iTBNTX
67KSyPmIqInjdw8S6CzLvpKuX4BZD64n9/u3/5jpkMKZAvBS/tkxVBJISp5q
su3gYaw/32z3MoEfRiKo3MZCvHJi3Z6zIGC6kKbSEnycDmm/Sh5SQOWoZ/6n
jwCDTJc3h3MVaPU8wuY3CVDhuvLXR1QFNlnbr7QUIcruTT573S6H+kzl39Jy
IVZ6VylOgXIwdFLCy0CEx7ULKUEvZIhn0O768UTo2gr3nouVoa5fs2WzIcJN
SthPv81K8domcXCHKcZAwjatNVGKL22XXegTYnRLzdkHXxYhcPtHy5TzEvAf
b4k7mUVwWAs9ldEmgaCN31vyUoLk8oaJgZNF6J8Jrv04QoLWA4x3aeoikIxK
lWWjYsS7t3T8YSHF8t18cqOvGGcLp+oybkrxnGVfE9kugs1Xly12dqS4ZWzi
S/URgX2tjPwiWwbbQ+vNxi1C3N9nVf5oTobeDgrBpguRFB5dve+qHCaDIQ96
GwTwe5g6SdbK4a5qyWo5KoCj0ZMa23MKVLonfkaL4iPnzbyOaFeAr1/lvBhZ
iJ4uRs+mEwEH+7VDZ9N40JWfSuuoJnAj0472u6wA/wG20cUs
                   "]]}}}, {
               DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                PlotRange -> {{0., 0.013}, {0., 0.013117066901220956`}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{}, {}, {
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVzG0w2wcAx/Ewp1On1dyUkgtj2lOnKqE49Nfu1nloSzysqG4lpPFMPSUe
Io/y8J+0hvbYMnJOo8zs1GpnPW5mVarqqbJiptRTWRGzMR3Wvfje5933fWZa
CEufRCJ5v+1/N1Rt1jy/FR8SKbr4PYf9p3+V8Rs3uh1hadCT07nti+dJOp3B
ujeKfNSUuLUInF/q8CoRnEPvUWv7PC4TlnrmjkNxF6DLSkwYCIiH694HURdX
g0H64ueRPXEqTE+4RV1K/gRW70TtV1llwHGQVm/nGgnmBMtJaZMNfmyuMmDp
Cg77ul5M0OdCEmqlDTgZDY8KoaDi6zwsNqUXD5syMey5o6kK54HN1ItOHoqF
Mm9FvNLDh/BG6y5NwQLDbnh8zEgIryzmL1HX2PiUE1Ma6iHCwXv+dbftEuBm
yghb/1AMcf2xZrphEqpK9rh2IRKUHTku3ZlKRik1NjDTvwjt02zuWGUqNE9v
nZunStHl8rTnc+90iKu19cvrUtynGs7SKdcRUa/jMDUycOLbyMoDGdg8pnog
DpNDtrKrKfg3A6l3VIvNS3LcsZnxzx7PxInRvm8L4xQo/e4MybovCxeIhRHO
MwWUS94Ph77JRpczVa05TkAb07dqKc/B/NhAMD2VwKrbqJMZh4N154ViXS0B
s9aCPItLXJQG0WvCHhEwLqsef+KbC51J6fDkOIGgxjC1uVse/Bqml6iTBNTX
67KSyPmIqInjdw8S6CzLvpKuX4BZD64n9/u3/5jpkMKZAvBS/tkxVBJISp5q
su3gYaw/32z3MoEfRiKo3MZCvHJi3Z6zIGC6kKbSEnycDmm/Sh5SQOWoZ/6n
jwCDTJc3h3MVaPU8wuY3CVDhuvLXR1QFNlnbr7QUIcruTT573S6H+kzl39Jy
IVZ6VylOgXIwdFLCy0CEx7ULKUEvZIhn0O768UTo2gr3nouVoa5fs2WzIcJN
SthPv81K8domcXCHKcZAwjatNVGKL22XXegTYnRLzdkHXxYhcPtHy5TzEvAf
b4k7mUVwWAs9ldEmgaCN31vyUoLk8oaJgZNF6J8Jrv04QoLWA4x3aeoikIxK
lWWjYsS7t3T8YSHF8t18cqOvGGcLp+oybkrxnGVfE9kugs1Xly12dqS4ZWzi
S/URgX2tjPwiWwbbQ+vNxi1C3N9nVf5oTobeDgrBpguRFB5dve+qHCaDIQ96
GwTwe5g6SdbK4a5qyWo5KoCj0ZMa23MKVLonfkaL4iPnzbyOaFeAr1/lvBhZ
iJ4uRs+mEwEH+7VDZ9N40JWfSuuoJnAj0472u6wA/wG20cUs
                   "]]}}}, {
               DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                PlotRange -> {{0., 0.013}, {0., 0.013117066901220956`}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["3", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["False", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
        Baseline], DynamicModuleValues :> {}], 
      StyleBox["]", "NonInterpretableSummary"]}]},
   "CopyTag",
   DisplayFunction->(#& ),
   InterpretationFunction->("InterpolatingFunction[{{0., 0.013}}, <>]"& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.662624496599176*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"deriv2", "[", "VE", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "VE", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "VE", "]"}], ",", "2"}], "}"}]}], "]"}], "]"}],
      ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.6626235494568357`*^9, 
   3.6626235537922993`*^9}}],

Cell[BoxData["603.0651210311946`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.662624496679113*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"plot", "[", "VE", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<z (m)\>\"", ",", "\"\<F (N/A)\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, {
   3.453838538440839*^9, 3.453838572806719*^9}, 3.463844247723119*^9, 
   3.478894943196905*^9, 3.4788950132010527`*^9, {3.478961709433363*^9, 
   3.47896175216029*^9}, {3.478961842569364*^9, 3.478961894377494*^9}, {
   3.4789619830038633`*^9, 3.478961984506156*^9}, {3.4789699280628653`*^9, 
   3.478969982243393*^9}, {3.478970021389124*^9, 3.478970165180615*^9}, {
   3.478970224319232*^9, 3.478970261501657*^9}, {3.4789703108875017`*^9, 
   3.478970348344078*^9}, 3.478970398020482*^9, {3.478970871122594*^9, 
   3.47897087265033*^9}, {3.478971414854863*^9, 3.4789714317583723`*^9}, {
   3.4789723334965277`*^9, 3.4789723911200447`*^9}, {3.4794964690726423`*^9, 
   3.4794964944567127`*^9}, {3.479496975356181*^9, 3.479496976183571*^9}, {
   3.47949787094656*^9, 3.479497874578391*^9}, {3.4794981429899273`*^9, 
   3.479498147044504*^9}, {3.479498193967552*^9, 3.479498236581649*^9}, {
   3.479662116006764*^9, 3.479662117075882*^9}, {3.479666955542605*^9, 
   3.479666963425733*^9}, 3.480262070375884*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], LineBox[CompressedData["
1:eJwV13k4lF8bB3C0iBTZWlCWlKLIFjX5oj0pLZQKvyhrlphhnllE1nlarUmJ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"z (m)\"", TraditionalForm], 
    FormBox["\"F (N/A)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 0.013}, {0., 0.013119230032904723`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.480262195466113*^9, 3.480692274101901*^9, 
  3.481941952516597*^9, 3.662624496743587*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fz", "[", 
  RowBox[{"VE", ",", "0.0064"}], "]"}]], "Input",
 CellChangeTimes->{{3.45375087506522*^9, 3.453750875607725*^9}, 
   3.453823640650034*^9, 3.453837393601057*^9, 3.45383890126833*^9, 
   3.4538394359743757`*^9}],

Cell[BoxData["0.013117074132794832`"], "Output",
 CellChangeTimes->{
  3.453749602972189*^9, 3.453749666574046*^9, 3.453750876352957*^9, 
   3.453752731604185*^9, 3.4538236694422503`*^9, 3.4538259483409157`*^9, 
   3.453826469350016*^9, {3.4538373992114477`*^9, 3.4538374256931763`*^9}, 
   3.453837477368595*^9, 3.453838646018355*^9, {3.453838905538686*^9, 
   3.453838910306279*^9}, 3.453839436745421*^9, 3.463844880639366*^9, 
   3.4802621955329037`*^9, 3.4806922741384277`*^9, 3.481941952544153*^9, 
   3.662624496811386*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"oldsweetspot", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "0.0254"}], "*", 
    RowBox[{"0.205", "/", "2"}]}], "-", 
   RowBox[{"0.0254", "*", "0.12"}], "-", "0.001115", "+", 
   RowBox[{"0.003175", "/", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.4537508826011543`*^9, 3.453750883775889*^9}, {
  3.4537527418735323`*^9, 3.453752742503742*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.0051790000000000004`"}]], "Output",
 CellChangeTimes->{
  3.4537496030114202`*^9, 3.453749666610465*^9, {3.453750887396463*^9, 
   3.453750909722947*^9}, 3.4537527433073397`*^9, 3.4538236694697313`*^9, 
   3.453825948369759*^9, 3.453837425726906*^9, 3.453838918528926*^9, 
   3.4638448806922894`*^9, 3.480262195562632*^9, 3.4806922741597643`*^9, 
   3.481941952586825*^9, 3.662624496879122*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"VE", ",", "oldsweetspot"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4537509122631893`*^9, 3.45375094919713*^9}, {
   3.453823640684885*^9, 3.453823640735626*^9}, {3.453826474859961*^9, 
   3.45382647576938*^9}, 3.4538373936510477`*^9, 3.453838901300256*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.026328`", ",", 
   RowBox[{"-", "0.012695220225685581`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.453750950353718*^9, 3.453823671960964*^9, 
  3.453825948604528*^9, 3.453826476451028*^9, 3.453837425763947*^9, 
  3.453838918661368*^9, 3.4638448807548018`*^9, 3.4802621956072607`*^9, 
  3.480692274189659*^9, 3.4819419526252537`*^9, 3.662624496930757*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"VE", ",", 
    RowBox[{"-", "0.010"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.453751088575416*^9, 3.453751089087048*^9}, 
   3.453823640769184*^9, 3.453837393699996*^9, 3.453838901333053*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.026417`", ",", 
   RowBox[{"-", "0.010337130337810325`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.453749683527301*^9, 3.45375109040812*^9, 
  3.4538236722686167`*^9, 3.453825948821306*^9, 3.45382648659874*^9, 
  3.453837425793631*^9, 3.453838918742206*^9, 3.463844880837522*^9, 
  3.4802621956487217`*^9, 3.480692274215329*^9, 3.481941952668998*^9, 
  3.662624496982448*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"VE", ",", 
    RowBox[{"-", "0.003"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.453751094726705*^9, 3.453751095317946*^9}, 
   3.453823640822011*^9, 3.453837393750527*^9, 3.453838901368658*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.027174`", ",", 
   RowBox[{"-", "0.009243782811928638`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4537496838232193`*^9, 3.4537510967086277`*^9, 
  3.453823672557324*^9, 3.4538259490222588`*^9, 3.4538264890979757`*^9, 
  3.453837425851626*^9, 3.4538389187839413`*^9, 3.46384488093897*^9, 
  3.480262195696735*^9, 3.480692274248917*^9, 3.48194195271663*^9, 
  3.662624497032889*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sweet spot relative to centre of coil", "Text",
 CellChangeTimes->{{3.453823657396553*^9, 3.45382366152324*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"VE", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"-", "0.010"}], ",", "0.010"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453750960628242*^9, 3.453750962514122*^9}, 
   3.453823640869858*^9, 3.4538373938007517`*^9, {3.453838657031551*^9, 
   3.453838662984824*^9}, 3.453838901400448*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwt2Xk0VP//B3CRJcleoWQpslWKlCUvSyqVpE+lxRIlhbKbuTNjbDPM3EJp
04JIWUqlRVr0sksioQ1JQhtliajk9/6e8/vLeZyZOe773tfz+X7PGS3vwC0+
oiIiIjemiIj87y/vVY75BxYPJWQ1zLIM+dgqXzKQx+Bhas6uLbuX8NF4Q1NO
SBgPRRp4esomfGzHvzOnHuaht6TbJM+CjyZ5LkO6Xjzkng+02evIxy72n/yA
tTysc11cruDLRxst57ljSjw09FnYvCiLj3/9R//JFsRhT1iC44rZ8WiV1YN9
9bE49dI8hzMzEpAeb+o5MRGDzHVpstW9CbhgbYaTy9IYdOlJ/jLrqgDjl8sU
Pv4vGieenul67yvEyg+LjsZtjsav/svMD/oJUTTJ2XedUzQ+6n72ZiBAiJG9
KepNa6JRXyyz/3ewEMPOqNI95tF485XKut9sIXqP6+6V0YzGQrVdp7OThchh
xRnceROFtv1HpNLvCnGsqbpzVVMURuvu/tB/T4ihhtJnauqicK7029eWD4To
135MrO1xFHbGHlJpeizEHdbp7VMuR2EP70HZpxohmoreT3IOjsKo2rS4ordC
7BN+H/o6LQrHHk1b+uaPEA9/ktX/KhqFCnMd18/8J8SB1Us8v/zh4oqfgnFn
ERqHJwPrPvVzcXSdrNLjqTT+Dh+81P2Ci5Lt66dEzqBRyvvn1o6zXKzjOtvz
5tGoY/G76IU+F3+qc+dfs6bxyhm1/kZtLu7ZmXIu1YZGvRGL+Y1zuCgrXxMY
a0ej0U12csMMLtolpS7atIZGU90J37rBSDw6R666yolGO0UR1ar7kSh1X7vb
xI1Gj6/i7GLHSExemX91MoLGFFi+941dJH7+rr4okUlj9cl9G8YsI1GHO/B9
NovGxVAxZ+XiSMyx+bVYJ5LGyRPRj+4pkteVfUPmxdF4cdWfiaI2Dp4tWpBB
J9HYkmLQ+6qFg5tydQK+JZP1fd7ZMFrPQVn/uXscj9MYlFKcblbKwUfrI4v+
nqDR9lM4FGVzcH0N/cPmLI1dxwai7x7i4HIdhoH1JRpn9WocfLmfg2cqVl0O
yqZxvaWzy4gnB7uttiy6eJnGWz0FWsu3cPBlvaznaA6NcRb+5XfMOGjqd1Mt
6hqNC7p7xO5MsvGyy39JIndp3GE+s695jI1Fk1fUxYpoPJq0umV4kI0SGbUX
Re/ROLLyUrZJNxuDlmtyxorJ/Ujc43D7CRtdq8J34yMafVe0xd86zkZ7VTf3
4goasyOXPVh3hI2TT3IpdiWNnRXC/g4eGy+4B7+1rKJx1+aVW6cz2VglleRx
p5rGjQdPae3zYOO/GOfdvFoaBTf6tv52ZWNoon/Q0qc0Vo3YC465sPFdngi2
EVvHDn1/tJqNRlf3iek9o9H4vPOjmYZs7Pc5LZnRQGPAhys/ri5go9z821XL
n9OYt/Cftt08NqZUut+uJda+c014WIGNFOxX+dJIo3L9NNeaXyxcojf3k3gz
jZuVvGj3QRYq1JtP8okTdxaXDH9lYZ+I8iqxFholevcv0Oxg4elD6jojxOP/
KgaZlSyMnsnkFb2i0cxhjo7cYxa2rlp9ReM1jSFHQnZcvsfCyEarXj5x32wt
fJHPwn73wLuOb8j8ejCHfLNZmG9ta5dD7JP9XOdfGguFSY69U97S2GHMPWpw
nIVJnssCrxOrMV5iKc3CNu51F5FWGl1LjIa381i4dEPqGmfiRse2nXEMFoZ7
DXp3E8scW5aoGszCnTGzBAZtNDq+Epbe8GPhSPuLB4eIy71XLmx3Z2HGnwvw
jfhfbvKuEFcWjps5ndRpp9HyR2+ilAsLv8/oHXQjZi63Lktfz8Ityg6ux4nv
sE/9NF3Nwigpk4py4oGyvoV1q1gYYHbWdJB4kdTq3V4rWOiw1zZ/7juS35ND
ZYkG5PMzr6X5EXe1Oo7MX8BCJWU11URiDa1MvQfq5HoltE5eI3bzHdu9eTYL
J36dmVFLnFrgnNwrz0JPznZeF/HL4SvlHGny+Rumv8aIFS3+jShOZWGD6XQf
mQ4aN0Vv08+boLDZ8vazucRHqq+5wS8KjSMlFhkQNyh8kNswQKFL502b5cTy
7jMrtn+h8EpnV5kV8X+5jhHeXRQ2RSy8YUN8ejhS/3Abhbme0pK2xG+tb7VT
LRQuUld5sop4Lt2bzK+n8NmvdwNmxJ4v1eyPV1OYPfklyog4S9N59AJSyJhR
FzqPuMc/Li+3mMLnFfJ1/7tevXv33O4UUph1bAPvF1mPn2ifXGk+hU8LZNI7
iAucNCvqLlF4Tbt3VjnxQOrWiNcXKJxz03okk3hZt0D/4ykKO4Zl9LjE4UtK
2r8nUagxlnN3O3ExazD5dwKFfYIbFwyJ/1Tp2EvEUNj+vLDtL3le1gq7RhVY
FMJtx+CnxDFuSXnqoRSyxmTdThJX5pS76QdQ+Mvy3LldxJLDo3LLfSiMG+QZ
qhOvtzassPGgUH//wRntZJ6et5zQ37GZQu0QweNNxIqaT9r3OlJ4jCNyRJR4
q//f5EA7Cr2lu7NukXltneIzGm9K4YDnkzxJ4t7FZhV3VSiMerxRjk/yoc/y
iyhToDDybY78HOKAqnT9emmyvhmcLQUkX4O7JY91/2UiP2lhSjXJ41/BGzel
D0yM6exuqyN5hRYZeY1WJqbucHtoTxyrYVth0MxE15CTjfdI3qWK8vTtqpgo
Ivr39MkmGpU+skaD8pioKtZyWJP0xfbFN/I4WUxM8w9/TZE+SaU+ugnOM3Hh
it3+z0n/zJPfWJGRyMSc5U/kAutpNFilfqwhmIkqpY4Lo0l/2ZxBfSMLJlqu
zQ/9TPrySPMcvesmTMwrV3FQIn4lx9Q1XsTEsltW1y3KaTwkMJ5vqslETads
+6hSGs9RmXOtJJhYWqjm+Z7078/dcXIbmxjYeoTB+X2HrC/1/YyGOgYeO/py
y/fbNNItljKbqxj4k726sOMWjVpOP6W2FjNwzZBA9O5Nkg9rH1G3dAb2L1/T
voLsD7maa0f8/RjYpWB84VQW2a/dLg3372UgZR4a55JJ5uPs5GCgOwOrR8c/
TrtI8qdQ/D10MwOtDqyaEZRGo6iY/me2GQPzNR59Ukgl+e2RbjsiysCtH8+M
5R8l+cpvKL16LgJ3l1w6axRKo2yHefCmkxEIa51yucE0Tle8rDWYGIFL+5PM
6wNJ37LYsWYxEdir/q3TM4DGCUe91WW+EVh7vmDxbh8av36JqXllGoGc69aL
8raT+dRf3jDleTi2cxJL08xIv7lf5GY/CUels6k1XFMa8fj0JWvLw3HRgjhL
t2U0Phj/kHz0bjiafOH6yiymsbA2yWX2hXD8t8XIAHRoTD/4ucXoYDjuUz/n
PKFI+i/vfJurWDhOpRsEFd/I+arr4/Sgv2F4+07Kp7HPQoyeY2QlGAnDlgcj
f/R7hShIfHSh+FMYypjPso/qFOKZ4Hfuqs/CcIl/rPloixCLzDU6W0+G4bx3
DbYzS4T4szar2103DGPNp3xUosl5TfSbcoRGGE5JF2l9HC/Ev5YmDkkqYdis
tC3cJ06IU69XXH4sHYYdO1ecucwRolJK936NH6Fo+OsZe/CwEJft0v3SeS8U
g/edDLi3RYjBX/P69zqG4sWX2Z7js4TIVVY7OGQXijGPvzzcpSRE2prujrYK
RfUrUvbFckLMSvFrS1sSisZWYi98pYTYYmFY+3pmKJreCO9NHReg2ZFr2Ru6
QrBs75Hndm0C/GN4Y7cJOwT7xl3O3zkvQP6hO7WiBcE4/WOnioyCAFMvTKmS
uBKM3Nayq8oyAsyv21QqnRFMzmdH7qtICrBR/0uR4vFg1GfsXKM0kYBqverZ
2uHBWDy9Va/pcwJe90jg2q0KxvvjuWTKEvCN8y6T2PogfK5qNu55MAG37ROx
EGsPxBfdiS9LbsRjR2HxyY0NgdgXcLusIi8eD0wG/ThVGoj27UG+VZfikXPu
Q7be5UC8Jlv/4eGZeMxuLJfbdDgQd+ydlRkeFY8/rfg9qSKBOJsdVjN3Uzym
zJQ+vljnMGa2fx1c9ZmPz6uVPu88HIBTdr5+PiTHR26BhsEry4Po9K/fX8Ul
DjfPvr5LsdIHt8SJf1c3jsEd4ss1whK8MdFc+djpyUgU7+dkG073QPircNO5
g4nFMQmqWnqu2P3q/L7T0aH4al5ckdfDzejQH2eyPz4Aw3iSXqsF9mhiWPP2
QN0eXBd09cRhVQNcv7dItzlhDW5In9Zz6bMe/FCNCvgZ7QAF6T7vCuRWA+g6
Xyqz9gKmd/PKTZzNYKHWfD9LPQC2/vh+2YHtCtYuG5/8Kw+FplrFqUd2eoDU
73sWx1QpGKrXTivf4w1c/TvlorWR8Pb2/drJtz4g9phXt946BuiZO7xnqxyE
p9Vly7ZZxYFMOmv4pUMArF3vbq/zhwf+l9ROtxQHwkJjk3rPi/EQZLvt9+2q
QNCdkcUQvRIPYe+TPU40BcIHE2mPzKvxwJ0jvnBLXyBkiMu+ay6Khye1v9o+
yQXByJB66vT6eGiz7QrwsQ+ChPwVuVVj8SCy7F7SnvwgSDK8kuHllADrFb2a
tjODofZcbLDetwRY45Y51SUqGBR3WKlZDSSA3ZUPZhvig8FjfIrthpEEsLDw
Pg8ng8G4XlHKbTIBDLz37tO7GQwxJq7MtUoCmH7LZ3T8UzDopnvVOFgI4JmL
n1qaawiYx6/Nfc8TwJPz+RvPeISAh/pIj7dQAJU9X7nHfUIgpnQs40OiAB5R
/h/5oSHQEmwlfHFaANcyA64dTg6BXw5Xl7FzBXB08LC1TU0ISIPL6MhTATgd
D/X+aBYKS7uDbWkZIdh8PeLouyoUQp4dDrOQF4KpfbbxN/tQyFys+qhXSQhz
R1r+DW0OBbk3LrTJHCF83WF2XtQ/FBghqXrp+kIQaI43a2WEgn9OUdY9ByGU
3+A67JEMA71XiVETLCEUSZ0x6p4RBqYBz2qNuULI87qhdEA5DGqjvi3dEyOE
Y0qdHwK1wkD1iZ377QQheDJsuVGWYRDk3WFgeFIIf62n3ksPDINTJiPje64J
waxBqPfudRg83de9//NbITCWnHC36QiDD/mzMlLahVB87ELKpe4wuHDKWN/8
vRAs/7vx9+BgGHyzll7O7ibrfdPSOCodDrESKubN34WwvkuDkrcOB5GYBfua
RWnwGL1ba58dDj/ZkVIqejRkuOK/K/nhEHnzb7STAQ2dxU9MpAvDIfPP8YEY
Ixr2stvSGkvC4fC6aS2txjQcEJkS4v46HJosF3h4mdMQIr1RjSEdARyjPply
RxoS5nX55QdFgNSxqsBXvjSUs2Q1UxkRMNE9ehEP0jDxyuIlnxsBXwfYV7P9
aQhNPgFeRyNAs8dqs3cgDZ4iDsoquRGgGyk5fDWChhVdOSX89xGwS18+nOKR
/2fdEhLaGwFfnipf14ynoeCciJ5XfwTsFw4+r0igYf5/O1Os/kRAyxKTpgma
BrlKad/hWQyY+9Kv3+Y4DZ8uH5L32sSAbbLLfaem0aAteq5q0zYGVJ3YlueX
ToO7RzXLyo0BUZtEe55l0NA8S6Nnth8D1jvsdOJn0YAJjfcb+Aw4EJQpUp1D
w5mDJnutShhQJx74NaGQhqYqTxWDSgbsFQw5Xr9Fwwzto/Wz6xigXPjxTuNt
GuJau1cMv2HALGZl4bQiGgI3nJbJ/8kAm7Djvhsf0LB20fjd2UZM6Ilwejaz
nAZW6oRG8jImiPXnzvlOfE1MlJYwZ4JhU/i0igoaFFulPUYcmNCe7FbpXUVD
e/xciWZPJsx7sa2ZekKD7JBm0Pr9TFhhsWTZiloabN11WssCmGAZHLVikPiK
yeLrNykmNAUzzXfX0RDUCduTTjDBqUB9pWQDDVkbVpeKn2OCwuP1n/KIXxat
M4i8yAQrxgIHx+c0WCS6/PMvYELhewkFbiMN4hZ7rzjWMKHN+LlEaRMNKy/7
ypfVM6Fkava6dc00+MkHsFa2MOGtE21bT9zYG7Zp4QcmLLKpc6tvoeHcifjR
qX+YsEBKwvXKKxqe/aP3cKZQwOtbF6j8mobJg8lPhyUpyGMsWRtFvM8mNb1L
mYL3JassNryh4fTVC1K75lCwdX2K6zXi2lmZIS+0KCiY171S+i0Ni/vz1pQu
pqDkWueGR8R7dly/uWI5BWJnS6LkW2k4UXFL7YYlBSn7z8Z4EY+dffg9bR0F
/XMyX48TG4qX7pjpTEFqdbaJbRvJU1Bl+dFtFDhfjHTjE1esqT/N9qagVkNW
dWo7DaOFL0SGD1DAFpG8YU2sp/7Kzy+QguR6x1kRxLsFrS0fwinwDR11zidO
Gu6w3smhwCB6kXsbcanHx9zGWAomtOVh2jsahms/Ka4TUiBnWDpqQqy7vI+D
yeR6FNz4u4l3XBzoNTtNwaIW2b4oYnr6yObrFyjwOj9oSL7fQEnE+AOdSxQc
uutjjcQDHyYWpOVREJK4yLSVWNtJNFn5JgXd6eckhoi3FkuMHymi4JlYc5FE
B8n3/Ol7xUoo+BU44aBC/CBJrp5VQcEKY9u7usR940orhmopCNCvFl9GrLLH
UutnIwXczKWVFsSrq72nj76mYHFpeBsQBxnRI786KAg8MMOJfB+EtJTC9+M9
FCSuD1P73+tPx97U/umj4GKXroM58aiHyJ2JYQoSGFkNS4i1qxamT/6mIEvV
p1ibeJOhs2CKKAsyM/vFFIlZxyNCxKaxYM+Nh7cmyHpyfqW5icuzIDDXubqH
uMW9ao3kbBasumdg85RYpLLPeNo8FtC1DVpXiY0MlOdM12GBZ/LjAMH/7u8x
S/EZRix4RUVqexPzRr1/yJqwAO8nr15JXOhGv5W3YAHPmtUiTdxRXlihaMsC
6bvlzW/J85TWf1ugvI4Fm+J/2F8m9h5ZGKuynQUKRvMil/7v+e92DlBzZ0Hs
Ex3HITJPD8sits/dxwKYXHj0BrFyUpWBZggLhDr7YzWIbX72KWtTLIiXyTVp
IvMZsEt5cn40C2Tal3rHEFfp7m1emMQCv/EZq16SeY9AEc6SfBYMfKVm/kfy
kaWjt39pIQuyrb61fSF5ajjivNmkmAWiRySNIokX7khfsKKaBVUiN4PPkjy+
GbCst+4i13dJ5FYuyetU1733bL6wwOLZl8H5xMYldKbdAAuq7bWenCf5Fgrf
hq/5xwLz629WxZA+sNBmzNukxgazzQrs+aQv9gvSpTZrsWH5LtVzcaRPUr5X
DbnosWF2kIVbJ+mbbw+Ua7aZsUF//crG5HoaLvx3K9B9CxuEsUezq5+SPuD1
lwbQbHDYUnTgVCUNzGHxcafjbJijmLGvkvTjkNe8pUtS2UCVFFsOkP7stXbO
HLzMhvczvsRYl5H1jt2MiShjg6zE/rN3S2hIDwizix5jQ1AIb6sc6WeVtqMs
r0k2rHbKR5m75PocL9+yk+CAT7GmhuQdGuJ1X2mLK3NgusfBsiHS/4c7V4jR
SzggXb8HLxfQsGrrn4oT+zlgs7hrKiebhqJypb9hhzjwXP55qOMlcr+WGplu
DyPvH9gwoET2lwWy7tkqsRxwLmCoXiT7j8yTx7y0NA6wIzNdT50j/W4Z65DT
wgEj2/H+n8k0sOdPq3lgFwlL5KRen2CS/F0cv63jGAn3VBL6NBmkn+Z9vXjM
ORJi1nlkXA2nwU61jrXfLRKamy913g+hQUoucbFiRCQUhDwZvR9Aw8nf8qcP
5kVCQFLzecc9ZL95oeKjIs8Fo8kfWjcdaJjnPG1L3Cwu3HlR7jNsT0Pys3Hr
73O5IO45O9jUjuzPNa0qlfpcOJV26eMNa9L/JReeBdpz4TfnnfvRFTRU5mqa
1kRwYYrNleZ2cv5oj9ITi3jHhbB7uUY908j+N2YZ5N/NhQ9URkaxJA23gpzf
7flG3PkxVyhO5skr4t6GcS74yhjzF0yhwcy+0l9rZhT4v3h2ctUYOW9J7Gl5
tjEKEs9j8r8eIaxOPHN5/qMoeKhyrq8GhbDdSSz7gFM0ZKdQl14HCEFKYdw0
d3M0ZPxWYm/0E8L9lu9Vn/6Lhpz7UmfQl5wP3Vo/7d8VDdMnnTMveguhy6/Q
0Mc3GmR9D+hu2iGEQwLP214x0TDf5N+CHfZC4FU8LN91Nxq+Tz52W6oihELz
sA8b1WOguHPgrX2JAHCJxDu1LzFQaj2wZ82fBJjK/9W+sjoWeKFabztmJsCq
+18ZiSfjoOfo1UONy+LhVsFgtW5qHDxVUi6qXBwPelljM0vPx8GvtY92FhvE
g+IRiTtDWXFgZT63OE07HnrdtAdcC+PAf/aC0T2K8ZAksuuAdkMciJ6RSHs6
yIfOtbU77knyYHLt7XSTm3zYZtWYs3k6D2rOirfMvMaHp8avR7/I8kBzY0bi
rxw+3FHtOTl3Fg8G/tSk3M/gg/CbyIuYBTzILtwhuTKZD8uSVzputOXBptCP
qpqH+ZATB6k9q3nQ+AB0/xzkw1zmmk/cdTxQKNlV99KHDxJeW/mFzjxY2vOm
U+jOh7ZlQWWzPHhgNGA30LeRD5sXMuRvevEguqSqvXIdH6rncD0dfXjAqmH4
XVjNh5tTj06wA3hwuVPh8HorPuiMp2ycGcQDJ532Hs2VfDjXf/b89VAe9J74
KvbLhA9yXRe/rmUQT//55NkSPvz/71vw/79vwf8BH8d/hg==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{-0.01, 0.01}, {-0.013119228389129337`, 0.013119230426742427`}},
  
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.45374974088566*^9, 3.453751021464161*^9, 3.453823734388617*^9, 
   3.45382595105693*^9, 3.453826495876092*^9, 3.453837430614188*^9, {
   3.453838660033111*^9, 3.45383867436195*^9}, 3.4538389289668913`*^9, 
   3.46384489286368*^9, 3.4802622059949303`*^9, 3.480692283838723*^9, 
   3.481941962908568*^9, 3.662624508597904*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"VE", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.0", ",", "0.01"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, 
   3.453823640937874*^9, {3.4538265543875103`*^9, 3.453826559178968*^9}, 
   3.453837393850636*^9, {3.453838705965811*^9, 3.453838717842711*^9}, 
   3.453838901436325*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwV13k8VN8bB3CypJJCSVnL8qVVuyQfhCJkiRZLkZQSKmbm3pnJNoO5qKSi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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0., 0.01}, {0., 0.01311922977134438}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4538234640829372`*^9, 3.45382375947115*^9, 
  3.453825952943671*^9, 3.4538265081040163`*^9, 3.453826563804844*^9, 
  3.45383743232346*^9, 3.453838725272155*^9, 3.453838935442772*^9, 
  3.463844900055211*^9, 3.480262212578673*^9, 3.48069228997019*^9, 
  3.48194196963024*^9, 3.66262451582117*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSdata", "[", "VE", "]"}], " ", "=", " ", 
  RowBox[{"FindMinimum", "[", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"fz", "[", 
      RowBox[{"VE", ",", "p"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"p", ",", "0.005"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.453823404829797*^9, 3.453823405956604*^9}, {
   3.453823506088236*^9, 3.453823516693254*^9}, 3.453823641011278*^9, {
   3.4538265379087467`*^9, 3.453826543745769*^9}, 3.453837393910678*^9, {
   3.4538387257460747`*^9, 3.453838749683352*^9}, {3.4538387973199577`*^9, 
   3.453838821469616*^9}, {3.453862450307226*^9, 3.45386248039209*^9}, {
   3.453862568949154*^9, 3.453862570115514*^9}, {3.45386264847299*^9, 
   3.453862649636854*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.013119230572841676`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", "0.006315454198548418`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453823468555167*^9, 3.453823535452108*^9, 3.453825954168241*^9, {
   3.453826526324848*^9, 3.453826545225122*^9}, 3.4538374328189507`*^9, {
   3.4538387298936996`*^9, 3.4538387449128933`*^9}, {3.4538387984605837`*^9, 
   3.453838822542676*^9}, 3.453840162093855*^9, 3.4538402359560423`*^9, {
   3.4538624679971113`*^9, 3.4538624812382927`*^9}, 3.453862586264966*^9, 
   3.453862659344542*^9, 3.453862832601221*^9, 3.463844900650577*^9, 
   3.480692290440241*^9, 3.481941970310296*^9, 3.662624516428594*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSpos", "[", "VE", "]"}], " ", "=", " ", 
  RowBox[{"p", "/.", 
   RowBox[{
    RowBox[{"SSdata", "[", "VE", "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.453862483701729*^9, 3.4538625105182133`*^9}, {
  3.453862576749049*^9, 3.453862581411574*^9}, {3.453862650555091*^9, 
  3.45386265144018*^9}}],

Cell[BoxData["0.006315454198548418`"], "Output",
 CellChangeTimes->{{3.4538625068641663`*^9, 3.4538625109082727`*^9}, 
   3.4538625864136257`*^9, 3.453862659454235*^9, 3.4538628327231894`*^9, 
   3.463844900679907*^9, 3.480692290473279*^9, 3.481941970349381*^9, 
   3.6626245164738493`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSpeak", "[", "VE", "]"}], " ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"SSdata", "[", "VE", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.453862473476694*^9, 3.453862474190342*^9}, {
  3.453862598812314*^9, 3.453862615921789*^9}, {3.453862652024186*^9, 
  3.4538626531996193`*^9}}],

Cell[BoxData["0.013119230572841676`"], "Output",
 CellChangeTimes->{3.453862616387323*^9, 3.4538626595105743`*^9, 
  3.453862832777169*^9, 3.4638449007258987`*^9, 3.4806922905067368`*^9, 
  3.481941970402519*^9, 3.6626245165282593`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["New coil calc for alternate value-engineered LIGO-I", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
  3.45382361286519*^9, 3.4538236144707003`*^9}, {3.453838874626217*^9, 
  3.4538388807274017`*^9}, {3.453841072413919*^9, 3.4538410760356073`*^9}}],

Cell[CellGroupData[{

Cell["\<\
VE2vals = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->lold,\t\t\t\t(* length *)
\t\ta->aold,\t\t\t(* radius *)
\t\t(* coil length *)
\t\tcoillen->0.207*0.0254, (* D0901048-v4 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.334*0.0254, (* 0.334=0.498-0.164, increased from 0.302 *)
\t\tcoilarea->0.347*0.164*0.0254^2, (* desired area, same as VEvals *)
\t\tcoildr->coilarea/(0.207*0.0254), (* desired difference in radius for \
desired area and length from OOvals *)
\t\tcoilrad2->coilrad1+coildr, (*  *)
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453819143842659*^9, 3.45381916873015*^9}, {
   3.453819205916604*^9, 3.453819229397924*^9}, {3.4538192680904627`*^9, 
   3.453819317992671*^9}, {3.453819379538721*^9, 3.453819381962309*^9}, {
   3.453819414835219*^9, 3.453819449256628*^9}, {3.453823205503562*^9, 
   3.453823222597754*^9}, {3.453826073117807*^9, 3.453826150751071*^9}, 
   3.4538373389188223`*^9, 3.453841092308299*^9, {3.453841283965046*^9, 
   3.4538412881475286`*^9}, {3.4538413725493402`*^9, 
   3.4538413849806833`*^9}, {3.453841501978483*^9, 3.453841779519685*^9}, {
   3.480274240165839*^9, 3.480274249772677*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.00006696614374535086`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.014824999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.005257799999999999`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.0026288999999999996`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.0026288999999999996`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.0084836`"}], ",", 
   RowBox[{"coilarea", "\[Rule]", "0.00003671476528`"}], ",", 
   RowBox[{"coildr", "\[Rule]", "0.006982914009661837`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.015466514009661838`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.089479932527026`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4538417843516493`*^9, 3.463844900775058*^9, 
  3.480692290540955*^9, 3.481941970502873*^9, 3.662624516578066*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "VE2", "]"}], " ", ":=", " ", "VE2vals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, {
   3.453823624487136*^9, 3.453823640631469*^9}, {3.453837378474317*^9, 
   3.453837393571328*^9}, {3.4538388861923847`*^9, 3.453838889904484*^9}, {
   3.453841247783547*^9, 3.4538412572609777`*^9}, 3.4538417923838587`*^9}],

Cell[CellGroupData[{

Cell["Sweet spot relative to centre of coil", "Text",
 CellChangeTimes->{{3.453823657396553*^9, 3.45382366152324*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"VE2", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"-", "0.010"}], ",", "0.010"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453750960628242*^9, 3.453750962514122*^9}, 
   3.453823640869858*^9, 3.4538373938007517`*^9, {3.453838657031551*^9, 
   3.453838662984824*^9}, 3.453838901400448*^9, 3.453841257421837*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwt2Xk4VO/bAHBJKhVCFMqShERJVORuoayhVMguZctu5sxYwow5R0iLSipU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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{-0.01, 0.01}, {-0.011911333952301924`, 0.011911334632164655`}},
  
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.45374974088566*^9, 3.453751021464161*^9, 3.453823734388617*^9, 
   3.45382595105693*^9, 3.453826495876092*^9, 3.453837430614188*^9, {
   3.453838660033111*^9, 3.45383867436195*^9}, 3.4538389289668913`*^9, 
   3.4538418441367064`*^9, 3.4638449203570347`*^9, 3.480692306252309*^9, 
   3.4819419881990843`*^9, 3.662624531874794*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"VE2", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.0", ",", "0.01"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, 
   3.453823640937874*^9, {3.4538265543875103`*^9, 3.453826559178968*^9}, 
   3.453837393850636*^9, {3.453838705965811*^9, 3.453838717842711*^9}, 
   3.453838901436325*^9, 3.453841257441544*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwV1nk8VPsbB3BaLCVdYkKUkKRLlBTJB1kiZBfJTlnKNmbOGLthThKhK0LU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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0., 0.01}, {0., 0.01191133464487429}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4538234640829372`*^9, 3.45382375947115*^9, 
  3.453825952943671*^9, 3.4538265081040163`*^9, 3.453826563804844*^9, 
  3.45383743232346*^9, 3.453838725272155*^9, 3.453838935442772*^9, 
  3.453841854513754*^9, 3.463844932499839*^9, 3.480692315858614*^9, 
  3.481942001190299*^9, 3.6626245411818647`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindMinimum", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"fz", "[", 
     RowBox[{"VE2", ",", "p"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.005"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823404829797*^9, 3.453823405956604*^9}, {
   3.453823506088236*^9, 3.453823516693254*^9}, 3.453823641011278*^9, {
   3.4538265379087467`*^9, 3.453826543745769*^9}, 3.453837393910678*^9, {
   3.4538387257460747`*^9, 3.453838749683352*^9}, {3.4538387973199577`*^9, 
   3.453838821469616*^9}, 3.453838901466652*^9, 3.453841257454495*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.011911334644952153`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", "0.0059628691227386005`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453823468555167*^9, 3.453823535452108*^9, 3.453825954168241*^9, {
   3.453826526324848*^9, 3.453826545225122*^9}, 3.4538374328189507`*^9, {
   3.4538387298936996`*^9, 3.4538387449128933`*^9}, {3.4538387984605837`*^9, 
   3.453838822542676*^9}, 3.453838936153399*^9, 3.453839519837987*^9, 
   3.453841855442709*^9, 3.463844933406391*^9, 3.48069231649853*^9, 
   3.481942002157364*^9, 3.6626245418391943`*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSpeak", "[", "VE", "]"}], "/", 
  RowBox[{"SSpeak", "[", "OO", "]"}]}]], "Input",
 CellChangeTimes->{{3.453865307265691*^9, 3.453865311272402*^9}}],

Cell[BoxData["0.8271099479070376`"], "Output",
 CellChangeTimes->{3.4538653118630533`*^9, 3.463844933516652*^9, 
  3.48069231654394*^9, 3.481942002211248*^9, 3.662624541891303*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["New coil calc for AOSEM (D0901048-v4) and LIGO-I magnet", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
  3.45382361286519*^9, 3.4538236144707003`*^9}, {3.453838874626217*^9, 
  3.4538388807274017`*^9}, {3.453841072413919*^9, 3.4538410760356073`*^9}, {
  3.48069476991868*^9, 3.4806947920213118`*^9}}],

Cell[CellGroupData[{

Cell["\<\
AOvals = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->lold,\t\t\t\t(* length *)
\t\ta->aold,\t\t\t(* radius *)
\t\t(* coil length *)
\t\tcoillen->0.207*0.0254, (* D0901048-v4 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.304*0.0254, (* D0901048-v4 *)
\t\tcoilrad2->0.996/2*0.0254, (* D0901048-v4 *)
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453819143842659*^9, 3.45381916873015*^9}, {
   3.453819205916604*^9, 3.453819229397924*^9}, {3.4538192680904627`*^9, 
   3.453819317992671*^9}, {3.453819379538721*^9, 3.453819381962309*^9}, {
   3.453819414835219*^9, 3.453819449256628*^9}, {3.453823205503562*^9, 
   3.453823222597754*^9}, {3.453826073117807*^9, 3.453826150751071*^9}, 
   3.4538373389188223`*^9, 3.453841092308299*^9, {3.453841283965046*^9, 
   3.4538412881475286`*^9}, {3.4538413725493402`*^9, 
   3.4538413849806833`*^9}, {3.453841501978483*^9, 3.453841779519685*^9}, {
   3.480274240165839*^9, 3.480274249772677*^9}, 3.480694811626128*^9, {
   3.4806948459029713`*^9, 3.480694858042783*^9}, {3.480694900775441*^9, 
   3.480694950070912*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.00006696614374535086`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.014824999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.005257799999999999`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.0026288999999999996`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.0026288999999999996`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.0077215999999999995`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.0126492`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.5439046765338914`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4538417843516493`*^9, 3.463844900775058*^9, 
  3.480692290540955*^9, 3.480695055734477*^9, 3.481942002252563*^9, 
  3.662624541953936*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "AO", "]"}], " ", ":=", " ", "AOvals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, {
   3.453823624487136*^9, 3.453823640631469*^9}, {3.453837378474317*^9, 
   3.453837393571328*^9}, {3.4538388861923847`*^9, 3.453838889904484*^9}, {
   3.453841247783547*^9, 3.4538412572609777`*^9}, 3.4538417923838587`*^9, {
   3.480694812819429*^9, 3.480694813277412*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "AO", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.01577331278972314`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.005342368876734437`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"fz", "[", 
          RowBox[{"AO", ",", "z"}], "]"}]}], ",", " ", 
        RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.479667008672338*^9, 3.4796670332310963`*^9}, {
   3.480244318582687*^9, 3.4802443450940313`*^9}, {3.4806950416816607`*^9, 
   3.48069504236414*^9}, 3.4806950855740757`*^9, 3.480695391023115*^9, {
   3.480695424453774*^9, 3.480695426213916*^9}, 3.6626239713916283`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.015773312789729835`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.005342372488880814`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6626245970991707`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "AO", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV13k8VOsfB3C0EJLspIuSshNtwkebuCHK0kaijRBmzgwzk50yjDNZElGR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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 0.01577331278116163}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"AO", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.479666887455168*^9, 
   3.479666888838862*^9}, {3.480244879780376*^9, 3.480244897499516*^9}, 
   3.4802450058581*^9, {3.480695043059854*^9, 3.480695043824891*^9}, 
   3.480695087059374*^9, 3.480695404783731*^9, 3.662623973998605*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], LineBox[CompressedData["
1:eJwV13k4lO0XB3BLdqHsUpaQQrS+eZMv6i2K0kKSNt5s2c0zM2bsZBnLM4hk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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 0.013}, {0., 0.015773312781134165`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.662624605422865*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "AO", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "AO", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.479666890574193*^9, 
   3.479666892310862*^9}, {3.480695044500922*^9, 3.480695045299432*^9}}],

Cell[BoxData["0.005342372488880814`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.4796669544241667`*^9, 
  3.479667628122774*^9, 3.480244912925961*^9, 3.480692316685502*^9, 
  3.480695182351778*^9, 3.4819420024634247`*^9, 3.6626246054880657`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "AO", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "AO", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.479666893782012*^9, 
   3.479666894910797*^9}, {3.480695045805807*^9, 3.480695046244318*^9}}],

Cell[BoxData["0.015773312789729835`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.479666954466415*^9, 
  3.4796676281467333`*^9, 3.480244912993281*^9, 3.480692316727179*^9, 
  3.480695182407237*^9, 3.4819420025016727`*^9, 3.662624605533827*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "AO", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"AO", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, {3.6626235658776608`*^9, 3.662623567527854*^9}}],

Cell[BoxData[
 TagBox[
  TemplateBox[{RowBox[{
      StyleBox[
       TagBox["InterpolatingFunction", "SummaryHead"], 
       "NonInterpretableSummary"], 
      StyleBox["[", "NonInterpretableSummary"], 
      DynamicModuleBox[{Typeset`open$$ = False}, 
       PanelBox[
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{}, {}, {
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVyGlMEwYAhuFyCF5DKDIuB8i1zAbGvS0cHxCMgE5aUGTiBKpQpFXOlrOl
Lb1baEeJASShG5PDMdhEQYiSGE4HbIAM5VgqjHmwzdLJRDnnfrx5kvcwNTM2
1ZBAIAS9639X67od2ZEvgwmEZPL+cMuQR+LS1tVBEs7fPKF71UDBY7peb/xP
EN7b3FVrEkvF8eXeQBX3KP7toc8orOiwM7AmTVw8gS93UR0X+rLht+Oa+LmO
glsxgrekYBbMPf0T4xmnYenew+BEFYE07tPi4vcF2IkXH9oLOCi9UFgevXwO
bl/vi2oP5kEQZz8d7ZWM76eKiBM7fDxvy1JMmlNBORhHp44KQKMaJDMmLiAi
OtzE97wIvIrObR9pKqbnKUkHxsQIzKP2J6bR0Bl8p9IoUIoDN6Oarrpcgtr2
GmsyW4aylg9/9DWho6PBcE2rkb/7R0RbWgZWFMQXKU0K3FugFczUXAE5ou1T
Dbscfd4/D8uDsvDVvE3D5YgK3HYwWfI9lI0FVnhKqrYC+endxHKzHNw1dKM9
SVNC/HK7sWQzByGNSZs7I0pcd1qMYs7mwrjG+2S7qQqV7aEEx5E8VN9v9rBw
UKF8OWhg4jsmmEJ1qsRdhemUEZ2dhAVqyuCeJRcVdP6/eljl58PNeN292koF
q86SIpv4AmzaXW3q3VRin7p+dvRYId5P2DC61alETOspjbV/ETbyEzVTSUpo
spvy6MRiqB7Pv6UQlLivZp7LMixBqDzepEVWAV3KQixnsQRT7t+aWltUgM7Q
tjn3siHgNP9eoCpH18MEh4JWDnIfjIVUbyhg/iyzblpWCi7tdCX1kgJ1JAPr
V8FcFCWovSL65ej8zJZW2sbF0PUH7Neucqylrr+YPsSDX4xnlZ9QBk1ozWtR
FQ8dJU8nu6akIOtFskBjPoqZ6Y77PaVIJ/s0R7L56NvrlXekQIKmscY3Tqt8
WPMXB+0HxPjbKWN8i1oGG9s7B3MdxKh1/tPbd64M+u6AWGmGCCfXe+wuHxdA
S74R+HG/EB+txAXkdAswJ9p9aslZCEbVjblfvIRYNhsfsmcJ0GlG3u2jEaJ6
1tk07FEZ0j/p6P3LRoTK53cJOx5lCONom3KUIkxZzhC75Hw4XTtrs7UlwjOj
tr11azzQ0tTEJ0wxfOJ+IArP8nDb1L5q6A8xXDcyFGdGuKCfSa43TZJAQjH+
6QM/LiIHrvxGnJbAdiW2gnOsFKQ9o984H5XijV4X1BXGAWvjqV52TwoLh5z+
Yk82hvvIw2seMnAnNdvj/iXQVwVk9tbLkGtfWVgbXoz/AP3zt+Q=
                   
                   "]]}}}, {
               DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                PlotRange -> {{0., 0.013}, {0., 0.01577199096653233}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{}, {}, {
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVyGlMEwYAhuFyCF5DKDIuB8i1zAbGvS0cHxCMgE5aUGTiBKpQpFXOlrOl
Lb1baEeJASShG5PDMdhEQYiSGE4HbIAM5VgqjHmwzdLJRDnnfrx5kvcwNTM2
1ZBAIAS9639X67od2ZEvgwmEZPL+cMuQR+LS1tVBEs7fPKF71UDBY7peb/xP
EN7b3FVrEkvF8eXeQBX3KP7toc8orOiwM7AmTVw8gS93UR0X+rLht+Oa+LmO
glsxgrekYBbMPf0T4xmnYenew+BEFYE07tPi4vcF2IkXH9oLOCi9UFgevXwO
bl/vi2oP5kEQZz8d7ZWM76eKiBM7fDxvy1JMmlNBORhHp44KQKMaJDMmLiAi
OtzE97wIvIrObR9pKqbnKUkHxsQIzKP2J6bR0Bl8p9IoUIoDN6Oarrpcgtr2
GmsyW4aylg9/9DWho6PBcE2rkb/7R0RbWgZWFMQXKU0K3FugFczUXAE5ou1T
Dbscfd4/D8uDsvDVvE3D5YgK3HYwWfI9lI0FVnhKqrYC+endxHKzHNw1dKM9
SVNC/HK7sWQzByGNSZs7I0pcd1qMYs7mwrjG+2S7qQqV7aEEx5E8VN9v9rBw
UKF8OWhg4jsmmEJ1qsRdhemUEZ2dhAVqyuCeJRcVdP6/eljl58PNeN292koF
q86SIpv4AmzaXW3q3VRin7p+dvRYId5P2DC61alETOspjbV/ETbyEzVTSUpo
spvy6MRiqB7Pv6UQlLivZp7LMixBqDzepEVWAV3KQixnsQRT7t+aWltUgM7Q
tjn3siHgNP9eoCpH18MEh4JWDnIfjIVUbyhg/iyzblpWCi7tdCX1kgJ1JAPr
V8FcFCWovSL65ej8zJZW2sbF0PUH7Neucqylrr+YPsSDX4xnlZ9QBk1ozWtR
FQ8dJU8nu6akIOtFskBjPoqZ6Y77PaVIJ/s0R7L56NvrlXekQIKmscY3Tqt8
WPMXB+0HxPjbKWN8i1oGG9s7B3MdxKh1/tPbd64M+u6AWGmGCCfXe+wuHxdA
S74R+HG/EB+txAXkdAswJ9p9aslZCEbVjblfvIRYNhsfsmcJ0GlG3u2jEaJ6
1tk07FEZ0j/p6P3LRoTK53cJOx5lCONom3KUIkxZzhC75Hw4XTtrs7UlwjOj
tr11azzQ0tTEJ0wxfOJ+IArP8nDb1L5q6A8xXDcyFGdGuKCfSa43TZJAQjH+
6QM/LiIHrvxGnJbAdiW2gnOsFKQ9o984H5XijV4X1BXGAWvjqV52TwoLh5z+
Yk82hvvIw2seMnAnNdvj/iXQVwVk9tbLkGtfWVgbXoz/AP3zt+Q=
                   
                   "]]}}}, {
               DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                PlotRange -> {{0., 0.013}, {0., 0.01577199096653233}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["3", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["False", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
        Baseline], DynamicModuleValues :> {}], 
      StyleBox["]", "NonInterpretableSummary"]}]},
   "CopyTag",
   DisplayFunction->(#& ),
   InterpretationFunction->("InterpolatingFunction[{{0., 0.013}}, <>]"& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.6626246067933207`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"deriv2", "[", "AO", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "AO", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "AO", "]"}], ",", "2"}], "}"}]}], "]"}], "]"}],
      ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.662623569112307*^9, 
   3.662623572807571*^9}}],

Cell[BoxData["919.3122713869577`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.662624606848462*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"plot", "[", "AO", "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fmax", "[", "AO", "]"}], "-", 
      RowBox[{"0.5", "*", 
       RowBox[{"deriv2", "[", "AO", "]"}], "*", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"p", "-", 
          RowBox[{"zmax", "[", "AO", "]"}]}], ")"}], "^", "2"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"p", ",", "0.", ",", "0.013"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "Red"}], "}"}]}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.66284663709056*^9, 3.662846643001965*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
     LineBox[CompressedData["
1:eJwV13k4lO0XB3BLdqHsUpaQQrS+eZMv6i2K0kKSNt5s2c0zM2bsZBnLM4hk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      "]]}}, {{}, {}, 
    {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
     LineBox[CompressedData["
1:eJwV1nk8VN0fB3C77LIkSxmSVCptTyp8aNNGVI8ibTzWLMPMHTP2XUbmThKF
tKNSUQhhFPmJkpSoJFJRVHjUo6h+p7/u6/26Z7nnnHu+36+BW+B2DwkxMTF5
cTGxP89qtZ5Uh9WjlrVbqe1UjQecXqvd2FvRasU1ELOJ7fdARl3Q6pUVPVYF
y8V3Jal6omy5gdicimGrcD3P7zw3TzR85r6ZUSGGnr5KLXEZL9g3X9ihXaGK
M87Cyowt3kirWKWoVcHA1t6PJ163+qKkKGFAs8IM9Qf2lffXBWKIOeJg6G+D
Zx/nvLwkR2H2dLtjI32bcGK4ecIxk4fd97R79ac7Im+DX3nhowiMMIoouxN/
IxB2G58rx+CV5IyfGc3O4Gk1S9gOx0JP7qp4/+59kBgTnbF6Fg+JVTZWYd4H
kbu5dnQOnQjGUq2vqpHucLvdX68rfxje1ZEfL9V6QHOLQlp9TDJcUhyft3Z5
QX9IdMRFxAdD0TZu12cfZHzdkZHfkQKVmS2Hek39oMzotpV5dwQFrFq77+sC
sLXqc0KNKBVr49ZUKtkHoKnMyW9BXSq60+qNDXcFYKP8OYmshlRo3Gj8vdkn
ABuq3lj5PUxF9HBrcU5qANZvVfw29iIVu/17Na2fBcBOT2x/5tdUyHlJdCd6
BSI53FeXMVeA5QsMV8ivZ6LUcrOVTbIA3qHPTaM2MVF5PfKe8hEBcv4nNByz
Y2Jsv4LaC4EAEm6/lbqdmJAKWzDhky5AS0bX22JvJk5mpysFnib9xTLTnI8w
kZn4eYlyqQDZTxQ+FzxhokvycdSZbtKeUdc3o5OJAAulG8a9ZLyA0OdpXUws
u3n20uU+0n/Kh/rwd0zs3fNk4MqAAMssG7Id/mPCKMM5/9go6Z8XvWlcJwgJ
pSNG49I0xEO/XrB1C0JatoOh5nwaVadOlwV6BkHtaeeOBQtocO5sasz0DULE
kMLxtYtoDE3JHewPDoJGdfAG36U0nmVuWHI4Lgg2r9Z4nFlN43JppqjxQhBO
an9Ku76FxvaRlS829QdhY6zPNWdfGoqabweDBoMwo9yufakfjf+ZC36e/BKE
Vw+7FBQDaFhEv2F8/I+8PzmRXxZEw1glxYs/JRinrq3OGePS+GHaNdY0l7j9
Hls9icY570iVrX7ByFKXeN91lkbU9YtzWpjBuMhyuJ99nobrtwdwoIIxz7L2
n90XaWjG6zJ3RgbjjKJUfVMBjcOny1tdhcGwPqVnlH6dRuCz0aP+JcFwTDjq
W1FFvmedlwY9GYwbTL6qfTsN7RSB6VRxFkZ/S4/XPaPx7XHpumPSLBSOn8tc
0UmjaL8UlanMQqqxzW+tlzRmhZ1tP81gQYKtzKzuoSF/42VG0ToWqtuHOrIG
aXToO2i3HWEhuKS89vRvMp+lr53sURb8Dsk7u4oJccYlPsbiOAvtHe5P+om9
j5d/yDvFwoa70x9OiAsxLm9QGXaNhSuv+E+1pITQ+TbiMruVhdCFwqWMKUJE
qivSLk9ZkPr334Yc4jdmxnV0Jwv1apKu0+WEuHzIZf6PHhbeus9KUZQXYnXv
3YmWERbyt/r9HFAQwvXBsRyuOhuLzfWXBKsIUfvhautVLTbUi8x7uomNZBul
+nTZmBf3k96sKsSQzaSfnREb31clj82cKkTErX8sDZezMX2k4PFtNSFyzy3v
bnZiY1+IXNc9TSEkarepie9hI/Nc5wXDaUJ4vvLZ8Nd+NmTm7giMJF40Pffa
GS824mw3yy3VIvOnykRRXDbEm60dhdOF6OV26OtnEQ/ZL9bVJftTEeByLZeN
47E7OAHEn79LH7c8z4avbKWwlvhH6DJ510I2nr8sXH9QTwiNiKNjJ2rYuH99
blH6DCGyqk0WmdSx4V1ueaab2OCXyOfW/9jYfP2mx5yZQiyM+tzd3spGq9c9
Zinxxpgt99X62PgiGZ1Upy9Ey503kuf62ciOPG8oxRDib4lQq8VDbBzuNzm2
ltgtruDmtq9sGMc7j9UQhydI5x6RpcAecLyVb0D2oyGnU1eRgml7/M9u4mSZ
ZepXVCkYFWlraxoKkZHkdvi+NoUXZj6tEcRFyaJgGVMKu/eehs0sIf5qcrp6
3IyCblWvWSBxtfznfqPlFPTlEv/LJm5K0du71orCJ/8xqVFihwc3M9vWUChL
qNmiayREh+KWtoO2FGpTPnqtJX6byrONdqCQ5ebNEBL7tqjGqvxNwWdpZVUJ
8YhyQVWuMwXeqP/CTuJf9LPF1W4U9q2eOKo7W4jpaUv1frAprBovdE4nzm1r
ckrmUdBcrXz2OvFsdbej0yMpLPZ7XH2feEm6UGZFEoWFJyNCfhCXP51j05BC
Qfm4p8ZUYyGgKQr7W0jBLKo40Zh4a8anYdZJCitn+g/aEbc9i58vmUuB8eTV
q/3Ezlp6nmnnKGzkFF1kEvfsunnGIJ9Csey7NdHEnic2vyy6QsE1KaxUQDzU
SeJ9EWn/lfUzm5ilzXN4VEKB49iiU0D8w1k1ZV8FhffZfKWbxNFZ+fc+VVPI
eFrQXkXsxygVed0l41sX2t0j3p13t6K3gUKJVOfFB8TrTFtv7mmmcJph2t1G
bHbj1dX2RxSC0gu+dRDrmQ/mb3tKzv+A3ZeXxFNqxs/e76TwKE6nsZt4bK1M
ztpXFFx+q8T0EPfeV8+o7qXwsG2BTi9xyzYD4Yr3FOb+Yh37876yfSG/+CMF
v5g3Q3/65+2xiJ//hUKmK8+4izitd1PkxX8pXKbNrTuJI712cfXHKeTpMFY9
Ifb99E/wyUkKyT8XaTwkdmIF+6mLc/C3uXfLn/Wt+R7lmSrNwZTmRu9q4z/3
I/WArDwHF0od+/7sj450tkuMMgcm4xJWl4hlUgp2TqhxkJ7WxT1FPKpaZk9p
cdAf331MSNydUbfxiy4Hsx5NoWOJm/Qer/FhcGAbtMeXRXzeZOivvXOJq3l3
HImF176bdSwg7b3WW4I4fJnsfMclHAx4rzw5n3intaH++tVkfnbWiBixdcMi
bRE4uBgh+/kD+b9Mt1qqr1zHgdzrnKbHxFK7d8susOOAf8naKJd4+JWHeL4j
B/lq287GEne5syYYThwUPkn45UFcEij4orGfA/+9fs5zic98zf4gcOdgnrHe
LjniI2GX+qZ4c/Bow9iyAXI/PJLqOyaZHDymZxw9R7xdqe0xh+JgYXmASiSx
1bHXzcM8DtjmA/67iaed/iF6G8tBmfXOZjnihjKzggfpHOgxVafsJ/f3hoXV
uQ0nOajcdSFpMXHu3S05tac4sM480C9BHNLiKSzJ40By5nbbcyRemLzP4eaU
c3Bos3bykz/xRVNuk18XBzUzzTXESDyaDJLbf7KHg2eB/b31JJ4xW+Sohrfk
fG6qlx4mdkqSP8v4xMEPjb5DSsRG3xW+P/3JwfNVe3UVSDys7VK+ZKkfghhN
UUwHibfLVqqIfGeFwCLDMv8Icf5xlfbMOSEYlVvZZk0ssFcVH10Ugs1NeeZ5
OiTf1E51zrMOwa1re209tEl+O68hp+IWAp7MSr8Skg/8xDT1LTxD0FGW+MGZ
+LWr5nIf3xCYuTj6/SL5pEFz2sG64BA84u2NXUecnqRVERIXgkY9x+F6dXLf
Dun49FwIwcWRi08ySL7yWsK4X9wfAukO6fJIkg8ni0+9Mx8KAfOEQ+YPki/T
FutK1A6HYOcbhgNFXGM2bXXL9xAkq2y395Il57NI8epHBS7OPvoWbiktRP38
ceEsMy5S3m86f4Pka8bs1t3HuVwIu01Noj/RKLtgR+lFcFESZbRx4RCNrUbN
R8/HcNG8eI7ui480QmY1NBXzuWhttHsxb4BGi0GVRUsOF3/d1a8uekMjYmYB
Q/YOF9w3zzTsO2i80Ioe4Mrx8LDzqOKjGhr/+Q8zbirxYFMyf8i+moZG/QHn
T1N5kIl1bXpwm4Y906bpoA4PCWOxsXfLadQ1ShRuns+D8/K+3uM3aBTyEgL1
7HjYbjzi2kXqpciX/G8iIQ/8e2vWDfBpZC+eWPgjnYflg5Xf5iTTKE865LXs
JA9mkk35HqQeG126tbPgLA8z5K9Kv4yj4XVEqfLoDR6aWYlFV8NpOFgKI9yf
8sAtS7w76k/D8PRxKdnpodD5XtUxYU/j4qrwyfl6obi7xSVY2o6GyTO3MQdG
KO59SNBXIvXkAiWzt1kmoeiSPVw8zZaGeVhT3cKVodj6YEWJGsj6dv2OdXIJ
xSrO+mXXFtIIU/ERz8sJxXp7bX2WIo2nURa/1hmEQV/l/OlldwXgWZ2ZrJsd
htFBp2upIgFm/pScWDMvDNLr7Llvq/7U883/WS8NQ7+HrFXKLQF+sl1GLNaH
4RTzvLC6UABjX+7bZT5h6Dgbu700QwDuzpImo+IwRLFebRzxFkB3rmmmlE04
cp5IiWXLCLCC/dg0xS4CLh8EePBXKgaSRAePMSOh3Sdh1Lv4CCS/WrG3CKKg
9uKpWrZSCr6LV9p4bI3Gr3sxCdVdybj9afzEu65oVDf7tA4HHIbX5bSA++4x
mO4YYBkwnohG9a9LpAdi8Htgx8gO3wSweycaYkJisaR81YZLmXGQj977/ODP
WLwpnK1ysy4Gg7Hut2MFcdgQuUmqZVMUypzqdWWnxSPtH70ph6aG4a+OT759
WfGI5CfIFl3nQLzqdrLY/AT4lXuqfC0IQlnQW+OY4gQ4FEYGX/bzQWlK8bE1
axMxbBzxJnCjK3y3237Z05aIAwuvTLkysRRyH1fc79yVhNrOdUbG1Y6i0XcP
gjMGktA6ennJHJGHqOFGVdatwMM4UGowUmEUJNpmShWbjR3GhUb3ydDDISJD
+bbMj3HJqJqWrt9cFSnqKU+elJXnIze1yEDwMlZkamX/bJ8iH27cvA8+g7Ei
bp1aUakyHzpVgcYbJ2JFU1uy3d3V+WDbh/9S0I0Trem72lSjx0dOboRJsUuc
6IJS2wlqER89Q4x/gl7EiXzcdJb37eRjg81H3v2X8aKy/m7lVbv4KNm8pevf
wXiRhP/5AaEzH2pXo24yJuNFWSGmOVb7+Lgc7lYbo5cgenDESjLLiw9PW9Wd
B/cmiBbecnvsEMpHI1/RPeN1gijUYs6V/HA+YmedVxv4kiBquDMY/yuSDzNN
pRUWYomi/Q/Y5oVxfARL7ukeZCSKhL2Jp2VT+WAqvM7zdksUdXlu4e2j+Wg7
pPrzYXCiyGRIZUfpUT7mzdZsXB6XKLrz7YSMewYfNedOVCleSBQph+/tqTjB
x6Sn1vuwkkSRi7hhpWo2HybxPvGf6hNFeYnvj3md4mPjD0HmwfZE0ajCFf+a
03zsu5+k3/kuUfR/IPygcg==
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 0.013}, {0., 0.015773312781134165`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6628466519886923`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sweet spot relative to centre of coil", "Text",
 CellChangeTimes->{{3.453823657396553*^9, 3.45382366152324*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"AO", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"-", "0.010"}], ",", "0.010"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453750960628242*^9, 3.453750962514122*^9}, 
   3.453823640869858*^9, 3.4538373938007517`*^9, {3.453838657031551*^9, 
   3.453838662984824*^9}, 3.453838901400448*^9, 3.453841257421837*^9, 
   3.4806948139055853`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwt2Xk0lV8XB3BDqUhCKlMiiQZpUkm2oUmEilIZooyZ72TOcK/ZfW40qojI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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{-0.01, 0.01}, {-0.01577331277004164, 0.015773310656795696`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.45374974088566*^9, 3.453751021464161*^9, 3.453823734388617*^9, 
   3.45382595105693*^9, 3.453826495876092*^9, 3.453837430614188*^9, {
   3.453838660033111*^9, 3.45383867436195*^9}, 3.4538389289668913`*^9, 
   3.4538418441367064`*^9, 3.4638449203570347`*^9, 3.480692306252309*^9, 
   3.481942019293109*^9, 3.662624620495331*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"AO", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.0", ",", "0.01"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, 
   3.453823640937874*^9, {3.4538265543875103`*^9, 3.453826559178968*^9}, 
   3.453837393850636*^9, {3.453838705965811*^9, 3.453838717842711*^9}, 
   3.453838901436325*^9, 3.453841257441544*^9, 3.480694814624156*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwV1nk8VP0XB3CkLFkiIXnKGpVESbuPaLE9iJRdZSmSbebesS81YzczSj3Z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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0., 0.01}, {0., 0.015773312580964153`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4538234640829372`*^9, 3.45382375947115*^9, 
  3.453825952943671*^9, 3.4538265081040163`*^9, 3.453826563804844*^9, 
  3.45383743232346*^9, 3.453838725272155*^9, 3.453838935442772*^9, 
  3.453841854513754*^9, 3.463844932499839*^9, 3.480692315858614*^9, 
  3.481942029259119*^9, 3.6626246289498587`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindMinimum", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"fz", "[", 
     RowBox[{"AO", ",", "p"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.005"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823404829797*^9, 3.453823405956604*^9}, {
   3.453823506088236*^9, 3.453823516693254*^9}, 3.453823641011278*^9, {
   3.4538265379087467`*^9, 3.453826543745769*^9}, 3.453837393910678*^9, {
   3.4538387257460747`*^9, 3.453838749683352*^9}, {3.4538387973199577`*^9, 
   3.453838821469616*^9}, 3.453838901466652*^9, 3.453841257454495*^9, 
   3.480694816395583*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.01577331278970188`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", "0.005342364902701453`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453823468555167*^9, 3.453823535452108*^9, 3.453825954168241*^9, {
   3.453826526324848*^9, 3.453826545225122*^9}, 3.4538374328189507`*^9, {
   3.4538387298936996`*^9, 3.4538387449128933`*^9}, {3.4538387984605837`*^9, 
   3.453838822542676*^9}, 3.453838936153399*^9, 3.453839519837987*^9, 
   3.453841855442709*^9, 3.463844933406391*^9, 3.48069231649853*^9, 
   3.481942029872281*^9, 3.662624629579126*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
New coil calc for AOSEM (D0901048-v4) and extra small, \[OSlash]2 mm x 0.5 mm \
magnet\
\>", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
   3.45382361286519*^9, 3.4538236144707003`*^9}, {3.453838874626217*^9, 
   3.4538388807274017`*^9}, {3.453841072413919*^9, 3.4538410760356073`*^9}, {
   3.48069476991868*^9, 3.4806947920213118`*^9}, {3.480695820456702*^9, 
   3.4806958224791937`*^9}, {3.480699030573723*^9, 3.480699039227467*^9}, 
   3.480699179006065*^9}],

Cell[CellGroupData[{

Cell["\<\
AOESvals = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.0005,\t\t\t\t(* length *)
\t\ta->0.002/2,\t\t\t(* radius *)
\t\t(* coil length *)
\t\tcoillen->0.207*0.0254, (* D0901048-v4 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.304*0.0254, (* D0901048-v4 *)
\t\tcoilrad2->0.996/2*0.0254, (* D0901048-v4 *)
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453819143842659*^9, 3.45381916873015*^9}, {
   3.453819205916604*^9, 3.453819229397924*^9}, {3.4538192680904627`*^9, 
   3.453819317992671*^9}, {3.453819379538721*^9, 3.453819381962309*^9}, {
   3.453819414835219*^9, 3.453819449256628*^9}, {3.453823205503562*^9, 
   3.453823222597754*^9}, {3.453826073117807*^9, 3.453826150751071*^9}, 
   3.4538373389188223`*^9, 3.453841092308299*^9, {3.453841283965046*^9, 
   3.4538412881475286`*^9}, {3.4538413725493402`*^9, 
   3.4538413849806833`*^9}, {3.453841501978483*^9, 3.453841779519685*^9}, {
   3.480274240165839*^9, 3.480274249772677*^9}, 3.480694811626128*^9, {
   3.4806948459029713`*^9, 3.480694858042783*^9}, {3.480694900775441*^9, 
   3.480694950070912*^9}, 3.480695858267105*^9, {3.480696997173448*^9, 
   3.48069702724988*^9}, {3.480699187974929*^9, 3.480699197276938*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.000011623892818282234`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.017499999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.0005`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.001`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.005257799999999999`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.0026288999999999996`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.0026288999999999996`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.0077215999999999995`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.0126492`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.5439046765338914`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4538417843516493`*^9, 3.463844900775058*^9, 
  3.480692290540955*^9, 3.480695055734477*^9, 3.480697045556779*^9, 
  3.480699218382852*^9, 3.481566729144149*^9, 3.481942029907995*^9, 
  3.6626246296430073`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "AOES", "]"}], " ", ":=", " ", "AOESvals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, {
   3.453823624487136*^9, 3.453823640631469*^9}, {3.453837378474317*^9, 
   3.453837393571328*^9}, {3.4538388861923847`*^9, 3.453838889904484*^9}, {
   3.453841247783547*^9, 3.4538412572609777`*^9}, 3.4538417923838587`*^9, {
   3.480694812819429*^9, 3.480694813277412*^9}, {3.4806958602050734`*^9, 
   3.480695860693163*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "AOES", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.002807824198073727`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.005198473408953153`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"fz", "[", 
          RowBox[{"AOES", ",", "z"}], "]"}]}], ",", " ", 
        RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.479667008672338*^9, 3.4796670332310963`*^9}, {
   3.480244318582687*^9, 3.4802443450940313`*^9}, {3.4806950416816607`*^9, 
   3.48069504236414*^9}, 3.4806950855740757`*^9, 3.480695391023115*^9, {
   3.480695424453774*^9, 3.480695426213916*^9}, {3.4806958612576303`*^9, 
   3.480695861809552*^9}, 3.480697041276504*^9, 3.480699359418405*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.0028078241980730805`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.005198472889722748`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4806971192435513`*^9, 3.4806993237886267`*^9, 
  3.4806993994484053`*^9, 3.48156682235257*^9, 3.481942029984186*^9, 
  3.662624679655575*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "AOES", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nk4VdsbB3Bxi0qSypBuKIXiRikUvgglQ5mHUqazKeI45+zjGDJHjkhF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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 0.002807824129332503}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"AOES", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.479666887455168*^9, 
   3.479666888838862*^9}, {3.480244879780376*^9, 3.480244897499516*^9}, 
   3.4802450058581*^9, {3.480695043059854*^9, 3.480695043824891*^9}, 
   3.480695087059374*^9, 3.480695404783731*^9, {3.4806958623058577`*^9, 
   3.480695862857663*^9}, 3.4806970427358437`*^9, 3.480699363708275*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], LineBox[CompressedData["
1:eJwV1nk0Ve0XB3CUvMakVFKRiopCKSV8I01E3JshjYZ7DOGO55qKS0puJQmp
DJWmlwhRiJK8KIWkUilDioRQMjT9nt8fZ531Weuc8wz77L2fee5sBktKQkLi
L7n+fy9TaTthv3bIzGL7E9X9fwbMnFpV8ncXN5g/FUomuCytN096yF27prjN
XGQrCFZZ2mp+e+U8CZ3iAfMvevpjXXpfzav6gzrmFEtAVs66r0Dvr7ld7WWm
WrEyuMEwWaA3GfHFJgozijURksnd/HexBgpyD3erFhvg+4Hjiw/M00cvZ9Be
y98CjyXO21xZsA4LZ9qeHvywBTu/30p2r9sEl//U2jVmOqBWbr7J87nbMKiZ
S9smO0J16vwTn9yYeDdhzu+k2h1wXq1WXV/jhNmy2ZJdLnugPG+Xt/R6V0iZ
WJiHertBpbm0TIezG5orZgwrh3lgJNe6+5bqPniXhfX8W87CWHnKT78AN7ge
c3jd0OKF5TnaS07EukNTYdMh534fmMmss0k76oHJc+v2t+v5ISLL8oUd3xNU
l2OtxUo/VKm4p/OEnijNfbfkkpkf3nO0XBKCPeG9vu+zu50fRi91Jj4L90SF
t4J3J9sPfcvVNqw47gnhLWvPrnw/xLQrxpy+7ImWzdW7+lb7Y0KlGq/muSeu
88ttx6wCkMYY3y+vx8L6Q5YlinYBmHGhYFXnMhbex1dqazkH4MYrmbQSQxam
5df8tfYJQOxNn/X7jFkQDTTkpZwIwLW7CwZiLVlw8W9XXfcyAAmne2VDXFiQ
9ZJ6f8SLDaXqdXNjIlm4LIyyPs9h46WR+2/VwyysOzLpzs1gNuQ49REXolkQ
XpGLaz7GRrp6YWjOcRY6PqhYLsll4/O29aY5SSyU7Jt/9ekoGx0G2avMMllY
uVTLWG4DBxsbDrmer2fBO+S1XvgWDqR38b43PmMhpTpO67stB93OOcx/mliQ
cv+r+N6Jgzna+z38mlmoS2rpzPPmINUr6ZlaO3lf4kz8juMcPOWNrZIbYuH8
c/n+68856BJcubFehUKd5sMPc5o5qCmNv2A0jYJUQMjr+BYO2vq4rPnTKXj/
87nywEcOQk0SPMbVKBiZVZ23H+HAmbPPNHYeef+qaMvoLC6iZWSLbQ0oSIYM
X97kzoVT+cziZVsplKam32ZTXLC+Pqwrs6UgfLCl5owvF7d3J8rabKPQ+0/a
ly4eF8YClYG9DAovz2xcfvQQF8dUXMR8FwqZhWfu11zmIsd1ZL2lJwXG4Jo3
W7q4UOy56CwKoaCg2vmF+4WLfaNBlU2hFKpXx/4++5WLgyfi3XUOUjAVdWj2
jHBBheYtrw6noD35mJf4Hx5MDDctG4yiMK7X8v3xYh6K1XK6+2MpXPIOm7zV
j4cp2Vu1Ey5SCL95RaeOw8OQ4xxm9SUKu348gT3NQ+PETv/RDAqqUeqc7WE8
XGtPZ2+/SuFoelHDrjge2m3u5n/LpMB+OXTKv4CHzltK2fW3KGydMyvzaxEZ
/3bqWHsBhUWeFhXcMh7efsw2HSqk0DF4coiu4kHCwPm6QhEFJ8WlzLBmHu5k
5C1cXErWY+U17eQvHv4cNTWUrKSgdixWb4okHz2CXu1vxD+eFVqdluYj9ugL
9Q//UcjdO5E+o8THiuYY6bJqCvNDL75I1+RjLlO+26WWglz+26RcKz5qD66j
DBspvNKwV2s8zge1M9rc5z0Zz8zXVuYUHzPW0o7KrRQuuEZFmCbycbiWXVZI
7J1Y9PlqKh8bLQ5E/myjMCo3ryQ0h4/5Wc19vA8UZv0YdF3YwIfezemFU7op
hE1VOOnaxIex60vVNOIOA+2HJ5v5ePc2vH7RZxLv/a664218yETAbk0PhbXt
FT/rBvnoH+fEbOwl+//kdErQVAGOlam4qwxQKP+c3ZA9Q4DVu2uio4gXyNRM
/KAuwKaBEcVh4l6LX362CwRIeeNl9myQwsE7nmZaKwWQnvnGWPiNjN8UxnVe
I8CKtcMBb4k3DiVfOW4mgHoWXw7fKSgtfao4skEAf5V0L8lhCmmXVr6vdRJg
oYndH94Pki/l21QkdwqgoOlF1RJT73w2rtorwNnKN6u0Rijoz0zLueAlwJql
b1VqictPTAqng8j8BZP+kx0j883SvJV5QADDe70HHYmP1ph0tYoEaCrUy0gn
tp/A3mYdIwBz6mMj/XEK7UGvNDTOCRDptCBy7U+y/8UBrjlpAsjFLmkPJ+4f
k040yxDgfP2k/RXE4yFGcrtuCOC17bmk5S8Koru1Vl9yBfj3lYJyOLHML/fw
kEIBfIKu2JQQTzt46nvyPQGCFItsdX9TOFe2SH/RQ7L+uzxVN+J5f+773Kkm
83+xRDGReFl4//sXDQJc9i+IHSEuuH9YjfVCAO20jbO0/5D4SczZ/v21AIMG
/s0M4s0RNo9UPgiwOFVn5Cpx3YOOCZe6BHgX9Nm+jthRKsTcsFeAU3Pftn4j
dj90/da2YRI/Tkv6mr8Uuh+i//2YAJ/+rG3cQcye+GpRwB8SPwc70yDiA4el
047L0LiwJKHkJrFUVUqzugKNb4ckGmqIYyYZTc1SpsF3btRoI1beVGtrokrj
ln5e5jBxUrT70UdqNNYUWnFlJbwwu2aswmUuDWa2kUCdOOOfU7+7tGgcDjAs
0CVesmXR6kAdGhvPFRuaEOfG3OdN0qOR8iKnbyPxqsdO2YkGNB4VXeh2IC6T
6+9asJLG/jPG83cSW9kc1ipYQ+NSm3qaO/HjY7N3rzenIa3xY4c3sf2TW2ca
LWl8HQlw9iN+pWDT6LaJrE9X/0wA8R7bDoVBGxqnE1rV2MSdJ4I3iexpFOks
bvMn9q1TjpzsSCPrW0GPL/Gg0vXStB00RJp6JhRx0DaMLN1Do+urcf1e4j8n
XxqWudPwKI3IdCaOavD32+pFY8NY/hNbYvkp0tfe7qfhvZxeZUkc75DS7suh
US3P6zYinhm/Yva4gIaVBfPDQuK0xsdOMcE02FcrdFSJF051PzUzjIa9tu9t
KeIbzLHaa5E0/qv4drKf7P/yhLhJxtEkHgmyhc3ERU06FlXHaBysddR+QAzV
+6GOcTTeLz3eeY14a1LfAP8sDa1gQ2sOcePLKN0JaTTKmv8MORDvmDGbir9E
Y0+j0xdDYirZ+m1uFo2tfg5Pe8n/1dtM+nsujZdZW4qqiflqwfb1BTRiHgYO
XyAWnbv2X18Z+X7SPB87Yj/NwvteFTRcwl9x5hO7XK0obq+i0TPnZcsP8v8b
5L/LflFPY2SuaWcycfujqUll7WT/31lXPCL5VbdtXpzxJxqJe8Z/nyIuebFM
nNdDo2CHcoYLcXz7lrAr32iU/OjQbSf5azkWTp2QFiLeQsG6dfz/+XZin4yc
EHmjAR3niGdJn3eNUBJiwtTh7u3EQ8q37egZQrAz0q0qSf3IWNS7avdiIWSu
JW+OG6Uw0cVFZqmtEMdmZY6/I/Vs4B1L8pqDEGmf7laJiFs8+D81nYQIu0jL
axEXsGO/TtsrRBnFl9xH6iEruvLVL44QcvFReY+GKFTdNrj+JIHMZ2d43vav
FPJNzS9tPCvEm6Cf21v7Sb2ssEkpTxWi2M0t1Js4sI6KK7gqhHx1KFPYR/rf
p5SglCIhSk8NW4q+kPxUld3i1yJEwk5+jm0XhV9c2b1n24Q4e2CZ7eNPFDh1
snRVpxCMDKl/NxA7Rctd1OwTYp/fgXOrP5J6OiY/1vRbiDv+TP5k0n/KW5T+
NdMIRNtQODeC9LPRjGmyk90D0ZDpvSmkicRTQlXDlArETvmiuPrnFFp3qa70
8Q3EyMzxa/OJq1Snuz3kBUIU5GdZ84xCQvSM4sBDgVj3O3PlhHoS7/2zfNou
ByJXxBCve0TBa7nmo7yuQKwQBZ9qIf36V17qx9W9gXAw2iv/8y6Jr6G6VPlA
IKYNahjOJL5nMH1t3VggjN0/RdoVU5iur5DdIx+EwAWKjCxyHqjUHY2bbxCE
vd71y7VzKGgubHBJDArCWPKP8wvTKLyZIeoOkg1GeV/CUzY5D434D2jeUgyG
Y/i7IkYwqeeV+3b0TQmGk9HSC0ZBFOw4Fo/dZpHnpX97DtMUHtZI3bDWDUZY
2YyXvlwKN4IPs2fbBuNBbnftQm/Sr9+Kf9yPC8aSlhM5rdspaKUnTpSZGYKf
Ezt2i3QpNIWb/rGaFwqbe9fP2jawoL5Y78xEiwNITk06On0fi5zrnukdsz2I
VFGTZHOvJ7qj77ud5oRBVlkrX0R5YsKwucAmNhz6WkZJP954YEyyxIK1VQSf
t02jR5geuNs3mvyxRQSzGbwon1J3eGXGBzzyiMCSXwNWF/TcUTN1eLl0dwQ2
d6y9opvmBkH7z6qIwEi0rnN4NyjlBjnR7tduvyMxGvuTt5O3D18iPe5Gxh5C
3OjGdq/svbjtVKkuMz0KY1OipJVi92DVqz7fD+ei0Pv6Zmx40G5Ilt6NkdA9
jIor7TUKDrtwm9upHZF3GDKdljyH9TtReCzvtOX6I5h1J+O5mbYrfBmbvu5s
PAKxv6/G8uk7INtj/KjZORqmBda1VRouGPr4hJfUHY0kk4ZP7bOdUZVfeu4O
+yiouvitC1Y4YZsenWfw/Sh8K44Ijzs6Qkuu8UzPoRgUHzm1It1/O9qKYn7J
yIkhG5otrZPKhJ653cs9CmI8c7sRkXiWiaCHKrmFSmKURJ1OnJjExJS68x4e
U8WY5DclvDOWCcsP2Y/vzRbj+I5NIVkiJi4rNibT+mIkyZU1OXoy4eM+a+WH
7WLknXPoV9dj4nbXeyUTZzF6FbsYqYuYkPLP6I7bIYb+atVtGguZOBeol2K+
Rww5rzuyC+cy8eS4+YRzXmLs158Za6zMxLI77s/sQ8R4lcF+HPSdgRBTnaxr
B8SQHLRKmjDIQNWDL1F/wsRw1DEfje1jYO8Tweobh8TghNJh1z4xENd+JF3m
hBibfT7GtzYz0ELZBO85KcbD8Wol9gsGFvVOZhaeEkN0MVzz7zMGHvxInuSR
JEZKzwbpebUMKB3Y3VacLIaF/brm/GoGXCW1SpTPi3Ez+67FhkoGrh75dNor
VYzOyxPXNZczMCSf5X8vXQzW7Y/P95cx8D/8imJ+
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 0.013}, {0., 0.0028078241293650412`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.48069712546273*^9, 3.480699332309153*^9, 
  3.480699399566325*^9, 3.481566829952278*^9, 3.481942030040433*^9, 
  3.662624688188848*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "AOES", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "AOES", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.479666890574193*^9, 
   3.479666892310862*^9}, {3.480695044500922*^9, 3.480695045299432*^9}, {
   3.48069586344763*^9, 3.480695864000742*^9}}],

Cell[BoxData["0.005198472889722748`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.4796669544241667`*^9, 
  3.479667628122774*^9, 3.480244912925961*^9, 3.480692316685502*^9, 
  3.480695182351778*^9, 3.480697125524988*^9, 3.480699332401712*^9, 
  3.481566830010151*^9, 3.48194203006644*^9, 3.6626246882658*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "AOES", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "AOES", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.479666893782012*^9, 
   3.479666894910797*^9}, {3.480695045805807*^9, 3.480695046244318*^9}, {
   3.480695864548365*^9, 3.4806958649909143`*^9}}],

Cell[BoxData["0.0028078241980730805`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.479666954466415*^9, 
  3.4796676281467333`*^9, 3.480244912993281*^9, 3.480692316727179*^9, 
  3.480695182407237*^9, 3.480697125554319*^9, 3.480699332444682*^9, 
  3.481566830040126*^9, 3.481942030118945*^9, 3.662624688341494*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "AOES", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"AOES", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, {3.6626235829632797`*^9, 3.662623584946313*^9}}],

Cell[BoxData[
 TagBox[
  TemplateBox[{RowBox[{
      StyleBox[
       TagBox["InterpolatingFunction", "SummaryHead"], 
       "NonInterpretableSummary"], 
      StyleBox["[", "NonInterpretableSummary"], 
      DynamicModuleBox[{Typeset`open$$ = False}, 
       PanelBox[
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{}, {}, {
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVxX041AcAB/Dj8ZZtwqPnvE23M9vssnGo6fBVsbxV5z1O515/tDt5yXuO
83bOmVGsPZkntme5LFPLwx720IRRyVzWZco4sWJeS8u7bX98ns87vIRgoTaJ
RHL/z/+v1LTtlfgueJBIv2iSvOY8HhXnNq78SsODYXmbz4Q9RkTLyzov3JG6
4XKD/OdBBMx2MiqkPgjnFq1fGD0CSy0yTSUIRIr9vOGYgT9cdt5lHVsMwisH
SwbTjwnjj1xZ4eIwmAyKlW95hIA2RG+wdYmERK55cZMZjlx+Zpn/bDQUqi5D
slMkCkOs1P6OHOi4WVo++pmF502Jnz8w5sGCnfZQN4SNWJ4WR6zi4+mbKxSB
Hwd5X7Ru00uEoAR+5Td+nAtGCq+HRcTibp6ofymIh903/ZQXbU+DHEihn9rH
R0HD+z8664nwbKElSrLDR6XFh7KtcTHuXl4SlTcL0KGJzfjj0hmU9pDtrnsL
0e002F/qnohjFavs0TtCtNjoTTlbJ0FDz/yY5EggPa7NtMwoGYcVEYNSGYHi
he367M1kbBzwcrfpJnCFMumXOnoWDoGiKdZzAheue5H23ktBn3TXxvQmgbJZ
917VtVTsvHoqPb9NQM29t2gpT0OXAAPfLRFYdH3osCc9HdcsSFJPFYE9rdlZ
5uEZONQV27yvnsAblbWjA0czces9A+WT0wRONIbWkV2z0NR2P8GTSqAuSZki
Mj2HeuHOLV21EF2VqdGJ2tkYio+86JslxCJXE5wzmY3hepHVbWshROLxJmqn
BFlN04X17QL8NHzSJqMxB9KwpXYzfwGMnyXUqBW5SEzS/K4/xkcNTYv80kMK
7XKDBjc+H61uFrG5TVJ0XqVPHFng4bVwfUZtnYeAEbbJ4Uwe6rwu/SOrykPf
7WCcW+WCuSxTMHTyETN0/uVaLhdxTPpVX0k+VLZTpOgtDpT361cpK/nYvBGU
aCLhYJ7y2dAWrwC7Q9gWvbocVFP/dnJ+XACbmTsJlYYxOL7ebhkfUIgrXInd
WRs27JdC9ie3FWKVZveB58FTEFd9//g3xyIopr809v40Gq1GTAN6XRF+oBrS
4ggW4g40d86Zy7CiN9fPzojCoZxxZXK5DFyzNYOOqkhQvo4y39qSIcK7pVrU
exKxRKXpRGoxOAZGmvmZCLToW1X1TRfD9htz6ifUCIgiOLX6MXKUrvnTLp8I
h2/vmTFTtRxGh1z6nsjCQNs18C3VpwTxDMakmSoUaRt/LSs6SsB9WyeCZhqK
/m5m/2sHBTzlPUdHhCFYrtqf0FmrQFd1hUrUEYx/AUXWtGA=
                   "]]}}}, {
               DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                PlotRange -> {{0., 0.013}, {0., 0.002806934534531846}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{}, {}, {
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVxX041AcAB/Dj8ZZtwqPnvE23M9vssnGo6fBVsbxV5z1O515/tDt5yXuO
83bOmVGsPZkntme5LFPLwx720IRRyVzWZco4sWJeS8u7bX98ns87vIRgoTaJ
RHL/z/+v1LTtlfgueJBIv2iSvOY8HhXnNq78SsODYXmbz4Q9RkTLyzov3JG6
4XKD/OdBBMx2MiqkPgjnFq1fGD0CSy0yTSUIRIr9vOGYgT9cdt5lHVsMwisH
SwbTjwnjj1xZ4eIwmAyKlW95hIA2RG+wdYmERK55cZMZjlx+Zpn/bDQUqi5D
slMkCkOs1P6OHOi4WVo++pmF502Jnz8w5sGCnfZQN4SNWJ4WR6zi4+mbKxSB
Hwd5X7Ru00uEoAR+5Td+nAtGCq+HRcTibp6ofymIh903/ZQXbU+DHEihn9rH
R0HD+z8664nwbKElSrLDR6XFh7KtcTHuXl4SlTcL0KGJzfjj0hmU9pDtrnsL
0e002F/qnohjFavs0TtCtNjoTTlbJ0FDz/yY5EggPa7NtMwoGYcVEYNSGYHi
he367M1kbBzwcrfpJnCFMumXOnoWDoGiKdZzAheue5H23ktBn3TXxvQmgbJZ
917VtVTsvHoqPb9NQM29t2gpT0OXAAPfLRFYdH3osCc9HdcsSFJPFYE9rdlZ
5uEZONQV27yvnsAblbWjA0czces9A+WT0wRONIbWkV2z0NR2P8GTSqAuSZki
Mj2HeuHOLV21EF2VqdGJ2tkYio+86JslxCJXE5wzmY3hepHVbWshROLxJmqn
BFlN04X17QL8NHzSJqMxB9KwpXYzfwGMnyXUqBW5SEzS/K4/xkcNTYv80kMK
7XKDBjc+H61uFrG5TVJ0XqVPHFng4bVwfUZtnYeAEbbJ4Uwe6rwu/SOrykPf
7WCcW+WCuSxTMHTyETN0/uVaLhdxTPpVX0k+VLZTpOgtDpT361cpK/nYvBGU
aCLhYJ7y2dAWrwC7Q9gWvbocVFP/dnJ+XACbmTsJlYYxOL7ebhkfUIgrXInd
WRs27JdC9ie3FWKVZveB58FTEFd9//g3xyIopr809v40Gq1GTAN6XRF+oBrS
4ggW4g40d86Zy7CiN9fPzojCoZxxZXK5DFyzNYOOqkhQvo4y39qSIcK7pVrU
exKxRKXpRGoxOAZGmvmZCLToW1X1TRfD9htz6ifUCIgiOLX6MXKUrvnTLp8I
h2/vmTFTtRxGh1z6nsjCQNs18C3VpwTxDMakmSoUaRt/LSs6SsB9WyeCZhqK
/m5m/2sHBTzlPUdHhCFYrtqf0FmrQFd1hUrUEYx/AUXWtGA=
                   "]]}}}, {
               DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                PlotRange -> {{0., 0.013}, {0., 0.002806934534531846}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["3", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["False", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
        Baseline], DynamicModuleValues :> {}], 
      StyleBox["]", "NonInterpretableSummary"]}]},
   "CopyTag",
   DisplayFunction->(#& ),
   InterpretationFunction->("InterpolatingFunction[{{0., 0.013}}, <>]"& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.6626246894085207`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"deriv2", "[", "AOES", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "AOES", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "AOES", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.662623586641572*^9, 
   3.662623589762891*^9}}],

Cell[BoxData["169.0060994167717`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.662624689486725*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sweet spot relative to centre of coil", "Text",
 CellChangeTimes->{{3.453823657396553*^9, 3.45382366152324*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"AOES", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"-", "0.010"}], ",", "0.010"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453750960628242*^9, 3.453750962514122*^9}, 
   3.453823640869858*^9, 3.4538373938007517`*^9, {3.453838657031551*^9, 
   3.453838662984824*^9}, 3.453838901400448*^9, 3.453841257421837*^9, 
   3.4806948139055853`*^9, 3.48069586856068*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwt2Xk0VO0fAHBlKSpJoaQsbRSFSoV8hZISKlRiNJhryTozdwaDyJBCRJGS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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{-0.01, 0.01}, {-0.0028078239864873177`, 
   0.0028078241960281746`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.45374974088566*^9, 3.453751021464161*^9, 3.453823734388617*^9, 
   3.45382595105693*^9, 3.453826495876092*^9, 3.453837430614188*^9, {
   3.453838660033111*^9, 3.45383867436195*^9}, 3.4538389289668913`*^9, 
   3.4538418441367064`*^9, 3.4638449203570347`*^9, 3.480692306252309*^9, 
   3.480697135921809*^9, 3.480699347175211*^9, 3.481566843006109*^9, 
   3.481942047830917*^9, 3.662624703720014*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"AOES", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.0", ",", "0.01"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, 
   3.453823640937874*^9, {3.4538265543875103`*^9, 3.453826559178968*^9}, 
   3.453837393850636*^9, {3.453838705965811*^9, 3.453838717842711*^9}, 
   3.453838901436325*^9, 3.453841257441544*^9, 3.480694814624156*^9, 
   3.480695869313149*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwV1nk4lFscB3CK0EKjLKmQlC2VFleSbyEhpUsqy4xt5q3QMGbese9TKVQU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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0., 0.01}, {0., 0.002807824072042847}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4538234640829372`*^9, 3.45382375947115*^9, 
  3.453825952943671*^9, 3.4538265081040163`*^9, 3.453826563804844*^9, 
  3.45383743232346*^9, 3.453838725272155*^9, 3.453838935442772*^9, 
  3.453841854513754*^9, 3.463844932499839*^9, 3.480692315858614*^9, 
  3.480697141979739*^9, 3.480699356475226*^9, 3.481566851563313*^9, 
  3.481942060181831*^9, 3.662624712512875*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindMinimum", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"fz", "[", 
     RowBox[{"AOES", ",", "p"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.005"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823404829797*^9, 3.453823405956604*^9}, {
   3.453823506088236*^9, 3.453823516693254*^9}, 3.453823641011278*^9, {
   3.4538265379087467`*^9, 3.453826543745769*^9}, 3.453837393910678*^9, {
   3.4538387257460747`*^9, 3.453838749683352*^9}, {3.4538387973199577`*^9, 
   3.453838821469616*^9}, 3.453838901466652*^9, 3.453841257454495*^9, 
   3.480694816395583*^9, 3.4806958708335733`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.0028078241980691236`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", "0.005198470254076427`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453823468555167*^9, 3.453823535452108*^9, 3.453825954168241*^9, {
   3.453826526324848*^9, 3.453826545225122*^9}, 3.4538374328189507`*^9, {
   3.4538387298936996`*^9, 3.4538387449128933`*^9}, {3.4538387984605837`*^9, 
   3.453838822542676*^9}, 3.453838936153399*^9, 3.453839519837987*^9, 
   3.453841855442709*^9, 3.463844933406391*^9, 3.48069231649853*^9, 
   3.480697142379641*^9, 3.4806993585664883`*^9, 3.481566852005377*^9, 
   3.481942060656612*^9, 3.662624712959793*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
New coil calc for AOSEM (D0901048-v4) and (approximately) double length, \
\[OSlash]2 mm x 6 mm magnet\
\>", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
  3.45382361286519*^9, 3.4538236144707003`*^9}, {3.453838874626217*^9, 
  3.4538388807274017`*^9}, {3.453841072413919*^9, 3.4538410760356073`*^9}, {
  3.48069476991868*^9, 3.4806947920213118`*^9}, {3.480695820456702*^9, 
  3.4806958224791937`*^9}, {3.480699030573723*^9, 3.480699039227467*^9}, {
  3.480699105085774*^9, 3.480699140273758*^9}, {3.480699240398816*^9, 
  3.4806992456450768`*^9}, {3.4806992858633623`*^9, 3.480699289781164*^9}}],

Cell[CellGroupData[{

Cell["\<\
AODLvals = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.006,\t\t\t\t(* length *)
\t\ta->0.002/2,\t\t\t(* radius *)
\t\t(* coil length *)
\t\tcoillen->0.207*0.0254, (* D0901048-v4 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.304*0.0254, (* D0901048-v4 *)
\t\tcoilrad2->0.996/2*0.0254, (* D0901048-v4 *)
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453819143842659*^9, 3.45381916873015*^9}, {
   3.453819205916604*^9, 3.453819229397924*^9}, {3.4538192680904627`*^9, 
   3.453819317992671*^9}, {3.453819379538721*^9, 3.453819381962309*^9}, {
   3.453819414835219*^9, 3.453819449256628*^9}, {3.453823205503562*^9, 
   3.453823222597754*^9}, {3.453826073117807*^9, 3.453826150751071*^9}, 
   3.4538373389188223`*^9, 3.453841092308299*^9, {3.453841283965046*^9, 
   3.4538412881475286`*^9}, {3.4538413725493402`*^9, 
   3.4538413849806833`*^9}, {3.453841501978483*^9, 3.453841779519685*^9}, {
   3.480274240165839*^9, 3.480274249772677*^9}, 3.480694811626128*^9, {
   3.4806948459029713`*^9, 3.480694858042783*^9}, {3.480694900775441*^9, 
   3.480694950070912*^9}, 3.480695858267105*^9, {3.480696997173448*^9, 
   3.48069702724988*^9}, {3.48069930379321*^9, 3.480699340598193*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.0001394867138193868`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.011999999999999999`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.006`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.001`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.005257799999999999`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.0026288999999999996`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.0026288999999999996`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.0077215999999999995`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.0126492`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.5439046765338914`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4538417843516493`*^9, 3.463844900775058*^9, 
  3.480692290540955*^9, 3.480695055734477*^9, 3.480697045556779*^9, 
  3.480699411967904*^9, 3.481566894140891*^9, 3.4819420607019053`*^9, 
  3.6626247130171137`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "AODL", "]"}], " ", ":=", " ", "AODLvals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, {
   3.453823624487136*^9, 3.453823640631469*^9}, {3.453837378474317*^9, 
   3.453837393571328*^9}, {3.4538388861923847`*^9, 3.453838889904484*^9}, {
   3.453841247783547*^9, 3.4538412572609777`*^9}, 3.4538417923838587`*^9, {
   3.480694812819429*^9, 3.480694813277412*^9}, {3.4806958602050734`*^9, 
   3.480695860693163*^9}, {3.480699304968781*^9, 3.480699305631609*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.01577331278972314`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.005342368876734437`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"fz", "[", 
          RowBox[{"AODL", ",", "z"}], "]"}]}], ",", " ", 
        RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.479667008672338*^9, 3.4796670332310963`*^9}, {
   3.480244318582687*^9, 3.4802443450940313`*^9}, {3.4806950416816607`*^9, 
   3.48069504236414*^9}, 3.4806950855740757`*^9, 3.480695391023115*^9, {
   3.480695424453774*^9, 3.480695426213916*^9}, {3.4806958612576303`*^9, 
   3.480695861809552*^9}, 3.480697041276504*^9, {3.480699306305072*^9, 
   3.480699307040391*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.03093422318713476`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.005708650614527121`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4806971192435513`*^9, 3.480699516644302*^9, 
  3.481566985502486*^9, 3.481942060779174*^9, 3.662624769885214*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV13k8VOsfB3C0EJLspIuSshNtwkebuCHK0kaijRBmzgwzk50yjDNZElGR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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 0.01577331278116163}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"AODL", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.479666887455168*^9, 
   3.479666888838862*^9}, {3.480244879780376*^9, 3.480244897499516*^9}, 
   3.4802450058581*^9, {3.480695043059854*^9, 3.480695043824891*^9}, 
   3.480695087059374*^9, 3.480695404783731*^9, {3.4806958623058577`*^9, 
   3.480695862857663*^9}, 3.4806970427358437`*^9, {3.480699307709909*^9, 
   3.4806993083441687`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], LineBox[CompressedData["
1:eJwV1nk4lN0bB3AUIkt2QiSVolLRIny1StErSqhUvJaiYszMM3YiMozGnu15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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 0.013}, {0., 0.03093422317893168}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.48069712546273*^9, 3.480699525015361*^9, 
  3.481566993083891*^9, 3.4819420608359413`*^9, 3.6626247782161903`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "AODL", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "AODL", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.479666890574193*^9, 
   3.479666892310862*^9}, {3.480695044500922*^9, 3.480695045299432*^9}, {
   3.48069586344763*^9, 3.480695864000742*^9}, {3.4806993090802107`*^9, 
   3.480699309671587*^9}}],

Cell[BoxData["0.005708650614527121`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.4796669544241667`*^9, 
  3.479667628122774*^9, 3.480244912925961*^9, 3.480692316685502*^9, 
  3.480695182351778*^9, 3.480697125524988*^9, 3.4806995251344767`*^9, 
  3.481566993139513*^9, 3.481942060861919*^9, 3.662624778303006*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "AODL", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "AODL", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.479666893782012*^9, 
   3.479666894910797*^9}, {3.480695045805807*^9, 3.480695046244318*^9}, {
   3.480695864548365*^9, 3.4806958649909143`*^9}, {3.4806993103161793`*^9, 
   3.480699311077731*^9}}],

Cell[BoxData["0.03093422318713476`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.479666954466415*^9, 
  3.4796676281467333`*^9, 3.480244912993281*^9, 3.480692316727179*^9, 
  3.480695182407237*^9, 3.480697125554319*^9, 3.480699525202236*^9, 
  3.481566993161881*^9, 3.4819420609176197`*^9, 3.662624778357869*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"AODL", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, {3.662623603106723*^9, 3.662623611969966*^9}}],

Cell[BoxData[
 TagBox[
  TemplateBox[{RowBox[{
      StyleBox[
       TagBox["InterpolatingFunction", "SummaryHead"], 
       "NonInterpretableSummary"], 
      StyleBox["[", "NonInterpretableSummary"], 
      DynamicModuleBox[{Typeset`open$$ = False}, 
       PanelBox[
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{}, {}, {
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAA9Jy5H31I7j0AAEDyw4AhPteHf6z0
xis/ZkCNbIEJYD/Ya/HxBPI8P4b+RtoeqnA/S+q+O5CART/kAdaduad4PxoB
FyvRZEw/qjin/SUwgD80/yRbTe9RP0Ubj0jiSoQ/EC41W1ZsVT++mUrFRQaI
PyvQMqkjNFk/+lXwgPnxiz9/Y3mNSupcP/dUR5kPpo8/hFMb1kowYD/uvADY
wnqRP+iucIzSEGI/S18haVYwkz9nYgFgbNFjP/Kx549dspQ/gY62/jKJZT9k
B7k38BaWPzt0YsRbZmc/qsoHIrt/lz8PskmnliNpPyL8zbgut5g/g6knsTMG
az+0wSz2oOyZP5MZKob932w/Fs/fvAP/mj+94Wd42ZluPzlLbB/W5Js/wzHO
yIs8cD/xDPCHH8GcP7UeBuQzHHE/qwIIjO5znT93aLkSjQ5yP5hHsRPNGJ4/
h+7+pnz8cj+ON1Twz52eP6Ug4kl12nM/BdrJhBMBnz+Sr0AAH8t0P0jdGccl
Up8/jeo8xdGrdT8aQ4wqG4afP9Zhy+8aiHY/FSkOkrajnz/vNdUtFXd3PycP
HlIUrZ8/FbZ8ehhWeD+vHMo6y6GfPwuTn9rMR3k/6WqNSAGBnz9PrFSgFzV6
P6zmfCWVTZ8/oHGndGsSez/W9H19xg2fP8GTdVxwAnw/F6XAgcC4nj/vYeFS
fuJ8P5tYmqzhW54/a2zfriK+fT9GAaR3f/WdP7fTWB54rH4/yyy0A/h6nT8Q
52+c1op/PxLVuLs6/5w/nCsBF/M9gD+AjXM1JHCcP7Y5GWd/roA/nNjcDETj
mz/3Zfrp1hyBP6I+7MmJU5s/oECZ9oaUgT+UewbYR7KaP1Dxhoo7BII/vs5c
PNgXmj9oUDKoSH2CPyfoO2wrbZk/p82m+CD0gj+8OmirJ8OYP+0gatD9YoM/
OG3f2UMjmD+aIusxM9uDP8pAGJwVdZc/Tvq6Gm1LhD8XRNnpfNKWPynwUzZy
uYQ/gz4Pv5Azlj9slKrbzzCFP5wPuVM1iJU/tg5QCDKghT9zdMQm2OmUP2g3
s77sGIY/IrK+dy1AlD9Bft+nco+GP+GcavognJM/IJtaGP39hj/0BqedmQWT
P2dmkxLgdYc/okyTNVVlkj+1BxuUx+WHPzVrmenK0pE/a1dgnwdfiD8OuOo+
dzeRP0jFbt0S1og/n5isKbWikD8rCcyiIkWJPyvyEf1PG5A/dvvm8Yq9iT9x
KWoLnxiPP8jDUMj3LYo/EgwAL98Ujj/xlDZvvp+KP/UEivJZFY0/rlvABg==

                   "]]}}}, {
               DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                PlotRange -> {{0., 0.013}, {0., 0.030933682930039865`}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{}, {}, {
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAA9Jy5H31I7j0AAEDyw4AhPteHf6z0
xis/ZkCNbIEJYD/Ya/HxBPI8P4b+RtoeqnA/S+q+O5CART/kAdaduad4PxoB
FyvRZEw/qjin/SUwgD80/yRbTe9RP0Ubj0jiSoQ/EC41W1ZsVT++mUrFRQaI
PyvQMqkjNFk/+lXwgPnxiz9/Y3mNSupcP/dUR5kPpo8/hFMb1kowYD/uvADY
wnqRP+iucIzSEGI/S18haVYwkz9nYgFgbNFjP/Kx549dspQ/gY62/jKJZT9k
B7k38BaWPzt0YsRbZmc/qsoHIrt/lz8PskmnliNpPyL8zbgut5g/g6knsTMG
az+0wSz2oOyZP5MZKob932w/Fs/fvAP/mj+94Wd42ZluPzlLbB/W5Js/wzHO
yIs8cD/xDPCHH8GcP7UeBuQzHHE/qwIIjO5znT93aLkSjQ5yP5hHsRPNGJ4/
h+7+pnz8cj+ON1Twz52eP6Ug4kl12nM/BdrJhBMBnz+Sr0AAH8t0P0jdGccl
Up8/jeo8xdGrdT8aQ4wqG4afP9Zhy+8aiHY/FSkOkrajnz/vNdUtFXd3PycP
HlIUrZ8/FbZ8ehhWeD+vHMo6y6GfPwuTn9rMR3k/6WqNSAGBnz9PrFSgFzV6
P6zmfCWVTZ8/oHGndGsSez/W9H19xg2fP8GTdVxwAnw/F6XAgcC4nj/vYeFS
fuJ8P5tYmqzhW54/a2zfriK+fT9GAaR3f/WdP7fTWB54rH4/yyy0A/h6nT8Q
52+c1op/PxLVuLs6/5w/nCsBF/M9gD+AjXM1JHCcP7Y5GWd/roA/nNjcDETj
mz/3Zfrp1hyBP6I+7MmJU5s/oECZ9oaUgT+UewbYR7KaP1Dxhoo7BII/vs5c
PNgXmj9oUDKoSH2CPyfoO2wrbZk/p82m+CD0gj+8OmirJ8OYP+0gatD9YoM/
OG3f2UMjmD+aIusxM9uDP8pAGJwVdZc/Tvq6Gm1LhD8XRNnpfNKWPynwUzZy
uYQ/gz4Pv5Azlj9slKrbzzCFP5wPuVM1iJU/tg5QCDKghT9zdMQm2OmUP2g3
s77sGIY/IrK+dy1AlD9Bft+nco+GP+GcavognJM/IJtaGP39hj/0BqedmQWT
P2dmkxLgdYc/okyTNVVlkj+1BxuUx+WHPzVrmenK0pE/a1dgnwdfiD8OuOo+
dzeRP0jFbt0S1og/n5isKbWikD8rCcyiIkWJPyvyEf1PG5A/dvvm8Yq9iT9x
KWoLnxiPP8jDUMj3LYo/EgwAL98Ujj/xlDZvvp+KP/UEivJZFY0/rlvABg==

                   "]]}}}, {
               DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                PlotRange -> {{0., 0.013}, {0., 0.030933682930039865`}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["3", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["False", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
        Baseline], DynamicModuleValues :> {}], 
      StyleBox["]", "NonInterpretableSummary"]}]},
   "CopyTag",
   DisplayFunction->(#& ),
   InterpretationFunction->("InterpolatingFunction[{{0., 0.013}}, <>]"& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.66262477963708*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"deriv2", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "AODL", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "AODL", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.6626236050185127`*^9, 
   3.662623609386401*^9}}],

Cell[BoxData["1637.369766137467`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.662624779712291*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sweet spot relative to centre of coil", "Text",
 CellChangeTimes->{{3.453823657396553*^9, 3.45382366152324*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"AODL", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"-", "0.010"}], ",", "0.010"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453750960628242*^9, 3.453750962514122*^9}, 
   3.453823640869858*^9, 3.4538373938007517`*^9, {3.453838657031551*^9, 
   3.453838662984824*^9}, 3.453838901400448*^9, 3.453841257421837*^9, 
   3.4806948139055853`*^9, 3.48069586856068*^9, 3.48069931407596*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwt2Xk0VP//B3B70SYpsmStkKJEu5eoECGRCIU2shtzZ2wRkiVLyjLMvSUl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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{-0.01, 0.01}, {-0.030934220270433594`, 0.03093422209137373}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.45374974088566*^9, 3.453751021464161*^9, 3.453823734388617*^9, 
   3.45382595105693*^9, 3.453826495876092*^9, 3.453837430614188*^9, {
   3.453838660033111*^9, 3.45383867436195*^9}, 3.4538389289668913`*^9, 
   3.4538418441367064`*^9, 3.4638449203570347`*^9, 3.480692306252309*^9, 
   3.480697135921809*^9, 3.480699539484208*^9, 3.481567006130314*^9, 
   3.481942077639205*^9, 3.66262479351025*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"AODL", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.0", ",", "0.01"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, 
   3.453823640937874*^9, {3.4538265543875103`*^9, 3.453826559178968*^9}, 
   3.453837393850636*^9, {3.453838705965811*^9, 3.453838717842711*^9}, 
   3.453838901436325*^9, 3.453841257441544*^9, 3.480694814624156*^9, 
   3.480695869313149*^9, 3.480699314862365*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwV1nk4lPsbBnDJCSkdklBJUUgL/aJI7iJZEiJkrZAiyTIz74ydJqEUydhm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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0., 0.01}, {0., 0.03093422184696805}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4538234640829372`*^9, 3.45382375947115*^9, 
  3.453825952943671*^9, 3.4538265081040163`*^9, 3.453826563804844*^9, 
  3.45383743232346*^9, 3.453838725272155*^9, 3.453838935442772*^9, 
  3.453841854513754*^9, 3.463844932499839*^9, 3.480692315858614*^9, 
  3.480697141979739*^9, 3.480699548181242*^9, 3.481567013982223*^9, 
  3.4819420873711357`*^9, 3.662624801931018*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindMinimum", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"fz", "[", 
     RowBox[{"AODL", ",", "p"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.005"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823404829797*^9, 3.453823405956604*^9}, {
   3.453823506088236*^9, 3.453823516693254*^9}, 3.453823641011278*^9, {
   3.4538265379087467`*^9, 3.453826543745769*^9}, 3.453837393910678*^9, {
   3.4538387257460747`*^9, 3.453838749683352*^9}, {3.4538387973199577`*^9, 
   3.453838821469616*^9}, 3.453838901466652*^9, 3.453841257454495*^9, 
   3.480694816395583*^9, 3.4806958708335733`*^9, 3.4806993158810596`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.030934223187089317`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", "0.005708643128291139`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453823468555167*^9, 3.453823535452108*^9, 3.453825954168241*^9, {
   3.453826526324848*^9, 3.453826545225122*^9}, 3.4538374328189507`*^9, {
   3.4538387298936996`*^9, 3.4538387449128933`*^9}, {3.4538387984605837`*^9, 
   3.453838822542676*^9}, 3.453838936153399*^9, 3.453839519837987*^9, 
   3.453841855442709*^9, 3.463844933406391*^9, 3.48069231649853*^9, 
   3.480697142379641*^9, 3.480699548871449*^9, 3.481567014542268*^9, 
   3.4819420880567417`*^9, 3.662624802649501*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["New coil calc for bigmagnetvals5", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, 
   3.463844192181329*^9}],

Cell[CellGroupData[{

Cell["\<\
bigmagnetvals5 = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.005,\t\t\t\t(* length of half-big magnets *)
\t\ta->0.005,\t\t\t\t(* radius of half-big magnets *)
\t\t(* coil length *)
\t\tcoillen->0.16*0.0254,
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.35*0.0254,
\t\tcoilrad2->0.55*0.0254,
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453837228357688*^9, 3.453837230833909*^9}, {
  3.463844183252262*^9, 3.463844223147016*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.0029059732045705585`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.012999999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.005`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.005`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.004064`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.002032`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.002032`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.008889999999999999`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.01397`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.9375038750077497`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.463844933665338*^9, 3.47966690722052*^9, 
  3.4802449126813803`*^9, 3.4806923165771303`*^9, 3.481941607857794*^9, 
  3.481942088088718*^9, 3.662624802714809*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "BM5", "]"}], " ", ":=", " ", "bigmagnetvals5"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, 
   3.463844187524227*^9, 3.463845359588154*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "BM5", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.6371543615438662`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.0050900302724624065`"}], "}"}]}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"fz", "[", 
          RowBox[{"BM5", ",", "z"}], "]"}]}], ",", " ", 
        RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.479667008672338*^9, 3.4796670332310963`*^9}, {
   3.480244318582687*^9, 3.4802443450940313`*^9}, 3.6626239941508102`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.6371543615438757`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.005090030919822695`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.662625110723606*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "BM5", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nc8Vf8fB3ANo5KZFZUVDX1pkKyXSsMsWREZTXvcc+xN4qLQoK3SllQq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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 0.6371543536135365}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BM5", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.479666887455168*^9, 
   3.479666888838862*^9}, {3.480244879780376*^9, 3.480244897499516*^9}, 
   3.4802450058581*^9, 3.662623996847999*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], LineBox[CompressedData["
1:eJwV1nk8VF0YB/BJJLtsqVRSitIeeSt+thZr2pBEKFv2uWPNUqSMZClrSYuW
VxQRUbYSkmQmLYSYuaKSyptd9Z7+up/v557nnuWe8zxnkZPP7iMCDAZj+jQG
4++zQqY73nLzkM6/7T3SLxR8dK0+yNw7WNaiO66beOd2tBlSn/ht/qesW9f7
sJXT0Wg7lGguYiwr+667/r8FHMNoT9QNBvHmlzGgIGdlJxN9DBbPc/bMKZNG
VOmp/05EnUFy2Sbx2WXKWGmqePPQ8YsoLjjZL1+2BklmKhv6gvIw4PvDUsVL
H4P7qq2Noyugqmh+7gffGLcfTuj9qXoKm6dzehYq7kJR66YJT7cm/FAuYJmn
78P7mvyVs/M46Jw+/1fq8/0wlo+fvbmqFUoi+dP6bOyhlDqiNvbhLQQ26euG
ujmCobrlzuLSdiivnz0sHe6M79+8/vVa0gm3ivDP/1YfAXOXVrtb9AfYxu1q
a+lwRfmxivWSld1QFt8eZT3oDr2Dmt5hqT1wU/uUu2vUHZk7+sZ7M3pQYBTH
NWV44Bjjj6lZVg8Q9nKRnowH3n+8YCiT0wP7QetqNS0P5J7TPBFV2IOLLW6/
xsM8UPLJ22zyeQ8UU9iBFyWOYka57x29Pz2QWtB8tEfDE/f7RPTVHXhw6dv3
XF/TE3GvHu5/5cjDo4LO5Vd1PJHNc44NPcyDm+HXT04WnlDn6Kyqc+fhsZu4
G+3jiYz6g8lGFA8BRSaH++55oni7/afe0zx07Ki3+6rthe2yw+KPCni4xaw2
Hzfyxpp7uv/UTPBgGGVQLmHhjUmjm0mLfvHQlVy7VMXaG/ZFd8oj/vAgd6/h
j4m7N1i2aRGagnxEfm8pvBjvjefhNz7GSPBh49Ujr/fGG06mEahZyIeIq0BX
jKsPagepB6kGfOQERJtc8PWB2VPhhkIjPvRiZpTeDfbBFtnZRY3b+Ai4Lpr4
Ls4Hu5q05o+Y8MHjyxgsL/AB/fKW2fo9fJQfWnzjxZgPmFOhntud+dBcqbJR
dKsvTtub+bcd58MtpE0jwtgXbVdN596K4uNifaLKT3NfpHF/VFAn+RBw+iPR
ZeULx5OcceFYPppTO+hCN1886c/aqZBI4hlpyfvP+MLqj0oTN4uPC6/EBm+9
8kWJjcp/L0pJe+Un/PnvyPdUqjvtysj3vEPakjt8oXONzflUTuJnfqo91uuL
/vMDb35V8LFBp+6C5agvtpanO0nWkvgbkcZjc/1w9LxAL+clH9NChnO2O/mh
levb2dvLx6Os7BIfFz8oNG1ertxH1qPGuCHNww8/fsY32/TzMTDz0pc+fz9E
dR9Y+PQzH2/Stq07HeWHDVbnBmK/8ZF7P62qIccPe6tr42vH+Nj945924z4/
yKUK1TBEaYjL01/8vvjBdGDx0xliNOq1z/7K+Eba3ypbKSZOY0skT/nzqB+u
OYyulJKksVQqzpU90x/FZxNGpsvQmNDo+Nmo7g9ZxcszrsyhcdUtXMrM0x/5
A9SCvGU0Iu5eX9bs648o0+t7k9Ro2I00wZLlj7TvvSWUOg356Hm+e8P94aH3
eprWChqnsx+02CX6Y/pMnZqrq2j4vBlK8ir2R1kK77CqJg2z+XNzvz3wR+Vr
Ovsrsdph/cd+Ff5wUlCQLtaiwfuRMMSq80fRjrjkzdo0rCRW7gl/5w+TS2kr
NTeT+Ri5yiVM+eONt6X+Kz0ac+LOasyaxoSSx6hshD6NEc59o3NCTEQFiqqq
G9AocBBkpUkyUWj1RjDIkMbi0Cuvs5WZGHt+5DljGw3Re+9TC4yYWGlYP1Fp
QqNvTODuOmMmtNrEJi1MadRieX2xORPnjTcYdhKHvQgafWDFhGZ3d/5PMxrf
++VtatyY2GFSPym5k8bbhZZzuGeYcFnHFBjaTcar42EunMTEAe4zSYc9NC7b
Rh/fksKEVNPVa43EbikPPt3IYiLh5qRH1l4aY6KLykPvMOF9vjhkrRVZb7XN
gwX3mJD+z68jmbh66z6VjyVMqH7MSxwijo2MZVtWMaH2etLyjjWNuSM/bFVb
mCjJypKQ208jXFY8wbaVCeuqcNqdmLdm6ZOEd0y0JhqaVRLnHrVdMdHNRL1v
aIuTLY3NPY8nm38wMTMjoizzAOm/6dzFIFkKcZox4XUHSf+f8lvyZ1NICWjN
FrKnsUS4QZA/j4LS4A4bQ+IB/SlP8yUUjDtuZpQTh5Ue1lHRpDB6xsg+3YH0
3xruZ/0PBTclzX1NxNuG0q+f0aFQdH7Bp9/EkitfSIxupZD0buCTwyEal65q
dj23orBOOffgLEcaAtU7ZaYdoGAVc9dkE7FLp/s2LQcKjNzH7xyJVyteunPZ
lUL3mnntecTnNR/wXh+l0GPgatFCPLabqyDmS8HQpebIEHF1/IwIVhCFjruh
PuucyHxuKxflHqOwOkefaUl8umFT34dICiLGZkpexJbTfXaaxFIILsx0uEpc
rBwbFRFPwdRku9hDYkXda6XFSRSS17wz5xL3BL1duDCTwpekmY1TxG5l3rZ3
LlHoDDZPmuVMY3BcKEXnGhk/f1rdEmJqU9bLppsUosKE3LWIJ0I2iNrlUaBv
joZsI458+NzoSwGFRt/gqb3EwlNOESH3KXRJaQ86Ep/dMlEmUk7hYbzYLi9i
ubCkn+mVFE6GrlMNJM6sUFut9oTCDllVrwjiRb+r3EvrKSiOhi6NIb6la52z
rYmClMPqPXHEqyIGu163UMi4KfPxLHFx1ck5R15TsB8pnUwk3syYv/dnGwWt
0E8xScSP9YrPRnVREDi2/vTf9zuOmz6T4VNo6d/G+BvfXMObfrWPgsyHzG+x
xPsEQnTXDpD5FWpZRxN3GMwKrv5O5nc+ZWMYsVPUraKdwxQOX7ZLooj7n2Cw
a5xC8UNxpgexj+BbNe/fFNo+/JNrTzxi5O38S4CFrbe0qV3Ex04KXTojzEJd
yqFHBsQCdRffzRNn4ecC+Yh1xLEzNsjelmZB9JRmlTKx9Pbn5pvkWQiKqA+T
IE495XT62RwWbp2sLh8j/0+pYfyxzQIWPIV+BvCIr81M+tWnwsLjcEZRI3FB
bJX/DA0WtCRm3Ukl1mq0yk9Zw8IJx63eIcQVooN9SzRZGJJm3LUjboxTOmio
y8KsvqYqpb/7q6kojWvAwvfevLMTZH++FTflOm5nYZC5lfeGmI4P3h5pyYKR
4gelOGKPZukTUvtYMHlbKehM/EPy1qNL+0n8je3UP8S/E96srXBiYW6a12AP
OU+KyeuVJigWmHJzDi36e764jVaxwSReeSTjKzl/qrJOSYrhLEzViDg+IF53
PnHGxlMs2Op8zTAmNkv9+p2ZwYLFTlaTLTnf3DfRK6ZfYkE9p/LEPOL9s5Vc
kq+ycNs67nk7yRcu6SbvC26zMHzl9ax9xJGZN59+rWChdW3odW07Gp7K96tc
H7OweUOJ4zeSb2xuPC7rqWNBOzfvcQ7xmnud+a9fsjA+/IglRtzzTDa1ooeF
WNbuwgaSvwzGI1zihQJw5Z2P6HTrv/s1/pCwaAAMDBgOOSQ/zhW6YHtcMgBz
7yQ7GREPSZdYsGYTr2AHRe4j/09tQOugegAkEsyH+kk+FrSxEV5pHoCPUjr/
hlqS/N55ZNrNXQGYl39ZayZxhzNzUtkqAHsGBo+dI/m+2OfsNzmHAJzxu6F1
w4LGkVO1b6d8AxA4U9X3EakPdSVrbjWdD0DjhsmYvB1kv8mLGHt2BKCW13E5
GzSm/EQcMroDUKHIGJIk9m0WYdXRAXhdVrMxTJfUv1OiV5S/BkCvdPY1Kx2S
n8bFxlt/BYBxxVr41yaSvzok/9VZGIh6/XvWiqR+jl2TE5FyCsTd6KXMeFKP
PRnyC7e4BGLQ9q1lx3IaH+zkNd09ApFzY9n65cR18gqOT/wD0Xtwi/ATUt/P
n5pdFhgVCDH1ml/9qmT9j851784JRGvJcMIMZRqu65SfFfYFwsUlgBsnS8Zf
mNWrPRCIJK9nRbnkPpG8dp5A9fdAqK/ZFNkwi0blGoXNzeOBMDywoJMhTUNh
tXj+Z7EgrHgleP8wuZ/UrhhLXLwmCAFm5wLHBWkoq7bYpAQFYSgm5uSBYT7a
Z0f2B4kEQ2eAMbz4FR+jXt+ViySCoTn/5B15Lh9ytYf2f50VjBq/c+kzOHxY
+Oo3Os4NBmPBJsbHZj6eNAjkmawIBveFzooLjXzkBZ/0UTIPhly/+/4PNXyE
v2ePVCUGw/FMdgD3Lh8q2SmCwoohSDLK+B5G7pOtEVt+Gy0Khfv+VVeCtPiY
p66RJqh/DLANbdbm8rCR4mjEmYdBj60ZUefJQ/+pKsdzvuFIbGdofx3twfRh
Xcr0bARa2uc31Uf0YHxauf4Rs0j89FNSnSveg4dfx9J7OyJR2+bO643rhmtu
svcz5+Po/c2TS5fpRoPs8Dqh/uO4UBDzu1vzA6ieybrjgSdQvMeiS3pdF0Qj
D7Y5/jqBqq5VMtV6nfhywvnhibNRsFgtXRml04ESq9p5wgrRUIxwv33O4j20
3n714GdGo3NB74NR13ZMe/QwlrHiJJZU/fjvrH8bSvzopccLT2Jl4NrlrOR3
uB9XeM7AMAYJO95zfa6/hcfu7d8OcGOwUN1bdPLxG4h83vjsnfUpyLmsbWUP
v8ZQb5N/av8pXFCck2I6/zXq7j3KLPU5jfE84b7s/a3YqcEqXPPzNCperWjL
z34FFVFu2ueoWPhl/fA43cFF94PYKWFRNiTl3l/N1OBCQ9fijb04G02CGadT
1bkIeiJTcF+SjZwoKTp5KRezmi84O8uyUV8nNXVGmQsDfn5jpRIb3XmVd2Pk
uMiR4KazVrNxV6lUOXGKA3enuZr8vWxkp+X+mWjioKSvS3KTNRuPRDWShBo5
EPC61p+4n41dA35p0vUcZAZqXNS1ZyPtWY2AWg0HTWd0p2e6srEz9/4eu/sc
rCp14liGsMFmTrxrz+IgZMuy2zePseGj51EykMlBXc2X6N/h5H3ToZl/0jhw
aKK086LYMHGUm6mazEFiT0y2cDwbFx5NRgTEcNDhYhpsn8DGgbntjDNRHKgN
SO25n8TGEW2hkSuRHNSMpM9wTmVjGKt0XoZwIHnsYHdZOhuCmrIJHwM5sJ2m
Ui59gY2Cjcv2/aY4uBHz8ZxrFmnf4JSg4M/BkNhtr8psNvSdKnVW+3DwPxG0
0vU=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 0.013}, {0., 0.6371543536186894}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6626251467152987`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "BM5", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "BM5", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.479666890574193*^9, 
   3.479666892310862*^9}}],

Cell[BoxData["0.005090030919822695`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.4796669544241667`*^9, 
  3.479667628122774*^9, 3.480244912925961*^9, 3.480692316685502*^9, 
  3.4819416080006037`*^9, 3.4819420881974697`*^9, 3.662625146797575*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "BM5", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "BM5", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.479666893782012*^9, 
   3.479666894910797*^9}}],

Cell[BoxData["0.6371543615438757`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.479666954466415*^9, 
  3.4796676281467333`*^9, 3.480244912993281*^9, 3.480692316727179*^9, 
  3.481941608053739*^9, 3.4819420882381277`*^9, 3.662625146876009*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "BM5", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"BM5", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, {3.662623628457925*^9, 3.662623630065835*^9}}],

Cell[BoxData[
 TagBox[
  TemplateBox[{RowBox[{
      StyleBox[
       TagBox["InterpolatingFunction", "SummaryHead"], 
       "NonInterpretableSummary"], 
      StyleBox["[", "NonInterpretableSummary"], 
      DynamicModuleBox[{Typeset`open$$ = False}, 
       PanelBox[
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{}, {}, {
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVz3swGwYAx/EwK72tbZrWicd5taupmUcq09H9rD2l1LuY6q7K0niEoPHq
EEEiSctYsu6suTHrQlvl9sC4NncbrThsQiXINCKpVawilqvNsHV/fO/z99ct
nRlPsyQQCMEv+1+zpN+lInz1BIEw8WrSZNZ7qjp2p/mRFzKbbk5d6WjHTI7J
ZLUejDmL4WxJ44+INMiCGqtCsWX3gyfnjZ/hYGHnpfjoLMqXpH7u8mEc+/dw
apQxDo3z9v3nBsZBfDsgNYmRiN4h/tcW1xTwmvC/fehYCrqdxHTrhMdgZ5TV
RxguoC9QRIs1KFGb4KiM8E0Dq3Z9c8ZvFs+68q9PEtORazzfcJKjBj3dIo2h
yMBxiTohqmoenIbeHX8BDbaO5LijURoEsdKHUi/TsdbyXMUWLGDfd2fabxzK
QnZPPNMvTIua2x7fUnbl4HTIDrdjSwuR/VHetoaBe83SO9U3FvFASy+dbc6D
3Fzj9BVRh0G/X+TXgvPhnRhKTqvUocd5l57iVABx5AyJOqFDSWY/qX5vIfDu
2P3sA3rUre5Iy7cKwaRRPCZC9PjGdfFM0dwV+Gx//pkuRY9Pu0MILqMsyNZd
RwQZetQbgh8q7haBppbaJXyoh/LSqNGBX4yn5inukQg9jAHT3rYlJai5H21l
86Yetr3lV8lJpXBpY99a2dLhNVHL3FhYGVShnIiTgzrEdJ5rtQu4isXrp6t1
VTq0FrSzckgfYymxICMtSIefREUX8i3LwVLtc55+tgjjJW185WI59sdFJdu8
/M9haLrcZRU4wGV/mRiyiL6pD5xLOytR/0i++7BGC+LvTIlSyEb+C774FEcL
iZeF3Z8nqqBJbvKRk7XoPW5PZ3dVYcX8enhMzwI2aJvLSicOWtmhe4TxC2gN
aX7BE3PQFBGtPTiuQayJJwyyqobz8rj3kKUGmbH+HeEV1WiYGRC0ejxB+7j0
L1dzNUplltFpcfN47po9sZ1eAw1n/55V4W/4wn3Fj6KuwT2jgajtUSN6c8Ah
N7IWZZ3UlFzTHDzXEqiF/bXwdDorraLMgSG+o/7Vl4tAel/CcOYsevfG2vi3
cpEV3GR4pXsGme98L/uDzEPXrYvpbcsqvF+paS/8hAeGs+DJwbdUcL15nry9
zcMoaceXylaCfllEWiiqA5UYxnORT6PH2lE8/LQOA3xWVr7bNHKS01qsL/Lx
d74Fu7jgMcIf5s2TlHzYho3EsEam4LV7rM09VIC81M2NNd8pFP+zZBI+EMA9
UN1CaZyEfDBWvuEthMTtLrdgRwGTmMqUtQhxRDQZ5MNU4D855M/k
                   
                   "]]}}}, {
               DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                PlotRange -> {{0., 0.013}, {0., 0.6371506622595786}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{}, {}, {
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVz3swGwYAx/EwK72tbZrWicd5taupmUcq09H9rD2l1LuY6q7K0niEoPHq
EEEiSctYsu6suTHrQlvl9sC4NncbrThsQiXINCKpVawilqvNsHV/fO/z99ct
nRlPsyQQCMEv+1+zpN+lInz1BIEw8WrSZNZ7qjp2p/mRFzKbbk5d6WjHTI7J
ZLUejDmL4WxJ44+INMiCGqtCsWX3gyfnjZ/hYGHnpfjoLMqXpH7u8mEc+/dw
apQxDo3z9v3nBsZBfDsgNYmRiN4h/tcW1xTwmvC/fehYCrqdxHTrhMdgZ5TV
RxguoC9QRIs1KFGb4KiM8E0Dq3Z9c8ZvFs+68q9PEtORazzfcJKjBj3dIo2h
yMBxiTohqmoenIbeHX8BDbaO5LijURoEsdKHUi/TsdbyXMUWLGDfd2fabxzK
QnZPPNMvTIua2x7fUnbl4HTIDrdjSwuR/VHetoaBe83SO9U3FvFASy+dbc6D
3Fzj9BVRh0G/X+TXgvPhnRhKTqvUocd5l57iVABx5AyJOqFDSWY/qX5vIfDu
2P3sA3rUre5Iy7cKwaRRPCZC9PjGdfFM0dwV+Gx//pkuRY9Pu0MILqMsyNZd
RwQZetQbgh8q7haBppbaJXyoh/LSqNGBX4yn5inukQg9jAHT3rYlJai5H21l
86Yetr3lV8lJpXBpY99a2dLhNVHL3FhYGVShnIiTgzrEdJ5rtQu4isXrp6t1
VTq0FrSzckgfYymxICMtSIefREUX8i3LwVLtc55+tgjjJW185WI59sdFJdu8
/M9haLrcZRU4wGV/mRiyiL6pD5xLOytR/0i++7BGC+LvTIlSyEb+C774FEcL
iZeF3Z8nqqBJbvKRk7XoPW5PZ3dVYcX8enhMzwI2aJvLSicOWtmhe4TxC2gN
aX7BE3PQFBGtPTiuQayJJwyyqobz8rj3kKUGmbH+HeEV1WiYGRC0ejxB+7j0
L1dzNUplltFpcfN47po9sZ1eAw1n/55V4W/4wn3Fj6KuwT2jgajtUSN6c8Ah
N7IWZZ3UlFzTHDzXEqiF/bXwdDorraLMgSG+o/7Vl4tAel/CcOYsevfG2vi3
cpEV3GR4pXsGme98L/uDzEPXrYvpbcsqvF+paS/8hAeGs+DJwbdUcL15nry9
zcMoaceXylaCfllEWiiqA5UYxnORT6PH2lE8/LQOA3xWVr7bNHKS01qsL/Lx
d74Fu7jgMcIf5s2TlHzYho3EsEam4LV7rM09VIC81M2NNd8pFP+zZBI+EMA9
UN1CaZyEfDBWvuEthMTtLrdgRwGTmMqUtQhxRDQZ5MNU4D855M/k
                   
                   "]]}}}, {
               DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                PlotRange -> {{0., 0.013}, {0., 0.6371506622595786}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["3", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["False", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
        Baseline], DynamicModuleValues :> {}], 
      StyleBox["]", "NonInterpretableSummary"]}]},
   "CopyTag",
   DisplayFunction->(#& ),
   InterpretationFunction->("InterpolatingFunction[{{0., 0.013}}, <>]"& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.662625159674733*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"deriv2", "[", "BM5", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "BM5", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "BM5", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.662623631777481*^9, 
   3.66262363489753*^9}}],

Cell[BoxData["38794.45907746318`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.662625159753221*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"plot", "[", "BM5", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<z (m)\>\"", ",", "\"\<F (N/A)\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, {
   3.453838538440839*^9, 3.453838572806719*^9}, 3.463844247723119*^9, 
   3.478894943196905*^9, 3.4788950132010527`*^9, {3.478961709433363*^9, 
   3.47896175216029*^9}, {3.478961842569364*^9, 3.478961894377494*^9}, {
   3.4789619830038633`*^9, 3.478961984506156*^9}, {3.4789699280628653`*^9, 
   3.478969982243393*^9}, {3.478970021389124*^9, 3.478970165180615*^9}, {
   3.478970224319232*^9, 3.478970261501657*^9}, {3.4789703108875017`*^9, 
   3.478970348344078*^9}, 3.478970398020482*^9, {3.478970871122594*^9, 
   3.47897087265033*^9}, {3.478971414854863*^9, 3.4789714317583723`*^9}, {
   3.4789723334965277`*^9, 3.4789723911200447`*^9}, {3.4794964690726423`*^9, 
   3.4794964944567127`*^9}, {3.479496975356181*^9, 3.479496976183571*^9}, {
   3.47949787094656*^9, 3.479497874578391*^9}, {3.4794981429899273`*^9, 
   3.479498147044504*^9}, {3.479498193967552*^9, 3.479498236581649*^9}, {
   3.479662116006764*^9, 3.479662117075882*^9}, {3.479666955542605*^9, 
   3.479666963425733*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], LineBox[CompressedData["
1:eJwV1nk8VF0YB/BJJLtsqVRSitIeeSt+thZr2pBEKFv2uWPNUqSMZClrSYuW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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"z (m)\"", TraditionalForm], 
    FormBox["\"F (N/A)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 0.013}, {0., 0.6371543536186894}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.478970312655707*^9, 3.478970349956621*^9}, 
   3.4789703994875298`*^9, 3.478971607584939*^9, 3.4789719008193083`*^9, {
   3.478972321794873*^9, 3.4789723915815496`*^9}, 3.478973514856566*^9, 
   3.479486967021886*^9, {3.479496470359309*^9, 3.479496495124946*^9}, 
   3.479496976846184*^9, 3.479497079117694*^9, 3.479497903680291*^9, 
   3.4794981476612797`*^9, 3.4794982377851954`*^9, 3.479663512480014*^9, 
   3.479664582004204*^9, 3.4796657495921383`*^9, 3.479665823576626*^9, 
   3.47966696773402*^9, 3.479667628752988*^9, 3.480245019281752*^9, 
   3.48069231710384*^9, 3.481941608391829*^9, 3.4819420887496758`*^9, 
   3.6626251598288507`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["New coil calc for BOSEM (10x10 magnet)", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, 
   3.463844192181329*^9, {3.478894850822432*^9, 3.478894851717502*^9}, {
   3.4788951705281897`*^9, 3.4788951754720497`*^9}}],

Cell["\<\
bigmagnetvalsSA = bosemvals10 = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.010,\t\t\t\t(* length of big magnets *)
\t\ta->0.005,\t\t\t\t(* radius of big magnets *)
\t\t(* coil length *)
\t\tcoillen->0.315*0.0254,  (* SA email, 08/14/06 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.35*0.0254, (* unchanged *)
\t\tcoilrad2->0.65*0.0254, (* SA email, 08/14/06 *)
\t\t(* the number of turns *)
\t\tcoilturns->800, (* SA email, 08/14/06 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
];\
\>", "Input",
 CellChangeTimes->{{3.453837228357688*^9, 3.453837230833909*^9}, {
  3.463844183252262*^9, 3.463844223147016*^9}, {3.478894862544446*^9, 
  3.4788948852377567`*^9}, {3.478894985619047*^9, 3.4788949913587503`*^9}, {
  3.4788950240972023`*^9, 3.478895025494358*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "BO10", "]"}], " ", ":=", " ", "bosemvals10"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, 
   3.463844187524227*^9, 3.463845359588154*^9, {3.47889491108751*^9, 
   3.47889491212925*^9}, {3.4788949966551943`*^9, 3.478894997123682*^9}, 
   3.4788950699694643`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1.694858202857608`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.0071958504693359565`"}], "}"}]}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"fz", "[", 
          RowBox[{"BO10", ",", "z"}], "]"}]}], ",", " ", 
        RowBox[{"0.006", " ", "<", " ", "z", " ", "<", " ", "0.010"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.480244382554545*^9, 3.480244405961742*^9}, 
   3.66262400355859*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.6948582028562238`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.007195845485312815`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.66262557733585*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nk4VdsbB3BDRQiRWWiiwU9Cg8I31VUpogFxyVhRpCScc/Y5h5BOEyVT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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 1.6948581299755139`}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BO10", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.4794970273251*^9, 3.4794970280748262`*^9}, {3.479497850691868*^9, 
   3.479497851721608*^9}, {3.4802445496159487`*^9, 3.4802445841180058`*^9}, {
   3.4802446656757193`*^9, 3.4802446687524443`*^9}, 3.662624006302704*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], LineBox[CompressedData["
1:eJwV1nc8VX8YB3CjkhWRIrJHRRoaWj5NJUkhq6JIURmZ97r3XJcK3ZZRVkOa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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 0.013}, {0., 1.694858130003234}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.662625615035322*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "BO10", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "BO10", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.4796619220112333`*^9, 3.4796619454416037`*^9}, 3.479665671740583*^9}],

Cell[BoxData["0.007195845485312815`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.479486914888383*^9, 
  3.479659289850292*^9, 3.4796634565750093`*^9, 3.479665742764594*^9, 
  3.479665816570661*^9, 3.480243747684814*^9, 3.480692317253339*^9, 
  3.481566060871256*^9, 3.481941615983523*^9, 3.4819420888840933`*^9, 
  3.6626256151021233`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "BO10", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "BO10", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, 
   3.479661922078005*^9, 3.4796619593447857`*^9, 3.479665787682528*^9}],

Cell[BoxData["1.6948582028562238`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.479486914934926*^9, 
  3.479659289887826*^9, 3.479663456628942*^9, 3.479665742793458*^9, 
  3.4796658166882772`*^9, 3.480243747711088*^9, 3.480692317295466*^9, 
  3.481566060924111*^9, 3.481941616034875*^9, 3.481942088922996*^9, 
  3.6626256151756268`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"BO10", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, {3.662623646129085*^9, 3.662623647656955*^9}}],

Cell[BoxData[
 TagBox[
  TemplateBox[{RowBox[{
      StyleBox[
       TagBox["InterpolatingFunction", "SummaryHead"], 
       "NonInterpretableSummary"], 
      StyleBox["[", "NonInterpretableSummary"], 
      DynamicModuleBox[{Typeset`open$$ = False}, 
       PanelBox[
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{}, {}, {
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVkmkw3AcAR5caxyiVbRJnHCtNGttN1z2p1V+OSeJKCSJVGldYtVvnOrtu
1tFskrLTliom6lYE0WGGNhPE1EaIsVKiiErZhM069vgvSfXDm/f1fXhW4XG+
keokEomxz//eruqzyHTbcCWRFlvr8lI/nSnKbtseoYJ7YDJnnH8PT1lSqcYm
Az2/zuqlsEfgKR50uZ1zHiIjjMf8PAETNUPq5HUvNIWI+6nz03B4ezTokuQy
biqWFDXcORicdAwKYF9BvNdENsdvEdQJu2Zrh0BwzVzLL5CXkR2RzvcQB+Nu
5lRTYM8KCvxMRR70UBDq3zVaGa9itT3+xhODcNRrrP/xZbUYzHC1UPZkBC5J
63PNV14h92bvG7uSSIxYPLLofFcCF074UFAUE+2rKdbP6l/jvS73xu+tv8LQ
9eaDZQ1S5Dcfv2uvycJ0k5puQ8cmyo1teHsLbKgYeizNhi0MLDHT/qqIRd1w
kL529jYe2I6PfsuIx5Xk2VWz4B3cM9f8x94sATn8YJ+HZjKkRveR+fqJcIuo
SQr/W4aijTcN3N1ElDyd+kB6Q456y+fuybNJoMdfTXhspUBZx2mSxRgHimXj
vLVuBfhixvBkazIOax88tkVTQhQ2JjEpTkHA0diOEz8qIXGcph1KTUVgvYDG
2VXiUC83wyggDWr+7tU2XgR0y2tmhRfTEcY5u1JXTsC7zb/W0DEDVlrBl1V/
EqhNaOSwyN9gJc118hcpgfvlycHx6lysjdl6CPVUkIQt+WY95+KI8ACdZ6oC
i73QThnMBKln61jlERV+m/rcPK0tC/SK/qiK91Uw+DeuSlSajeXbiZWn3xKo
oqoZbrnmgH9n48nIPIHeU8bM7PYctP7eIgzpISCPJNZEZrl4J907dTpvv+d0
hYwnyIVBYZzD0DkCPlJeqYtGHry7Bs4MkwhE+9g1uWXmYUaYpKPTqUTjowaF
5XYeygQpsZ6BSqxbxkzshedj6BShf01diUrKS1v7uXzQh7sizlYr8BnRb/K1
ZwEiLwpXZC4KnHjt55TYVwD5y8WSxhk52IKWucf0QmT4dzvrMOXo1ffRtqst
xIhAy3GHkCHauXvwlREPNh/TCo/ny3Ama6Ex8RYPo+agsnRlsPzpC6O9PR7a
nSz3fCt3wIwqJy8mF6H6ZDXlB/P9P7RMBQ9XirA+PkvhtmyDdTW0RiukGB+S
GTGxH23DbTh2niwqxgvxusFY5xaoOsI7lPMloBz+RD7ruoUU1Qtp6UAJhtNu
Xdu9v4nRBz6jclop1iQazue8NyEVOMUN1pQigeam4fVMiv8AYzrXyg==
                   
                   "]]}}}, {
               DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                PlotRange -> {{0., 0.013}, {0., 1.6947270890771051`}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{}, {}, {
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVkmkw3AcAR5caxyiVbRJnHCtNGttN1z2p1V+OSeJKCSJVGldYtVvnOrtu
1tFskrLTliom6lYE0WGGNhPE1EaIsVKiiErZhM069vgvSfXDm/f1fXhW4XG+
keokEomxz//eruqzyHTbcCWRFlvr8lI/nSnKbtseoYJ7YDJnnH8PT1lSqcYm
Az2/zuqlsEfgKR50uZ1zHiIjjMf8PAETNUPq5HUvNIWI+6nz03B4ezTokuQy
biqWFDXcORicdAwKYF9BvNdENsdvEdQJu2Zrh0BwzVzLL5CXkR2RzvcQB+Nu
5lRTYM8KCvxMRR70UBDq3zVaGa9itT3+xhODcNRrrP/xZbUYzHC1UPZkBC5J
63PNV14h92bvG7uSSIxYPLLofFcCF074UFAUE+2rKdbP6l/jvS73xu+tv8LQ
9eaDZQ1S5Dcfv2uvycJ0k5puQ8cmyo1teHsLbKgYeizNhi0MLDHT/qqIRd1w
kL529jYe2I6PfsuIx5Xk2VWz4B3cM9f8x94sATn8YJ+HZjKkRveR+fqJcIuo
SQr/W4aijTcN3N1ElDyd+kB6Q456y+fuybNJoMdfTXhspUBZx2mSxRgHimXj
vLVuBfhixvBkazIOax88tkVTQhQ2JjEpTkHA0diOEz8qIXGcph1KTUVgvYDG
2VXiUC83wyggDWr+7tU2XgR0y2tmhRfTEcY5u1JXTsC7zb/W0DEDVlrBl1V/
EqhNaOSwyN9gJc118hcpgfvlycHx6lysjdl6CPVUkIQt+WY95+KI8ACdZ6oC
i73QThnMBKln61jlERV+m/rcPK0tC/SK/qiK91Uw+DeuSlSajeXbiZWn3xKo
oqoZbrnmgH9n48nIPIHeU8bM7PYctP7eIgzpISCPJNZEZrl4J907dTpvv+d0
hYwnyIVBYZzD0DkCPlJeqYtGHry7Bs4MkwhE+9g1uWXmYUaYpKPTqUTjowaF
5XYeygQpsZ6BSqxbxkzshedj6BShf01diUrKS1v7uXzQh7sizlYr8BnRb/K1
ZwEiLwpXZC4KnHjt55TYVwD5y8WSxhk52IKWucf0QmT4dzvrMOXo1ffRtqst
xIhAy3GHkCHauXvwlREPNh/TCo/ny3Ama6Ex8RYPo+agsnRlsPzpC6O9PR7a
nSz3fCt3wIwqJy8mF6H6ZDXlB/P9P7RMBQ9XirA+PkvhtmyDdTW0RiukGB+S
GTGxH23DbTh2niwqxgvxusFY5xaoOsI7lPMloBz+RD7ruoUU1Qtp6UAJhtNu
Xdu9v4nRBz6jclop1iQazue8NyEVOMUN1pQigeam4fVMiv8AYzrXyg==
                   
                   "]]}}}, {
               DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                PlotRange -> {{0., 0.013}, {0., 1.6947270890771051`}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["3", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["False", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
        Baseline], DynamicModuleValues :> {}], 
      StyleBox["]", "NonInterpretableSummary"]}]},
   "CopyTag",
   DisplayFunction->(#& ),
   InterpretationFunction->("InterpolatingFunction[{{0., 0.013}}, <>]"& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.662625626200384*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"deriv2", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "BO10", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "BO10", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.6626236492010603`*^9, 
   3.662623652752903*^9}}],

Cell[BoxData["61049.68679663531`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.662625626266868*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f95plus", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BO10", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "BO10", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BO10", "]"}], "+", "0.001"}], ",", 
       RowBox[{"zmax", "[", "BO10", "]"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BO10", "]"}], "+", "0.005"}]}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658987032153*^9, 3.47965898990287*^9}, {3.479659310386307*^9, 
   3.4796593125701933`*^9}, {3.479661624172262*^9, 3.479661679901505*^9}, {
   3.479661945541445*^9, 3.4796619594445953`*^9}, {3.4796656734658623`*^9, 
   3.479665674680963*^9}, 3.47966578778349*^9}],

Cell[BoxData["0.008975706429658207`"], "Output",
 CellChangeTimes->{{3.479659290207419*^9, 3.4796593177022877`*^9}, {
   3.479661644377719*^9, 3.4796616514833097`*^9}, 3.479661686065053*^9, 
   3.4796634593803263`*^9, 3.479665745824663*^9, 3.4796658197389708`*^9, 
   3.480243751933235*^9, 3.480692320796873*^9, 3.4815660640155077`*^9, 
   3.4819416198814373`*^9, 3.481942093179961*^9, 3.6626256284126587`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f95minus", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BO10", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "BO10", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BO10", "]"}], "-", "0.001"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BO10", "]"}], "-", "0.005"}], ",", 
       RowBox[{"zmax", "[", "BO10", "]"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658997678957*^9, 3.4796590027188377`*^9}, {3.479659318794853*^9, 
   3.479659344898431*^9}, {3.479661657421668*^9, 3.4796616780054293`*^9}, {
   3.479661945775414*^9, 3.479661959545474*^9}, {3.479665675209929*^9, 
   3.479665676278386*^9}, 3.4796657878831253`*^9}],

Cell[BoxData["0.005594057700827178`"], "Output",
 CellChangeTimes->{
  3.479659290545846*^9, {3.479659322545879*^9, 3.479659348979048*^9}, {
   3.4796616661527233`*^9, 3.479661689555737*^9}, 3.479663462870864*^9, 
   3.479665749329587*^9, 3.479665823257647*^9, 3.480243756605932*^9, 
   3.480692324819867*^9, 3.481566067504561*^9, 3.481941624492373*^9, 
   3.481942097749235*^9, 3.66262563115217*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Measurement", "Subsubsection",
 CellChangeTimes->{{3.478970601031336*^9, 3.478970602486655*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v10", " ", "=", " ", 
  RowBox[{"Recurse", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"zflange", " ", "->", " ", 
      RowBox[{"0.1", "*", "0.0254"}]}], ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"end", " ", "flange", " ", "thickness"}], ",", " ", 
       RowBox[{"D060106", "-", "C"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"l", " ", "->", " ", "0.010"}], ",", "\[IndentingNewLine]", 
     RowBox[{"zplug", " ", "->", " ", "0.001"}], ",", "\[IndentingNewLine]", 
     RowBox[{"zcoil", " ", "->", " ", 
      RowBox[{"0.315", "*", "0.0254"}]}], ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"coil", " ", "length"}], ",", " ", 
       RowBox[{"D060106", "-", "C"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"zc", " ", "->", " ", 
      RowBox[{
       RowBox[{"l", "/", "2"}], "+", "zplug", "+", "zflange", "+", 
       RowBox[{"zcoil", "/", "2"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"newportcal", " ", "->", " ", "0.5"}]}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{
     "micrometer", " ", "to", " ", "stage", " ", "factor", " ", "for", " ", 
      "Newport", " ", "NVM80"}], " ", "*)"}], "\[IndentingNewLine]", "}"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478364871938177*^9, 3.4783650430215597`*^9}, {
   3.478365123922604*^9, 3.478365126702361*^9}, {3.478365254617469*^9, 
   3.4783652660805397`*^9}, {3.4783655084186296`*^9, 
   3.4783655130572557`*^9}, {3.47836555422621*^9, 3.478365578866078*^9}, 
   3.478366553883871*^9, 3.4783667391579103`*^9, {3.479485983949397*^9, 
   3.4794860302373734`*^9}, {3.4794860941303663`*^9, 3.479486095079904*^9}, 
   3.4794861957899227`*^9, {3.479502242049817*^9, 3.4795022420685263`*^9}, {
   3.47965572449089*^9, 3.479655724556625*^9}, {3.479655785531518*^9, 
   3.479655785532816*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"zflange", "\[Rule]", "0.00254`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.01`"}], ",", 
   RowBox[{"zplug", "\[Rule]", "0.001`"}], ",", 
   RowBox[{"zcoil", "\[Rule]", "0.008001`"}], ",", 
   RowBox[{"zc", "\[Rule]", "0.0125405`"}], ",", 
   RowBox[{"newportcal", "\[Rule]", "0.5`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.4794861147697887`*^9, 3.479486119482292*^9}, 
   3.479661794400094*^9, 3.4796627436715107`*^9, 3.47966574239032*^9, 
   3.4802437567011843`*^9, 3.4806923249227753`*^9, 3.4815660675895853`*^9, 
   3.4819416246164713`*^9, 3.4819420978508997`*^9, 3.662625631374776*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"m10", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "0", ",", " ", "0.5", ",", " ", "1", ",", " ", "1.5", ",", " ", "2", ",", 
     " ", "2.5", ",", " ", "3", ",", " ", "3.5", ",", " ", "4", ",", " ", 
     "4.5", ",", " ", "\[IndentingNewLine]", "5", ",", " ", "5.5", ",", " ", 
     "6", ",", " ", "6.5", ",", " ", "7", ",", " ", "7.5", ",", " ", "8", ",",
      " ", "8.5", ",", " ", "9", ",", " ", "9.5", ",", " ", 
     "\[IndentingNewLine]", "10", ",", " ", "10.5", ",", " ", "11", ",", " ", 
     "11.5", ",", " ", "12", ",", " ", "12.5", ",", " ", "13", ",", " ", 
     "13.5", ",", " ", "14", ",", " ", "14.5", ",", " ", 
     "\[IndentingNewLine]", "15", ",", " ", "15.5", ",", " ", "16", ",", " ", 
     "16.5", ",", " ", "17", ",", " ", "17.5", ",", " ", "18", ",", " ", 
     "18.5", ",", " ", "19", ",", " ", "19.5", ",", " ", 
     "\[IndentingNewLine]", "20", ",", " ", "20.5", ",", " ", "21", ",", " ", 
     "21.5", ",", " ", "22", ",", " ", "22.5", ",", " ", "21.10", ",", " ", 
     "21.03"}], "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.478359123403325*^9, 3.478359312201968*^9}, {
   3.478359382197403*^9, 3.478359482378661*^9}, 3.4783602880061617`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f10", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "21.6", ",", " ", "24", ",", " ", "26.4", ",", " ", "28.6", ",", " ", 
     "30.7", ",", " ", "32.7", ",", " ", "34.7", ",", " ", "36.4", ",", " ", 
     "38.3", ",", " ", "39.7", ",", " ", "\[IndentingNewLine]", "41", ",", 
     " ", "42.6", ",", " ", "43.8", ",", " ", "44.8", ",", " ", "45.7", ",", 
     " ", "46.4", ",", " ", "47", ",", " ", "47.6", ",", " ", "48", ",", " ", 
     "48.2", ",", "\[IndentingNewLine]", "48.4", ",", " ", "48.8", ",", " ", 
     "48.7", ",", " ", "48.6", ",", " ", "48.3", ",", " ", "48.0", ",", " ", 
     "47.4", ",", " ", "47.1", ",", " ", "46.2", ",", " ", "45.6", ",", 
     "\[IndentingNewLine]", "44.8", ",", " ", "44.0", ",", " ", "43.4", ",", 
     " ", "42.5", ",", " ", "41.6", ",", " ", "40.6", ",", " ", "39.6", ",", 
     " ", "38.7", ",", " ", "37.8", ",", " ", "36.7", ",", 
     "\[IndentingNewLine]", "35.8", ",", " ", "34.9", ",", " ", "34", ",", 
     " ", "33.1", ",", " ", "32.1", ",", " ", "31.3", ",", " ", "33.3", ",", 
     " ", "33.4"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.478358656639378*^9, 3.478358736957609*^9}, {
   3.478358785279069*^9, 3.478358785557148*^9}, {3.47835979499054*^9, 
   3.478360057375266*^9}, {3.478360132331086*^9, 3.478360132808681*^9}, {
   3.478360292284709*^9, 3.478360320802071*^9}, 3.478360369604032*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"c10", " ", "=", " ", 
   RowBox[{
    RowBox[{"zc", "+", 
     RowBox[{"newportcal", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m10", "-", 
         RowBox[{"m10", "[", 
          RowBox[{"[", 
           RowBox[{"-", "1"}], "]"}], "]"}]}], ")"}], "/", "1000"}]}]}], "/.",
     "v10"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.47837088802363*^9, 3.478370914162881*^9}, {
  3.478961618977281*^9, 3.478961625407113*^9}, {3.479486145012785*^9, 
  3.479486146227991*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"m10b", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "25.", ",", " ", "24.5", ",", " ", "24.", ",", " ", "23.5", ",", " ", 
     "23.", ",", " ", "22.5", ",", " ", "22.", ",", " ", "21.5", ",", " ", 
     "21.", ",", " ", "20.5", ",", " ", "\[IndentingNewLine]", "20.", ",", 
     " ", "19.5", ",", " ", "19.", ",", " ", "18.5", ",", " ", "18.", ",", 
     " ", "17.5", ",", " ", "17.", ",", " ", "16.5", ",", " ", "16.", ",", 
     " ", "15.5", ",", " ", "\[IndentingNewLine]", "15.", ",", " ", "14.5", 
     ",", " ", "14.", ",", " ", "13.5", ",", " ", "13.", ",", " ", "12.5", 
     ",", " ", "12.", ",", " ", "11.5", ",", " ", "11.", ",", " ", "10.5", 
     ",", " ", "\[IndentingNewLine]", "10.", ",", " ", "9.5", ",", " ", "9.", 
     ",", " ", "8.5", ",", " ", "8.", ",", " ", "7.5", ",", " ", "7.", ",", 
     " ", "6.5", ",", " ", "6.", ",", " ", "5.5", ",", " ", 
     "\[IndentingNewLine]", "5.", ",", " ", "4.5", ",", " ", "4.", ",", " ", 
     "3.5", ",", " ", "3.", ",", " ", "2.5", ",", " ", "2.", ",", " ", "1.5", 
     ",", " ", "1.", ",", " ", "0.5", ",", " ", "\[IndentingNewLine]", "0.", 
     ",", " ", 
     RowBox[{"-", "0.42"}]}], "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.480242266026979*^9, 3.4802422811926517`*^9}, {
  3.480242551485073*^9, 3.480242638696825*^9}, {3.480243603406623*^9, 
  3.480243604629949*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f10b", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "33", ",", " ", "33.9", ",", " ", "34.8", ",", " ", "35.6", ",", " ", 
     "36.4", ",", " ", "37.3", ",", " ", "38.5", ",", " ", "39.3", ",", " ", 
     "40.2", ",", " ", "40.9", ",", "\[IndentingNewLine]", "41.7", ",", " ", 
     "42.6", ",", " ", "43.3", ",", " ", "43.9", ",", " ", "44.5", ",", " ", 
     "45.2", ",", " ", "45.5", ",", " ", "46", ",", " ", "46.3", ",", " ", 
     "46.6", ",", "\[IndentingNewLine]", "46.7", ",", " ", "46.7", ",", " ", 
     "46.7", ",", " ", "46.7", ",", " ", "46.4", ",", " ", "45.9", ",", " ", 
     "45.4", ",", " ", "44.7", ",", " ", "44.1", ",", " ", "43.1", ",", 
     "\[IndentingNewLine]", "42.1", ",", " ", "41.0", ",", " ", "39.7", ",", 
     " ", "38.4", ",", " ", "37.0", ",", " ", "35.3", ",", " ", "33.5", ",", 
     " ", "31.6", ",", " ", "29.7", ",", " ", "27.6", ",", 
     "\[IndentingNewLine]", "25.6", ",", " ", "23.3", ",", " ", "21", ",", 
     " ", "18.5", ",", " ", "16.1", ",", " ", "13.5", ",", " ", "10.9", ",", 
     " ", "8.35", ",", " ", "5.70", ",", " ", "2.97", ",", 
     "\[IndentingNewLine]", "0.376", ",", " ", "1.90"}], " ", 
    "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.480242672165991*^9, 3.480242777357607*^9}, {
  3.4802428393374243`*^9, 3.480242994903599*^9}, {3.4802430986494913`*^9, 
  3.4802431295923853`*^9}, {3.480243226913352*^9, 3.480243571963694*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"c10b", " ", "=", " ", 
   RowBox[{
    RowBox[{"zc", "+", 
     RowBox[{"newportcal", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m10b", "-", 
         RowBox[{"m10b", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", "1000"}]}]}], "/.", 
    "v10"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.47837088802363*^9, 3.478370914162881*^9}, {
   3.478961618977281*^9, 3.478961625407113*^9}, {3.479486145012785*^9, 
   3.479486146227991*^9}, {3.480243648203948*^9, 3.4802436546744833`*^9}, 
   3.4802439178688*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1000", "*", "c10b"}], ",", "f10b"}], "}"}], "]"}], ",", 
   RowBox[{"AxesOrigin", "->", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.478358869240918*^9, 3.478358894149914*^9}, {
   3.478358970183876*^9, 3.4783590158067007`*^9}, {3.47836015386373*^9, 
   3.478360163119385*^9}, {3.478366673756214*^9, 3.478366679969379*^9}, {
   3.478367462673428*^9, 3.4783674799853067`*^9}, {3.478368631699589*^9, 
   3.478368685400792*^9}, {3.4783687314761667`*^9, 3.478368733441554*^9}, {
   3.4783687696995564`*^9, 3.478368770875265*^9}, {3.478370370616754*^9, 
   3.478370372904202*^9}, {3.478370502073501*^9, 3.478370514529298*^9}, 
   3.478370885346918*^9, {3.478370917867898*^9, 3.4783709191468763`*^9}, {
   3.478961631541224*^9, 3.4789616328231297`*^9}, {3.480243885079197*^9, 
   3.480243886827784*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.011000000000000001`],
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxdk8srRHEUx28S0jR5XMN4zmDGTFIyJEm/M2bmzgIppJSVoryysLHS/AFk
ozTKziOSBbFSRKywGBaGhWQhK6Yh5BHzO9+fhVO326fP+Z1zOvd37X1jHf1J
mqbV/j6J9/X75NCu7iYtESEiybMu8iQiDtZdNCDDC19BpyeJ8NKV9BWc72mG
d3L+Mlh3cn3ywTvgwbqD5sO/YfXDl3O9cbBezj6qfBn3bw3Al6EeeLYU8ytf
iv4GvJ3rhcG6nf2+8jZmLQhv4/rOIO3Evy4m3CXor7iY6/UEaVty0R+zL/zH
Bf84H/tT562Y3wDnMW8ZyM/FecUWnsek8nOYpwLwOrzibHxvPzgL+/XhfCbm
UZyB/GYauv9YjXWYsW8vDUo2YX9Eo5LTsV9BI5LTMH8TOAW+kYYlJ4MbwEnY
bz36afgedXR+9tp5t/QpeJ4aupL8Jvj+VFNU8jN7rZIuJT8Jvq8O2lh4XDlu
eRA8j43WJd/CW6ir8aZ9ei4iDl9cvTMHqRSSF3xRrMUibX0Zl8JI7jZXbR7t
8f/wLX4AeiSFBA==
      "]]}, {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{-0.16950000000000126`, 12.5405}, {0., 46.7}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.478358895979022*^9, 3.478358972250873*^9, {3.478359003617921*^9, 
   3.478359016368936*^9}, {3.47836013995588*^9, 3.478360163674849*^9}, 
   3.478360374248694*^9, 3.478366680674487*^9, 3.478367480647264*^9, {
   3.478368632443274*^9, 3.478368686420216*^9}, 3.478368734382247*^9, 
   3.478368772182708*^9, 3.47837037368084*^9, {3.478370502759603*^9, 
   3.478370515076358*^9}, 3.478370922682131*^9, 3.478894392703998*^9, 
   3.4789609320542917`*^9, 3.478961633495669*^9, 3.479485745361719*^9, {
   3.479486132534732*^9, 3.4794861523034983`*^9}, 3.479661794640168*^9, 
   3.479662743820785*^9, 3.479665742592085*^9, 3.480243756892487*^9, 
   3.4802438881018877`*^9, 3.480243922252112*^9, 3.480692325124424*^9, 
   3.481566067790287*^9, 3.481941625063833*^9, 3.481942098115423*^9, 
   3.662625631567731*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"quadsect", "[", "BO10", "]"}], " ", "=", " ", 
   RowBox[{"Take", "[", 
    RowBox[{
     RowBox[{"Sort", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"c10b", ",", "f10b"}], "}"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#1", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", 
         RowBox[{"#2", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"23", ",", 
       RowBox[{"-", "15"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.479492900596332*^9, 3.479493003075787*^9}, {
   3.479493311477222*^9, 3.479493315988943*^9}, {3.4794935683920727`*^9, 
   3.4794935803839912`*^9}, {3.479493647064962*^9, 3.4794936781853*^9}, {
   3.479494587120398*^9, 3.479494587799402*^9}, 3.479495122108719*^9, {
   3.479496268693829*^9, 3.4794962786689043`*^9}, {3.479496348223323*^9, 
   3.4794963960461197`*^9}, {3.479498099636911*^9, 3.479498116836277*^9}, {
   3.479661771654023*^9, 3.4796617820129557`*^9}, {3.4802439413724613`*^9, 
   3.480243944481743*^9}, {3.480243980865246*^9, 3.4802439981026154`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"quadsect", "[", "BO10", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.479492922070776*^9, 3.479492925832822*^9}, {
   3.47949628323759*^9, 3.479496283675993*^9}, 3.479661799309276*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], 
     PointBox[{{0.005290499999999999, 43.1}, {0.005540499999999999, 44.1}, {
      0.0057905, 44.7}, {0.006040499999999999, 45.4}, {0.006290499999999999, 
      45.9}, {0.0065404999999999994`, 46.4}, {0.0067905, 46.7}, {0.0070405, 
      46.7}, {0.007290499999999999, 46.7}, {0.0075404999999999995`, 46.7}, {
      0.0077905, 46.6}, {0.008040499999999999, 46.3}, {0.0082905, 46.}, {
      0.0085405, 45.5}, {0.0087905, 45.2}, {0.0090405, 44.5}}]}, {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.00523190625, 42.92},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{0.005290499999999999, 0.0090405}, {43.1, 46.7}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.47949292648037*^9, {3.4794929901025677`*^9, 3.479493006913755*^9}, 
   3.479493322040373*^9, {3.479493571055421*^9, 3.479493582720769*^9}, {
   3.479493654111162*^9, 3.479493680849517*^9}, 3.479494594442368*^9, 
   3.4794951275012083`*^9, 3.4794962841775846`*^9, {3.479496352894401*^9, 
   3.4794963992533207`*^9}, {3.4794981044621353`*^9, 3.47949812000502*^9}, 
   3.479661800865757*^9, 3.4796627438875427`*^9, 3.47966574265806*^9, 
   3.480243756913067*^9, 3.480243949523509*^9, {3.480243993159051*^9, 
   3.48024400283206*^9}, 3.480692325191889*^9, 3.481566067857037*^9, 
   3.481941625118208*^9, 3.481942098169249*^9, 3.662625631684383*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"q", "[", 
   RowBox[{"BO10", ",", "z_"}], "]"}], " ", "=", " ", 
  RowBox[{"Fit", "[", 
   RowBox[{
    RowBox[{"quadsect", "[", "BO10", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "z", ",", 
      RowBox[{"z", "^", "2"}]}], "}"}], ",", "z"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.479492821084407*^9, 3.479492906857025*^9}, {
   3.479493026130746*^9, 3.479493088769916*^9}, {3.479496292861574*^9, 
   3.479496298886504*^9}, {3.4796617492454433`*^9, 3.479661752316023*^9}, 
   3.4796618065898314`*^9}],

Cell[BoxData[
 RowBox[{"1.5052714249996817`", "\[VeryThinSpace]", "+", 
  RowBox[{"12320.257983193365`", " ", "z"}], "-", 
  RowBox[{"837815.126050426`", " ", 
   SuperscriptBox["z", "2"]}]}]], "Output",
 CellChangeTimes->{{3.479493065534417*^9, 3.479493090921401*^9}, 
   3.479493347575324*^9, 3.479493687032943*^9, 3.4794945945082073`*^9, 
   3.479495127601207*^9, 3.4794962995907373`*^9, {3.479496356170768*^9, 
   3.4794964020264187`*^9}, 3.479661807352735*^9, 3.479662743921276*^9, 
   3.479665742692679*^9, 3.480243756989594*^9, 3.480244010141424*^9, 
   3.480692325243474*^9, 3.481566067893443*^9, 3.481941625191751*^9, 
   3.4819420981852303`*^9, 3.662625631766376*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{"quadsect", "[", "BO10", "]"}], "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"q", "[", 
      RowBox[{"BO10", ",", "z"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "0.0055", ",", "0.0093"}], "}"}]}], "]"}], ",", 
   RowBox[{"PlotRange", "->", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.479493098474358*^9, 3.4794931473471107`*^9}, {
   3.4794950541082687`*^9, 3.479495059418387*^9}, 3.479495140140613*^9, {
   3.479496302750866*^9, 3.479496325477083*^9}, 3.479496410959276*^9, 
   3.4794980716129704`*^9, {3.479498110109133*^9, 3.479498134380343*^9}, {
   3.47966180953386*^9, 3.479661832340538*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], 
      PointBox[{{0.005290499999999999, 43.1}, {0.005540499999999999, 44.1}, {
       0.0057905, 44.7}, {0.006040499999999999, 45.4}, {0.006290499999999999, 
       45.9}, {0.0065404999999999994`, 46.4}, {0.0067905, 46.7}, {0.0070405, 
       46.7}, {0.007290499999999999, 46.7}, {0.0075404999999999995`, 46.7}, {
       0.0077905, 46.6}, {0.008040499999999999, 46.3}, {0.0082905, 46.}, {
       0.0085405, 45.5}, {0.0087905, 45.2}, {0.0090405, 
       44.5}}]}, {}}, {}}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwV13k8VN0bAPARImm1hBBCIhWFRJ5TmpkkuxKJJG1Usi9zzzC2FllKvJa3
JNWrtNEiIaJF/CItSEpJKioiRPJ75q/5fD/3zv2c8yznPld9+wFHn0ksFmua
CIsl/A1P2yahlxACz037K1WG2ORzRnyH96EQeGwbvzYNvSm78E7O4RD4WSt6
U2qYTZbnjfhOTwyB7p+33YfR36+mNPanhIDtDPFHDb/ZZEddZWZJVgjIBhhK
MONsYj9JfRHnSggI3rUa1YpxyAL/9/ZeL0Pgo+uWDToyHNK1V+SBnm4o6Eoa
KVobcIiOxOADl/BQWNEbH6+7gUNq948bDj0MBc1z4vOdfDgk4te5Jzpzw8Dk
x6MAKz6HXFNR/1G2JwxuqDxrWZvOIUM7zCy6KsLgTefdi42XOSQr1O83f3Y4
nAh5ZJlUzSHVev6redvCIXCqkU72Kw7583f2Demb4RCzOmBV7xcOKQ08VPxX
NAIeBn0+UDTKIc3FsvO8HSKgaK/+tKEpXCIqQ25uORcBllefCZYpcslNGYuW
mwMRcOuSqctibS4JXdamlb8uEsojrD93GXJJhmryO7GcSLA7+TRR1IJLzC/J
aT/6EglHU3tTdLhc0r/JLEPFggc7ZT02VNhxifaKZaGbgQcFq9+WtKHdFPVc
ThC0jcTs3+iaNqU5Uyx50CPifGSZPZf8s200fZCL/29rPn4BTfbeSa9z4MFK
x8OiiQ5cksSYpIf78MDH7oQ3x4lL9PKXnXyZyIPyBEvV6E1c8kbk1QPdJB7c
nqV/Pxud5Bk2xE/mge9GL7tb6D6lchfd4zyYmHJRqwd9I5WjxM/gQeuCsion
Fy6x4Lue1snjgbtx5221zVxi78YviLzNg1OnzHMKXLlEpET9dWMJD+o9mT1V
6CK5GintUh4Uv5ZUa0XLPpP0ayzjwdXxiXWSblzSyj2+WOs+D7aM7D/ig95u
dK74aT0Poivt6uZu4ZLgmXXl6h94IJqjzA515xLnWpUS/04emAUbvj6KNhT4
F937yAORuh2uuei+AbkLW7t5QHpV5WvRe5u3pWT28oAn/uWQ4lYu8Tw1tH3W
MA++HX/hdAtttUhDUkSagWrFKfx3Hlyi0xU0yX4aAyOxV1z60ZNPPfpzajoD
ZX7+SqKemI8Z+/rNZzHw67qVhzbaYuD26zB5BjRlHN/5opeV2lzuU2Mgemnp
w59olXXhjh1GDOg0d+v2beMSgfVEk4IJXt+4eu1f9CfbOCeHFQxcn5K0XtqL
S65tTHW+v5KBFBkRVR30Gu+CTfnAgMdlmw4P9G7a6rbbigGN31FNj9E3bph6
97kz4NZvty9pO5coltzr1PFgIFJ3plYWmt5l7/DyZCAgs7r2HJp738GnyYuB
TgWx12Xo1w17dt3YycDTf3vkvqInvmb6hvkz0HTPeYx4c8l69dFAViwDh3ck
8zrQemd02U5xDIxdVc7+ipZW3yJ/Ph7js459dhD9VK2sxPowAybbd/tL7uAS
RzU6np7EwCSjofHFaNd5kxL0MxnocV36KRS98rTh5qgsBkIiAk5FoZXmeS98
ns3Axs925DD6jWpNXdgpBiQK35As9DbV+Jk1ZxmweL7K6C56t4pUltsVBiZy
VXtG0Fb/rvS9fJWB8+lyq1g+XKKr4mvOus5AbuuFMAl0r3L923PFuB/uqUI5
tL9y0vz+Egb0q5skDNAOORWDlqUMeM3PP2+CNlT+8SD9LgNfGmcusUAPzrXf
bV7BQK9M2Z/16LC5sy8nVDPwyNTtqDfaNXsNfV2DzxebHLoHvXJuoJ3+QwZO
K9tsOID+o/Siv+kxAxXLLxdHoKOU0o1VnzLQIHYzOAWdoKhUeaOFAUvNzoe3
0d87mTn9rQwoXVvMKkNvuvJ+v34bA20dg1qVaE3LApXz7QzIGvQbP0ZX+q2I
zPjAwMHEgv3N6AUmOU3POxlIhidT29BJIizdmV0MnMjwOfkW7Z7+qOVQNwOb
jaX3d6FH7m0yjuhloG6xotFPtOeR0mO3vmF8psww/oV+6Kza9fM7A2GH+PNH
0Glfuk749jPwOLixehw9VmzVc+EnA//rvBbC2on9TC+v+TjAwN2hqfKi6KUy
wf3uQwzYTTVUkkRntLesyxxmYFh6nEqh/14wz305wkBC8ZpGaXS9uZid7RgD
23+sWjELvXvniUJgUWBpDKooohuWDovyRCj0rk/7pIQ2HnPbUjKJQrXC1Wxl
tFiKhpSBOAWds85189C+bvFe+yZTKPF8x1ZHN2l+LSmQoGBQ9bFQA5175/ou
DSkKbwI8iRZaIlbunsdUCtOrX/hpo/fbhstnS+PzSmriFqBfKrTva55GQd9x
yVEdtHkneSAzg4JiqiyzEH32cr6y/UwKP4KCtuiipcIkgxJnUSgct9XWQx9c
41f3eDYFZ738dqFbpBs1xGUpfBgPjF6EhuZlEavlKGwJrpiljz5/JuMZI0/h
bmpMktDT/MZ0SudQEHeqHhY6yNgzakiBgskdxmYxuo1V3WyoRMG+pihZ6DV1
2ksOzKWwMWh7hdAFJ4/EX1KmQGoTW4Weue17e7cKBflqg/dCh+o6GmnOo9Dk
5fBS6LeDNxO3qVGIONdzU2j2PcWPOeoUJJJYMUIXHmbMWjUoRM1NMRdaxvn9
cTlNCu9ssj4I1xehyv7qoEVhgda8YKE/fP5vdZI2BdczqoPC/VoVS2c+WUAh
8P4/nkK/bVErZS2k4LFP6q4wPgF/l7cZ6+J65e6ICj1Z0+qPnx4F5dJ8U2F8
s622qpxdhPHe8j93YfyXHjho0aqP8Ro13CfMT01anOeMJRSY9Jd7hfn79u7y
mUgDvL/mmb4w3wLx+/evG1LIdtEbmI+W13vV2b2MwuruqnPC+oCQv1rOxri+
8XNNwnp6kT2be8SEwkTMwAZVYX1Wae+uXEEhXoLeENZfqrTdxUVmGC/x9dbC
etU29K7bbk6hm380Yg661CW0959VFOyGp2TIoTvzTi8WJxTE2sszhPUe9rjY
zmw15st6IHIGWvr7I/+Da3B9t3xspqGNTPuK2tdSkIkVKRH20xMPsRcyHArs
T7oOk9EesQq/rLgU9rFTm4X9l9BATG5ZUbgwKlv4F/u11Sf1bpIthXIyEjiA
3n/03JsaOwpXj0wJ7UNPun5nfNSeQtYzl13f0Hp/3sMuJwoumy7N6EYzxw1r
YDOFYLPF/Fb07BJOV7ArBd19C3pfos+3u00udKPQnL2V04Ru0IlZp7AV+6Mv
6v4TtPq95/V9XhRWBZ1tLUXf+tj9TdubQvGx2Gu30Oul/kzfuoOCRn5eUBE6
cKOmQ+1OCp8enawpQD/oCXp5xpeCbI9LTAZ6j4L8W8dgCmOnrXnC8zai9IXd
2RDM73ROkfA8PuJ+omogFNfzVK9JeF4X5s48lxZBIWH1nQYX9A+dqX6v+BS2
/2yrEp73waasUdcjFCYJiEASHd9W4XvxKAVLVt8mEXQ6w7SPJlIIbzgiN4rv
n5Kq0crsZAoPtgnse9BjVr8S2tMovLINL69HR7t9lfM6TaFzc3zgUfTxP/8l
XM+lEPDp6ycBOu/Urt8ieRSGalaujUDXfPj4Ji+fQntQTtlutITvu7MfCyho
5u7KX4s+FvnCYPcNCjmaKvYj+P7NzKmwOVBLwbBLTMEOvfTwNXbBEwory3uP
rEU/DM5b1VlHYcXXzK+m6EHbeH2XpxTmWa7110Tbi9hOg+cUjva1pI3gPDB5
Z3v99HbsX9NJlv+ig5b8sb7SR4Ef77ysBeePqcrfLT/3U4gd/2RRh86T7DDT
GKAgqLUwqUA3vK/WS/9FwWebxfezaN20o1PpKIXaw0zwfvT7EaU6GzE+zKgb
+zyB85DtfdP13+bw4YTEiLcs2kvv1fHVinx4cK2uXBQdlBbQdlKJD7d7JEUG
cL7K2nnJz0KFD+/lKy2foT9JqSQna/DBeo16aSKa78R6YaDPh4BvV/ZO4Dx3
7ePDrSFr+CB5cvj1c5z/qm28zz+x5MOBkHGvSvSrWxPfVdl8yPzi11SI/nNo
RdQjLh8M4w4diBPOi/oX8xRs+BCSWpRlhP4QfKy71IUPG/8+u5GK86aMhPPB
CT8+uC+0GFmB86tzXW6MzX4+xDu0y85HpyV/O5l9gA/OFrfnTkPLKySUmgTw
odVn7ucOnH8VFpaK+ofy4XBvfmQCWtlaLb0jmg/hLWXHGnF+1kzuLa1K50Oh
LsvDEedv4zlxYrGVfLAveXFFdiOuV0v837tVfPh99pjBmDPub3mc0cB9PlwX
23TmPdreMW7n9gd82KIlt+4K2vdY3GPyhA+JnRuKOOhc0fjE8ed43SnvdyB+
P0j1xcuGdvPhCqvLqRK/Lw7sWDvbSCIKVh6vNVaz5ZK6+pMmAQZREHkhrsOC
zSVf4+znd2yOgisXFswvNsN+yJdnJ/CjQG7jwjm6Blwy3WkRL6wgCgpUJL/s
0cTz0PFSeFZjFAy2bYvmzsH67AhPnDwWBclPknuvSXDJwsrrPmc1osG63m/W
22EOMRP/FRRuFQ09Xec36nZzyMvWhMzMwGhQ/tb27PZzDjGYiIn9mhUN89Z/
POxQySFyNxpi4x5Egx4x1vlRwCH/PdW+6/ojGj6rfQlPO84hf027b3vIC2D9
lPfrUiI55M3y4drLRABHbL1uWXpxCC/KP09/twBO1buHB3I5pM7g17VPSQK4
n6GVO7SIQ/ICal98KRFA7AIXVvd0DjEXk7in0iGA1xZdojn9bHLncGRdPZqU
i1F5tPGMvubI9wJwDjXrSOljkyVKrX2tHwQQf+q7e9wPNtFYekkjvUsAs+/4
muz7xiaS7nbx03sEUK9a5b/iC5u8LM6wmfiFLmwZLOtgE0dTabcrQwIYzH13
cDn6aUXUzq3DAnjSOP7q0js2eVy7h393RAC0k++a9ZZNyt6ZXQ8dw+e/zIKQ
N2ySN7VDto8VA28+66UsbGGTeanO6qdFYuBDxvmk081skiNfq287KQayBCuC
5dAn1Ys4haIxMHNq3ijrFZscMokN2z05BnQ+H/306jmbiJePxM6RiIG8oEqt
DWjBmn2pD9GPzaVtqprYJNJm00XNKTGgFvXF6dIzNhlpenLrOdpxLGKZGjpo
M1QLpGJgadH8sbRGNulvL24wmBoDFfmdF6eg93vrvOlAjzaVrqENbPJ/DqZ4
Aw==
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.00523190625, 42.92},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.479493147789712*^9, 3.479493348745586*^9, 3.479493687869093*^9, 
   3.479494594544231*^9, 3.4794950600870647`*^9, {3.479495127635968*^9, 
   3.4794951412551003`*^9}, {3.479496311016521*^9, 3.479496326374604*^9}, {
   3.479496357540121*^9, 3.479496411535761*^9}, 3.479498073597056*^9, {
   3.479498111163803*^9, 3.479498134994309*^9}, {3.4796618101860933`*^9, 
   3.479661833787763*^9}, 3.479662743973064*^9, 3.479665742731904*^9, 
   3.4802437570207*^9, 3.480244013149205*^9, 3.480692325283217*^9, 
   3.481566067931078*^9, 3.4819416252399197`*^9, 3.481942098241775*^9, 
   3.662625631852418*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmaxq", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"q", "[", 
        RowBox[{"BO10", ",", "z"}], "]"}], ",", "z"}], "]"}]}], "/", 
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{"q", "[", 
       RowBox[{"BO10", ",", "z"}], "]"}], ",", 
      RowBox[{"z", "^", "2"}]}], "]"}]}], "/", "2"}]}]], "Input",
 CellChangeTimes->{{3.479495438249634*^9, 3.479495505318678*^9}, 
   3.479662502748355*^9, 3.4796629041886263`*^9, 3.479664469475191*^9, {
   3.479665540402864*^9, 3.479665540432529*^9}, 3.479665679958331*^9, {
   3.480252658965609*^9, 3.4802526608978167`*^9}}],

Cell[BoxData["0.007352611334002007`"], "Output",
 CellChangeTimes->{{3.479495497456901*^9, 3.479495505729022*^9}, 
   3.479664646330089*^9, 3.479665767660248*^9, 3.4796658003302927`*^9, 
   3.479666123140691*^9, 3.480085429491647*^9, 3.480244564434903*^9, 
   3.480245921975265*^9, 3.480252685630768*^9, 3.4806923253165283`*^9, 
   3.481941625292397*^9, 3.481942098249529*^9, 3.662625631900302*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmaxq", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"q", "[", 
   RowBox[{"BO10", ",", 
    RowBox[{"zmaxq", "[", "BO10", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4796645166114473`*^9, 3.4796645680107403`*^9}, {
   3.479664629540166*^9, 3.4796646354272118`*^9}, 3.479665680445608*^9, 
   3.479665788251362*^9, {3.480252661732663*^9, 3.480252662768613*^9}}],

Cell[BoxData["46.7983056675278`"], "Output",
 CellChangeTimes->{3.479664568867193*^9, 3.479664646359799*^9, 
  3.479665585669737*^9, 3.479665767693388*^9, 3.479665800365254*^9, 
  3.479666123176936*^9, 3.48008543183556*^9, 3.480244564491827*^9, 
  3.480245922030847*^9, 3.480252685747806*^9, 3.4806923253494253`*^9, 
  3.481941625327002*^9, 3.481942098307748*^9, 3.662625631954908*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"delta", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"zmaxq", "[", "BO10", "]"}], " ", "-", " ", 
   RowBox[{"zmax", "[", "BO10", "]"}], " "}]}]], "Input",
 CellChangeTimes->{{3.479495523610161*^9, 3.479495542381401*^9}, 
   3.479661946209796*^9, 3.479662081271207*^9, 3.47966250284426*^9, 
   3.47966290430508*^9, 3.479664469476417*^9, {3.479665683454405*^9, 
   3.479665683520638*^9}, {3.480252663458889*^9, 3.480252664767067*^9}}],

Cell[BoxData["0.00015676584868919152`"], "Output",
 CellChangeTimes->{3.4794955436804543`*^9, 3.479665380340073*^9, 
  3.479665767759824*^9, 3.479665800431348*^9, 3.4796661232447157`*^9, 
  3.4800854342417307`*^9, 3.4802445645293713`*^9, 3.480245953636918*^9, 
  3.4802526858259706`*^9, 3.480692325383745*^9, 3.4819416253693733`*^9, 
  3.481942098341453*^9, 3.662625632016404*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Scale factor to make measured and theoretical curves have same maximum\
\>", "Text",
 CellChangeTimes->{{3.478970887912784*^9, 3.478970908928837*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"scale", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"fmax", "[", "BO10", "]"}], "/", 
   RowBox[{"fmaxq", "[", "BO10", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970696648231*^9, 3.478970705072441*^9}, {
   3.478970839616865*^9, 3.478970857497159*^9}, 3.4789715324564857`*^9, {
   3.478971784562731*^9, 3.4789717872495337`*^9}, 3.478971846731222*^9, {
   3.4789723755682993`*^9, 3.478972380734989*^9}, {3.4789735142646723`*^9, 
   3.4789735163909893`*^9}, 3.479661959846012*^9, 3.479662130234865*^9, {
   3.479665563524087*^9, 3.479665591276129*^9}, {3.479665788451865*^9, 
   3.479665788518486*^9}, {3.480252675294587*^9, 3.4802526771361427`*^9}}],

Cell[BoxData["0.03621623002544395`"], "Output",
 CellChangeTimes->{
  3.478971485608411*^9, 3.478971533659111*^9, 3.478971787849442*^9, {
   3.478971841091794*^9, 3.4789718473084917`*^9}, 3.478972382639682*^9, 
   3.4789745781001587`*^9, 3.478974629064003*^9, 3.4794913230668173`*^9, 
   3.4796653804411373`*^9, 3.479665592037429*^9, 3.4796657678267307`*^9, 
   3.47966580051572*^9, 3.479666123310278*^9, 3.480085442306896*^9, 
   3.480085474403487*^9, 3.480244564572826*^9, 3.480245967181128*^9, 
   3.480252685882967*^9, 3.4806923254154778`*^9, 3.481941625424059*^9, 
   3.4819420983918962`*^9, 3.662625632057599*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"plot", "[", "BO10", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"c10b", ",", 
        RowBox[{
         RowBox[{"scale", "[", "BO10", "]"}], "*", "f10b"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Blue", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"scale", "[", "BO10", "]"}], "*", 
      RowBox[{"q", "[", 
       RowBox[{"BO10", ",", "z"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "0.0055", ",", "0.0093"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Red", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<z (m)\>\"", ",", "\"\<F (N/A)\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, {
   3.453838538440839*^9, 3.453838572806719*^9}, 3.463844247723119*^9, 
   3.478894943196905*^9, 3.4788950132010527`*^9, {3.478961709433363*^9, 
   3.47896175216029*^9}, {3.478961842569364*^9, 3.478961894377494*^9}, {
   3.4789619830038633`*^9, 3.478961984506156*^9}, {3.4789699280628653`*^9, 
   3.478969982243393*^9}, {3.478970021389124*^9, 3.478970165180615*^9}, {
   3.478970224319232*^9, 3.478970261501657*^9}, {3.4789703108875017`*^9, 
   3.478970348344078*^9}, 3.478970398020482*^9, {3.478970871122594*^9, 
   3.47897087265033*^9}, {3.478971414854863*^9, 3.4789714317583723`*^9}, {
   3.4789723334965277`*^9, 3.4789723911200447`*^9}, {3.478973525233735*^9, 
   3.47897352833882*^9}, {3.479495227181163*^9, 3.4794952662789087`*^9}, {
   3.4794954131043873`*^9, 3.4794954161349077`*^9}, {3.479497883443406*^9, 
   3.479497887306903*^9}, {3.4794980354692507`*^9, 3.479498036795588*^9}, 
   3.4794982488155937`*^9, {3.479662131489229*^9, 3.479662133377276*^9}, 
   3.479665540471899*^9, {3.4802459792714577`*^9, 3.480245981573744*^9}, {
   3.4802525542284737`*^9, 3.4802525884311867`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
     LineBox[CompressedData["
1:eJwV1nc8VX8YB3CjkhWRIrJHRRoaWj5NJUkhq6JIURmZ97r3XJcK3ZZRVkOa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      "]]}}, {{}, {{}, 
     {RGBColor[0, 0, 1], PointSize[0.011000000000000001`], AbsoluteThickness[
      1.6], PointBox[CompressedData["
1:eJw90GtMUwcABeAr0YkwYAIKZWiDQ+cAI52og5Ydy2aNEmQWESk+EKGCdcJa
eXWtlKKFDmHq5ovHXLAGXINYFYqC0iiCNi4CVZJKg6SECgiTjT4vjegSw4+T
k+/fyQlKy2ZnuBAEEfEh//fLWYL34rocod7xRSzqNH7hZzkfhMqhoEh5jxXT
iBrprbjRUIblQc1J20LMGE+Kov6xsgwBYqPa+qcZVdq6G+V1pfDVe/lf8bMg
Nto9ppBaisqhmPkray2YaRLouDUylI7Lfv8y3grlCkP6TooMxazbZt0jK1LO
fW9lnj8JZ9zrocRYG9xdG0vX+pxE/jvP5rBbNrQJl1CWnT4BAYexRP+VHUcm
xX+5eZzA5IHseSlNdgSmmuh2eQkOeV94QfNz4Gnf9r9HPilBut+dZetyHBBt
Vu/TlUiRGjiQEfHEgbBW6pSGkMLw1CXKnUbCEFJWfF1cDM4zn8HyvSRO1U55
15AS9K8Or1LXk2B8lqyQ50uwM5T57TfPSegXlPD+GS2Cbg3b2ErMIPJNQuUT
43Gw9UlHK71mcKknWKUwiOdMNlt0Rf2iOXOqu6ycnp/nfFdygbJBK8TzfpbW
Y5hEADeTsbizEEniEE/jRRLC2Mj9E/cK8PILT3bLdhID4W7SbnU+9gtM4lcm
B+hLBxR1qjwcPNq5frDCgeoZZbdYmYustvJ7MocdziHR+O6rx5DjmrB5bYYd
e7riPCIuC2C75st0eWBDu3J5uNclPiRmbXDIPBsCz7xlj5/9CQtR7MreZIUo
T5P76FQOFg/SUhU5FrSqV9CYHtmoFvb65B0zo0DamWcjfkQ9j0fnZ02DEcdt
bzQfRoRqtv9i/H9w+rm6pI9mQmP9jd+x/l+0G69tCTBwUa2NnMh1voWoMbai
51k6mt/tcvdXToJRMNkne5j28d83cMb86h+tTsXUnrg7ybtGUfB5Wrspce/H
PSMgVFe3JEQnI7wliFrVYISENdbXEZyIKxpLimDbKxCGsH1hn+6Aybeh8OZ3
ehDDQ32011uxWpPRVMPRgfDMHHNrYUIvpBw+cEQLgj84271oHYj7Ez98LW8D
sYl7qJe+APldvdyDw+XQjPWMFW5c1UGvb2Odr1XhPamvlQg=
       
       "]]}, {}}, {}}, {{}, {}, 
    {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
     LineBox[CompressedData["
1:eJwV13k8lN0XAHBUSEhE9u2VLAkJleWUStHPmhJlLylC2ZnnDkOSpCwRSdJK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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"z (m)\"", TraditionalForm], 
    FormBox["\"F (N/A)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{641., Automatic},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 0.013}, {0., 1.694858130003234}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.478970312655707*^9, 3.478970349956621*^9}, 
   3.4789703994875298`*^9, 3.478971607584939*^9, 3.4789719008193083`*^9, {
   3.478972321794873*^9, 3.4789723915815496`*^9}, 3.47897462857933*^9, 
   3.479491375853756*^9, {3.479495240008403*^9, 3.479495266824088*^9}, 
   3.479495416841895*^9, 3.479497903792444*^9, 3.4794980383520308`*^9, 
   3.4794982508041973`*^9, 3.479665430756591*^9, 3.47966555437061*^9, 
   3.4796655952965937`*^9, 3.479665767861109*^9, 3.479665800596849*^9, 
   3.479666123343511*^9, 3.480085442474633*^9, 3.480085476792396*^9, 
   3.480244564663542*^9, {3.480245967281913*^9, 3.4802459841655083`*^9}, 
   3.480252591260969*^9, 3.480252685939891*^9, 3.480692325467414*^9, 
   3.481941625474936*^9, 3.4819420984427*^9, 3.6626256321537743`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["New coil calc for BOSEM (5x10 magnet)", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, 
   3.463844192181329*^9, {3.478894850822432*^9, 3.478894851717502*^9}, {
   3.478895153999941*^9, 3.478895157728011*^9}}],

Cell["\<\
bosemvals5 = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.005,\t\t\t\t(* length of big magnets *)
\t\ta->0.005,\t\t\t\t(* radius of big magnets *)
\t\t(* coil length *)
\t\tcoillen->0.315*0.0254,  (* SA email, 08/14/06 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.35*0.0254, (* unchanged *)
\t\tcoilrad2->0.65*0.0254, (* SA email, 08/14/06 *)
\t\t(* the number of turns *)
\t\tcoilturns->800, (* SA email, 08/14/06 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
];\
\>", "Input",
 CellChangeTimes->{{3.453837228357688*^9, 3.453837230833909*^9}, {
  3.463844183252262*^9, 3.463844223147016*^9}, {3.478894862544446*^9, 
  3.4788948852377567`*^9}, {3.478894985619047*^9, 3.4788949913587503`*^9}, {
  3.4788950240972023`*^9, 3.478895025494358*^9}, {3.478895116514908*^9, 
  3.478895118897944*^9}, {3.478895285651181*^9, 3.478895286185315*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "BO5", "]"}], " ", ":=", " ", "bosemvals5"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, 
   3.463844187524227*^9, 3.463845359588154*^9, {3.47889491108751*^9, 
   3.47889491212925*^9}, {3.4788949966551943`*^9, 3.478894997123682*^9}, 
   3.4788950699694643`*^9, {3.478895122464415*^9, 3.478895146305952*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.9628352953498257"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.0061809572312008145`"}], "}"}]}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"fz", "[", 
          RowBox[{"BO5", ",", "z"}], "]"}]}], ",", " ", 
        RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, {
   3.4789735053303223`*^9, 3.478973506356164*^9}, 3.478974572010633*^9, {
   3.478974602170628*^9, 3.4789746026573887`*^9}, 3.479661922162386*^9, {
   3.480244453457839*^9, 3.480244472141658*^9}, {3.480244801803609*^9, 
   3.4802448024252663`*^9}, 3.662624014406456*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.9628352953498244`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.006180957187169586`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.662626007345862*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV1ns4VNv/B/C+IaIkRAqhUqdUkopc3m5FJ5wUKoqiIiG3MbNnSK5pQhSi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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 0.9628352949866621}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BO5", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.4802448296734753`*^9, 
   3.480244857272909*^9}, 3.662624016974782*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], LineBox[CompressedData["
1:eJwV1nk4VdsbB3CklCaZKlMnKQ0yJBXhWyJ1JRRC4hchItPhnH2OKVE5SWSo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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 0.013}, {0., 0.9628352949880826}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.662626043423575*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "BO5", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "BO5", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9}],

Cell[BoxData["0.006180957187169586`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.480085256476678*^9, 
  3.480244563873888*^9, 3.480244811221223*^9, 3.4802459142441196`*^9, 
  3.480692325590218*^9, 3.481941625685656*^9, 3.481942098570314*^9, 
  3.662626043505526*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "BO5", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "BO5", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9}],

Cell[BoxData["0.9628352953498244`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.480085460576848*^9, 
  3.480244563919486*^9, 3.480245914361339*^9, 3.4806923256341553`*^9, 
  3.481941625797789*^9, 3.4819420986261683`*^9, 3.6626260435614357`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"BO5", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, {3.662623663118393*^9, 3.662623666744122*^9}}],

Cell[BoxData[
 TagBox[
  TemplateBox[{RowBox[{
      StyleBox[
       TagBox["InterpolatingFunction", "SummaryHead"], 
       "NonInterpretableSummary"], 
      StyleBox["[", "NonInterpretableSummary"], 
      DynamicModuleBox[{Typeset`open$$ = False}, 
       PanelBox[
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{}, {}, {
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVjHtQEwQAh0FIQDucS4+XyIZk0o54CUTDftIdDiRkgZkFCUxw0MZrMEAe
AwZujBh2Qt4Ru4M4ELE5kAShYko6oQAVTOIhjY3nxjZaIZo2iP747vv++siM
9KikbWZmZkFb/O81Sa9LUajhyFauJpHT3/9dWCxdu09B8ElPkr9IigmW0Wj5
VxAyFORnadI+hGvl1K9KQtCT6mTDfaGAo7kdZTTxQ0g8Z8vnVMM4vOkWE7H6
EXYF8EYcyWMgvOMXc4r9Mfi6TlufkiegPPJpO3D4U5yp3zzmQJhE8dnz4uPa
WASTf7SwyH6K8min8eNe8XgWoYuy4yuxLMuoGiMwcCjljIJ/WgUmwzyePXoW
QlO7wPKeGqXV3Rs+oiQUWX4tS7abBzWbcS/mHBNTCfqDFVkL2NUZ1nr5QAqa
XS06q5oXUdb21g3f7SwQgi24NyaWUOPwtsCkZGNiRD/Wu7qMPhUzb7IuDZc7
rN8o+kODu94PBr8MysDV9rgh6S9adO3fPu+7LxM0f9vN69UryE3uJYptObB5
2u98KVwHoWHjSuG/HFDl1eJQnQ4tJHUYdyoLJTkVtnFsPS61HzVzGcrGzd/G
umaUeoi1QYrR77gYFdkQwvwNGE8YWnWsyAGn63W+ONeAVb8nHntzc6GUrJcl
tBmwt7sw3/5UHirmhrx2KAzYWdMwNUw7j7GB3T3ChwZESk822vnlg9fxU9MH
AwY0ZrZms4gF2Cj+NXFHhwH9NdzYjG2F4ESEFxwSbv0TVFE8dSG4bs3ZidEG
sNhKmau8CNrPR4j/7DHg1uPT+/OkPMRw8utjFXoQltIl45XFUE2Xkq0z9ZBQ
zO3+PlICcZ533dROPboDHZjFshK4BcW2H2vR4XnSS834vlLoLpp2Ed/TofFo
3bqgthQad4ks5vYK6EZBJdWSj1m9Ok9GW0Ey3edqaBEfcdfue0b2a9E6cuUF
aY2POyX2zuWBWuhJXzwyMcrgmpJe6tCjwTeuK96+02UghdM2i9w1OPHyB8fU
8HJEcPOtHzQtw/3PaH9Obzm+nfH0HXVeBrv22vRDrwtYvG7t8apqCd22dGuf
xgs4UVC7R/7aEpIDvpfr7AVwPnhrmpe1iGCespVzUQDxzXcbW+YXQKr/zN5k
EkC/acaIi18A81wNcZYrxOTtAjuMzaPLyql2YEGIDfeprN2R82B9Et9gFVcB
Da1vYPDnOYQq0maI4xUQGa3oLtQ5UGyGm1xDRAiOpIRUy9XIebVorOwTIeBN
dsbjQDUG79IHn3tUgr5O7fG4o4Kx1j9d3lCJlrRUFpOmwn+PGdKn
                   
                   "]]}}}, {
               DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                PlotRange -> {{0., 0.013}, {0., 0.9628332705599354}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{}, {}, {
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVjHtQEwQAh0FIQDucS4+XyIZk0o54CUTDftIdDiRkgZkFCUxw0MZrMEAe
AwZujBh2Qt4Ru4M4ELE5kAShYko6oQAVTOIhjY3nxjZaIZo2iP747vv++siM
9KikbWZmZkFb/O81Sa9LUajhyFauJpHT3/9dWCxdu09B8ElPkr9IigmW0Wj5
VxAyFORnadI+hGvl1K9KQtCT6mTDfaGAo7kdZTTxQ0g8Z8vnVMM4vOkWE7H6
EXYF8EYcyWMgvOMXc4r9Mfi6TlufkiegPPJpO3D4U5yp3zzmQJhE8dnz4uPa
WASTf7SwyH6K8min8eNe8XgWoYuy4yuxLMuoGiMwcCjljIJ/WgUmwzyePXoW
QlO7wPKeGqXV3Rs+oiQUWX4tS7abBzWbcS/mHBNTCfqDFVkL2NUZ1nr5QAqa
XS06q5oXUdb21g3f7SwQgi24NyaWUOPwtsCkZGNiRD/Wu7qMPhUzb7IuDZc7
rN8o+kODu94PBr8MysDV9rgh6S9adO3fPu+7LxM0f9vN69UryE3uJYptObB5
2u98KVwHoWHjSuG/HFDl1eJQnQ4tJHUYdyoLJTkVtnFsPS61HzVzGcrGzd/G
umaUeoi1QYrR77gYFdkQwvwNGE8YWnWsyAGn63W+ONeAVb8nHntzc6GUrJcl
tBmwt7sw3/5UHirmhrx2KAzYWdMwNUw7j7GB3T3ChwZESk822vnlg9fxU9MH
AwY0ZrZms4gF2Cj+NXFHhwH9NdzYjG2F4ESEFxwSbv0TVFE8dSG4bs3ZidEG
sNhKmau8CNrPR4j/7DHg1uPT+/OkPMRw8utjFXoQltIl45XFUE2Xkq0z9ZBQ
zO3+PlICcZ533dROPboDHZjFshK4BcW2H2vR4XnSS834vlLoLpp2Ed/TofFo
3bqgthQad4ks5vYK6EZBJdWSj1m9Ok9GW0Ey3edqaBEfcdfue0b2a9E6cuUF
aY2POyX2zuWBWuhJXzwyMcrgmpJe6tCjwTeuK96+02UghdM2i9w1OPHyB8fU
8HJEcPOtHzQtw/3PaH9Obzm+nfH0HXVeBrv22vRDrwtYvG7t8apqCd22dGuf
xgs4UVC7R/7aEpIDvpfr7AVwPnhrmpe1iGCespVzUQDxzXcbW+YXQKr/zN5k
EkC/acaIi18A81wNcZYrxOTtAjuMzaPLyql2YEGIDfeprN2R82B9Et9gFVcB
Da1vYPDnOYQq0maI4xUQGa3oLtQ5UGyGm1xDRAiOpIRUy9XIebVorOwTIeBN
dsbjQDUG79IHn3tUgr5O7fG4o4Kx1j9d3lCJlrRUFpOmwn+PGdKn
                   
                   "]]}}}, {
               DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                PlotRange -> {{0., 0.013}, {0., 0.9628332705599354}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["3", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["False", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
        Baseline], DynamicModuleValues :> {}], 
      StyleBox["]", "NonInterpretableSummary"]}]},
   "CopyTag",
   DisplayFunction->(#& ),
   InterpretationFunction->("InterpolatingFunction[{{0., 0.013}}, <>]"& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.662626054357819*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"deriv2", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "BO5", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "BO5", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.662623664744658*^9, 
   3.662623670310789*^9}}],

Cell[BoxData["43704.57581798506`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.6626260544412813`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Measurement", "Subsubsection",
 CellChangeTimes->{{3.478970601031336*^9, 3.478970602486655*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v5", " ", "=", " ", 
  RowBox[{"Recurse", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"zflange", " ", "->", " ", 
      RowBox[{"0.1", "*", "0.0254"}]}], ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"end", " ", "flange", " ", "thickness"}], ",", " ", 
       RowBox[{"D060106", "-", "C"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"l", " ", "->", " ", "0.005"}], ",", "\[IndentingNewLine]", 
     RowBox[{"zplug", " ", "->", " ", "0.001"}], ",", "\[IndentingNewLine]", 
     RowBox[{"zcoil", " ", "->", " ", 
      RowBox[{"0.315", "*", "0.0254"}]}], ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"coil", " ", "length"}], ",", " ", 
       RowBox[{"D060106", "-", "C"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"zc", " ", "->", " ", 
      RowBox[{
       RowBox[{"l", "/", "2"}], "+", "zplug", "+", "zflange", "+", 
       RowBox[{"zcoil", "/", "2"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"newportcal", " ", "->", " ", "0.5"}]}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{
     "micrometer", " ", "to", " ", "stage", " ", "factor", " ", "for", " ", 
      "Newport", " ", "NVM80"}], " ", "*)"}], "\[IndentingNewLine]", "}"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478364871938177*^9, 3.4783650430215597`*^9}, {
   3.478365123922604*^9, 3.478365126702361*^9}, {3.478365254617469*^9, 
   3.4783652660805397`*^9}, {3.4783655084186296`*^9, 
   3.4783655130572557`*^9}, {3.478365552219092*^9, 3.4783656736355543`*^9}, 
   3.47948618034295*^9, 3.479486213991674*^9, {3.479502242119833*^9, 
   3.4795022421218023`*^9}, {3.479655724672627*^9, 3.479655724740677*^9}, {
   3.4796557854574213`*^9, 3.479655785465637*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"zflange", "\[Rule]", "0.00254`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.005`"}], ",", 
   RowBox[{"zplug", "\[Rule]", "0.001`"}], ",", 
   RowBox[{"zcoil", "\[Rule]", "0.008001`"}], ",", 
   RowBox[{"zc", "\[Rule]", "0.010040499999999999`"}], ",", 
   RowBox[{"newportcal", "\[Rule]", "0.5`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.478365674218483*^9, 3.4788943916835203`*^9, 
  3.478960931218412*^9, 3.478973701033331*^9, 3.479490566372048*^9, 
  3.479664646024015*^9, 3.4796657673893423`*^9, 3.480084171866323*^9, 
  3.480244564038784*^9, 3.480245921425527*^9, 3.4806923260597963`*^9, 
  3.481941626208601*^9, 3.481942099102745*^9, 3.66262605449503*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"cal5", " ", "=", " ", "0.5"}], ";"}]], "Input",
 CellChangeTimes->{{3.4783589573423653`*^9, 3.478358966550098*^9}, 
   3.478973591713312*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"m5", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "20.02", ",", "\[IndentingNewLine]", "20.0", ",", "\[IndentingNewLine]", 
     "19", ",", "18", ",", "17", ",", "16", ",", "15", ",", 
     "\[IndentingNewLine]", "14", ",", "13", ",", "12", ",", "11.5", ",", 
     "11", ",", "10.5", ",", "10", ",", "\[IndentingNewLine]", "9.5", ",", 
     "9.0", ",", "8.5", ",", "8", ",", "7.5"}], "\[IndentingNewLine]", 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.47835857022501*^9, 3.478358649532322*^9}, {
  3.478358853952238*^9, 3.478358855805633*^9}, {3.478370614629692*^9, 
  3.4783706455854597`*^9}, {3.478370676433776*^9, 3.478370679402834*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f5", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"21.7", ",", "  ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"was", " ", "25.7"}], " ", "-", " ", 
       RowBox[{"typo", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", "21.7", 
     ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"was", " ", "25.7"}], " ", "-", " ", 
       RowBox[{"typo", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", "23", ",",
      "\:3000", "24", ",", "\:3000", "25", ",", "\:3000", "26", ",", "\:3000",
      "26.9", ",", "\:3000", "\[IndentingNewLine]", "27.6", ",", "\:3000", 
     "28.2", ",", "\:3000", "28.7", ",", "\:3000", "28.6", ",", "\:3000", 
     "28.7", ",", "\:3000", "28.5", ",", "\:3000", "28.2", ",", "\:3000", 
     "\[IndentingNewLine]", "27.6", ",", "\:3000", "27.4", ",", "\:3000", 
     "26.5", ",", "\:3000", "25.9", ",", "\:3000", "25.4"}], 
    "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.478358656639378*^9, 3.478358736957609*^9}, {
   3.478358785279069*^9, 3.478358785557148*^9}, {3.47836952405042*^9, 
   3.478369528607705*^9}, {3.4783705484182587`*^9, 3.478370609603867*^9}, 
   3.478370656935858*^9, {3.478370688621035*^9, 3.47837070158915*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"c5", " ", "=", " ", 
   RowBox[{
    RowBox[{"zc", "+", 
     RowBox[{"newportcal", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m5", "-", 
         RowBox[{"m5", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", "1000"}]}]}], "/.", 
    "v5"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.478370938123036*^9, 3.478370942043363*^9}, {
   3.478961639423946*^9, 3.478961643935979*^9}, 3.4789735974419727`*^9, 
   3.479490549175753*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"m5b", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "25", ",", "24.5", ",", "24", ",", "23.5", ",", "23", ",", "22.5", ",", 
     "22", ",", "21.5", ",", "21", ",", "20.5", ",", "\[IndentingNewLine]", 
     "20", ",", "19.5", ",", "19", ",", "18.5", ",", "18", ",", "17.5", ",", 
     "17", ",", "16.5", ",", "16", ",", "15.5", ",", "\[IndentingNewLine]", 
     "15", ",", "14.4", ",", "14", ",", "13.5", ",", "13", ",", "12.5", ",", 
     "12", ",", "11.5", ",", "11", ",", "10.5", ",", "\[IndentingNewLine]", 
     "10", ",", "9.5", ",", "9", ",", "8.5", ",", "8", ",", "7.5", ",", "7", 
     ",", "6.5", ",", "6", ",", "5.5", ",", "\[IndentingNewLine]", "5.25", 
     ",", "5", ",", "4.75", ",", "4.5", ",", "4.25", ",", "4"}], 
    "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.480082947570427*^9, 3.4800831719740562`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f5b", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "21.9", ",", "22.5", ",", "23.0", ",", "23.4", ",", "23.9", ",", "24.4", 
     ",", "24.9", ",", "25.4", ",", "25.8", ",", "26.2", ",", 
     "\[IndentingNewLine]", "26.5", ",", "26.9", ",", "27.3", ",", "27.5", 
     ",", "27.6", ",", "27.7", ",", "27.8", ",", "27.9", ",", 
     "\[IndentingNewLine]", "27.7", ",", "27.5", ",", "27.1", ",", "26.6", 
     ",", "26.1", ",", "25.4", ",", "24.7", ",", "23.8", ",", "22.8", ",", 
     "21.8", ",", "20.7", ",", "19.4", ",", "\[IndentingNewLine]", "18", ",", 
     "16.6", ",", "15.0", ",", "13.4", ",", "11.7", ",", "10.0", ",", "8.17", 
     ",", "6.34", ",", "4.45", ",", "2.53", ",", "\[IndentingNewLine]", 
     "1.61", ",", "0.658", ",", "0.290", ",", "0.124", ",", "0.222", ",", 
     "3.19"}], "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.48008383483594*^9, 3.4800841583652897`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"c5b", " ", "=", " ", 
   RowBox[{
    RowBox[{"zc", "+", 
     RowBox[{"newportcal", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m5b", "-", 
         RowBox[{"m5b", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", "1000"}]}]}], "/.", 
    "v5"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.478370938123036*^9, 3.478370942043363*^9}, {
   3.478961639423946*^9, 3.478961643935979*^9}, 3.4789735974419727`*^9, 
   3.479490549175753*^9, {3.480085294755208*^9, 3.480085305264647*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{"c5b", ",", "f5b"}], "}"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.480244170219839*^9, 3.480244174751951*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQvbtKVFJ2Qot9Ggg8M3XIflu7iou3xZ4BBBrMHKQT
nln/6GyG8BnMHU5f8jv7lK0Zoj7N3KHGdXvc5eYmqH5zB50d8h8OMED5aRYO
d7Q6GtfVNkLlLRx65n4QmvOrASpv6WAjELmks7zB/uwZELB0uMHanP3uRb29
MRhYOVi8Du47+agO6h4rh5kXVDYuuVMLNc/K4efWr5frr9VA9PtYO0TOPvYt
6kI1VL21w66G6ZJmp6rsZ80EAWsHqbQMG8EjlRDzN1s7VHlbxr/ZWwG139rh
lgFX0/Ht5VDzrR2sxW4vWbSxDK5+9u/Vx2tXl8LN//2g5lXE0hKI+ZLWDld7
y92PZRVD7bNy2LNazoB/ZhFU3spBZuL7oFeTCuH+ryk7UHq0pwBqvoXDju1K
ho68+VD3mDtUNR0p+86QC+WbOVj5pu1Z+yULyjd1+CXOwZTyIgOq38Rh16OV
7lJ30qDmGzvUrPXuvXA+BRp/Rg42FW8vtR1OgrrPwOGPU7+E7fYEqLyeQ4V0
0p5nobFQ87UcfmxY6h5sGwk1T92hwu3lpf0qoVD1Kg4Md3TidHgC7a8vLrDl
CldwYHj84JLhc0/7mP5DXzViJB0Y+DJecm1zhJon6MBQdO//cU5je1sukA4W
Bwar0zpOG1XtDwNV9x/6ac/gkJZ+0ZrVvnSyBEsY31N7BhODT5vUxPaDjeu/
ZM9whNNnean2/gjLLSfK9u23Z9he2//rten+i0q3f9ZlnbFn6PlWoShrt7/1
deAOuVZOBwCkWD22
      "]]}, {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{-0.0004595000000000016, 0.010040499999999999`}, {0, 27.9}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.480244175910057*^9, 3.480244564266391*^9, 
  3.480245921792756*^9, 3.4806923262774763`*^9, 3.481941626785322*^9, 
  3.48194209932056*^9, 3.662626054674625*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"g5", " ", "=", " ", 
   RowBox[{"Take", "[", 
    RowBox[{
     RowBox[{"Sort", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"c5", ",", "f5"}], "}"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#1", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", 
         RowBox[{"#2", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "6"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.479492900596332*^9, 3.479493003075787*^9}, {
   3.479493311477222*^9, 3.479493315988943*^9}, {3.4794935683920727`*^9, 
   3.4794935803839912`*^9}, {3.479493647064962*^9, 3.4794936781853*^9}, {
   3.479494587120398*^9, 3.479494587799402*^9}, 3.479495122108719*^9, 
   3.479664850461237*^9, {3.479666071209745*^9, 3.479666118376079*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"g5b", " ", "=", " ", 
   RowBox[{"Take", "[", 
    RowBox[{
     RowBox[{"Sort", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"c5b", ",", "f5b"}], "}"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#1", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", 
         RowBox[{"#2", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"23", ",", 
       RowBox[{"-", "10"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.479492900596332*^9, 3.479493003075787*^9}, {
   3.479493311477222*^9, 3.479493315988943*^9}, {3.4794935683920727`*^9, 
   3.4794935803839912`*^9}, {3.479493647064962*^9, 3.4794936781853*^9}, {
   3.479494587120398*^9, 3.479494587799402*^9}, 3.479495122108719*^9, 
   3.479664850461237*^9, {3.479666071209745*^9, 3.479666118376079*^9}, {
   3.4800842394941673`*^9, 3.480084256187529*^9}, {3.480085381741091*^9, 
   3.4800854050584*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", "g5b", "]"}]], "Input",
 CellChangeTimes->{{3.479492922070776*^9, 3.479492925832822*^9}, 
   3.480084241379088*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], 
     PointBox[{{0.004290499999999999, 25.4}, {0.004540499999999999, 26.1}, {
      0.004740499999999999, 26.6}, {0.005040499999999999, 27.1}, {
      0.005290499999999999, 27.5}, {0.005540499999999999, 27.7}, {
      0.005790499999999999, 27.9}, {0.006040499999999999, 27.8}, {
      0.006290499999999999, 27.7}, {0.0065404999999999994`, 27.6}, {
      0.006790499999999999, 27.5}, {0.007040499999999999, 27.3}, {
      0.007290499999999999, 26.9}, {0.007540499999999999, 26.5}, {
      0.007790499999999999, 26.2}}]}, {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.004235812499999998, 25.275000000000002`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{0.004290499999999999, 0.007790499999999999}, {25.4, 27.9}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.47949292648037*^9, {3.4794929901025677`*^9, 3.479493006913755*^9}, 
   3.479493322040373*^9, {3.479493571055421*^9, 3.479493582720769*^9}, {
   3.479493654111162*^9, 3.479493680849517*^9}, 3.479494594442368*^9, 
   3.4794951275012083`*^9, 3.479664646222107*^9, 3.479665767557681*^9, 
   3.4796658002277327`*^9, {3.479666082950231*^9, 3.479666122957705*^9}, 
   3.480085257681452*^9, 3.48008532219565*^9, {3.480085387449814*^9, 
   3.480085408824621*^9}, 3.4802445643515987`*^9, 3.480245921875152*^9, 
   3.4806923263613043`*^9, 3.481941626886848*^9, 3.481942099405159*^9, 
   3.662626054790688*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"q", "[", 
   RowBox[{"BO5", ",", "z_"}], "]"}], " ", "=", " ", 
  RowBox[{"Fit", "[", 
   RowBox[{"g5b", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "z", ",", 
      RowBox[{"z", "^", "2"}]}], "}"}], ",", "z"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.479492821084407*^9, 3.479492906857025*^9}, {
   3.479493026130746*^9, 3.479493088769916*^9}, 3.47966554034807*^9, 
   3.480085337997651*^9}],

Cell[BoxData[
 RowBox[{"2.6127607538419637`", "\[VeryThinSpace]", "+", 
  RowBox[{"8218.061371644679`", " ", "z"}], "-", 
  RowBox[{"669099.8444305112`", " ", 
   SuperscriptBox["z", "2"]}]}]], "Output",
 CellChangeTimes->{{3.479493065534417*^9, 3.479493090921401*^9}, 
   3.479493347575324*^9, 3.479493687032943*^9, 3.4794945945082073`*^9, 
   3.479495127601207*^9, 3.4796646462647676`*^9, 3.4796655437102633`*^9, 
   3.479665767592616*^9, 3.479665800264008*^9, {3.4796660829847727`*^9, 
   3.479666123040353*^9}, 3.480085339448057*^9, 3.480085414970368*^9, 
   3.4802445643682337`*^9, 3.4802459219083157`*^9, 3.48069232640238*^9, 
   3.481941626925313*^9, 3.481942099421473*^9, 3.662626054845523*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", "g5b", "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"q", "[", 
      RowBox[{"BO5", ",", "z"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "0.00375", ",", "0.008"}], "}"}]}], "]"}], ",", 
   RowBox[{"PlotRange", "->", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.479493098474358*^9, 3.4794931473471107`*^9}, {
   3.4794950541082687`*^9, 3.479495059418387*^9}, 3.479495140140613*^9, {
   3.479498020636153*^9, 3.4794980214908237`*^9}, 3.4796655403666763`*^9, 
   3.480085344678802*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], 
      PointBox[{{0.004290499999999999, 25.4}, {0.004540499999999999, 26.1}, {
       0.004740499999999999, 26.6}, {0.005040499999999999, 27.1}, {
       0.005290499999999999, 27.5}, {0.005540499999999999, 27.7}, {
       0.005790499999999999, 27.9}, {0.006040499999999999, 27.8}, {
       0.006290499999999999, 27.7}, {0.0065404999999999994`, 27.6}, {
       0.006790499999999999, 27.5}, {0.007040499999999999, 27.3}, {
       0.007290499999999999, 26.9}, {0.007540499999999999, 26.5}, {
       0.007790499999999999, 26.2}}]}, {}}, {}}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwV13k8lN0XAHApUsiSNpVSUkqkVDMedS7ZCoUo2SptkiVh5nnGNsWrUhLZ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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.004235812499999998, 25.275000000000002`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.479493147789712*^9, 3.479493348745586*^9, 3.479493687869093*^9, 
   3.479494594544231*^9, 3.4794950600870647`*^9, {3.479495127635968*^9, 
   3.4794951412551003`*^9}, 3.479498022175354*^9, 3.479664646293791*^9, 
   3.479665767627028*^9, 3.479665800298114*^9, {3.4796660830395527`*^9, 
   3.4796661230758743`*^9}, 3.4800853458498983`*^9, 3.480085417240912*^9, 
   3.480244564408826*^9, 3.48024592195185*^9, 3.4806923264358673`*^9, 
   3.481941626979694*^9, 3.481942099477305*^9, 3.662626054895088*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmaxq", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"q", "[", 
        RowBox[{"BO5", ",", "z"}], "]"}], ",", "z"}], "]"}]}], "/", 
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{"q", "[", 
       RowBox[{"BO5", ",", "z"}], "]"}], ",", 
      RowBox[{"z", "^", "2"}]}], "]"}]}], "/", "2"}]}]], "Input",
 CellChangeTimes->{{3.479495438249634*^9, 3.479495505318678*^9}, 
   3.479662502748355*^9, 3.4796629041886263`*^9, 3.479664469475191*^9, {
   3.479665540402864*^9, 3.479665540432529*^9}, 3.479665679958331*^9}],

Cell[BoxData["0.006141132328792641`"], "Output",
 CellChangeTimes->{{3.479495497456901*^9, 3.479495505729022*^9}, 
   3.479664646330089*^9, 3.479665767660248*^9, 3.4796658003302927`*^9, 
   3.479666123140691*^9, 3.480085429491647*^9, 3.480244564434903*^9, 
   3.480245921975265*^9, 3.480692326468603*^9, 3.481941627025852*^9, 
   3.481942099487645*^9, 3.6626260549302607`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmaxq", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{"q", "[", 
   RowBox[{"BO5", ",", 
    RowBox[{"zmaxq", "[", "BO5", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4796645166114473`*^9, 3.4796645680107403`*^9}, {
   3.479664629540166*^9, 3.4796646354272118`*^9}, 3.479665680445608*^9, 
   3.479665788251362*^9}],

Cell[BoxData["27.846861938546528`"], "Output",
 CellChangeTimes->{3.479664568867193*^9, 3.479664646359799*^9, 
  3.479665585669737*^9, 3.479665767693388*^9, 3.479665800365254*^9, 
  3.479666123176936*^9, 3.48008543183556*^9, 3.480244564491827*^9, 
  3.480245922030847*^9, 3.480692326501891*^9, 3.481941627098565*^9, 
  3.4819420995401154`*^9, 3.6626260549826117`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"delta", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"zmaxq", "[", "BO5", "]"}], " ", "-", " ", 
   RowBox[{"zmax", "[", "BO5", "]"}], " "}]}]], "Input",
 CellChangeTimes->{{3.479495523610161*^9, 3.479495542381401*^9}, 
   3.479661946209796*^9, 3.479662081271207*^9, 3.47966250284426*^9, 
   3.47966290430508*^9, 3.479664469476417*^9, {3.479665683454405*^9, 
   3.479665683520638*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.00003982485837694498`"}]], "Output",
 CellChangeTimes->{3.4794955436804543`*^9, 3.479665380340073*^9, 
  3.479665767759824*^9, 3.479665800431348*^9, 3.4796661232447157`*^9, 
  3.4800854342417307`*^9, 3.4802445645293713`*^9, 3.480245953636918*^9, 
  3.48069232653566*^9, 3.481941627141439*^9, 3.4819420995770683`*^9, 
  3.662626055031432*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Scale factor to make measured and theoretical curves have same maximum\
\>", "Text",
 CellChangeTimes->{{3.478970887912784*^9, 3.478970908928837*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"scale", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"fmax", "[", "BO5", "]"}], "/", 
   RowBox[{"fmaxq", "[", "BO5", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970696648231*^9, 3.478970705072441*^9}, {
   3.478970839616865*^9, 3.478970857497159*^9}, 3.4789715324564857`*^9, {
   3.478971784562731*^9, 3.4789717872495337`*^9}, 3.478971846731222*^9, {
   3.4789723755682993`*^9, 3.478972380734989*^9}, {3.4789735142646723`*^9, 
   3.4789735163909893`*^9}, 3.479661959846012*^9, 3.479662130234865*^9, {
   3.479665563524087*^9, 3.479665591276129*^9}, {3.479665788451865*^9, 
   3.479665788518486*^9}}],

Cell[BoxData["0.0345760788944422`"], "Output",
 CellChangeTimes->{
  3.478971485608411*^9, 3.478971533659111*^9, 3.478971787849442*^9, {
   3.478971841091794*^9, 3.4789718473084917`*^9}, 3.478972382639682*^9, 
   3.4789745781001587`*^9, 3.478974629064003*^9, 3.4794913230668173`*^9, 
   3.4796653804411373`*^9, 3.479665592037429*^9, 3.4796657678267307`*^9, 
   3.47966580051572*^9, 3.479666123310278*^9, 3.480085442306896*^9, 
   3.480085474403487*^9, 3.480244564572826*^9, 3.480245967181128*^9, 
   3.480692326580511*^9, 3.4819416271735687`*^9, 3.481942099628888*^9, 
   3.662626055082137*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"plot", "[", "BO5", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"c5b", ",", 
        RowBox[{
         RowBox[{"scale", "[", "BO5", "]"}], "*", "f5b"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Blue", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"scale", "[", "BO5", "]"}], "*", 
      RowBox[{"q", "[", 
       RowBox[{"BO5", ",", "z"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "0.00375", ",", "0.008"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Red", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<z (m)\>\"", ",", "\"\<F (N/A)\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, {
   3.453838538440839*^9, 3.453838572806719*^9}, 3.463844247723119*^9, 
   3.478894943196905*^9, 3.4788950132010527`*^9, {3.478961709433363*^9, 
   3.47896175216029*^9}, {3.478961842569364*^9, 3.478961894377494*^9}, {
   3.4789619830038633`*^9, 3.478961984506156*^9}, {3.4789699280628653`*^9, 
   3.478969982243393*^9}, {3.478970021389124*^9, 3.478970165180615*^9}, {
   3.478970224319232*^9, 3.478970261501657*^9}, {3.4789703108875017`*^9, 
   3.478970348344078*^9}, 3.478970398020482*^9, {3.478970871122594*^9, 
   3.47897087265033*^9}, {3.478971414854863*^9, 3.4789714317583723`*^9}, {
   3.4789723334965277`*^9, 3.4789723911200447`*^9}, {3.478973525233735*^9, 
   3.47897352833882*^9}, {3.479495227181163*^9, 3.4794952662789087`*^9}, {
   3.4794954131043873`*^9, 3.4794954161349077`*^9}, {3.479497883443406*^9, 
   3.479497887306903*^9}, {3.4794980354692507`*^9, 3.479498036795588*^9}, 
   3.4794982488155937`*^9, {3.479662131489229*^9, 3.479662133377276*^9}, 
   3.479665540471899*^9, {3.4802459792714577`*^9, 3.480245981573744*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
     LineBox[CompressedData["
1:eJwV1nk4VdsbB3CklCaZKlMnKQ0yJBXhWyJ1JRRC4hchItPhnH2OKVE5SWSo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      "]]}}, {{}, {{}, 
     {RGBColor[0, 0, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
      1.6], PointBox[CompressedData["
1:eJw9kXtQywEAx39yRTHlET0UunA0bpJXK1/lGBp3omMo3ax0daHRmrVptS52
Vnmcx5R36chrnK3rcRtNr+lkkdK4XV17tf1KR6Vy4c71x/e+/3zue/e57yL2
8egEJ4IgVv7Nv64SeHr7XciFbJ/vbj+6BSkO0SM3Si74HOU8jx4LfONN9GGp
BCb5uppnXCt0+l3NPS4StA/dihjrtkK4RRXXKskBY8VCc1GaDdSKBf0aIgdK
9l0ZfdwGw/Jz2U9F2Vh8PSC4U9YL2c3+WcUjYlxuvv9Z4GNHmAerRJohRl7Q
tEP15+1od5akkJYs8KVc4+zfdqzv3VPQ2HUGpLtmMyXaAXlLoKLEIIIxdWkD
q9aBX69+tma1CaHXFTAfhJBgFdUNHmjJhE7wpoCZSqJSfM17bZMA26INz25L
SfgkJoXN1J6Gdtlgy0ApCUHUhsP2Gj4iJnkMbHlD4gvNLadelYGa9mWz5d9I
0Od2ltxT8Cb4otHyelF5+sT+qFFo2196Ch3zD7oRYw58ys9g1CWfRIq5gxN/
zIHqcn+au5yLMcV+tcZox/yLfdG2S2kT/kKeJv2t7ASoVrIvZG8vKlQBqyIo
x6GLcanbFmODIEfLGyJSQdomZ7qGWhG6M7H6yY9keIgn0Zr8LRiZN9WJY0mC
Mryndp3ZhMquhwwfQyLYzCue47weCJ9E5be85+CyJGjrSVs3wvgOfV4tG9rK
1zxzbBfGIgu9wlXxGIkMTHh13Qi+L7vaFBMLzlVKmUvZVww/L2XsCWf9/7sD
/K1WvTowBrtYNMP3hW0gDNQ46vTd8A70Ohs5Rw+i26hfZd6Ohq/jR5a4vwMx
I8nqpozAjY9Dk5sVtSC438brXVdj1vCUS3aOEkSojhqpWIwq+lELV/wYxKbE
ox/ozvBkeDVSmNdAhNAGXiyZq35xJ0A+U5oLQuvKLEsPUpvn+Gx8WZgGQiUq
HOldo95x127SnMgCIRvkL/LbqB4sLgzmh1XjD0A5bfE=
       "]]}, {}}, {}}, {{}, {}, 
    {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
     LineBox[CompressedData["
1:eJwV13k4VVsUAHBJInNpJLMMiZSQaJmSyEwIGYqQebrnXNMtXnk0iUopeRWK
UDJXiDIlkZRnSmhwHacyRK/prfvX/X7fvufsfdZee++1ZX1C7X25ubi4hBdx
cXF+D/WEzdtVh0ChbVrJXAYbOr11G4UehEDBfjs+hfNs0P3y52TboxC4PDaq
Y3+BDUJCZ+SMmkLAN8J/TUkWGyrNiq02d4ZARtKv4YNX2bC0duKG8HgI7Imy
OdaSz4bCXB/bZyKhsOnMOdnQGjZ8DXa8bXo4FB4Vnm+EYTYkuYrtYSwPA54A
0cLOjZPQyTwZsfhIGHjlalsHh08Cr5D+zMvHYRC7zjlb+P4kHJv1EvktHQ4i
n9dTNvOTUN9/yWuEEQ5DwkVKRloUGK4yt5J6Ew4BL4O+WERSUNKomn5NKwKc
1NRuypdQMBgsu6wvLQKqD2RZ2Y5SYBNySiqIHQEt+225plZPwbFgIf8q40h4
Wu5oorl7Cq4PPeYzuxQJS++ez5+MmALeG5Omm+cj4XWOTG34tSnYeFilsts6
CppW/b0GmqcgkzXY2FkcBZEOTmJ2U1PAXvZkg4hANGxZbJyeJ0rDosz6el6f
aHCQC5gZV6fBPWLzrGtDNLR79ow27KWBsKnwOLQmBixSglYM+NLQd7TUp50R
A5eE1aSXJdCgoDhcF9kbA061lcsfnKPhjoa8UffrGJCYdD7DnUGDlp5/k3pf
DHxhDb7bg95lM90y0R8DbwbO8PWh/Ujebs+RGEi0vuY+nUlDwXP1McvJGDBX
8paWvkiDakziUoVFDCjPDxNxzaZBs0XG9pUaAyYH6y5Z36BBuKDH0EadAVVR
h0vPoqnjxzXbNRiQ63Um4yU634xa3rCFAW1aHi1ON2mQbK7qLdJlQELnl0HX
PBp4n1q7JZkywKNlvt6lgIb+xji/Le4M4HqR7KtZRENSXV/c2TQGvNuWrW5d
hvGhPS2mTzIgSTHNiYXWkvq42vE0A7xnHezK0OPxc2Wr07E/jbCWlfdpMDNY
PpFzgQGO63uK+9F8Dy2div9hwL4e44PuFTScrKnb1F7FANGitjCopuHQxK4f
G2sY8ONo75YgtP7a562nahkgo1vbloWeIgYO2j1iwFpj4ZivaGvdhUt9jQxo
7hhpza2hQbRKk/fjcwYIP9Jwnq+l4Xz5zeHF4wyw4Y9elfyIhs2VKTUH3jOA
x1C+pBDdURWUWfOBARkzzpLdaJ4HWhahEwyw63aMW19HQ9TjJxX9NAM0Dl+x
KEc7do6fvPedASk/fWT662kQ/6Sww1OEgGvPn9/lbaTh7gTfqlpRAoRyLdcq
o/dOUl/ElxOw/7ONyx50Ml2e3y5OwEkeyjUNPTtrulx7HQFu/BFHhJpoeLXI
d0JQkYD0uIoW/ic0ZErkXazVI8Cbf53v2FMa/pr+NrJFn4BfVRmLuJtpiGkz
Vy0yIOBBtkGwDNqFQT3MNiTgCrdcmTtasmfraJwZAfNWm6ZfovNSG9XAngCx
ASvLyhYaLniLx1Q5EPB8oL2/G52i61ev4URAsRixfQod+IHfXsaFgC7Jg4fk
W2lQN7ZjLDpAwJ27sWGn0JXf3z5uCiDgWWelt0sb5m+XpoD+EQIKZHXGw9BZ
BUmO5UHo2x+3/Y1mOil9vBlKAL/rv2Y16J33QgSPRxNwZNsfqdXtNDT7/9pn
fpSA0+OOt9rQb96sozqyCPCQVJZe1kHDk9+Gy9UuExBNH7SWQN9VPKyblk1A
bO16BzV0SuT95D05BDgYCgxZoXVF9q5vvkGA0uLO6dPoLLN46/oSAvx9pxX5
n+N8BN+IkrpLgOdroeLV6LDMtsvx9wgwMSrg34A2H135cUc5Aa95HE2M0Qvx
JYnVNQRImZyvJtCuFW/v3ntCgOWVysIhtNngkjeizdh+597fE+gti9V+hbYQ
MFKhunMOvcyO2KPeTsDGqgtKgp001FKio4UvCGCH7fupg85focO3rJsAdVuj
E8boc3oe6gEvCXBXKfy4Fx2Ycpup1EvAibY5ZW/0OgXjFTf7CeB+HFV8As1r
6b998SAB90Jtxs+ip8NPe/oMEWCz5taXS+j2+v4imRECXJx7/i5CM90iTa++
JyDtpFhdB9rv2KXAnx8IKFo2mPsKbX+7/qzbJwJqjim4DqJV5wWG1k4ScNVL
w2ISPXDuZvSFL/h8j5r60heYb2d0l62YJiAo4c5uYfSBtI6cMzMErD5loLES
PZI025LyjYCO3gx/ObQsK8V9yQLGV8S1VhntEyf59eh37L9Yo18dPR5lui72
JwFl4mLJemjF8L6S+V8EfBiSEDZE+wUHmUT9IWBsma7fLvQn38ygYG4SDM7e
ZNmgVXyUF7EXk3D506yxIzrwwMPzfktIeHxzX48LemrfeJ0nHwmh5tYHvNHq
DoTDID8JMxrjLr7oMBvBTy4CJOyKTZMNQN+zzI3rFSTBU9W0Ogg9vVtLzF6Y
BFMD4fVh6K2mrXmdIvj8/QmbSHSUobuepRgJQadf28agv+kmHzQVJ6E+ZPxh
LFpn25qFhpUkZEUtUU5AE5p3ThqsJmHHsI43C12zyVC2dg0Jt4ti/Y+h/1N5
VaG9joSRwS6DZPSODf4W9yVIGA3XefcXOk7u57DGehKKA0vtT6DrpM5G3pHC
8bXonktB/1mnwKciQ0LeiZ5rf6MNV1dfyZMloasoMTYVfWzFXk05eRKatxoo
pqGbREae5iiQcFxa8CrHPIJR+yU2kCAaSo1yvIuP7/NFJRJ85Ya/cXyc50qS
uAoJydvf9XHcwrV5TboqCcHlcykc8/1quiOkRoJshsRSjvd8dzZK3UTCtV57
B07/qXOTvbwaJHyMzQ7mjO/Z18TApM0kfP9rzokzfkF6xZ8/miT0zXgJcr7P
il2QEbeVhMSnQ2c533/6ww7l71okfPnvyFgSumv0xcNobRLUMgV4OPETe3vQ
blqHhC3pD6cT0fYD8+9DtpOweDqhNB6d+SaNOalHQk6lvR5nfnp7pEX89bH9
rU4GgV7Vdf/GuAEJW4+o10ajnTt263oDvt9NuzQCndU60DFkSMLXEpuIUPS6
x4u/vTbB8R6t9PFHuz26mOqwi4QfXDxnD6Gv1GyU7jIj4dOYT5oXWqrMwbxt
DwnyvY6UM1r+xo3LD2xIWO7L72yKVg7P1Ne0w3xxjhcGtBr8NZxvT4KAXPf5
7WjtAT+5c04kVOxcI85ZPxYrVAv93UhYc1HhhTja5t26vcPuJHDtubiEsz4d
SwVohwMkvHw5IcBZvx6WU5rgjesnRD1lAdd3WNLdmpWHcb6ebIN/0dF2/7il
+ZMQuK1gtouzf0if+8UVSMLVhAWyFZ38INKICiKhJUtvthJ9cUa7rTEC40Pp
F6Sj6w4+6gtNIEFLRG/pTnSTZgnzfSIJ+n9u1W5Bt/7JkXQ7SsKmlnkDJXR3
NsvLLBnjN6xVLoIe7zH5JJlKguGmTZ7DuJ8KmLbPt50nwcJsVWkEWnT5g0tw
kQSximNeh9DiI0U7KrJIePKj850TWiruVGJuNgmfRZc66nL253LbpYx/SHDZ
P/ftPzwfXBTerFIoJsEnoF2bwbHxlfOsEsw/khY7zLGXt/hQKQkLXlpN+9DO
VybFLpSRoFymeGsbep84lxBfNQnO3jmxX5/R4MSjsphqxP6mP5p7ox3l6KPm
TzA/A1SOW3NseJ8r7yn+v+rkpR0cxxn89mjF8fRWG6/keNbu+4vnJChJFeQ0
43loP878fL+PBO6xgThZjrkNQ0T7STjSoCcpyLHMkqmgAYxn1IP0b3i+2ruf
YSsOkyDsKfenHW336sb7i2MksIyOj4WjbZ90DMTSmO/b819W4XludVOq1YSH
CQ3fzCwU8Py/ftGu4tESJtRHXw9aiv6WmnxdZykTtv9u8GBjPZEbzo7buIwJ
BRt33ylFz+6s1FwhygTHBcZ/Ougr/1plj0owYanrETfA+oUtHB9ydCsTnuhc
0lDBege477r90GKC3QcnVV505tyoebQ2Ew7k9M6MYn20c9BcPmA7Ez6pSs1k
o9Nvi/fZAhO6K3quC6B1Te8YyVgy4fu5ruZ3DTScIAfE632YkBcoJhuA9drr
h6PD0oeYULT9VZkxegMX+xbLlwnU+tK1kujm4wv6xv5MkN5Q7NeJ9R9v5krf
p8FMcNjW/msz+niJTcUzggkT1iky9APM77Emp77TTGgPEdc1x3rzqNWdC19r
mRDkHVQai/Vtpo9oiOVDJuTfiUy0RN9iRO3Ke8SEE0GwQQLd9Y/+rEsDE7ZZ
KCzUYL0s9a3DruEpE0zi5Yvn7mE9kDMleKaLCRqN826+dzGen9WT1D5gfFrm
OxSLafA/dy/0sFgsXK9z+qmaj+sjLqlieHkszNzeenQS63m9w04/nMRjYTvv
X71FaAH978dNV8dCrtgxaiO65L1hjuz6WBiMfN+jgveBGd2ujgHlWODxs0uR
vE5DwltaxdYwFqQX1Z0YukpDhprauG5oLKQuZ488x/tJ4tPaU4+bY2FlUILA
8FEaSu/XvcxTjINygerB/YGYD7mv9xolxEHdFvu+LDt83285KZneOHhooHqk
TBvb742n7t8aD3Pre6ozVuH94mCt2t60eGAXGzBfz01BYeCSwEvseGjq0g9w
fTEFdaPJv1XME0DsXKtycv4UnHNd0xp+LQGSPxgfK4+fgiJF2U0rfydA4ckD
AXHWU5D8xaAldF8ifDWQyrgqPQUWameqhYoT4XZ877DQZwqKhguvJy1hwcdu
WZPwKgrSN2QtdtdkQUbZRP1zFgXs3LZ26S0seOOj87gnkQITiR/pY+i9qYWn
/k2gYE7kgMwRLRaU7VyUMh5Hget3eQOmDguyDcK4FwgKZDtKY7IMWEBlOAqv
DKfgXnjLxKs9LHC7rn1MyZuCZdTC3SwLFhjqbv20wYuCg36qhLslC+x3Oa3d
4EnBSrdTvON7WcD9lH9I3oMC0tRBfsaGBXH7tdiSrhQYrX7rLraPBe+Gzkgs
saPgcrqoQi/6woexrYtsKZgRMJ7McmYB089j9S9rCvK48kgZVxZ0PmuA2b0U
8LMDL2i4syBVbc+qEXMKfA5d8ZhBF9KtJ/p3U/Bg+LlClQcLFpRCnrwyoyC4
Z/P9nZ4sWM+lcq3VlIJmKx8mtxcLvubsNGg0oUC6NcOoGT1dTuY/MKaAMH7K
l+rNAjnj/v5yIwq6H357YeXDglgzr/5iQwr+B6p0XCc=
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"z (m)\"", TraditionalForm], 
    FormBox["\"F (N/A)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{641., Automatic},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 0.013}, {0., 0.9628352949880826}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.478970312655707*^9, 3.478970349956621*^9}, 
   3.4789703994875298`*^9, 3.478971607584939*^9, 3.4789719008193083`*^9, {
   3.478972321794873*^9, 3.4789723915815496`*^9}, 3.47897462857933*^9, 
   3.479491375853756*^9, {3.479495240008403*^9, 3.479495266824088*^9}, 
   3.479495416841895*^9, 3.479497903792444*^9, 3.4794980383520308`*^9, 
   3.4794982508041973`*^9, 3.479665430756591*^9, 3.47966555437061*^9, 
   3.4796655952965937`*^9, 3.479665767861109*^9, 3.479665800596849*^9, 
   3.479666123343511*^9, 3.480085442474633*^9, 3.480085476792396*^9, 
   3.480244564663542*^9, {3.480245967281913*^9, 3.4802459841655083`*^9}, 
   3.480692326631896*^9, 3.481941627229917*^9, 3.481942099677737*^9, 
   3.662626055125484*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["New coil calc for BOSEM (10x\[OSlash]5 magnet as for tiptilt)", \
"Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, 
   3.463844192181329*^9, {3.478894850822432*^9, 3.478894851717502*^9}, {
   3.4788951705281897`*^9, 3.4788951754720497`*^9}, {3.4819407269664*^9, 
   3.481940736973164*^9}}],

Cell["\<\
bosemvalsTT = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.010,\t\t\t\t(* length of big magnets *)
\t\ta->0.005/2,\t\t\t\t(* radius of big magnets *)
\t\t(* coil length *)
\t\tcoillen->0.315*0.0254,  (* SA email, 08/14/06 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.35*0.0254, (* unchanged *)
\t\tcoilrad2->0.65*0.0254, (* SA email, 08/14/06 *)
\t\t(* the number of turns *)
\t\tcoilturns->800, (* SA email, 08/14/06 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
];\
\>", "Input",
 CellChangeTimes->{{3.453837228357688*^9, 3.453837230833909*^9}, {
  3.463844183252262*^9, 3.463844223147016*^9}, {3.478894862544446*^9, 
  3.4788948852377567`*^9}, {3.478894985619047*^9, 3.4788949913587503`*^9}, {
  3.4788950240972023`*^9, 3.478895025494358*^9}, {3.481940748223406*^9, 
  3.481940763510077*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "BOTT", "]"}], " ", ":=", " ", "bosemvalsTT"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, 
   3.463844187524227*^9, 3.463845359588154*^9, {3.47889491108751*^9, 
   3.47889491212925*^9}, {3.4788949966551943`*^9, 3.478894997123682*^9}, 
   3.4788950699694643`*^9, {3.4819407740626507`*^9, 3.481940800888165*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "BOTT", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.3925374169455943`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.00759707468312686`"}], "}"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"fz", "[", 
          RowBox[{"BOTT", ",", "z"}], "]"}]}], ",", " ", 
        RowBox[{"0.006", " ", "<", " ", "z", " ", "<", " ", "0.010"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.480244382554545*^9, 3.480244405961742*^9}, {
   3.4819408015577917`*^9, 3.4819408027090397`*^9}, {3.481940979763582*^9, 
   3.481940981746011*^9}, {3.481941548420309*^9, 3.481941559738948*^9}, 
   3.662607121040988*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.3925374169455944`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.0075970745443657`"}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{3.662607374243556*^9, 3.6626261664898033`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "BOTT", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nk4Fe0bB3BR2ZckS5EoKiolhMo3RKVCSrRQka1EQjjOOXOOLR3SqkWb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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 0.3925374150688015}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BOTT", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.4794970273251*^9, 3.4794970280748262`*^9}, {3.479497850691868*^9, 
   3.479497851721608*^9}, {3.4802445496159487`*^9, 3.4802445841180058`*^9}, {
   3.4802446656757193`*^9, 3.4802446687524443`*^9}, {3.481940803363203*^9, 
   3.481940804034131*^9}, {3.481941063760079*^9, 3.4819410664063997`*^9}, {
   3.481941556057631*^9, 3.4819415664906*^9}, 3.6626071369677134`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], LineBox[CompressedData["
1:eJwV1nk8VVsfBnBDrgxlKkNRKEkhUSiup1A0kMhYUcpUmYkz7nMo5RTNSCmV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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 0.013}, {0., 0.3925374150709206}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.662607247679082*^9, 3.662626182329171*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "BOTT", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "BOTT", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.4796619220112333`*^9, 3.4796619454416037`*^9}, 3.479665671740583*^9, {
   3.48194080448247*^9, 3.481940804971867*^9}}],

Cell[BoxData["0.0075970745443657`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.479486914888383*^9, 
  3.479659289850292*^9, 3.4796634565750093`*^9, 3.479665742764594*^9, 
  3.479665816570661*^9, 3.480243747684814*^9, 3.480692317253339*^9, 
  3.481566060871256*^9, 3.481940897154257*^9, 3.481940954139496*^9, 
  3.4819414009024477`*^9, 3.481941627387727*^9, 3.481942099804831*^9, 
  3.6626070429154387`*^9, 3.66260724788386*^9, 3.6626261823851137`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "BOTT", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "BOTT", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, 
   3.479661922078005*^9, 3.4796619593447857`*^9, 3.479665787682528*^9, {
   3.481940805601218*^9, 3.481940806091435*^9}}],

Cell[BoxData["0.3925374169455944`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.479486914934926*^9, 
  3.479659289887826*^9, 3.479663456628942*^9, 3.479665742793458*^9, 
  3.4796658166882772`*^9, 3.480243747711088*^9, 3.480692317295466*^9, 
  3.481566060924111*^9, 3.48194089720923*^9, 3.48194095418651*^9, 
  3.481941400927742*^9, 3.4819416274500303`*^9, 3.48194209986127*^9, 
  3.6626070429656773`*^9, 3.662607247938093*^9, 3.662626182432036*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "BOTT", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"BOTT", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}}],

Cell[BoxData[
 TagBox[
  TemplateBox[{RowBox[{
      StyleBox[
       TagBox["InterpolatingFunction", "SummaryHead"], 
       "NonInterpretableSummary"], 
      StyleBox["[", "NonInterpretableSummary"], 
      DynamicModuleBox[{Typeset`open$$ = False}, 
       PanelBox[
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{}, {}, {
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVjnswGwYAh6Mc66lHjXk2gq0zKacJOiP9tdczhGG06Tpdp2m9ygTzCItn
iTdd43rRWplevel1maBd3SrNPKKtRF5Uz2NGqx7NZrVDutkf3333/fc5MFnh
0XsIBILvLv97o77fPidgjUYgkBZC+CePqkryOjd+I2MwYzqgaO4q1Akajd6f
vrgu6dzHuH0LQcsDPlfy/SCRUaKC7btgo2NJll4MhuDWESWHLIDHv+9Hfrb+
OZq+mtZlH+iDqZtnJCPxFMIPOdNa238BeZzS5uRxBs01vJ89B39F3oWsKvry
WSQrA9QsSxGKImyVdPcodJnTjlt9LMaL7uRKmSkTUe9dNO7MHEIsUycqUXoB
sqlBdn3BCAqqhW8pZdH4MSZC2pcigU8a81FkTCyoDJJdfNZjmPwU2HLNKR5u
NA5nKugpLrd9eJeqn4DWm31uTvxx8KxduNqZRPztfCW0P1uKB3Ox7Mm6JCzw
jKbbTsggOvxkuMI3GYcERt6r+yfQQ9RfoNqlIElQRKcOTSAzrt+syjgV7dT4
Yus8OUrW3jZzdlLhbXJuUXRQgduk+cD0qW8xbpWxyO1V4OqdYwR7SRr2rdG+
b/dXomrZVyztSEeIqtHDZVAJ5XnJuk1pBjYp/OE1NxXWPRWuFpmZ8H8pekXn
q2Ah5GRbMdjo4jWcUaypYMhrmBrzz0Jm2pzRCtQI7TzZaOmZjZtLxJHpQjUa
U1rSEsy+w8ol9w13oRoPeelnk/dw0BFaTSHMq7F+fi48d56DmGsiI0PCJBIS
Z7odB3IguOOycOPdSfROfEFkd+Zi9PkYnUSchOkSq15Zngf3pkCHo7tdT9ax
/IuWj3vZbIdPzCch9LaOzevOx+8srptYZxKb0VsvlXYFaDTXhlQs7f4cq3vD
rS1AZZIhMWdQjTANt9xHrxDxZvosP74acWGU1oCcQhibzNrfZ6rR8rj5H9JG
IZaq+a7yg2qski6Na5mXIe/gHph9ocJ1x1eHqc8uY3Tmh6q6BhVCtu7ZfBNU
BEbO5ujGKRU+eh3hldpfhC2Gsw19rwqJte3PnroX4+H+hBT+XSWExmHvUBqL
8ST+09faSCXijggGVqy4sO/pja7cVuB47kxLag0XtgZB6911CpBufGml1XLh
R7+v0vgoEBvDM5tNL4FulYVEXy5Hj4Ft7dAfJeCHqKOCU+RIOB3VYPB1KU5L
7bwkenIEiJOemylLMeKn++iDugmQ9441OfqVYbVdWrFDnUDG9qKm/EEZ/LdD
W+ViGYZFYcObruXYEUuJsnMyaGq9WAMN5aivqY0UvpHiP9X+z+0=
                   
                   "]]}}}, {
               DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                PlotRange -> {{0., 0.013}, {0., 0.39247086764092654`}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{}, {}, {
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVjnswGwYAh6Mc66lHjXk2gq0zKacJOiP9tdczhGG06Tpdp2m9ygTzCItn
iTdd43rRWplevel1maBd3SrNPKKtRF5Uz2NGqx7NZrVDutkf3333/fc5MFnh
0XsIBILvLv97o77fPidgjUYgkBZC+CePqkryOjd+I2MwYzqgaO4q1Akajd6f
vrgu6dzHuH0LQcsDPlfy/SCRUaKC7btgo2NJll4MhuDWESWHLIDHv+9Hfrb+
OZq+mtZlH+iDqZtnJCPxFMIPOdNa238BeZzS5uRxBs01vJ89B39F3oWsKvry
WSQrA9QsSxGKImyVdPcodJnTjlt9LMaL7uRKmSkTUe9dNO7MHEIsUycqUXoB
sqlBdn3BCAqqhW8pZdH4MSZC2pcigU8a81FkTCyoDJJdfNZjmPwU2HLNKR5u
NA5nKugpLrd9eJeqn4DWm31uTvxx8KxduNqZRPztfCW0P1uKB3Ox7Mm6JCzw
jKbbTsggOvxkuMI3GYcERt6r+yfQQ9RfoNqlIElQRKcOTSAzrt+syjgV7dT4
Yus8OUrW3jZzdlLhbXJuUXRQgduk+cD0qW8xbpWxyO1V4OqdYwR7SRr2rdG+
b/dXomrZVyztSEeIqtHDZVAJ5XnJuk1pBjYp/OE1NxXWPRWuFpmZ8H8pekXn
q2Ah5GRbMdjo4jWcUaypYMhrmBrzz0Jm2pzRCtQI7TzZaOmZjZtLxJHpQjUa
U1rSEsy+w8ol9w13oRoPeelnk/dw0BFaTSHMq7F+fi48d56DmGsiI0PCJBIS
Z7odB3IguOOycOPdSfROfEFkd+Zi9PkYnUSchOkSq15Zngf3pkCHo7tdT9ax
/IuWj3vZbIdPzCch9LaOzevOx+8srptYZxKb0VsvlXYFaDTXhlQs7f4cq3vD
rS1AZZIhMWdQjTANt9xHrxDxZvosP74acWGU1oCcQhibzNrfZ6rR8rj5H9JG
IZaq+a7yg2qski6Na5mXIe/gHph9ocJ1x1eHqc8uY3Tmh6q6BhVCtu7ZfBNU
BEbO5ujGKRU+eh3hldpfhC2Gsw19rwqJte3PnroX4+H+hBT+XSWExmHvUBqL
8ST+09faSCXijggGVqy4sO/pja7cVuB47kxLag0XtgZB6911CpBufGml1XLh
R7+v0vgoEBvDM5tNL4FulYVEXy5Hj4Ft7dAfJeCHqKOCU+RIOB3VYPB1KU5L
7bwkenIEiJOemylLMeKn++iDugmQ9441OfqVYbVdWrFDnUDG9qKm/EEZ/LdD
W+ViGYZFYcObruXYEUuJsnMyaGq9WAMN5aivqY0UvpHiP9X+z+0=
                   
                   "]]}}}, {
               DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                PlotRange -> {{0., 0.013}, {0., 0.39247086764092654`}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["3", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["False", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
        Baseline], DynamicModuleValues :> {}], 
      StyleBox["]", "NonInterpretableSummary"]}]},
   "CopyTag",
   DisplayFunction->(#& ),
   InterpretationFunction->("InterpolatingFunction[{{0., 0.013}}, <>]"& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662626186307064*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"deriv2", "[", "BOTT", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "BOTT", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "BOTT", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}}],

Cell[BoxData["12441.390653444461`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662626186396759*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f95plus", "[", "BOTT", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BOTT", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "BOTT", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BOTT", "]"}], "+", "0.001"}], ",", 
       RowBox[{"zmax", "[", "BOTT", "]"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BOTT", "]"}], "+", "0.005"}]}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658987032153*^9, 3.47965898990287*^9}, {3.479659310386307*^9, 
   3.4796593125701933`*^9}, {3.479661624172262*^9, 3.479661679901505*^9}, {
   3.479661945541445*^9, 3.4796619594445953`*^9}, {3.4796656734658623`*^9, 
   3.479665674680963*^9}, 3.47966578778349*^9, {3.481940808072547*^9, 
   3.4819408112927933`*^9}}],

Cell[BoxData["0.009502179799014016`"], "Output",
 CellChangeTimes->{{3.479659290207419*^9, 3.4796593177022877`*^9}, {
   3.479661644377719*^9, 3.4796616514833097`*^9}, 3.479661686065053*^9, 
   3.4796634593803263`*^9, 3.479665745824663*^9, 3.4796658197389708`*^9, 
   3.480243751933235*^9, 3.480692320796873*^9, 3.4815660640155077`*^9, 
   3.4819408973674994`*^9, 3.481940954361327*^9, 3.481941402301373*^9, 
   3.481941628781619*^9, 3.481942101498692*^9, 3.662607043922553*^9, 
   3.662607248914266*^9, 3.662626187196279*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f95minus", "[", "BOTT", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BOTT", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "BOTT", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BOTT", "]"}], "-", "0.001"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BOTT", "]"}], "-", "0.005"}], ",", 
       RowBox[{"zmax", "[", "BOTT", "]"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658997678957*^9, 3.4796590027188377`*^9}, {3.479659318794853*^9, 
   3.479659344898431*^9}, {3.479661657421668*^9, 3.4796616780054293`*^9}, {
   3.479661945775414*^9, 3.479661959545474*^9}, {3.479665675209929*^9, 
   3.479665676278386*^9}, 3.4796657878831253`*^9, {3.481940812147341*^9, 
   3.481940829419257*^9}}],

Cell[BoxData["0.00589724805759103`"], "Output",
 CellChangeTimes->{
  3.479659290545846*^9, {3.479659322545879*^9, 3.479659348979048*^9}, {
   3.4796616661527233`*^9, 3.479661689555737*^9}, 3.479663462870864*^9, 
   3.479665749329587*^9, 3.479665823257647*^9, 3.480243756605932*^9, 
   3.480692324819867*^9, 3.481566067504561*^9, 3.4819408974084797`*^9, 
   3.481940954404307*^9, 3.481941404076367*^9, 3.481941630539411*^9, 
   3.481942103389555*^9, 3.66260704523952*^9, 3.6626072502629004`*^9, 
   3.66262618829943*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"plot", "[", "BOTT", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<z (m)\>\"", ",", "\"\<F (N/A)\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, {
   3.453838538440839*^9, 3.453838572806719*^9}, 3.463844247723119*^9, 
   3.478894943196905*^9, 3.4788950132010527`*^9, {3.478961709433363*^9, 
   3.47896175216029*^9}, {3.478961842569364*^9, 3.478961894377494*^9}, {
   3.4789619830038633`*^9, 3.478961984506156*^9}, {3.4789699280628653`*^9, 
   3.478969982243393*^9}, {3.478970021389124*^9, 3.478970165180615*^9}, {
   3.478970224319232*^9, 3.478970261501657*^9}, {3.4789703108875017`*^9, 
   3.478970348344078*^9}, 3.478970398020482*^9, {3.478970871122594*^9, 
   3.47897087265033*^9}, {3.478971414854863*^9, 3.4789714317583723`*^9}, {
   3.4789723334965277`*^9, 3.4789723911200447`*^9}, {3.478973525233735*^9, 
   3.47897352833882*^9}, {3.479495227181163*^9, 3.4794952662789087`*^9}, {
   3.4794954131043873`*^9, 3.4794954161349077`*^9}, {3.479497883443406*^9, 
   3.479497887306903*^9}, {3.4794980354692507`*^9, 3.479498036795588*^9}, 
   3.4794982488155937`*^9, {3.479662131489229*^9, 3.479662133377276*^9}, 
   3.479665540471899*^9, {3.4802459792714577`*^9, 3.480245981573744*^9}, {
   3.4802525542284737`*^9, 3.4802525884311867`*^9}, {3.48194087775911*^9, 
   3.481940886937986*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], LineBox[CompressedData["
1:eJwV1nk8VVsfBnBDrgxlKkNRKEkhUSiup1A0kMhYUcpUmYkz7nMo5RTNSCmV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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"z (m)\"", TraditionalForm], 
    FormBox["\"F (N/A)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 0.013}, {0., 0.3925374150709206}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.478970312655707*^9, 3.478970349956621*^9}, 
   3.4789703994875298`*^9, 3.478971607584939*^9, 3.4789719008193083`*^9, {
   3.478972321794873*^9, 3.4789723915815496`*^9}, 3.47897462857933*^9, 
   3.479491375853756*^9, {3.479495240008403*^9, 3.479495266824088*^9}, 
   3.479495416841895*^9, 3.479497903792444*^9, 3.4794980383520308`*^9, 
   3.4794982508041973`*^9, 3.479665430756591*^9, 3.47966555437061*^9, 
   3.4796655952965937`*^9, 3.479665767861109*^9, 3.479665800596849*^9, 
   3.479666123343511*^9, 3.480085442474633*^9, 3.480085476792396*^9, 
   3.480244564663542*^9, {3.480245967281913*^9, 3.4802459841655083`*^9}, 
   3.480252591260969*^9, 3.480252685939891*^9, 3.480692325467414*^9, 
   3.481940897619549*^9, 3.481940954553793*^9, 3.4819414042893677`*^9, 
   3.481941630662005*^9, 3.4819421034795094`*^9, 3.662607045369123*^9, 
   3.6626072503934526`*^9, 3.662626188358437*^9}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"cases", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"BO5", ",", "BO10", ",", "BM5", ",", " ", "BM", ",", "BOTT"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.479668457935833*^9, 3.479668481450539*^9}, {
  3.479668587715115*^9, 3.4796685878908243`*^9}, {3.4819414768722143`*^9, 
  3.481941481456056*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Join", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "cases", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Transpose", "[", "\[IndentingNewLine]", 
     RowBox[{"Table", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fmax", "[", 
          RowBox[{"cases", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
         RowBox[{"1000", "*", 
          RowBox[{"zmax", "[", 
           RowBox[{"cases", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
         RowBox[{"1000", "*", 
          RowBox[{"zmaxq", "[", 
           RowBox[{"cases", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
         RowBox[{"delta", "[", 
          RowBox[{"cases", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
         RowBox[{"deriv2", "[", 
          RowBox[{"cases", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "cases", "]"}]}], "}"}]}], 
      "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", "]"}]}], 
   "\[IndentingNewLine]", "]"}], "//", "TableForm"}]], "Input",
 CellChangeTimes->{{3.479668483217331*^9, 3.479668563563539*^9}, {
  3.4796686215578623`*^9, 3.479668666780747*^9}, {3.479668701726816*^9, 
  3.479668747295388*^9}, {3.481942141220706*^9, 3.481942165968225*^9}, {
  3.481942240350567*^9, 3.481942242583256*^9}, {3.6626233925731487`*^9, 
  3.662623394158786*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"BO5", "BO10", "BM5", "BM", "BOTT"},
    {"0.9628352953498244`", "1.6948582028562238`", "0.6371543615438757`", 
     "1.0843322046661032`", "0.3925374169455944`"},
    {"6.180957187169586`", "7.195845485312815`", "5.090030919822695`", 
     "6.361540102283618`", "7.5970745443657`"},
    {"6.141132328792641`", "7.352611334002007`", 
     RowBox[{"1000", " ", 
      RowBox[{"zmaxq", "[", "BM5", "]"}]}], 
     RowBox[{"1000", " ", 
      RowBox[{"zmaxq", "[", "BM", "]"}]}], 
     RowBox[{"1000", " ", 
      RowBox[{"zmaxq", "[", "BOTT", "]"}]}]},
    {
     RowBox[{"-", "0.00003982485837694498`"}], "0.00015676584868919152`", 
     RowBox[{"delta", "[", "BM5", "]"}], 
     RowBox[{"delta", "[", "BM", "]"}], 
     RowBox[{"delta", "[", "BOTT", "]"}]},
    {"43704.57581798506`", "61049.68679663531`", "38794.45907746318`", 
     "53808.558131265105`", "12441.390653444461`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.479668564704335*^9, 3.479668590873575*^9}, 
   3.4796686679295673`*^9, {3.479668724514228*^9, 3.479668747827025*^9}, 
   3.480244564877256*^9, 3.480245967399906*^9, 3.480245998712572*^9, 
   3.480252760111574*^9, 3.4806923267132607`*^9, 3.481941485393458*^9, 
   3.4819416307948303`*^9, 3.4819421035619698`*^9, 3.48194216744412*^9, 
   3.4819422448464603`*^9, 3.662626188428562*^9}]
}, Open  ]],

Cell["Combinations with opposed magnets", "Section",
 CellChangeTimes->{{3.4802635577614393`*^9, 3.480263564378763*^9}}],

Cell[CellGroupData[{

Cell["\<\
10x10 magnets 5 mm apart with hybrid OSEM coil - historical interest only.\
\>", "Subsection",
 CellChangeTimes->{{3.480700103981674*^9, 3.4807001348451366`*^9}, {
  3.481565209358251*^9, 3.48156521929447*^9}, {3.481565959348879*^9, 
  3.48156595959684*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot2", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"fz", "[", 
      RowBox[{"BM", ",", "z"}], "]"}], "-", 
     RowBox[{"fz", "[", 
      RowBox[{"BM", ",", 
       RowBox[{"z", "+", "0.015"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.010"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", "Black", "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.480263490827755*^9, 3.4802634980091763`*^9}, {
   3.4802639392440853`*^9, 3.480263973553187*^9}, 3.480264058574482*^9, 
   3.480264152546308*^9, {3.480264362832872*^9, 3.480264366942833*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], LineBox[CompressedData["
1:eJwV1ns0VVsbBnAVlYhIUkcoIt0OUUl4hAoR6UguEUWiULnutfbeaJOUpCQJ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.480263609670712*^9, 3.480264091847402*^9, 
  3.480264219397868*^9, 3.480692381982799*^9, 3.481568304979225*^9, 
  3.662626226196561*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata2", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.9124418416937872`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.0068007634327481815`"}], "}"}]}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fz", "[", 
            RowBox[{"BM", ",", "z"}], "]"}], "-", 
           RowBox[{"fz", "[", 
            RowBox[{"BM", ",", 
             RowBox[{"z", "+", "0.015"}]}], "]"}]}], ")"}]}], ",", " ", 
        RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, {
   3.4789735053303223`*^9, 3.478973506356164*^9}, 3.478974572010633*^9, {
   3.478974602170628*^9, 3.4789746026573887`*^9}, 3.479661922162386*^9, {
   3.480244453457839*^9, 3.480244472141658*^9}, {3.480244801803609*^9, 
   3.4802448024252663`*^9}, {3.480264669104636*^9, 3.480264684559224*^9}, 
   3.480264725697961*^9, {3.480264827573757*^9, 3.480264835420212*^9}, 
   3.480265037916628*^9, 3.480693722607716*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.9124418416938382`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.00680076504966241`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.480264812348777*^9, 3.480265632924423*^9, 
  3.480693092309564*^9, 3.481568926418055*^9, 3.662626522075367*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax2", "[", "BM", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata2", "[", "BM", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.4802646918142347`*^9, 
   3.480264705945876*^9}}],

Cell[BoxData["0.00680076504966241`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.480085256476678*^9, 
  3.480244563873888*^9, 3.480244811221223*^9, 3.4802459142441196`*^9, 
  3.480265633025037*^9, 3.480693092364389*^9, 3.481568926517033*^9, 
  3.662626522160326*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax2", "[", "BM", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata2", "[", "BM", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.4802646945892344`*^9, 
   3.4802647077937603`*^9}}],

Cell[BoxData["0.9124418416938382`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.480085460576848*^9, 
  3.480244563919486*^9, 3.480245914361339*^9, 3.480265633047605*^9, 
  3.4806930923900967`*^9, 3.481568926569429*^9, 3.6626265222042217`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"BM", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}}],

Cell[BoxData[
 TagBox[
  TemplateBox[{RowBox[{
      StyleBox[
       TagBox["InterpolatingFunction", "SummaryHead"], 
       "NonInterpretableSummary"], 
      StyleBox["[", "NonInterpretableSummary"], 
      DynamicModuleBox[{Typeset`open$$ = False}, 
       PanelBox[
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{}, {}, {
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVjnsw2wcAx0ONbjpVPaOYZnRnlasSj271+NKxeXVNaa0eK6ERqww1GioI
IUhnbNE5HcM6VfXao7KjZWea0oUOs3jNeSVEKpLfanTa6OyPz33++9znjdjk
EIYuiUTy2OF/r1d3Hsz2X/Mkkcj7jhukeI0X5basP6BA+YWbvu+FVkwkEoTe
3x7g9v8yffdaD4KUPe7lXD9Y6UjuFzQ/gIWOGWXkQjB2yVZCsyaG4PLiUORJ
9WnE35iWV4pHYezgGhnGOouR8QFzT5oUlGFqk61LOOiFoUcbTKeQG5dZGqiM
gq5btEp7ZwYFoZbSQMcYqLxKb2Vw56BoS/ls1DgWFyn6e/U8F8CM1YlhjcRB
PmF79/yjReR9LtqmljCwMXu0VxQgh3ta7P3IeCYcy/eEGo0tYe+PAY1f2X4M
1djwqzyqArwmux+c9RNhVGP4RFG1AuEBe752loXr9VXkdpkS3fPMjMmqJNjn
1bTG6a2iz+nRwFWPFETcptvdO6RCh7W+zNnqElYeipYkFmtgJ3SalBqlYkX5
bz3fUI2ite2bnOepCPQa87CcUaOBvBCQPvUp9jDPC5x8Nfiy3Zt0UJIGF39e
Qq9Qg1Klh3ikOR1hdB9S5YgGUrpEbVF8GfvDJuiNugTUrn8eMWWzUaOXNneY
QsBUxLliHpaB6mhhVIgfAUNh7dTg+5lg10QIGGcJnGo5U2fmegUvUuflfuEE
6i41piWaZIHzLOhpfwiBXmF6VIouB92Ola+E++z06fMhOQscRHbJlIQdgUTW
bJtNTza+W/bysjQg8PMf56wzWnLw3njSvlPTGhgvJ1dLBbk4tvjRHLtZg2qK
jtkTTy4OOrw0LU7RQPTOAWZuGxe/uej3ebtosMnYWpFa5UEo2qplKdSo867a
4Ffkoars3dFzZ9SgEXyBu14+yF6MpKFf15BAo97yz87H905DyfHWa2gcuvmU
vJ6PAgbreRZbBRX54rA2lodN2kalbHwV120eOzlP89Di+/Bag90qPtjqsvgk
qAC7J09qN7iPcVgT6pbaWQDJmJs28C8lWBW3p393LAS1q3T4n7eUEBnRdlPr
CrFtctW7Jm8FCcd+6lk15yMp6LRiclABn5zZxtQyPrzvrL0ptFKA/HWEuVbL
h7grwrcpcxnMeKHJXHoReLvonbqSJXQYWFb0y4twwzL39eP2S0j8MKbWILoY
Ha9x94tz5PAXJ82YSIsR/E2rLWdSBsrLg9/a+JUgcOHtdpcTMlx+tkQIuktQ
fo9qUFa/iIE+2sDmEcHOv8PohNEiiAq35J5aAdaDCUFH9gL+A7Z915E=
                   
                   "]]}}}, {
               DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                PlotRange -> {{0., 0.013}, {0., 1.084295175525028}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{}, {}, {
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVjnsw2wcAx0ONbjpVPaOYZnRnlasSj271+NKxeXVNaa0eK6ERqww1GioI
IUhnbNE5HcM6VfXao7KjZWea0oUOs3jNeSVEKpLfanTa6OyPz33++9znjdjk
EIYuiUTy2OF/r1d3Hsz2X/Mkkcj7jhukeI0X5basP6BA+YWbvu+FVkwkEoTe
3x7g9v8yffdaD4KUPe7lXD9Y6UjuFzQ/gIWOGWXkQjB2yVZCsyaG4PLiUORJ
9WnE35iWV4pHYezgGhnGOouR8QFzT5oUlGFqk61LOOiFoUcbTKeQG5dZGqiM
gq5btEp7ZwYFoZbSQMcYqLxKb2Vw56BoS/ls1DgWFyn6e/U8F8CM1YlhjcRB
PmF79/yjReR9LtqmljCwMXu0VxQgh3ta7P3IeCYcy/eEGo0tYe+PAY1f2X4M
1djwqzyqArwmux+c9RNhVGP4RFG1AuEBe752loXr9VXkdpkS3fPMjMmqJNjn
1bTG6a2iz+nRwFWPFETcptvdO6RCh7W+zNnqElYeipYkFmtgJ3SalBqlYkX5
bz3fUI2ite2bnOepCPQa87CcUaOBvBCQPvUp9jDPC5x8Nfiy3Zt0UJIGF39e
Qq9Qg1Klh3ikOR1hdB9S5YgGUrpEbVF8GfvDJuiNugTUrn8eMWWzUaOXNneY
QsBUxLliHpaB6mhhVIgfAUNh7dTg+5lg10QIGGcJnGo5U2fmegUvUuflfuEE
6i41piWaZIHzLOhpfwiBXmF6VIouB92Ola+E++z06fMhOQscRHbJlIQdgUTW
bJtNTza+W/bysjQg8PMf56wzWnLw3njSvlPTGhgvJ1dLBbk4tvjRHLtZg2qK
jtkTTy4OOrw0LU7RQPTOAWZuGxe/uej3ebtosMnYWpFa5UEo2qplKdSo867a
4Ffkoars3dFzZ9SgEXyBu14+yF6MpKFf15BAo97yz87H905DyfHWa2gcuvmU
vJ6PAgbreRZbBRX54rA2lodN2kalbHwV120eOzlP89Di+/Bag90qPtjqsvgk
qAC7J09qN7iPcVgT6pbaWQDJmJs28C8lWBW3p393LAS1q3T4n7eUEBnRdlPr
CrFtctW7Jm8FCcd+6lk15yMp6LRiclABn5zZxtQyPrzvrL0ptFKA/HWEuVbL
h7grwrcpcxnMeKHJXHoReLvonbqSJXQYWFb0y4twwzL39eP2S0j8MKbWILoY
Ha9x94tz5PAXJ82YSIsR/E2rLWdSBsrLg9/a+JUgcOHtdpcTMlx+tkQIuktQ
fo9qUFa/iIE+2sDmEcHOv8PohNEiiAq35J5aAdaDCUFH9gL+A7Z915E=
                   
                   "]]}}}, {
               DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                PlotRange -> {{0., 0.013}, {0., 1.084295175525028}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["3", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["False", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
        Baseline], DynamicModuleValues :> {}], 
      StyleBox["]", "NonInterpretableSummary"]}]},
   "CopyTag",
   DisplayFunction->(#& ),
   InterpretationFunction->("InterpolatingFunction[{{0., 0.013}}, <>]"& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.662626531280512*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"deriv2", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"fzi", "[", "BM", "]"}], "[", "z", "]"}], "-", 
         RowBox[{
          RowBox[{"fzi", "[", "BM", "]"}], "[", 
          RowBox[{"z", "+", "0.015"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "BM", "]"}], ",", "2"}], "}"}]}], "]"}], "]"}],
      ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, 3.662623730198477*^9, {
   3.662846418987355*^9, 3.6628464235824213`*^9}}],

Cell[BoxData["73712.41140137974`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.6626265314140587`*^9, 3.662846424961239*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"deriv2", "[", "BM", "]"}], ",", 
      RowBox[{"zmax", "[", "BM", "]"}], ",", 
      RowBox[{"fmax", "[", "BM", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"deriv2", "[", "BM", "]"}], ",", 
      RowBox[{"zmax2", "[", "BM", "]"}], ",", 
      RowBox[{"fmax2", "[", "BM", "]"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.481567608225747*^9, 3.481567635059455*^9}, {
  3.4815676689801073`*^9, 3.481567724116664*^9}, {3.481567816726468*^9, 
  3.481567818793173*^9}, {3.4815681797948217`*^9, 3.48156818542627*^9}, {
  3.662623414299822*^9, 3.6626234188219624`*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"73712.41140137974`", "0.006361540102283618`", "1.0843322046661032`"},
    {"73712.41140137974`", "0.00680076504966241`", "0.9124418416938382`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4815677247383738`*^9, 3.48156775513408*^9, 
  3.481567825373666*^9, 3.481568186322205*^9, 3.4815689269394617`*^9, 
  3.6626265314412413`*^9, 3.6628464281771193`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
10x10 magnets 20 mm apart with BOSEM coil per pitch magnets on top mass and \
UIM of quad\
\>", "Subsection",
 CellChangeTimes->{{3.480700103981674*^9, 3.480700176213991*^9}, {
  3.481565949718953*^9, 3.481565983045248*^9}, {3.481566089551104*^9, 
  3.48156609404573*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot2", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV13k8Vc0fB3ASiSRlS7ZKSkmJ0sZHRaEIJUkUZQlJC3HvPede3FK2HipR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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{All, All},
     PlotRangeClipping->True,
     PlotRangePadding->{Automatic, Automatic}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fz", "[", 
         RowBox[{"BO10", ",", "z"}], "]"}], "-", 
        RowBox[{"fz", "[", 
         RowBox[{"BO10", ",", 
          RowBox[{"z", "+", "0.030"}]}], "]"}]}], ")"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0", ",", "0.010"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.480263490827755*^9, 3.4802634980091763`*^9}, {
   3.480263536719996*^9, 3.480263537125444*^9}, {3.480263833591049*^9, 
   3.480263861642727*^9}, {3.48026393264508*^9, 3.48026393627591*^9}, {
   3.480264005377029*^9, 3.4802640754825783`*^9}, {3.4802641643969183`*^9, 
   3.480264165325192*^9}, {3.4806937485908546`*^9, 3.480693765401557*^9}, {
   3.481566119159527*^9, 3.481566119550919*^9}, 3.4815661573148108`*^9, 
   3.4815682113946342`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], LineBox[CompressedData["
1:eJwV13k8lN8XB3BE2UqEpNKCtq+KqOQnH2mjEEoS2QplTyqzPDODIVkqS6Io
CW2KFGUpW6GStahEIaGSso1H1O/217zer9e9M2fOc59zzl3k4mvlKiIkJCQl
LCT073P9ltF+lvT3jbYPrJ3mLi8vaRafH/6w8LlBc+g0yyt/y0r6NNR9uYXv
DBJOVHmoNpeVDBncdDlY2GfAy6hboBFSVjK23dPeupA2CC+PLUZbaQnT1NTW
vFAC3Oq2HZ2LS0qKaotbdhTOQXSW8j2Z4YKSDzIjiiaFyxErLXH4pFZ2Safq
KbZxnR6Uls0IvL/iEngtb2d4ft2M8LBmkT0xRcjxOFHPNd2BlyaT5yY7qvCK
dWp/RLIFvj+9c4pr14DpBq262S27ofOpSZZv04wVVNYy+X028BFaoG5xvRVK
XcKyC6v3o05S9X2t8yfUP3VwnTp5AD/pXu30/E7cj0l2TShyQsHwkfDqld3o
4kTXKtq5QPfJwcRMjx6wuKX3PQYP4snpNvGmyD4EG+RedchyhdydqsvPq77B
p+j6sxJjd2j8XP1d7UU/no/aDZZOO4L2pKkbEzsGELXV6tL5Jx4osIrMnfz2
EzpWpswWGy8kjlraBb38hZ3zxVwKZvngkEbV4tZ7g9ieWcYVz/VF/IAYDKkh
vDuh0sQq8ENYHN4WmQ5jsxql1nb+KNpOqgqtkBpBak7bzOMH/bHOpvtLXc4I
dJJThA8YHYPvr4vx2jajKHJzjGbJBcCv9chuhS+jGNUzaglpD4BWriX3qJsA
h3346h+KjsNsQ/XuhM8CvOJVz/CMOIHIk4G2UuZjODLoOWHicRIPHx28NvP+
GAq8NW/IbQtE266WhJ/iNBaf2pmxzSQQddZuBkqSNKJS3dKYpoGYE/pNE1I0
HJqSkzutAvE5VUgQMZ2GyAaJmFzHQJRcZYory9HYIdrJsGIEInzCw0RxLo33
F+N2xmYF4qnPw6hTGjQmqkZ/yM5iIPuJG3uXGY1OB1WNSEUG2DOl9jua06ge
2XVEVJmBzaZSbj67aMSr3uwaXcjAMgMHiQhLGv9x7d62rmJAxcqd89Caxv51
pWUZOxioS0/S/HaARkH66fgNwQw0xmxRy/emcSJonp7zLwZOh9R1tkXQeLsg
z/LKMAP+ufJ6tyNp6D0xO9ImYOBEt1T7ySgak+OcRNs/DGRcsZkuc4YGP6Bj
1FKKicqPuyTWxtCIcc+8b6TOhJzs7RDHCzSyzDRXqtkyYZw28HXVNRozvldv
cbFnQrNqykQ3sV+Es32qIxOWLh12yek0tKtiI+e5MeH1WUd8WiaNQsORPvlj
TGwdElJ4fYP8f+3CTLFoJlZ6dEib3aXRNWfLwp5SJmx0z3cXPqLhpf+mXf4p
E8rb3J7uK6Ax7OCWYlTFxK3h5vER4qnp4cqXXzHhGPPGZ1URjWWrXslbv2fi
aanI8QuPyX6jvRIVQ0woND+btqOc7Pc4PHh5CQt/8orytV7SYEfTOTXLWegd
3XijkFgsJ8J3XIMFVqDTkFENDcWRrO/W2ix4rKlOsHxFQ5f764u0IQtN5b9m
udeR/XHMVqYtC19ZG0f9m2iIFkc93RvFwhnJ8voZrTQk7VdXPD/LQv1K0+Eo
YpmJhjL9OBb0s/z2Sn6goaw/u2TxRRZif7Q1i7TRWF18teDHdRZs95S8+NpO
nndx/t2wCha2ROnHJnTScLK3vUNXkvUy7TfFu2i4Tvy+7fWCBQeaJ8wk9tPf
dNOqgYX22epH93+mEVr88prKRxaW/DbaI/eFRk7xp8T8cRYmqX4Dhz4a+fYh
F5b/YWFzn6fzU+KiCfWEZGE2VHDg2fKvNCr1PeOCxdl47jdhOUjcWjwSba7I
xp6oizzmd5L/x5IhX7TY+PBxvbH7AA37xzreikfYQO3hZfeHabQd2rzN3IsN
9dRVnhPEDtJWC8J82YhefEdy6wgNZzvfhpHjbAhpazi9Jnajb659E8xGjb6N
+7dRGr5rF/yJS2ZDv1d4bHyMxs8PK1teXmEj6nyXjB5Nw5+vnzPlGvn9BYWh
gcQBTbYux26ykRF6L3KIOPBofKVVPhuneJ9+d4zTCL4jcVa2no3UR//dSp2g
McVa6bBJExvB87m33xDzJ5ZsCmpmg/l7rrTkJI2wnVuGfn5gw3qI982POLKP
Y1Pfx8Z5GyP19X9oSMdEa4r3s3FcXFLVnfiMbrKE4U824m+08RKIz50qKMoe
ZYN/PcV+iDhefXjB2SkUvitNJGT8paHwSoSunErh3uCNhHrihADZxj8SFFKW
DoyOEydVrOL7zKTgbZzxzkxoHJedj/SazacwdW/b8u/E11Pac6TXU1h99aeM
lMg4Msv/PD+tR+HjeEXXKuL0HpWuqQYUxhidk5bEqVqOCsJbKZgP2IolECc+
+8gYsaKQIax1SGHKOBK+/o3130uh94OOtzZxvMzCrAFbCsPedo8tiM/ZOrX3
OVH4O3BC+zRxeP8no3YfCivH1zJ/EYfJCdvb+VOQsXMpkRAdB3/9ouNvj1NY
eD/WdBExL8j5eiObAiPFD+bEnMyg0l08CjW/9mYcJGa/vPquJoRCZlnu7kDi
QIVOqaoICmtrEXGF+ISeiPqWMxTkNhXL5RIHOC42KIuhoDBL6nMFsd9NF7+i
RAr7hRqcu4l9aoNP6yZToA6fnTFC7DWUlpZ3hYKs4iVRUbFxHN7Y9To7k0Lj
QZ1XC4jdXKb80LhFns/131c0iA+dUp126w4FZ/a5Yl1il6zNC5feo/B54zzV
LcRODQc3pD+gICZIazIndhgNsVr0iEL4tmO1+4jt56Z7Xi6iMNTsOMuFeL/h
U/7cEgpFV9PSPIj3uX5OSSyn4GGoy/Yn3hsh+lChkoJF0oVUBvGebLX62OcU
jBqzZHjEVq+39Mm8ohC64PzzUGIL+pBIdD0FiSfetRHE5iqhcyVfU5Ae3q1y
lth0c4bOqRYKVrKuBbHEOw4/MxNtpbB0e96V88TG0d1uQe0U1hkHNFwg3pYr
xvvTQeHZ3nzzJOItLepJrG5yvnoSZ18kNprYmjvWSyHs5AaNfzZc5Pby+HcK
N87kRf1bb7At7PPgAIWS4hUbEon1PTMnfYdIvi7mayUQ652rVOwfJfH7SrjE
EevmfVntMU4hgqUy9C/ede+nmvRMUnDRv1YfSazzd4nLIWEOXvrmjYcRr1Hb
zuoQ5WBnm//RIGJNE/d4B3EOsvbQOiziVT6n7rRKcaAke3BrALFG3PXKfTIc
3FvzJs2LeMWjqo9v5Di4IeZhdoh4eVvPmJUiB/InN221I06TCPgeP4eDkc4B
HSvieeuEPjXP48DphSDcmHjmWaWq/aocXFXxctAmjihKL0xewkFZhNSnpcSi
vZp325dz4BV+qHIu8ZihyXkXTQ5OxGSUCRP7e78JT9fmILCzrHmInMfvSc7s
L+s4CNMVWPw7rx8HGQc9NnJwVl/heCVxZfotLf8dJF5WNyeI2LBhnfoDMxLv
r7gSH+LCyXKlUQvyfffV3OyI7+5t/cuw4UCr1KJ7DfF5cenaoEMkf+9i7r4n
7+eMtYllFe4cPD4yfVHFv/fXWS1PzJMDP13t8VvE7EL95NNHOWBKdX4KJD7k
5e0Rw+GgQy88eDpxeyJ9oCmIA81PMit/kfqx71mopUIoB+MfZfGaeKfKZd2k
SA56a5qTEonX1NdOvZrIQWGH6kpl4qyJ/eOdlzgI8JmtSAuPY8nynn61Kxz8
Ut/h3kKsHPz39Y0MDhrXNxnFEgvraF7LySX5NDPoECJmOhUnDOZxMOkhmNFK
6t9wlHGETgEHxzKKMx4Q93Y7HX1UwsEDt8YZbsT1F2JQWsPBcqPJhjJSTy//
Hmyt+8KBaWjXmgOkHhtknTwh/JUDGf7rb6uIP9pPzNTu52DWVH0FIeKFT8S2
JQxxILz0XUEqqf/XeEo59kJcZDc+N20l/eKGmAG/bw4X/805k732Nw3j/HKV
ufO5iOnmsv6QftPntr3AdCEXL2SOF1QSr6i2+JG9hIupQa8irYnvRBzcd0Kb
7F8zHOVF+lWuzGmNKWZcHFBfMZsnoGFVOr1Kx4ILYyjKGBIP+cU6u+3m4uLW
ROZf0h91Gi8lPLflonniSRab+GH8XaFzblwsNg/g+ZF+Wjzn9et5PC5qW6p/
bxyiUaW6gFp3nwu+V8aI3w8any3zbO7kc1E6UJOpRCzC27lGrZALF//T+SX9
NPQ/nOyRLeNiLGHjoBRxbny9ZX8tF9eivdqTv5F8igUvSf/KhbDfp8zUXjI/
HBvsEZflod2C0aVJ5pUXERutn8rxIG607sbTDjKPXg0v58rz0CBaUWdDPFqn
kjI6m4fo7Mrt7E80tDR2Wn1W4aFa3ujjYzL/XP98rbhEgwfHhpLnqmR+irO2
jjlhzAPm9HBYZN5y8mv2lN/BQ/8yf3dRYo1Im225O3lIVqp7EdVI5pdS29/9
5jzo6AaIJDfQGPvPwdXVmofUU966D8j85iDivmGPCw9sDYe3L8n8tyw7sEOL
zUPtq285iRUkf+LJWv3ZPGhYzZ6XfY/G9k71rDv3ePi+8lafJHFjUfYSn/s8
aLKcVN1yaPT6VMwdyOdB+aHiB+VsGvJvvor9eszD/FwHVyqLhvfVDe+HX/LQ
zRwYW3KdhopeS/BEDw/BHzZsmp5MI8hT7rXUwiDMypu0WMUn5293kvWCM0Hg
gxmiSO4HG1ZcVasdDoK0cH7xGUUa/TlvR9QOBaOwbtHcNY1jUF4aIz+7Jhhh
4XmuW6PGsHjxfrk/WiGIzbumyjMaw7MaK7no1BCk3Asd+K9fgE63GseH0/hg
iJc0zU4SYF7Hrml8CT7istc7X7gggI1d010LKT6q/SvSFBMEqNn1frJvBh8W
Rlr68nEC5Ov2XpqnSNbv3T0kFS1AhKTo2yA1PkZ85Y/08wTQuvs/C9NNfMTu
mhPCOCyA17ISgdJmPnoY5Z0D5P6WmWZ0pXsLn9xn5H67ugqgfMHkB8eYDwmX
IFtLFwFEeTZR93aR9e5WNWr2Ary1PFat6MCHX/aj2092CSBXM+rb5ciH91bT
XE1zAcy2MWfnOPPxx/BYQJqpAOV6QW4mrnyk3Ji+MtREgCzVs6JsLz5mWMUf
3b5ZgC8pclnGPny8ecHf/3CTAIuUEnYr+PFxO4whtNRQgATplLS7x/hY6T+T
L7ZRgPqwhTtYx/n4+FLWJeB/AkgJp//afpLEX2Ux2blBgG2spUnyDD5WX8nb
a6krAG/klmEHk48j85f5lKwT4P8HPze0
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.480263682317749*^9, 3.4802639921266336`*^9, 
  3.480264150342636*^9, 3.480265704722389*^9, 3.480693170005075*^9, 
  3.481566223913733*^9, 3.662626577706636*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata2", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1.6263677836045267`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.007300967534849954`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fz", "[", 
            RowBox[{"BO10", ",", "z"}], "]"}], "-", 
           RowBox[{"fz", "[", 
            RowBox[{"BO10", ",", 
             RowBox[{"z", "+", "0.030"}]}], "]"}]}], ")"}]}], ",", " ", 
        RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, {
   3.4789735053303223`*^9, 3.478973506356164*^9}, 3.478974572010633*^9, {
   3.478974602170628*^9, 3.4789746026573887`*^9}, 3.479661922162386*^9, {
   3.480244453457839*^9, 3.480244472141658*^9}, {3.480244801803609*^9, 
   3.4802448024252663`*^9}, {3.480264669104636*^9, 3.480264684559224*^9}, 
   3.480264725697961*^9, {3.480264796714196*^9, 3.4802647976619177`*^9}, {
   3.480264858240645*^9, 3.4802648706070433`*^9}, 3.480265044282831*^9, 
   3.48069378671309*^9, {3.48156613564054*^9, 3.4815661608653307`*^9}, 
   3.481568221803894*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.626367783605898`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.007300973793652151`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.480266848202059*^9, 3.4806936239876947`*^9, 
  3.4815667132643127`*^9, 3.662626914105783*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax2", "[", "BO10", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata2", "[", "BO10", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.4802646918142347`*^9, 
   3.480264705945876*^9}, {3.4802647989584846`*^9, 3.480264799487084*^9}}],

Cell[BoxData["0.007300973793652151`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.480085256476678*^9, 
  3.480244563873888*^9, 3.480244811221223*^9, 3.4802459142441196`*^9, 
  3.480266848415159*^9, 3.480693624043004*^9, 3.481566713311575*^9, 
  3.662626914153386*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax2", "[", "BO10", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata2", "[", "BO10", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.4802646945892344`*^9, 
   3.4802647077937603`*^9}, {3.480264800442628*^9, 3.480264800914262*^9}}],

Cell[BoxData["1.626367783605898`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.480085460576848*^9, 
  3.480244563919486*^9, 3.480245914361339*^9, 3.480266848444786*^9, 
  3.4806936240713797`*^9, 3.481566713335513*^9, 3.662626914178856*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"BO10", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, 3.6626237826767893`*^9, 3.662623817129786*^9, {
   3.6626238562340107`*^9, 3.662623857953149*^9}}],

Cell[BoxData[
 TagBox[
  TemplateBox[{RowBox[{
      StyleBox[
       TagBox["InterpolatingFunction", "SummaryHead"], 
       "NonInterpretableSummary"], 
      StyleBox["[", "NonInterpretableSummary"], 
      DynamicModuleBox[{Typeset`open$$ = False}, 
       PanelBox[
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{}, {}, {
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVkmkw3AcAR5caxyiVbRJnHCtNGttN1z2p1V+OSeJKCSJVGldYtVvnOrtu
1tFskrLTliom6lYE0WGGNhPE1EaIsVKiiErZhM069vgvSfXDm/f1fXhW4XG+
keokEomxz//eruqzyHTbcCWRFlvr8lI/nSnKbtseoYJ7YDJnnH8PT1lSqcYm
Az2/zuqlsEfgKR50uZ1zHiIjjMf8PAETNUPq5HUvNIWI+6nz03B4ezTokuQy
biqWFDXcORicdAwKYF9BvNdENsdvEdQJu2Zrh0BwzVzLL5CXkR2RzvcQB+Nu
5lRTYM8KCvxMRR70UBDq3zVaGa9itT3+xhODcNRrrP/xZbUYzHC1UPZkBC5J
63PNV14h92bvG7uSSIxYPLLofFcCF074UFAUE+2rKdbP6l/jvS73xu+tv8LQ
9eaDZQ1S5Dcfv2uvycJ0k5puQ8cmyo1teHsLbKgYeizNhi0MLDHT/qqIRd1w
kL529jYe2I6PfsuIx5Xk2VWz4B3cM9f8x94sATn8YJ+HZjKkRveR+fqJcIuo
SQr/W4aijTcN3N1ElDyd+kB6Q456y+fuybNJoMdfTXhspUBZx2mSxRgHimXj
vLVuBfhixvBkazIOax88tkVTQhQ2JjEpTkHA0diOEz8qIXGcph1KTUVgvYDG
2VXiUC83wyggDWr+7tU2XgR0y2tmhRfTEcY5u1JXTsC7zb/W0DEDVlrBl1V/
EqhNaOSwyN9gJc118hcpgfvlycHx6lysjdl6CPVUkIQt+WY95+KI8ACdZ6oC
i73QThnMBKln61jlERV+m/rcPK0tC/SK/qiK91Uw+DeuSlSajeXbiZWn3xKo
oqoZbrnmgH9n48nIPIHeU8bM7PYctP7eIgzpISCPJNZEZrl4J907dTpvv+d0
hYwnyIVBYZzD0DkCPlJeqYtGHry7Bs4MkwhE+9g1uWXmYUaYpKPTqUTjowaF
5XYeygQpsZ6BSqxbxkzshedj6BShf01diUrKS1v7uXzQh7sizlYr8BnRb/K1
ZwEiLwpXZC4KnHjt55TYVwD5y8WSxhk52IKWucf0QmT4dzvrMOXo1ffRtqst
xIhAy3GHkCHauXvwlREPNh/TCo/ny3Ama6Ex8RYPo+agsnRlsPzpC6O9PR7a
nSz3fCt3wIwqJy8mF6H6ZDXlB/P9P7RMBQ9XirA+PkvhtmyDdTW0RiukGB+S
GTGxH23DbTh2niwqxgvxusFY5xaoOsI7lPMloBz+RD7ruoUU1Qtp6UAJhtNu
Xdu9v4nRBz6jclop1iQazue8NyEVOMUN1pQigeam4fVMiv8AYzrXyg==
                   
                   "]]}}}, {
               DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                PlotRange -> {{0., 0.013}, {0., 1.6947270890771051`}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{}, {}, {
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVkmkw3AcAR5caxyiVbRJnHCtNGttN1z2p1V+OSeJKCSJVGldYtVvnOrtu
1tFskrLTliom6lYE0WGGNhPE1EaIsVKiiErZhM069vgvSfXDm/f1fXhW4XG+
keokEomxz//eruqzyHTbcCWRFlvr8lI/nSnKbtseoYJ7YDJnnH8PT1lSqcYm
Az2/zuqlsEfgKR50uZ1zHiIjjMf8PAETNUPq5HUvNIWI+6nz03B4ezTokuQy
biqWFDXcORicdAwKYF9BvNdENsdvEdQJu2Zrh0BwzVzLL5CXkR2RzvcQB+Nu
5lRTYM8KCvxMRR70UBDq3zVaGa9itT3+xhODcNRrrP/xZbUYzHC1UPZkBC5J
63PNV14h92bvG7uSSIxYPLLofFcCF074UFAUE+2rKdbP6l/jvS73xu+tv8LQ
9eaDZQ1S5Dcfv2uvycJ0k5puQ8cmyo1teHsLbKgYeizNhi0MLDHT/qqIRd1w
kL529jYe2I6PfsuIx5Xk2VWz4B3cM9f8x94sATn8YJ+HZjKkRveR+fqJcIuo
SQr/W4aijTcN3N1ElDyd+kB6Q456y+fuybNJoMdfTXhspUBZx2mSxRgHimXj
vLVuBfhixvBkazIOax88tkVTQhQ2JjEpTkHA0diOEz8qIXGcph1KTUVgvYDG
2VXiUC83wyggDWr+7tU2XgR0y2tmhRfTEcY5u1JXTsC7zb/W0DEDVlrBl1V/
EqhNaOSwyN9gJc118hcpgfvlycHx6lysjdl6CPVUkIQt+WY95+KI8ACdZ6oC
i73QThnMBKln61jlERV+m/rcPK0tC/SK/qiK91Uw+DeuSlSajeXbiZWn3xKo
oqoZbrnmgH9n48nIPIHeU8bM7PYctP7eIgzpISCPJNZEZrl4J907dTpvv+d0
hYwnyIVBYZzD0DkCPlJeqYtGHry7Bs4MkwhE+9g1uWXmYUaYpKPTqUTjowaF
5XYeygQpsZ6BSqxbxkzshedj6BShf01diUrKS1v7uXzQh7sizlYr8BnRb/K1
ZwEiLwpXZC4KnHjt55TYVwD5y8WSxhk52IKWucf0QmT4dzvrMOXo1ffRtqst
xIhAy3GHkCHauXvwlREPNh/TCo/ny3Ama6Ex8RYPo+agsnRlsPzpC6O9PR7a
nSz3fCt3wIwqJy8mF6H6ZDXlB/P9P7RMBQ9XirA+PkvhtmyDdTW0RiukGB+S
GTGxH23DbTh2niwqxgvxusFY5xaoOsI7lPMloBz+RD7ruoUU1Qtp6UAJhtNu
Xdu9v4nRBz6jclop1iQazue8NyEVOMUN1pQigeam4fVMiv8AYzrXyg==
                   
                   "]]}}}, {
               DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                PlotRange -> {{0., 0.013}, {0., 1.6947270890771051`}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["3", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["False", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
        Baseline], DynamicModuleValues :> {}], 
      StyleBox["]", "NonInterpretableSummary"]}]},
   "CopyTag",
   DisplayFunction->(#& ),
   InterpretationFunction->("InterpolatingFunction[{{0., 0.013}}, <>]"& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.6626269251419783`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"deriv2", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"fzi", "[", "BO10", "]"}], "[", "z", "]"}], "-", 
         RowBox[{
          RowBox[{"fzi", "[", "BO10", "]"}], "[", 
          RowBox[{"z", "+", "0.030"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "BO10", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.66262382061903*^9, 
   3.662623864201857*^9}}],

Cell[BoxData["194679.00179182403`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.662626925257122*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"deriv2", "[", "BO10", "]"}], ",", 
      RowBox[{"zmax", "[", "BO10", "]"}], ",", 
      RowBox[{"fmax", "[", "BO10", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"deriv2", "[", "BO10", "]"}], ",", 
      RowBox[{"zmax2", "[", "BO10", "]"}], ",", 
      RowBox[{"fmax2", "[", "BO10", "]"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.481567608225747*^9, 3.481567635059455*^9}, {
  3.4815676689801073`*^9, 3.481567724116664*^9}, {3.481567816726468*^9, 
  3.481567818793173*^9}, {3.662623447715229*^9, 3.662623458100728*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"194679.00179182403`", "0.007195845485312815`", "1.6948582028562238`"},
    {"194679.00179182403`", "0.007300973793652151`", "1.626367783605898`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4815677247383738`*^9, 3.48156775513408*^9, 
  3.481567825373666*^9, 3.662626925288307*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
6x2 magnets 24 mm apart with AOSEM coil per pitch magnets on top mass and UIM \
of quad\
\>", "Subsection",
 CellChangeTimes->{{3.480700103981674*^9, 3.480700176213991*^9}, {
   3.481565949718953*^9, 3.481565983045248*^9}, {3.481566089551104*^9, 
   3.48156609404573*^9}, 3.4815663420577517`*^9, {3.4815664004646187`*^9, 
   3.4815664245209103`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot2", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nlUjG8UB/CKIqKQtEhRSEjCL5S+lqKylHZp06oSLTPzzjRpM0VlSRhK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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{All, All},
     PlotRangeClipping->True,
     PlotRangePadding->{Automatic, Automatic}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fz", "[", 
         RowBox[{"AODL", ",", "z"}], "]"}], "-", 
        RowBox[{"fz", "[", 
         RowBox[{"AODL", ",", 
          RowBox[{"z", "+", "0.030"}]}], "]"}]}], ")"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0", ",", "0.010"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.480263490827755*^9, 3.4802634980091763`*^9}, {
   3.480263536719996*^9, 3.480263537125444*^9}, {3.480263833591049*^9, 
   3.480263861642727*^9}, {3.48026393264508*^9, 3.48026393627591*^9}, {
   3.480264005377029*^9, 3.4802640754825783`*^9}, {3.4802641643969183`*^9, 
   3.480264165325192*^9}, {3.4806937485908546`*^9, 3.480693765401557*^9}, {
   3.481566119159527*^9, 3.481566119550919*^9}, 3.4815661573148108`*^9, {
   3.481566453354445*^9, 3.481566453404786*^9}, 3.481568229036901*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], LineBox[CompressedData["
1:eJwV1ns4VNsbB3A6CqlEJYlDUUmRSrqpb0guSeNarhWSW64zs2eMu0EXXaSm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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.480263682317749*^9, 3.4802639921266336`*^9, 
  3.480264150342636*^9, 3.480265704722389*^9, 3.480693170005075*^9, 
  3.481566223913733*^9, 3.48156671551313*^9, 3.4815668538117313`*^9, 
  3.481567024102026*^9, 3.6626269381991873`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata2", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.030257769468565232`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.005750794119386763`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fz", "[", 
            RowBox[{"AODL", ",", "z"}], "]"}], "-", 
           RowBox[{"fz", "[", 
            RowBox[{"AODL", ",", 
             RowBox[{"z", "+", "0.030"}]}], "]"}]}], ")"}]}], ",", " ", 
        RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, {
   3.4789735053303223`*^9, 3.478973506356164*^9}, 3.478974572010633*^9, {
   3.478974602170628*^9, 3.4789746026573887`*^9}, 3.479661922162386*^9, {
   3.480244453457839*^9, 3.480244472141658*^9}, {3.480244801803609*^9, 
   3.4802448024252663`*^9}, {3.480264669104636*^9, 3.480264684559224*^9}, 
   3.480264725697961*^9, {3.480264796714196*^9, 3.4802647976619177`*^9}, {
   3.480264858240645*^9, 3.4802648706070433`*^9}, 3.480265044282831*^9, 
   3.48069378671309*^9, {3.48156613564054*^9, 3.4815661608653307`*^9}, {
   3.481566453424974*^9, 3.481566453476396*^9}, 3.481568237964075*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.030257769468566578`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.0057507953218611865`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.480266848202059*^9, 3.4806936239876947`*^9, 
  3.481566715791988*^9, 3.481566854139357*^9, 3.481567149415079*^9, 
  3.662627026022953*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax2", "[", "AODL", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata2", "[", "AODL", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.4802646918142347`*^9, 
   3.480264705945876*^9}, {3.4802647989584846`*^9, 3.480264799487084*^9}, {
   3.4815664535103188`*^9, 3.481566453543878*^9}}],

Cell[BoxData["0.0057507953218611865`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.480085256476678*^9, 
  3.480244563873888*^9, 3.480244811221223*^9, 3.4802459142441196`*^9, 
  3.480266848415159*^9, 3.480693624043004*^9, 3.481566716026739*^9, 
  3.481566854410817*^9, 3.481567149455831*^9, 3.662627026053196*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax2", "[", "AODL", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata2", "[", "AODL", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.4802646945892344`*^9, 
   3.4802647077937603`*^9}, {3.480264800442628*^9, 3.480264800914262*^9}, {
   3.481566453577557*^9, 3.4815664536106653`*^9}}],

Cell[BoxData["0.030257769468566578`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.480085460576848*^9, 
  3.480244563919486*^9, 3.480245914361339*^9, 3.480266848444786*^9, 
  3.4806936240713797`*^9, 3.481566716286377*^9, 3.481566854706884*^9, 
  3.481567149468693*^9, 3.662627026079937*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"AODL", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, {3.662623917008511*^9, 3.662623918671576*^9}}],

Cell[BoxData[
 TagBox[
  TemplateBox[{RowBox[{
      StyleBox[
       TagBox["InterpolatingFunction", "SummaryHead"], 
       "NonInterpretableSummary"], 
      StyleBox["[", "NonInterpretableSummary"], 
      DynamicModuleBox[{Typeset`open$$ = False}, 
       PanelBox[
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{}, {}, {
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAA9Jy5H31I7j0AAEDyw4AhPteHf6z0
xis/ZkCNbIEJYD/Ya/HxBPI8P4b+RtoeqnA/S+q+O5CART/kAdaduad4PxoB
FyvRZEw/qjin/SUwgD80/yRbTe9RP0Ubj0jiSoQ/EC41W1ZsVT++mUrFRQaI
PyvQMqkjNFk/+lXwgPnxiz9/Y3mNSupcP/dUR5kPpo8/hFMb1kowYD/uvADY
wnqRP+iucIzSEGI/S18haVYwkz9nYgFgbNFjP/Kx549dspQ/gY62/jKJZT9k
B7k38BaWPzt0YsRbZmc/qsoHIrt/lz8PskmnliNpPyL8zbgut5g/g6knsTMG
az+0wSz2oOyZP5MZKob932w/Fs/fvAP/mj+94Wd42ZluPzlLbB/W5Js/wzHO
yIs8cD/xDPCHH8GcP7UeBuQzHHE/qwIIjO5znT93aLkSjQ5yP5hHsRPNGJ4/
h+7+pnz8cj+ON1Twz52eP6Ug4kl12nM/BdrJhBMBnz+Sr0AAH8t0P0jdGccl
Up8/jeo8xdGrdT8aQ4wqG4afP9Zhy+8aiHY/FSkOkrajnz/vNdUtFXd3PycP
HlIUrZ8/FbZ8ehhWeD+vHMo6y6GfPwuTn9rMR3k/6WqNSAGBnz9PrFSgFzV6
P6zmfCWVTZ8/oHGndGsSez/W9H19xg2fP8GTdVxwAnw/F6XAgcC4nj/vYeFS
fuJ8P5tYmqzhW54/a2zfriK+fT9GAaR3f/WdP7fTWB54rH4/yyy0A/h6nT8Q
52+c1op/PxLVuLs6/5w/nCsBF/M9gD+AjXM1JHCcP7Y5GWd/roA/nNjcDETj
mz/3Zfrp1hyBP6I+7MmJU5s/oECZ9oaUgT+UewbYR7KaP1Dxhoo7BII/vs5c
PNgXmj9oUDKoSH2CPyfoO2wrbZk/p82m+CD0gj+8OmirJ8OYP+0gatD9YoM/
OG3f2UMjmD+aIusxM9uDP8pAGJwVdZc/Tvq6Gm1LhD8XRNnpfNKWPynwUzZy
uYQ/gz4Pv5Azlj9slKrbzzCFP5wPuVM1iJU/tg5QCDKghT9zdMQm2OmUP2g3
s77sGIY/IrK+dy1AlD9Bft+nco+GP+GcavognJM/IJtaGP39hj/0BqedmQWT
P2dmkxLgdYc/okyTNVVlkj+1BxuUx+WHPzVrmenK0pE/a1dgnwdfiD8OuOo+
dzeRP0jFbt0S1og/n5isKbWikD8rCcyiIkWJPyvyEf1PG5A/dvvm8Yq9iT9x
KWoLnxiPP8jDUMj3LYo/EgwAL98Ujj/xlDZvvp+KP/UEivJZFY0/rlvABg==

                   "]]}}}, {
               DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                PlotRange -> {{0., 0.013}, {0., 0.030933682930039865`}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{}, {}, {
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAA9Jy5H31I7j0AAEDyw4AhPteHf6z0
xis/ZkCNbIEJYD/Ya/HxBPI8P4b+RtoeqnA/S+q+O5CART/kAdaduad4PxoB
FyvRZEw/qjin/SUwgD80/yRbTe9RP0Ubj0jiSoQ/EC41W1ZsVT++mUrFRQaI
PyvQMqkjNFk/+lXwgPnxiz9/Y3mNSupcP/dUR5kPpo8/hFMb1kowYD/uvADY
wnqRP+iucIzSEGI/S18haVYwkz9nYgFgbNFjP/Kx549dspQ/gY62/jKJZT9k
B7k38BaWPzt0YsRbZmc/qsoHIrt/lz8PskmnliNpPyL8zbgut5g/g6knsTMG
az+0wSz2oOyZP5MZKob932w/Fs/fvAP/mj+94Wd42ZluPzlLbB/W5Js/wzHO
yIs8cD/xDPCHH8GcP7UeBuQzHHE/qwIIjO5znT93aLkSjQ5yP5hHsRPNGJ4/
h+7+pnz8cj+ON1Twz52eP6Ug4kl12nM/BdrJhBMBnz+Sr0AAH8t0P0jdGccl
Up8/jeo8xdGrdT8aQ4wqG4afP9Zhy+8aiHY/FSkOkrajnz/vNdUtFXd3PycP
HlIUrZ8/FbZ8ehhWeD+vHMo6y6GfPwuTn9rMR3k/6WqNSAGBnz9PrFSgFzV6
P6zmfCWVTZ8/oHGndGsSez/W9H19xg2fP8GTdVxwAnw/F6XAgcC4nj/vYeFS
fuJ8P5tYmqzhW54/a2zfriK+fT9GAaR3f/WdP7fTWB54rH4/yyy0A/h6nT8Q
52+c1op/PxLVuLs6/5w/nCsBF/M9gD+AjXM1JHCcP7Y5GWd/roA/nNjcDETj
mz/3Zfrp1hyBP6I+7MmJU5s/oECZ9oaUgT+UewbYR7KaP1Dxhoo7BII/vs5c
PNgXmj9oUDKoSH2CPyfoO2wrbZk/p82m+CD0gj+8OmirJ8OYP+0gatD9YoM/
OG3f2UMjmD+aIusxM9uDP8pAGJwVdZc/Tvq6Gm1LhD8XRNnpfNKWPynwUzZy
uYQ/gz4Pv5Azlj9slKrbzzCFP5wPuVM1iJU/tg5QCDKghT9zdMQm2OmUP2g3
s77sGIY/IrK+dy1AlD9Bft+nco+GP+GcavognJM/IJtaGP39hj/0BqedmQWT
P2dmkxLgdYc/okyTNVVlkj+1BxuUx+WHPzVrmenK0pE/a1dgnwdfiD8OuOo+
dzeRP0jFbt0S1og/n5isKbWikD8rCcyiIkWJPyvyEf1PG5A/dvvm8Yq9iT9x
KWoLnxiPP8jDUMj3LYo/EgwAL98Ujj/xlDZvvp+KP/UEivJZFY0/rlvABg==

                   "]]}}}, {
               DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                PlotRange -> {{0., 0.013}, {0., 0.030933682930039865`}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["3", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["False", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
        Baseline], DynamicModuleValues :> {}], 
      StyleBox["]", "NonInterpretableSummary"]}]},
   "CopyTag",
   DisplayFunction->(#& ),
   InterpretationFunction->("InterpolatingFunction[{{0., 0.013}}, <>]"& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.662627027437167*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"deriv2", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"fzi", "[", "AODL", "]"}], "[", "z", "]"}], "-", 
         RowBox[{
          RowBox[{"fzi", "[", "AODL", "]"}], "[", 
          RowBox[{"z", "+", "0.030"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "AODL", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.6626238917931423`*^9, 
   3.662623924815764*^9}, 3.662846392788566*^9}],

Cell[BoxData["2694.6272163520007`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.662627027471949*^9, 3.66284639360896*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"deriv2", "[", "AODL", "]"}], ",", 
      RowBox[{"zmax", "[", "AODL", "]"}], ",", 
      RowBox[{"fmax", "[", "AODL", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"deriv2", "[", "AODL", "]"}], ",", 
      RowBox[{"zmax2", "[", "AODL", "]"}], ",", 
      RowBox[{"fmax2", "[", "AODL", "]"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.481567608225747*^9, 3.481567635059455*^9}, {
  3.4815676689801073`*^9, 3.481567724116664*^9}, {3.662623496752969*^9, 
  3.66262350152312*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"2694.6272163520007`", "0.005708650614527121`", "0.03093422318713476`"},
    {"2694.6272163520007`", "0.0057507953218611865`", 
     "0.030257769468566578`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4815677247383738`*^9, 3.48156775513408*^9, 
  3.662627027501245*^9, 3.662846404962121*^9}]
}, Open  ]]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{1276, 996},
WindowMargins->{{Automatic, 45}, {14, Automatic}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "CompatibilityToolbar"],
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"10.1 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 23, \
2015)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 140, 1, 77, "Title"],
Cell[CellGroupData[{
Cell[732, 27, 31, 0, 68, "Section"],
Cell[766, 29, 761, 13, 101, "Text"]
}, Open  ]],
Cell[1542, 45, 641, 13, 29, "Input"],
Cell[CellGroupData[{
Cell[2208, 62, 78, 2, 68, "Section",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[2311, 68, 34, 0, 35, "Subsection"],
Cell[CellGroupData[{
Cell[2370, 72, 197, 4, 37, "Subsubsection"],
Cell[2570, 78, 847, 19, 93, "Input"]
}, Open  ]]
}, Open  ]],
Cell[3444, 101, 34, 0, 28, "Input"],
Cell[3481, 103, 80, 1, 28, "Input"],
Cell[CellGroupData[{
Cell[3586, 108, 44, 0, 35, "Subsection"],
Cell[3633, 110, 150, 4, 29, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3820, 119, 71, 0, 35, "Subsection"],
Cell[CellGroupData[{
Cell[3916, 123, 54, 0, 24, "Subsubsection"],
Cell[3973, 125, 552, 16, 29, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4562, 146, 168, 4, 24, "Subsubsection"],
Cell[4733, 152, 122, 4, 42, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4892, 161, 97, 1, 24, "Subsubsection"],
Cell[4992, 164, 166, 5, 42, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5207, 175, 65, 0, 35, "Subsection"],
Cell[CellGroupData[{
Cell[5297, 179, 151, 13, 182, "Input"],
Cell[5451, 194, 1043, 25, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6531, 224, 84, 2, 28, "Input"],
Cell[6618, 228, 746, 15, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7401, 248, 155, 12, 168, "Input"],
Cell[7559, 262, 1016, 24, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8612, 291, 113, 3, 28, "Input"],
Cell[8728, 296, 683, 12, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9448, 313, 412, 13, 29, "Input"],
Cell[9863, 328, 579, 8, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[10491, 342, 83, 2, 27, "Subsection",
 Evaluatable->False],
Cell[10577, 346, 887, 24, 294, "Input"],
Cell[11467, 372, 209, 8, 112, "Input"],
Cell[11679, 382, 691, 21, 280, "Input"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12431, 410, 116, 1, 68, "Section"],
Cell[CellGroupData[{
Cell[12572, 415, 1727, 44, 560, "Input"],
Cell[14302, 461, 2850, 54, 105, "Output"]
}, Open  ]],
Cell[17167, 518, 192, 5, 29, "Input"],
Cell[CellGroupData[{
Cell[17384, 527, 1005, 24, 91, "Input"],
Cell[18392, 553, 232, 7, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18661, 565, 6541, 116, 166, "Input"],
Cell[25205, 683, 6148, 112, 235, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31390, 800, 500, 10, 29, "Input"],
Cell[31893, 812, 423, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32353, 823, 494, 10, 29, "Input"],
Cell[32850, 835, 414, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33301, 846, 1189, 21, 29, "Input"],
Cell[34493, 869, 10982, 216, 65, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[45512, 1090, 1731, 33, 28, "Input"],
Cell[47246, 1125, 519, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47802, 1138, 168, 4, 28, "Input"],
Cell[47973, 1144, 458, 7, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48468, 1156, 380, 9, 29, "Input"],
Cell[48851, 1167, 420, 7, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49308, 1179, 242, 5, 29, "Input"],
Cell[49553, 1186, 390, 7, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49980, 1198, 164, 3, 26, "Text"],
Cell[CellGroupData[{
Cell[50169, 1205, 6432, 118, 158, "Input"],
Cell[56604, 1325, 6476, 117, 239, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[63117, 1447, 306, 9, 84, "Input"],
Cell[63426, 1458, 464, 10, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[63951, 1475, 159, 2, 38, "Section"],
Cell[CellGroupData[{
Cell[64135, 1481, 1717, 41, 490, "Input"],
Cell[65855, 1524, 3187, 59, 119, "Output"]
}, Open  ]],
Cell[69057, 1586, 283, 7, 28, "Input"],
Cell[CellGroupData[{
Cell[69365, 1597, 216, 5, 28, "Input"],
Cell[69584, 1604, 570, 9, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[70191, 1618, 380, 9, 29, "Input"],
Cell[70574, 1629, 475, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[71086, 1642, 314, 6, 29, "Input"],
Cell[71403, 1650, 439, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[71879, 1663, 251, 6, 29, "Input"],
Cell[72133, 1671, 466, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72636, 1684, 251, 6, 29, "Input"],
Cell[72890, 1692, 472, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[73399, 1705, 118, 1, 26, "Text"],
Cell[CellGroupData[{
Cell[73542, 1710, 390, 10, 29, "Input"],
Cell[73935, 1722, 10060, 177, 231, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84032, 1904, 412, 9, 29, "Input"],
Cell[84447, 1915, 6534, 119, 226, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[91018, 2039, 701, 15, 29, "Input"],
Cell[91722, 2056, 704, 14, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[92487, 2077, 323, 8, 23, "Input"],
Cell[92813, 2087, 262, 3, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[93112, 2095, 316, 8, 29, "Input"],
Cell[93431, 2105, 210, 3, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[93678, 2113, 227, 3, 68, "Section"],
Cell[CellGroupData[{
Cell[93930, 2120, 2271, 52, 588, "Input"],
Cell[96204, 2174, 2997, 56, 119, "Output"]
}, Open  ]],
Cell[99216, 2233, 331, 7, 28, "Input"],
Cell[CellGroupData[{
Cell[99572, 2244, 1027, 24, 91, "Input"],
Cell[100602, 2270, 231, 7, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[100870, 2282, 6752, 120, 158, "Input"],
Cell[107625, 2404, 6315, 115, 229, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[113977, 2524, 495, 10, 29, "Input"],
Cell[114475, 2536, 391, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[114903, 2546, 494, 10, 29, "Input"],
Cell[115400, 2558, 393, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[115830, 2568, 1235, 21, 29, "Input"],
Cell[117068, 2591, 10934, 214, 65, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[128039, 2810, 1785, 34, 28, "Input"],
Cell[129827, 2846, 516, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[130380, 2859, 1377, 22, 76, "Input"],
Cell[131760, 2883, 6462, 118, 227, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[138259, 3006, 246, 5, 28, "Input"],
Cell[138508, 3013, 529, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[139074, 3026, 380, 9, 29, "Input"],
Cell[139457, 3037, 425, 7, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[139919, 3049, 336, 6, 29, "Input"],
Cell[140258, 3057, 397, 7, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[140692, 3069, 273, 6, 29, "Input"],
Cell[140968, 3077, 418, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[141423, 3090, 273, 6, 29, "Input"],
Cell[141699, 3098, 424, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[142160, 3111, 118, 1, 26, "Text"],
Cell[CellGroupData[{
Cell[142303, 3116, 412, 10, 29, "Input"],
Cell[142718, 3128, 10066, 177, 231, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[152821, 3310, 438, 10, 29, "Input"],
Cell[153262, 3322, 6485, 118, 226, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[159808, 3447, 750, 16, 29, "Input"],
Cell[160561, 3465, 721, 14, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[161319, 3484, 371, 9, 29, "Input"],
Cell[161693, 3495, 290, 4, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[162020, 3504, 367, 9, 29, "Input"],
Cell[162390, 3515, 236, 3, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[162663, 3523, 285, 3, 68, "Section"],
Cell[CellGroupData[{
Cell[162973, 3530, 2494, 55, 547, "Input"],
Cell[165470, 3587, 2935, 54, 70, "Output"]
}, Open  ]],
Cell[168420, 3644, 411, 8, 27, "Input"],
Cell[CellGroupData[{
Cell[168856, 3656, 118, 1, 26, "Text"],
Cell[CellGroupData[{
Cell[168999, 3661, 435, 10, 27, "Input"],
Cell[169437, 3673, 10360, 182, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[179834, 3860, 461, 10, 27, "Input"],
Cell[180298, 3872, 6567, 119, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[186902, 3996, 578, 12, 27, "Input"],
Cell[187483, 4010, 623, 13, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[188167, 4030, 183, 4, 23, "Input"],
Cell[188353, 4036, 180, 2, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[188570, 4043, 339, 4, 68, "Section"],
Cell[CellGroupData[{
Cell[188934, 4051, 2414, 54, 560, "Input"],
Cell[191351, 4107, 2834, 53, 105, "Output"]
}, Open  ]],
Cell[194200, 4163, 459, 9, 28, "Input"],
Cell[CellGroupData[{
Cell[194684, 4176, 1104, 25, 91, "Input"],
Cell[195791, 4203, 234, 7, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[196062, 4215, 6661, 118, 161, "Input"],
Cell[202726, 4335, 6213, 113, 229, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[208976, 4453, 496, 10, 29, "Input"],
Cell[209475, 4465, 398, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[209910, 4475, 492, 10, 29, "Input"],
Cell[210405, 4487, 396, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[210838, 4497, 1237, 21, 29, "Input"],
Cell[212078, 4520, 10980, 216, 65, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[223095, 4741, 1781, 34, 28, "Input"],
Cell[224879, 4777, 516, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[225432, 4790, 681, 19, 29, "Input"],
Cell[226116, 4811, 11735, 206, 263, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[237888, 5022, 118, 1, 26, "Text"],
Cell[CellGroupData[{
Cell[238031, 5027, 462, 11, 29, "Input"],
Cell[238496, 5040, 10056, 176, 231, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[248589, 5221, 482, 10, 29, "Input"],
Cell[249074, 5233, 6565, 119, 226, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[255676, 5357, 603, 13, 29, "Input"],
Cell[256282, 5372, 619, 13, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[256962, 5392, 505, 9, 68, "Section"],
Cell[CellGroupData[{
Cell[257492, 5405, 2538, 55, 560, "Input"],
Cell[260033, 5462, 2900, 54, 105, "Output"]
}, Open  ]],
Cell[262948, 5519, 515, 10, 28, "Input"],
Cell[CellGroupData[{
Cell[263488, 5533, 1181, 26, 91, "Input"],
Cell[264672, 5561, 354, 9, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[265063, 5575, 6632, 117, 154, "Input"],
Cell[271698, 5694, 6211, 113, 226, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[277946, 5812, 549, 11, 29, "Input"],
Cell[278498, 5825, 460, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[278995, 5836, 548, 11, 29, "Input"],
Cell[279546, 5849, 464, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[280047, 5860, 1241, 21, 29, "Input"],
Cell[281291, 5883, 10934, 214, 65, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[292262, 6102, 1788, 34, 28, "Input"],
Cell[294053, 6138, 516, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[294606, 6151, 118, 1, 26, "Text"],
Cell[CellGroupData[{
Cell[294749, 6156, 485, 11, 29, "Input"],
Cell[295237, 6169, 10110, 178, 232, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[305384, 6352, 510, 11, 29, "Input"],
Cell[305897, 6365, 6647, 120, 223, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[312581, 6490, 629, 13, 29, "Input"],
Cell[313213, 6505, 693, 14, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[313967, 6526, 639, 10, 68, "Section"],
Cell[CellGroupData[{
Cell[314631, 6540, 2536, 55, 560, "Input"],
Cell[317170, 6597, 2899, 54, 105, "Output"]
}, Open  ]],
Cell[320084, 6654, 561, 10, 28, "Input"],
Cell[CellGroupData[{
Cell[320670, 6668, 1208, 27, 91, "Input"],
Cell[321881, 6697, 324, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[322242, 6710, 6771, 120, 161, "Input"],
Cell[329016, 6832, 6366, 115, 229, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[335419, 6952, 601, 12, 29, "Input"],
Cell[336023, 6966, 465, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[336525, 6977, 600, 12, 29, "Input"],
Cell[337128, 6991, 464, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[337629, 7002, 1239, 21, 29, "Input"],
Cell[338871, 7025, 10959, 216, 65, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[349867, 7246, 1790, 34, 28, "Input"],
Cell[351660, 7282, 516, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[352213, 7295, 118, 1, 26, "Text"],
Cell[CellGroupData[{
Cell[352356, 7300, 506, 11, 29, "Input"],
Cell[352865, 7313, 10150, 178, 231, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[363052, 7496, 532, 11, 29, "Input"],
Cell[363587, 7509, 6559, 119, 226, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[370183, 7633, 653, 13, 29, "Input"],
Cell[370839, 7648, 692, 14, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[371592, 7669, 143, 2, 68, "Section"],
Cell[CellGroupData[{
Cell[371760, 7675, 1787, 45, 560, "Input"],
Cell[373550, 7722, 2808, 53, 105, "Output"]
}, Open  ]],
Cell[376373, 7778, 242, 6, 29, "Input"],
Cell[CellGroupData[{
Cell[376640, 7788, 959, 23, 91, "Input"],
Cell[377602, 7813, 230, 7, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[377869, 7825, 6540, 117, 167, "Input"],
Cell[384412, 7944, 6180, 113, 235, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[390629, 8062, 452, 10, 29, "Input"],
Cell[391084, 8074, 398, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[391519, 8084, 448, 10, 29, "Input"],
Cell[391970, 8096, 394, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[392401, 8106, 1237, 21, 29, "Input"],
Cell[393641, 8129, 10976, 216, 65, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[404654, 8350, 1784, 34, 28, "Input"],
Cell[406441, 8386, 516, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[406994, 8399, 1356, 22, 76, "Input"],
Cell[408353, 8423, 6884, 124, 233, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[415286, 8553, 249, 3, 68, "Section"],
Cell[415538, 8558, 2014, 47, 560, "Input"],
Cell[417555, 8607, 364, 8, 28, "Input"],
Cell[CellGroupData[{
Cell[417944, 8619, 907, 23, 91, "Input"],
Cell[418854, 8644, 229, 7, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[419120, 8656, 6483, 115, 165, "Input"],
Cell[425606, 8773, 6091, 111, 235, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[431734, 8889, 358, 8, 29, "Input"],
Cell[432095, 8899, 350, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[432482, 8909, 352, 8, 29, "Input"],
Cell[432837, 8919, 346, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[433220, 8929, 1239, 21, 29, "Input"],
Cell[434462, 8952, 10986, 216, 65, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[445485, 9173, 1790, 34, 28, "Input"],
Cell[447278, 9209, 516, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[447831, 9222, 1091, 25, 29, "Input"],
Cell[448925, 9249, 410, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[449372, 9259, 1089, 24, 28, "Input"],
Cell[450464, 9285, 400, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[450901, 9296, 102, 1, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[451028, 9301, 1870, 37, 141, "Input"],
Cell[452901, 9340, 642, 12, 29, "Output"]
}, Open  ]],
Cell[453558, 9355, 1264, 20, 119, "Input"],
Cell[454825, 9377, 1423, 22, 104, "Input"],
Cell[456251, 9401, 519, 15, 29, "Input"],
Cell[456773, 9418, 1433, 24, 134, "Input"],
Cell[458209, 9444, 1486, 23, 134, "Input"],
Cell[459698, 9469, 569, 15, 29, "Input"],
Cell[CellGroupData[{
Cell[460292, 9488, 980, 19, 29, "Input"],
Cell[461275, 9509, 2238, 47, 246, "Output"]
}, Open  ]],
Cell[463528, 9559, 1192, 27, 29, "Input"],
Cell[CellGroupData[{
Cell[464745, 9590, 236, 4, 29, "Input"],
Cell[464984, 9596, 1940, 39, 241, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[466961, 9640, 549, 13, 29, "Input"],
Cell[467513, 9655, 677, 11, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[468227, 9671, 729, 16, 29, "Input"],
Cell[468959, 9689, 7253, 130, 241, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[476261, 9825, 712, 18, 29, "Input"],
Cell[476976, 9845, 398, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[477411, 9855, 402, 8, 29, "Input"],
Cell[477816, 9865, 385, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[478238, 9875, 481, 9, 29, "Input"],
Cell[478722, 9886, 380, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[479139, 9896, 160, 3, 26, "Text"],
Cell[CellGroupData[{
Cell[479324, 9903, 700, 12, 29, "Input"],
Cell[480027, 9917, 619, 9, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[480695, 9932, 2172, 43, 108, "Input"],
Cell[482870, 9977, 13599, 237, 407, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[496518, 10220, 244, 3, 68, "Section"],
Cell[496765, 10225, 2090, 48, 560, "Input"],
Cell[498858, 10275, 408, 8, 28, "Input"],
Cell[CellGroupData[{
Cell[499291, 10287, 1083, 25, 91, "Input"],
Cell[500377, 10314, 230, 7, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[500644, 10326, 6354, 114, 165, "Input"],
Cell[507001, 10442, 6060, 111, 236, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[513098, 10558, 402, 9, 29, "Input"],
Cell[513503, 10569, 419, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[513959, 10580, 398, 9, 29, "Input"],
Cell[514360, 10591, 396, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[514793, 10601, 1237, 21, 29, "Input"],
Cell[516033, 10624, 10976, 216, 65, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[527046, 10845, 1785, 34, 28, "Input"],
Cell[528834, 10881, 518, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[529389, 10894, 102, 1, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[529516, 10899, 1744, 35, 141, "Input"],
Cell[531263, 10936, 710, 13, 29, "Output"]
}, Open  ]],
Cell[531988, 10952, 176, 4, 28, "Input"],
Cell[532167, 10958, 711, 13, 119, "Input"],
Cell[532881, 10973, 1264, 24, 122, "Input"],
Cell[534148, 10999, 491, 14, 29, "Input"],
Cell[534642, 11015, 914, 15, 119, "Input"],
Cell[535559, 11032, 978, 16, 119, "Input"],
Cell[536540, 11050, 540, 14, 29, "Input"],
Cell[CellGroupData[{
Cell[537105, 11068, 216, 5, 29, "Input"],
Cell[537324, 11075, 1848, 41, 245, "Output"]
}, Open  ]],
Cell[539187, 11119, 918, 23, 29, "Input"],
Cell[540108, 11144, 1023, 25, 29, "Input"],
Cell[CellGroupData[{
Cell[541156, 11173, 155, 3, 29, "Input"],
Cell[541314, 11178, 1997, 41, 240, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[543348, 11224, 431, 11, 29, "Input"],
Cell[543782, 11237, 702, 11, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[544521, 11253, 597, 14, 29, "Input"],
Cell[545121, 11269, 7307, 130, 235, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[552465, 11404, 657, 17, 29, "Input"],
Cell[553125, 11423, 376, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[553538, 11433, 353, 8, 29, "Input"],
Cell[553894, 11443, 367, 5, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[554310, 11454, 432, 9, 29, "Input"],
Cell[554745, 11465, 372, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[555154, 11476, 160, 3, 26, "Text"],
Cell[CellGroupData[{
Cell[555339, 11483, 649, 12, 29, "Input"],
Cell[555991, 11497, 594, 9, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[556634, 11512, 2112, 42, 108, "Input"],
Cell[558749, 11556, 13459, 235, 407, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[572257, 11797, 322, 5, 68, "Section"],
Cell[572582, 11804, 2047, 48, 560, "Input"],
Cell[574632, 11854, 412, 8, 28, "Input"],
Cell[CellGroupData[{
Cell[575069, 11866, 1057, 25, 91, "Input"],
Cell[576129, 11893, 251, 7, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[576417, 11905, 6768, 119, 172, "Input"],
Cell[583188, 12026, 6244, 113, 235, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[589469, 12144, 407, 9, 29, "Input"],
Cell[589879, 12155, 462, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[590378, 12166, 402, 9, 29, "Input"],
Cell[590783, 12177, 458, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[591278, 12188, 1143, 20, 29, "Input"],
Cell[592424, 12210, 10958, 216, 65, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[603419, 12431, 1688, 32, 28, "Input"],
Cell[605110, 12465, 491, 7, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[605638, 12477, 1143, 26, 29, "Input"],
Cell[606784, 12505, 526, 7, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[607347, 12517, 1139, 25, 28, "Input"],
Cell[608489, 12544, 520, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[609046, 12557, 1510, 24, 76, "Input"],
Cell[610559, 12583, 7166, 127, 233, "Output"]
}, Open  ]]
}, Open  ]],
Cell[617752, 12714, 349, 8, 28, "Input"],
Cell[CellGroupData[{
Cell[618126, 12726, 1571, 37, 154, "Input"],
Cell[619700, 12765, 1793, 39, 120, "Output"]
}, Open  ]],
Cell[621508, 12807, 120, 1, 68, "Section"],
Cell[CellGroupData[{
Cell[621653, 12812, 268, 5, 27, "Subsection"],
Cell[CellGroupData[{
Cell[621946, 12821, 733, 18, 29, "Input"],
Cell[622682, 12841, 6367, 116, 226, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[629086, 12962, 1397, 32, 91, "Input"],
Cell[630486, 12996, 320, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[630843, 13009, 454, 10, 29, "Input"],
Cell[631300, 13021, 418, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[631755, 13032, 452, 10, 29, "Input"],
Cell[632210, 13044, 394, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[632641, 13054, 1189, 21, 29, "Input"],
Cell[633833, 13077, 10982, 216, 65, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[644852, 13298, 1945, 38, 28, "Input"],
Cell[646800, 13338, 540, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[647377, 13351, 717, 17, 28, "Input"],
Cell[648097, 13370, 840, 19, 114, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[648986, 13395, 282, 6, 35, "Subsection"],
Cell[CellGroupData[{
Cell[649293, 13405, 6875, 123, 157, "Input"],
Cell[656171, 13530, 6379, 116, 230, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[662587, 13651, 1528, 34, 91, "Input"],
Cell[664118, 13687, 302, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[664457, 13700, 506, 10, 29, "Input"],
Cell[664966, 13712, 419, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[665422, 13723, 502, 10, 29, "Input"],
Cell[665927, 13735, 391, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[666355, 13745, 1291, 22, 29, "Input"],
Cell[667649, 13769, 10988, 216, 65, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[678674, 13990, 1929, 38, 28, "Input"],
Cell[680606, 14030, 517, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[681160, 14043, 677, 16, 28, "Input"],
Cell[681840, 14061, 767, 18, 56, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[682656, 14085, 360, 7, 35, "Subsection"],
Cell[CellGroupData[{
Cell[683041, 14096, 6838, 122, 156, "Input"],
Cell[689882, 14220, 6390, 116, 223, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[696309, 14341, 1576, 34, 91, "Input"],
Cell[697888, 14377, 351, 9, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[698276, 14391, 558, 11, 29, "Input"],
Cell[698837, 14404, 464, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[699338, 14415, 554, 11, 29, "Input"],
Cell[699895, 14428, 441, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[700373, 14439, 1239, 21, 29, "Input"],
Cell[701615, 14462, 10960, 216, 65, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[712612, 14683, 1954, 38, 28, "Input"],
Cell[714569, 14723, 538, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[715144, 14736, 630, 16, 28, "Input"],
Cell[715777, 14754, 778, 19, 114, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
